@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2009 Cyrille Berger <cberger@cberger.net>
+ *  SPDX-FileCopyrightText: 2009 Cyrille Berger <cberger@cberger.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -27,9 +27,10 @@ class StateShape;
 class StateShapeChangeStateCommand : public KUndo2Command
 {
 public:
-    StateShapeChangeStateCommand(StateShape* _shape, const QString& _newCategoryId, const QString& _newStateId);
-    virtual void undo();
-    virtual void redo();
+    StateShapeChangeStateCommand(StateShape *_shape, const QString &_newCategoryId, const QString &_newStateId);
+    void undo() override;
+    void redo() override;
+
 private:
     StateShape *m_shape;
     QString m_newCategoryId, m_newStateId;
