@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2009 Cyrille Berger <cberger@cberger.net>
+ *  SPDX-FileCopyrightText: 2009 Cyrille Berger <cberger@cberger.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -21,8 +21,8 @@
 
 #include <QItemDelegate>
 
-#include <kundo2command.h>
 #include <kcategorizedsortfilterproxymodel.h>
+#include <kundo2command.h>
 
 #include <KoCanvasBase.h>
 #include <KoCanvasController.h>
@@ -30,19 +30,20 @@
 
 #include <State.h>
 #include <StateCategory.h>
-#include <StatesRegistry.h>
 #include <StateShape.h>
+#include <StatesRegistry.h>
 
+#include "CategorizedItemDelegate.h"
+#include "StateShapeChangeStateCommand.h"
 #include "StateTool.h"
 #include "StatesModel.h"
-#include "StateShapeChangeStateCommand.h"
-#include "CategorizedItemDelegate.h"
 
-StateToolWidget::StateToolWidget(StateTool* _stateTool) : m_tool(_stateTool)
+StateToolWidget::StateToolWidget(StateTool *_stateTool)
+    : m_tool(_stateTool)
 {
     m_widget.setupUi(this);
     connect(m_widget.stateComboBox, SIGNAL(activated(int)), SLOT(save()));
-    connect(m_tool, SIGNAL(shapeChanged(StateShape*)), SLOT(open(StateShape*)));
+    connect(m_tool, SIGNAL(shapeChanged(StateShape *)), SLOT(open(StateShape *)));
     m_model = new StatesModel();
     m_proxyModel = new KCategorizedSortFilterProxyModel();
     m_proxyModel->setSourceModel(m_model);
@@ -60,36 +61,33 @@ void StateToolWidget::blockChildSignals(bool block)
 
 void StateToolWidget::open(StateShape *shape)
 {
-    m_shape = dynamic_cast<StateShape*>(shape);
-    if(! m_shape)
+    m_shape = dynamic_cast<StateShape *>(shape);
+    if (!m_shape)
         return;
     blockChildSignals(true);
-    m_widget.stateComboBox->setCurrentIndex(
-        m_proxyModel->mapFromSource(
-            m_model->indexFor(m_shape->categoryId(), m_shape->stateId())).row());
+    m_widget.stateComboBox->setCurrentIndex(m_proxyModel->mapFromSource(m_model->indexFor(m_shape->categoryId(), m_shape->stateId())).row());
     blockChildSignals(false);
 }
 
 void StateToolWidget::save()
 {
-    if(!m_shape)
+    if (!m_shape)
         return;
 
-//   QString newUrl = m_widget.urlEdit->text();
-    KoCanvasController* canvasController = KoToolManager::instance()->activeCanvasController();
-    if(canvasController) {
-        KoCanvasBase* canvas = canvasController->canvas();
-        const State* state = m_model->stateAt(
-                                 m_proxyModel->mapToSource(m_proxyModel->index(m_widget.stateComboBox->currentIndex(), 0, QModelIndex())).row());
-        if(state->category()->id() != m_shape->categoryId() || state->id() != m_shape->stateId()) {
+    //   QString newUrl = m_widget.urlEdit->text();
+    KoCanvasController *canvasController = KoToolManager::instance()->activeCanvasController();
+    if (canvasController) {
+        KoCanvasBase *canvas = canvasController->canvas();
+        const State *state = m_model->stateAt(m_proxyModel->mapToSource(m_proxyModel->index(m_widget.stateComboBox->currentIndex(), 0, QModelIndex())).row());
+        if (state->category()->id() != m_shape->categoryId() || state->id() != m_shape->stateId()) {
             canvas->addCommand(new StateShapeChangeStateCommand(m_shape, state->category()->id(), state->id()));
         }
     }
 }
 
-KUndo2Command * StateToolWidget::createCommand()
+KUndo2Command *StateToolWidget::createCommand()
 {
     save();
 
-    return 0;
+    return nullptr;
 }
