@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2009 Cyrille Berger <cberger@cberger.net>
+ *  SPDX-FileCopyrightText: 2009 Cyrille Berger <cberger@cberger.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -28,12 +28,13 @@ class FreeLayout : public Layout
 public:
     FreeLayout();
     virtual ~FreeLayout();
+
 protected:
-    virtual QRectF boundingBox() const;
-    virtual void shapeAdded(KoShape* _shape);
-    virtual void shapeRemoved(KoShape* _shape);
-    virtual void shapeGeometryChanged(KoShape* _shape);
-    virtual void relayout();
+    QRectF boundingBox() const override;
+    void shapeAdded(KoShape *_shape) override;
+    void shapeRemoved(KoShape *_shape) override;
+    void shapeGeometryChanged(KoShape *_shape) override;
+    void relayout() override;
 };
 
 class FreeLayoutFactory : public LayoutFactory
@@ -41,7 +42,7 @@ class FreeLayoutFactory : public LayoutFactory
 public:
     FreeLayoutFactory();
     virtual ~FreeLayoutFactory();
-    virtual Layout* createLayout() const;
+    Layout *createLayout() const override;
 };
 
 #endif
