@@ -1,22 +1,9 @@
 /*
  * This file is part of the KDE project
  *
- * Copyright (C) 2013 Arjen Hiemstra <ahiemstra@heimr.nl>
+ * SPDX-FileCopyrightText: 2013 Arjen Hiemstra <ahiemstra@heimr.nl>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  *
  */
 
@@ -25,15 +12,17 @@
 
 #include <QQuickPaintedItem>
 
-namespace Calligra {
-namespace Components {
+namespace Calligra
+{
+namespace Components
+{
 
 class Document;
 
 /**
  * \brief The view provides a View object for viewing Documents.
  *
- * The View object provides a view on a document. 
+ * The View object provides a view on a document.
  */
 
 class View : public QQuickPaintedItem
@@ -48,7 +37,7 @@ class View : public QQuickPaintedItem
      * \set setDocument()
      * \notify documentChanged()
      */
-    Q_PROPERTY(Calligra::Components::Document* document READ document WRITE setDocument NOTIFY documentChanged)
+    Q_PROPERTY(Calligra::Components::Document *document READ document WRITE setDocument NOTIFY documentChanged)
     /**
      * \property zoom
      * \brief The zoom level the view renders the document at.
@@ -68,7 +57,7 @@ public:
      *
      * \param parent The parent item.
      */
-    explicit View(QQuickItem* parent = 0);
+    explicit View(QQuickItem *parent = nullptr);
     /**
      * Destructor.
      */
@@ -77,16 +66,16 @@ public:
     /**
      * Inherited from QQuickPaintedItem.
      */
-    void paint(QPainter* painter) override;
+    void paint(QPainter *painter) override;
 
     /**
      * Getter for property #document.
      */
-    Document* document() const;
+    Document *document() const;
     /**
      * Setter for property #document.
      */
-    void setDocument(Document* newValue);
+    void setDocument(Document *newValue);
 
     /**
      * Getter for property #zoom.
@@ -104,7 +93,7 @@ Q_SIGNALS:
      * \param url The URL of the link that was clicked. For internal links, the protocol
      * `document://` will be used.
      */
-    void linkClicked(const QUrl& url);
+    void linkClicked(const QUrl &url);
 
     /**
      * Notify signal for property #document.
@@ -119,16 +108,16 @@ protected:
     /**
      * Inherited from QQuickPaintedItem.
      */
-    void geometryChanged(const QRectF& newGeometry, const QRectF& oldGeometry) override;
+    void geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry) override;
 
 private:
     class Private;
-    Private* const d;
+    Private *const d;
 };
 
 } // Namespace Components
 } // Namespace Calligra
 
-Q_DECLARE_METATYPE(Calligra::Components::View*)
+Q_DECLARE_METATYPE(Calligra::Components::View *)
 
 #endif // CALLIGRA_COMPONENTS_VIEW_H
