@@ -1,37 +1,25 @@
 /* This file is part of the KDE project
-   Copyright (C) 2002, The Karbon Developers
+   SPDX-FileCopyrightText: 2002 The Karbon Developers
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef __XAMLIMPORT_H__
 #define __XAMLIMPORT_H__
 
+#include "xamlgraphiccontext.h"
 #include <KoFilter.h>
+#include <QByteArray>
 #include <QDomDocument>
 #include <QMap>
 #include <QStack>
-#include <QByteArray>
-#include <core/KarbonDocument.h>
-#include <core/vgradient.h>
-#include <core/vfill.h>
-#include <core/vstroke.h>
-#include <core/vfillrule.h>
+#include <QTransform>
 #include <QVariantList>
-#include "xamlgraphiccontext.h"
+#include <core/KarbonDocument.h>
+#include <core/vfill.h>
+#include <core/vfillrule.h>
+#include <core/vgradient.h>
+#include <core/vstroke.h>
 
 class VGroup;
 
@@ -40,21 +28,22 @@ class XAMLImport : public KoFilter
     Q_OBJECT
 
 public:
-    XAMLImport(QObject* parent, const QVariantList&);
+    XAMLImport(QObject *parent, const QVariantList &);
     virtual ~XAMLImport();
 
-    virtual KoFilter::ConversionStatus convert(const QByteArray& from, const QByteArray& to);
+    virtual KoFilter::ConversionStatus convert(const QByteArray &from, const QByteArray &to);
 
 protected:
     class GradientHelper
     {
     public:
-        GradientHelper() {
+        GradientHelper()
+        {
             bbox = true;
         }
         VGradient gradient;
-        bool  bbox;
-        QMatrix gradientTransform;
+        bool bbox;
+        QTransform gradientTransform;
     };
 
     void parseGroup(VGroup *, const QDomElement &);
@@ -72,20 +61,20 @@ protected:
     QDomDocument inpdoc;
     QDomDocument outdoc;
     void convert();
-    VObject* createObject(const QDomElement &);
+    VObject *createObject(const QDomElement &);
     void createText(VGroup *, const QDomElement &);
     void parseFont(const QDomElement &);
     // find object with given id in document
-    VObject* findObject(const QString &name);
+    VObject *findObject(const QString &name);
     // find object with given id in given group
-    VObject* findObject(const QString &name, VGroup *);
+    VObject *findObject(const QString &name, VGroup *);
 
 private:
-    KarbonDocument      m_document;
-    QStack<XAMLGraphicsContext*> m_gc;
+    KarbonDocument m_document;
+    QStack<XAMLGraphicsContext *> m_gc;
     QMap<QString, GradientHelper> m_gradients;
-    QMap<QString, QDomElement>  m_paths;
-    KoRect       m_outerRect;
+    QMap<QString, QDomElement> m_paths;
+    KoRect m_outerRect;
 };
 
 #endif
