@@ -1,23 +1,11 @@
 /*
  * This file is part of Office 2007 Filters for Calligra
  *
- * Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+ * SPDX-FileCopyrightText: 2009 Nokia Corporation and /or its subsidiary(-ies).
  *
  * Contact: Suresh Chande suresh.chande@nokia.com
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * version 2.1 as published by the Free Software Foundation.
- *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA
+ * SPDX-License-Identifier: LGPL-2.1-only
  *
  */
 
@@ -25,7 +13,7 @@
 #include <MsooXmlSchemas.h>
 #include <MsooXmlUtils.h>
 
-//#define MSOOXML_CURRENT_NS
+// #define MSOOXML_CURRENT_NS
 #define MSOOXML_CURRENT_CLASS MsooXmlRelationshipsReader
 #define BIND_READ_CLASS MSOOXML_CURRENT_CLASS
 
@@ -33,28 +21,29 @@
 
 using namespace MSOOXML;
 
-MsooXmlRelationshipsReaderContext::MsooXmlRelationshipsReaderContext(
-    const QString& _path, const QString& _file, QMap<QString, QString>& _rels,
-    QMap<QString, QString>& _targetsForTypes)
-        : path(_path), file(_file)
-        , rels(&_rels), targetsForTypes(&_targetsForTypes)
+MsooXmlRelationshipsReaderContext::MsooXmlRelationshipsReaderContext(const QString &_path,
+                                                                     const QString &_file,
+                                                                     QMap<QString, QString> &_rels,
+                                                                     QMap<QString, QString> &_targetsForTypes)
+    : path(_path)
+    , file(_file)
+    , rels(&_rels)
+    , targetsForTypes(&_targetsForTypes)
 {
 }
 
 class MsooXmlRelationshipsReader::Private
 {
 public:
-    Private() {
-    }
-    ~Private() {
-    }
+    Private() = default;
+    ~Private() = default;
     QString pathAndFile;
 };
 
 MsooXmlRelationshipsReader::MsooXmlRelationshipsReader(KoOdfWriters *writers)
-        : MSOOXML::MsooXmlReader(writers)
-        , m_context(0)
-        , d(new Private)
+    : MSOOXML::MsooXmlReader(writers)
+    , m_context(nullptr)
+    , d(new Private)
 {
     init();
 }
@@ -68,11 +57,11 @@ void MsooXmlRelationshipsReader::init()
 {
 }
 
-KoFilter::ConversionStatus MsooXmlRelationshipsReader::read(MSOOXML::MsooXmlReaderContext* context)
+KoFilter::ConversionStatus MsooXmlRelationshipsReader::read(MSOOXML::MsooXmlReaderContext *context)
 {
-    m_context = dynamic_cast<MsooXmlRelationshipsReaderContext*>(context);
+    m_context = dynamic_cast<MsooXmlRelationshipsReaderContext *>(context);
     const KoFilter::ConversionStatus result = readInternal();
-    m_context = 0;
+    m_context = nullptr;
     if (result == KoFilter::OK)
         return KoFilter::OK;
     return result;
@@ -157,17 +146,18 @@ KoFilter::ConversionStatus MsooXmlRelationshipsReader::read_Relationship()
     READ_ATTR_WITHOUT_NS(Target)
     QString fixedPath(m_context->path);
     while (Target.startsWith(QLatin1String("../"))) {
-        //debugMsooXml << "- Target:" << Target << "fixedPath:" << fixedPath;
+        // debugMsooXml << "- Target:" << Target << "fixedPath:" << fixedPath;
         Target.remove(0, 3);
         fixedPath.truncate(fixedPath.lastIndexOf('/'));
-        //debugMsooXml << "= Target:" << Target << "fixedPath:" << fixedPath;
+        // debugMsooXml << "= Target:" << Target << "fixedPath:" << fixedPath;
     }
-    //debugMsooXml << "adding rel:";
-    //debugMsooXml << d->pathAndFile + Id;
-    //debugMsooXml << fixedPath + '/' + Target;
+    // debugMsooXml << "adding rel:";
+    // debugMsooXml << d->pathAndFile + Id;
+    // debugMsooXml << fixedPath + '/' + Target;
 
     m_context->rels->insert(d->pathAndFile + Id, fixedPath + '/' + Target);
-    //debugMsooXml << "added target" << Target << "for type" << Type << "path=" << fixedPath << "key=" << targetKey(m_context->path + '/' + m_context->file, Type);
+    // debugMsooXml << "added target" << Target << "for type" << Type << "path=" << fixedPath << "key=" << targetKey(m_context->path + '/' + m_context->file,
+    // Type);
     m_context->targetsForTypes->insert(targetKey(m_context->path + '/' + m_context->file, Type), fixedPath + '/' + Target);
 
     readNext();
