@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
 
-   Copyright (C) 2012-2014 Inge Wallin            <inge@lysator.liu.se>
+   SPDX-FileCopyrightText: 2012-2014 Inge Wallin <inge@lysator.liu.se>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef ODSREADER_H
@@ -29,10 +16,9 @@
 #include <KoXmlStreamReader.h>
 
 // this library
-#include "koodfreader_export.h"
 #include "OdfReader.h"
 #include "OdfReaderInternals.h"
-
+#include "koodfreader_export.h"
 
 class QSizeF;
 
@@ -44,7 +30,6 @@ class OdfReaderContext;
 
 class OdfTextReader;
 
-
 /** @brief Read the XML tree of the content of an ODS file.
  *
  * The OdsReader is used to traverse (read) the contents of an ODS
@@ -68,18 +53,18 @@ class OdfTextReader;
  */
 class KOODFREADER_EXPORT OdsReader : public OdfReader
 {
- public:
+public:
     OdsReader();
     ~OdsReader() override;
 
- protected:
+protected:
     // All readElement*() are named after the full qualifiedName of
     // the element in ODF that they handle.
 
     // ODS document level functions
     DECLARE_READER_FUNCTION(OfficeSpreadsheet) override;
 
- private:
+private:
     // Not much here. Most are already in OdfReader.
 };
 
