@@ -1,53 +1,38 @@
 /* This file is part of the KDE project
-   Copyright (C) 2010 KO GmbH <jos.van.den.oever@kogmbh.com>
+   SPDX-FileCopyrightText: 2010 KO GmbH <jos.van.den.oever@kogmbh.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #ifndef GLOBALOBJECTCOLLECTORS_H
 #define GLOBALOBJECTCOLLECTORS_H
 
-#include "PptToOdp.h"
 #include "ODrawToOdf.h"
+#include "PptToOdp.h"
 
 #include <KoGenStyles.h>
 
 /**
  * Report global objects belonging to global options to the collector.
  */
-template <typename C, typename T>
-void collectGlobalObjects(C& collector, const MSO::DrawingGroupContainer& c,
-                          const T& fopt)
+template<typename C, typename T>
+void collectGlobalObjects(C &collector, const MSO::DrawingGroupContainer &c, const T &fopt)
 {
-    foreach(const MSO::OfficeArtFOPTEChoice& f, fopt.fopt) {
+    foreach (const MSO::OfficeArtFOPTEChoice &f, fopt.fopt) {
         collector.add(c, f);
     }
 }
 /**
  * Report global objects belonging to incidental options to the collector.
  */
-template <typename C, typename T>
-void collectGlobalObjects(C& collector, const MSO::OfficeArtSpContainer& sp,
-                          const T& fopt)
+template<typename C, typename T>
+void collectGlobalObjects(C &collector, const MSO::OfficeArtSpContainer &sp, const T &fopt)
 {
-    foreach(const MSO::OfficeArtFOPTEChoice& f, fopt.fopt) {
+    foreach (const MSO::OfficeArtFOPTEChoice &f, fopt.fopt) {
         collector.add(sp, f);
     }
 }
-template <typename C>
-void collectGlobalObjects(C& collector, const MSO::OfficeArtSpContainer& sp)
+template<typename C>
+void collectGlobalObjects(C &collector, const MSO::OfficeArtSpContainer &sp)
 {
     if (sp.shapePrimaryOptions)
         collectGlobalObjects(collector, sp, *sp.shapePrimaryOptions);
@@ -60,19 +45,17 @@ void collectGlobalObjects(C& collector, const MSO::OfficeArtSpContainer& sp)
     if (sp.shapeTertiaryOptions2)
         collectGlobalObjects(collector, sp, *sp.shapeTertiaryOptions2);
 }
-template <typename C>
-void collectGlobalObjects(C& collector,
-                          const MSO::OfficeArtSpgrContainerFileBlock& spgr);
-template <typename C>
-void collectGlobalObjects(C& collector,
-                          const MSO::OfficeArtSpgrContainer& spgr)
+template<typename C>
+void collectGlobalObjects(C &collector, const MSO::OfficeArtSpgrContainerFileBlock &spgr);
+template<typename C>
+void collectGlobalObjects(C &collector, const MSO::OfficeArtSpgrContainer &spgr)
 {
-    foreach(const MSO::OfficeArtSpgrContainerFileBlock& o, spgr.rgfb) {
+    foreach (const MSO::OfficeArtSpgrContainerFileBlock &o, spgr.rgfb) {
         collectGlobalObjects(collector, o);
     }
 }
-template <typename C>
-void collectGlobalObjects(C& collector, const MSO::OfficeArtDgContainer& dg)
+template<typename C>
+void collectGlobalObjects(C &collector, const MSO::OfficeArtDgContainer &dg)
 {
     if (dg.groupShape) {
         collectGlobalObjects(collector, *dg.groupShape);
@@ -80,36 +63,33 @@ void collectGlobalObjects(C& collector, const MSO::OfficeArtDgContainer& dg)
     if (dg.shape) {
         collectGlobalObjects(collector, *dg.shape);
     }
-    foreach(const MSO::OfficeArtSpgrContainerFileBlock& o, dg.deletedShapes) {
+    foreach (const MSO::OfficeArtSpgrContainerFileBlock &o, dg.deletedShapes) {
         collectGlobalObjects(collector, o);
     }
 }
-template <class C>
-void collectGlobalObjects(C& collector,
-                          const MSO::OfficeArtSpgrContainerFileBlock& spgr)
+template<class C>
+void collectGlobalObjects(C &collector, const MSO::OfficeArtSpgrContainerFileBlock &spgr)
 {
     if (spgr.anon.is<MSO::OfficeArtSpContainer>())
         collectGlobalObjects(collector, *spgr.anon.get<MSO::OfficeArtSpContainer>());
     if (spgr.anon.is<MSO::OfficeArtSpgrContainer>())
         collectGlobalObjects(collector, *spgr.anon.get<MSO::OfficeArtSpgrContainer>());
 }
-template <class C>
-void collectGlobalObjects(C& collector, const ParsedPresentation& p) {
+template<class C>
+void collectGlobalObjects(C &collector, const ParsedPresentation &p)
+{
     // loop over all objects to find all OfficeArtFOPTE instances and feed them
     // into the collector
     // get object from default options
-    const MSO::DrawingGroupContainer& dg = p.documentContainer->drawingGroup;
+    const MSO::DrawingGroupContainer &dg = p.documentContainer->drawingGroup;
     if (dg.OfficeArtDgg.drawingPrimaryOptions)
-        collectGlobalObjects(collector, dg,
-                             *dg.OfficeArtDgg.drawingPrimaryOptions);
+        collectGlobalObjects(collector, dg, *dg.OfficeArtDgg.drawingPrimaryOptions);
     if (dg.OfficeArtDgg.drawingTertiaryOptions)
-        collectGlobalObjects(collector, dg,
-                             *dg.OfficeArtDgg.drawingTertiaryOptions);
+        collectGlobalObjects(collector, dg, *dg.OfficeArtDgg.drawingTertiaryOptions);
     // get objects from masters
-    foreach(const MSO::MasterOrSlideContainer* master, p.masters) {
-        const MSO::SlideContainer* sc = master->anon.get<MSO::SlideContainer>();
-        const MSO::MainMasterContainer* sm
-                = master->anon.get<MSO::MainMasterContainer>();
+    foreach (const MSO::MasterOrSlideContainer *master, p.masters) {
+        const MSO::SlideContainer *sc = master->anon.get<MSO::SlideContainer>();
+        const MSO::MainMasterContainer *sm = master->anon.get<MSO::MainMasterContainer>();
         if (sc) {
             collectGlobalObjects(collector, sc->drawing.OfficeArtDg);
         }
@@ -118,45 +98,54 @@ void collectGlobalObjects(C& collector, const ParsedPresentation& p) {
         }
     }
     // get objects from slides
-    foreach(const MSO::SlideContainer* slide, p.slides) {
+    foreach (const MSO::SlideContainer *slide, p.slides) {
         collectGlobalObjects(collector, slide->drawing.OfficeArtDg);
     }
     // get objects from notes
-    foreach(const MSO::NotesContainer* notes, p.notes) {
+    foreach (const MSO::NotesContainer *notes, p.notes) {
         if (notes) {
             collectGlobalObjects(collector, notes->drawing.OfficeArtDg);
         }
     }
 }
 /**
-  * Collector that retrieves all fill images.
-  **/
-class FillImageCollector {
+ * Collector that retrieves all fill images.
+ **/
+class FillImageCollector
+{
 public:
-    KoGenStyles& styles;
-    const PptToOdp& pto;
-    QMap<const MSO::DrawingGroupContainer*, QString> globalFillImageNames;
-    QMap<const MSO::OfficeArtSpContainer*, QString> fillImageNames;
+    KoGenStyles &styles;
+    const PptToOdp &pto;
+    QMap<const MSO::DrawingGroupContainer *, QString> globalFillImageNames;
+    QMap<const MSO::OfficeArtSpContainer *, QString> fillImageNames;
 
-    FillImageCollector(KoGenStyles& s, const PptToOdp& p) :styles(s), pto(p) {}
+    FillImageCollector(KoGenStyles &s, const PptToOdp &p)
+        : styles(s)
+        , pto(p)
+    {
+    }
 
-    void add(const MSO::DrawingGroupContainer& o, const MSO::OfficeArtFOPTEChoice& t) {
+    void add(const MSO::DrawingGroupContainer &o, const MSO::OfficeArtFOPTEChoice &t)
+    {
         const QString name = add(t);
-        if (!name.isEmpty()) globalFillImageNames[&o] = name;
+        if (!name.isEmpty())
+            globalFillImageNames[&o] = name;
     }
-    void add(const MSO::OfficeArtSpContainer& o, const MSO::OfficeArtFOPTEChoice& t) {
+    void add(const MSO::OfficeArtSpContainer &o, const MSO::OfficeArtFOPTEChoice &t)
+    {
         const QString name = add(t);
-        if (!name.isEmpty()) fillImageNames[&o] = name;
+        if (!name.isEmpty())
+            fillImageNames[&o] = name;
     }
-    QString add(const MSO::OfficeArtFOPTEChoice& t) {
-        const MSO::FillBlip* fb = t.anon.get<MSO::FillBlip>();
-        if (!fb || fb->opid.fComplex || fb->fillBlip == 0) return QString();
+    QString add(const MSO::OfficeArtFOPTEChoice &t)
+    {
+        const MSO::FillBlip *fb = t.anon.get<MSO::FillBlip>();
+        if (!fb || fb->opid.fComplex || fb->fillBlip == 0)
+            return QString();
         KoGenStyle fillImage(KoGenStyle::FillImageStyle);
         fillImage.addAttribute("xlink:href", pto.getPicturePath(fb->fillBlip));
         fillImage.addAttribute("xlink:type", "simple");
-        return styles.insert(fillImage,
-                             QString("fillImage%1").arg(fb->fillBlip),
-                             KoGenStyles::DontAddNumberToName);
+        return styles.insert(fillImage, QString("fillImage%1").arg(fb->fillBlip), KoGenStyles::DontAddNumberToName);
     }
 };
 
@@ -202,5 +191,4 @@ public:
 /*     } */
 /* }; */
 
-
 #endif
