@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
-   Copyright (C) 2010 KO GmbH <jos.van.den.oever@kogmbh.com>
-   Copyright (C) 2010, 2011 Matus Uzak <matus.uzak@ixonos.com>
+   SPDX-FileCopyrightText: 2010 KO GmbH <jos.van.den.oever@kogmbh.com>
+   SPDX-FileCopyrightText: 2010, 2011 Matus Uzak <matus.uzak@ixonos.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef PPTSTYLE_H
@@ -37,14 +24,14 @@ enum TextTypeEnum {
     Tx_TYPE_QUARTERBODY
 };
 
-class PptTextPFRun {
+class PptTextPFRun
+{
 public:
-
     /**
      * Only the default TextPFException is required.
      * @param d DocumentContainer address
      */
-    explicit PptTextPFRun(const MSO::DocumentContainer* d);
+    explicit PptTextPFRun(const MSO::DocumentContainer *d);
 
     /**
      * Special purpose constructor for default list styles of masters.
@@ -54,9 +41,9 @@ public:
      * @param textType specifies the type of the text body
      * @param indentLevel specifies the indentation level of the paragraph
      */
-    PptTextPFRun(const MSO::DocumentContainer* d,
-                 const MSO::TextMasterStyleLevel* level,
-                 const MSO::TextMasterStyle9Level* level9,
+    PptTextPFRun(const MSO::DocumentContainer *d,
+                 const MSO::TextMasterStyleLevel *level,
+                 const MSO::TextMasterStyle9Level *level9,
                  const quint32 textType,
                  const quint16 indentLevel);
 
@@ -70,15 +57,18 @@ public:
      * @param tr specifies tabbing, margins, and indentation for text
      * @param start specifies beginning of the paragraph in the slide text
      */
-    PptTextPFRun(const MSO::DocumentContainer* d,
-                 const MSO::MasterOrSlideContainer* m,
-                 const MSO::SlideListWithTextSubContainerOrAtom* texts = 0,
-                 const MSO::PptOfficeArtClientData* pcd = 0,
-                 const MSO::TextContainer* tc = 0,
-                 const MSO::TextRuler* tr = 0,
+    PptTextPFRun(const MSO::DocumentContainer *d,
+                 const MSO::MasterOrSlideContainer *m,
+                 const MSO::SlideListWithTextSubContainerOrAtom *texts = nullptr,
+                 const MSO::PptOfficeArtClientData *pcd = nullptr,
+                 const MSO::TextContainer *tc = nullptr,
+                 const MSO::TextRuler *tr = nullptr,
                  quint32 start = 0);
 
-    quint16 level() const { return m_level; }
+    quint16 level() const
+    {
+        return m_level;
+    }
     bool isList() const;
 
     // TextPFException
@@ -130,34 +120,34 @@ private:
      *
      * @param d DocumentContainer address
      */
-    void processPFDefaults(const MSO::DocumentContainer* d);
+    void processPFDefaults(const MSO::DocumentContainer *d);
 
-    //The indentation level of the paragraph.  MUST be <= 0x0005, [MS-PPT]
+    // The indentation level of the paragraph.  MUST be <= 0x0005, [MS-PPT]
     quint16 m_level;
 
-    //Specifies the text type, check the TextTypeEnum enumeration.
+    // Specifies the text type, check the TextTypeEnum enumeration.
     quint32 m_textType;
 
-    //Default values of bullet properties (text type specific).
+    // Default values of bullet properties (text type specific).
     bool m_fHasBullet;
 
-    //The ident/margin for text at m_level (provided by TextRuler)
+    // The ident/margin for text at m_level (provided by TextRuler)
     QList<qint16> m_indent;
     QList<qint16> m_leftMargin;
 
-    //Hierarchies of exceptions.
-    QList<const MSO::TextPFException*> pfs;
-    QList<const MSO::TextPFException9*> pf9s;
+    // Hierarchies of exceptions.
+    QList<const MSO::TextPFException *> pfs;
+    QList<const MSO::TextPFException9 *> pf9s;
 };
 
-class PptTextCFRun {
+class PptTextCFRun
+{
 public:
-
     /**
      * Only the default TextCFException is required.
      * @param d DocumentContainer address
      */
-    explicit PptTextCFRun(const MSO::DocumentContainer* d);
+    explicit PptTextCFRun(const MSO::DocumentContainer *d);
 
     /**
      * Special purpose constructor for default list styles of masters.
@@ -166,10 +156,7 @@ public:
      * @param level9 additional character-level and paragraph-level formatting
      * @param indentLevel specifies the indentation level of the paragraph
      */
-    PptTextCFRun(const MSO::DocumentContainer* d,
-                 const MSO::TextMasterStyleLevel* level,
-                 const MSO::TextMasterStyle9Level* level9,
-                 const quint16 indentLevel);
+    PptTextCFRun(const MSO::DocumentContainer *d, const MSO::TextMasterStyleLevel *level, const MSO::TextMasterStyle9Level *level9, const quint16 indentLevel);
 
     /**
      * Construct TextCFException hierarchy.
@@ -178,10 +165,7 @@ public:
      * @param tc TextContainer
      * @param indentLevel specifies the indentation level of the paragraph
      */
-    PptTextCFRun(const MSO::DocumentContainer* d,
-                 const MSO::MasterOrSlideContainer* m,
-                 const MSO::TextContainer* tc,
-                 quint16 indentLevel);
+    PptTextCFRun(const MSO::DocumentContainer *d, const MSO::MasterOrSlideContainer *m, const MSO::TextContainer *tc, quint16 indentLevel);
 
     /**
      * Add the TextCFException structure present in the current TextContainer,
@@ -195,7 +179,7 @@ public:
      * @return the number of characters of the corresponding text to which this
      * character formatting applies
      */
-    int addCurrentCFRun(const MSO::TextContainer* tc, quint32 start, quint32& num);
+    int addCurrentCFRun(const MSO::TextContainer *tc, quint32 start, quint32 &num);
 
     void removeCurrentCFRun();
 
@@ -221,16 +205,16 @@ private:
      * and TextMasterStyleAtom.
      * @param d DocumentContainer address
      */
-    void processCFDefaults(const MSO::DocumentContainer* d);
+    void processCFDefaults(const MSO::DocumentContainer *d);
 
-    //The indentation level of the paragraph.  MUST be <= 0x0005, [MS-PPT]
+    // The indentation level of the paragraph.  MUST be <= 0x0005, [MS-PPT]
     quint16 m_level;
 
-    //Each run of text has a separate character-level formatting provided by
-    //TextCFRun which is added/replaced on top of the cfs list.
+    // Each run of text has a separate character-level formatting provided by
+    // TextCFRun which is added/replaced on top of the cfs list.
     bool m_cfrun_rm;
 
-    QList<const MSO::TextCFException*> cfs;
+    QList<const MSO::TextCFException *> cfs;
 };
 
 /**
@@ -241,49 +225,39 @@ private:
  * @param textType specifies the type of the text body
  * @return TextMasterStyleAtom address
  */
-const MSO::TextMasterStyleAtom*
-getTextMasterStyleAtom(const MSO::MasterOrSlideContainer* m, quint16 textType);
-
+const MSO::TextMasterStyleAtom *getTextMasterStyleAtom(const MSO::MasterOrSlideContainer *m, quint16 textType);
 
 template<class T>
-const T*
-getPP(const MSO::DocumentContainer* dc)
+const T *getPP(const MSO::DocumentContainer *dc)
 {
-    if (dc == 0 || dc->docInfoList == 0) return 0;
-    foreach (const MSO::DocInfoListSubContainerOrAtom& a,
-                 dc->docInfoList->rgChildRec) {
-        const MSO::DocProgTagsContainer* d
-                = a.anon.get<MSO::DocProgTagsContainer>();
+    if (dc == nullptr || dc->docInfoList == nullptr)
+        return nullptr;
+    foreach (const MSO::DocInfoListSubContainerOrAtom &a, dc->docInfoList->rgChildRec) {
+        const MSO::DocProgTagsContainer *d = a.anon.get<MSO::DocProgTagsContainer>();
         if (d) {
-            foreach (const MSO::DocProgTagsSubContainerOrAtom& da,
-                     d->rgChildRec) {
-                const MSO::DocProgBinaryTagContainer* c
-                        = da.anon.get<MSO::DocProgBinaryTagContainer>();
+            foreach (const MSO::DocProgTagsSubContainerOrAtom &da, d->rgChildRec) {
+                const MSO::DocProgBinaryTagContainer *c = da.anon.get<MSO::DocProgBinaryTagContainer>();
                 if (c) {
-                    const T* t = c->rec.anon.get<T>();
-                    if (t) return t;
+                    const T *t = c->rec.anon.get<T>();
+                    if (t)
+                        return t;
                 }
             }
         }
     }
-    return 0;
+    return nullptr;
 }
 
 template<class T>
-const T*
-getPP(const MSO::PptOfficeArtClientData& o)
+const T *getPP(const MSO::PptOfficeArtClientData &o)
 {
-    foreach (const MSO::ShapeClientRoundtripDataSubcontainerOrAtom& s,
-             o.rgShapeClientRoundtripData) {
-        const MSO::ShapeProgsTagContainer* p
-                = s.anon.get<MSO::ShapeProgsTagContainer>();
+    foreach (const MSO::ShapeClientRoundtripDataSubcontainerOrAtom &s, o.rgShapeClientRoundtripData) {
+        const MSO::ShapeProgsTagContainer *p = s.anon.get<MSO::ShapeProgsTagContainer>();
         if (p) {
-            foreach (const MSO::ShapeProgTagsSubContainerOrAtom& s,
-                     p->rgChildRec) {
-                const MSO::ShapeProgBinaryTagContainer* a
-                        = s.anon.get<MSO::ShapeProgBinaryTagContainer>();
+            foreach (const MSO::ShapeProgTagsSubContainerOrAtom &s, p->rgChildRec) {
+                const MSO::ShapeProgBinaryTagContainer *a = s.anon.get<MSO::ShapeProgBinaryTagContainer>();
                 if (a) {
-                    const T* pp = a->rec.anon.get<T>();
+                    const T *pp = a->rec.anon.get<T>();
                     if (pp) {
                         return pp;
                     }
@@ -291,17 +265,13 @@ getPP(const MSO::PptOfficeArtClientData& o)
             }
         }
     }
-    foreach (const MSO::ShapeClientRoundtripDataSubcontainerOrAtom& s,
-             o.rgShapeClientRoundtripData0) {
-        const MSO::ShapeProgsTagContainer* p
-                = s.anon.get<MSO::ShapeProgsTagContainer>();
+    foreach (const MSO::ShapeClientRoundtripDataSubcontainerOrAtom &s, o.rgShapeClientRoundtripData0) {
+        const MSO::ShapeProgsTagContainer *p = s.anon.get<MSO::ShapeProgsTagContainer>();
         if (p) {
-            foreach (const MSO::ShapeProgTagsSubContainerOrAtom& s,
-                     p->rgChildRec) {
-                const MSO::ShapeProgBinaryTagContainer* a
-                        = s.anon.get<MSO::ShapeProgBinaryTagContainer>();
+            foreach (const MSO::ShapeProgTagsSubContainerOrAtom &s, p->rgChildRec) {
+                const MSO::ShapeProgBinaryTagContainer *a = s.anon.get<MSO::ShapeProgBinaryTagContainer>();
                 if (a) {
-                    const T* pp = a->rec.anon.get<T>();
+                    const T *pp = a->rec.anon.get<T>();
                     if (pp) {
                         return pp;
                     }
@@ -309,33 +279,36 @@ getPP(const MSO::PptOfficeArtClientData& o)
             }
         }
     }
-    return 0;
+    return nullptr;
 }
 
 template<class T, class C>
-const T*
-getPP(const C* c)
+const T *getPP(const C *c)
 {
-    if (!c) return 0;
-    const MSO::SlideProgTagsContainer* sc = c->slideProgTagsContainer.data();
-    if (!sc) return 0;
-    foreach (const MSO::SlideProgTagsSubContainerOrAtom& a , sc->rgTypeRec) {
-        const MSO::SlideProgBinaryTagContainer* bt
-                = a.anon.get<MSO::SlideProgBinaryTagContainer>();
+    if (!c)
+        return nullptr;
+    const MSO::SlideProgTagsContainer *sc = c->slideProgTagsContainer.data();
+    if (!sc)
+        return nullptr;
+    foreach (const MSO::SlideProgTagsSubContainerOrAtom &a, sc->rgTypeRec) {
+        const MSO::SlideProgBinaryTagContainer *bt = a.anon.get<MSO::SlideProgBinaryTagContainer>();
         if (bt) {
-            const T* t = bt->rec.anon.get<T>();
-            if (t) return t;
+            const T *t = bt->rec.anon.get<T>();
+            if (t)
+                return t;
         }
     }
-    return 0;
+    return nullptr;
 }
 template<class T>
-const T*
-getPP(const MSO::MasterOrSlideContainer* m) {
-    if (!m) return 0;
-    const MSO::MainMasterContainer* mm = m->anon.get<MSO::MainMasterContainer>();
-    if (mm) return getPP<T>(mm);
+const T *getPP(const MSO::MasterOrSlideContainer *m)
+{
+    if (!m)
+        return nullptr;
+    const MSO::MainMasterContainer *mm = m->anon.get<MSO::MainMasterContainer>();
+    if (mm)
+        return getPP<T>(mm);
     return getPP<T>(m->anon.get<MSO::SlideContainer>());
 }
 
-#endif //PPTSTYLE_H
+#endif // PPTSTYLE_H
