@@ -1,74 +1,52 @@
 /* This file is part of the KDE project
 
-   Copyright (C) 2012-2014 Inge Wallin            <inge@lysator.liu.se>
-   Copyright (C) 2012 Mojtaba Shahi Senobari <mojtaba.shahi3000@gmail.com>
+   SPDX-FileCopyrightText: 2012-2014 Inge Wallin <inge@lysator.liu.se>
+   SPDX-FileCopyrightText: 2012 Mojtaba Shahi Senobari <mojtaba.shahi3000@gmail.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-
 // Own
 #include "DocxFile.h"
 
 // Qt
-#include <QString>
 #include <QByteArray>
 #include <QList>
+#include <QString>
 
 // Calligra
-#include <KoXmlWriter.h>
 #include <KoStore.h>
 #include <KoStoreDevice.h>
+#include <KoXmlWriter.h>
 
 // This filter
-#include "OpcContentTypes.h"
-#include "OdfReaderDocxContext.h"
 #include "DocxExportDebug.h"
-
+#include "OdfReaderDocxContext.h"
+#include "OpcContentTypes.h"
 
 // ================================================================
 //                         class DocxFile
 
-DocxFile::DocxFile()
-{
-}
+DocxFile::DocxFile() = default;
 
-DocxFile::~DocxFile()
-{
-}
+DocxFile::~DocxFile() = default;
 
 // todo: commentsexist should be probably replaced with qlist qpair later
-KoFilter::ConversionStatus DocxFile::writeDocx(const QString &fileName,
-                                               const QByteArray &appIdentification,
-                                               const OdfReaderDocxContext &context,
-                                               bool  commentsExist)
+KoFilter::ConversionStatus
+DocxFile::writeDocx(const QString &fileName, const QByteArray &appIdentification, const OdfReaderDocxContext &context, bool commentsExist)
 {
     Q_UNUSED(context);
 
     m_commentsExist = commentsExist;
     // Create the store and check if everything went well.
     // FIXME: Should docxStore be deleted from a finalizer?
-    KoStore *docxStore = KoStore::createStore(fileName, KoStore::Write,
-                                              appIdentification, KoStore::Auto, false);
+    KoStore *docxStore = KoStore::createStore(fileName, KoStore::Write, appIdentification, KoStore::Auto, false);
     if (!docxStore || docxStore->bad()) {
         warnDocx << "Unable to create output file!";
         delete docxStore;
         return KoFilter::FileNotFound;
     }
-    KoFilter::ConversionStatus  status;
+    KoFilter::ConversionStatus status;
 
     // Write top-level rels
     status = writeTopLevelRels(docxStore);
@@ -92,7 +70,7 @@ KoFilter::ConversionStatus DocxFile::writeDocx(const QString &fileName,
     }
 
     // Finally, write the [Content_Types}.xml file.
-    OpcContentTypes  contentTypes;
+    OpcContentTypes contentTypes;
     contentTypes.addDefault("rels", "application/vnd.openxmlformats-package.relationships+xml");
     contentTypes.addDefault("xml", "application/xml");
     foreach (const FileInfo *file, files()) {
@@ -104,13 +82,9 @@ KoFilter::ConversionStatus DocxFile::writeDocx(const QString &fileName,
     return status;
 }
 
-
-
-
 // ----------------------------------------------------------------
 //                         Private functions
 
-
 KoFilter::ConversionStatus DocxFile::writeTopLevelRels(KoStore *docxStore)
 {
     // We can hardcode this one.
@@ -122,7 +96,7 @@ KoFilter::ConversionStatus DocxFile::writeTopLevelRels(KoStore *docxStore)
     KoStoreDevice metaDevice(docxStore);
     KoXmlWriter writer(&metaDevice);
 
-    writer.startDocument(0, 0, 0);
+    writer.startDocument(nullptr, nullptr, nullptr);
     writer.startElement("Relationships");
     writer.addAttribute("xmlns", "http://schemas.openxmlformats.org/package/2006/relationships");
 
@@ -131,23 +105,23 @@ KoFilter::ConversionStatus DocxFile::writeTopLevelRels(KoStore *docxStore)
     writer.addAttribute("Id", "rId1");
     writer.addAttribute("Type", "http://schemas.openxmlformats.org/officeDocument/2006/relationships/officeDocument");
     writer.addAttribute("Target", "word/document.xml");
-    writer.endElement();  // Relationship
+    writer.endElement(); // Relationship
 
     // Doc props core
-    //writer.startElement("Relationship");
-    //writer.addAttribute("Id", "rId2");
-    //writer.addAttribute("Type", "http://schemas.openxmlformats.org/package/2006/relationships/metadata/core-properties");
-    //writer.addAttribute("Target", "docProps/core.xml");
-    //writer.endElement();  // Relationship
+    // writer.startElement("Relationship");
+    // writer.addAttribute("Id", "rId2");
+    // writer.addAttribute("Type", "http://schemas.openxmlformats.org/package/2006/relationships/metadata/core-properties");
+    // writer.addAttribute("Target", "docProps/core.xml");
+    // writer.endElement();  // Relationship
 
     // Doc props app
-    //writer.startElement("Relationship");
-    //writer.addAttribute("Id", "rId3");
-    //writer.addAttribute("Type", "http://schemas.openxmlformats.org/officeDocument/2006/relationships/extended-properties");
-    //writer.addAttribute("Target", "docProps/app.xml");
-    //writer.endElement();  // Relationship
+    // writer.startElement("Relationship");
+    // writer.addAttribute("Id", "rId3");
+    // writer.addAttribute("Type", "http://schemas.openxmlformats.org/officeDocument/2006/relationships/extended-properties");
+    // writer.addAttribute("Target", "docProps/app.xml");
+    // writer.endElement();  // Relationship
 
-    writer.endElement();  // Relationships
+    writer.endElement(); // Relationships
     writer.endDocument();
 
     docxStore->close();
@@ -165,7 +139,7 @@ KoFilter::ConversionStatus DocxFile::writeDocumentRels(KoStore *docxStore)
     KoStoreDevice metaDevice(docxStore);
     KoXmlWriter writer(&metaDevice);
 
-    writer.startDocument(0, 0, 0);
+    writer.startDocument(nullptr, nullptr, nullptr);
     writer.startElement("Relationships");
     writer.addAttribute("xmlns", "http://schemas.openxmlformats.org/package/2006/relationships");
 
@@ -206,10 +180,9 @@ KoFilter::ConversionStatus DocxFile::writeDocumentRels(KoStore *docxStore)
     writer.endElement();
 #endif
 
-    writer.endElement();        // Relationships
+    writer.endElement(); // Relationships
     writer.endDocument();
 
     docxStore->close();
     return KoFilter::OK;
 }
-
