@@ -1,5 +1,5 @@
 /* This file is part of the wvWare 2 project
-   Copyright (C) 2001-2003 Werner Trobin <trobin@kde.org>
+   SPDX-FileCopyrightText: 2001-2003 Werner Trobin <trobin@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,24 +23,20 @@
 
 using namespace wvWare;
 
-Parser95::Parser95( OLEStorage* storage, OLEStreamReader* wordDocument ) :
-    Parser9x( storage, wordDocument, Word95::toWord97( Word95::FIB( wordDocument, true ) ) )
+Parser95::Parser95(OLEStorage *storage, OLEStreamReader *wordDocument)
+    : Parser9x(storage, wordDocument, Word95::toWord97(Word95::FIB(wordDocument, true)))
 {
-    if ( !isOk() )
+    if (!isOk())
         return;
 
     // Initialize the remaining data structures
     init();
 }
 
-Parser95::~Parser95()
-{
-}
+Parser95::~Parser95() = default;
 
 void Parser95::init()
 {
-    if ( m_fib.ccpHdd != 0 )
-        m_headers = new Headers95( m_fib.ccpHdd, m_fib.fcPlcfhdd, m_fib.lcbPlcfhdd,
-                                   m_fib.fcPlcfsed, m_fib.lcbPlcfsed,
-                                   m_table, m_properties->dop().grpfIhdt );
+    if (m_fib.ccpHdd != 0)
+        m_headers = new Headers95(m_fib.ccpHdd, m_fib.fcPlcfhdd, m_fib.lcbPlcfhdd, m_fib.fcPlcfsed, m_fib.lcbPlcfsed, m_table, m_properties->dop().grpfIhdt);
 }
