@@ -1,5 +1,5 @@
 /* This file is part of the wvWare 2 project
-   Copyright (C) 2001-2003 Werner Trobin <trobin@kde.org>
+   SPDX-FileCopyrightText: 2001-2003 Werner Trobin <trobin@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -31,13 +31,13 @@ namespace wvWare
 class Parser97 : public Parser9x
 {
 public:
-    Parser97( OLEStorage* storage, OLEStreamReader* wordDocument );
+    Parser97(OLEStorage *storage, OLEStreamReader *wordDocument);
     ~Parser97() override;
 
 private:
     // Don't copy or assign us
-    Parser97( const Parser97& rhs );
-    Parser97& operator=( const Parser97& rhs );
+    Parser97(const Parser97 &rhs) = delete;
+    Parser97 &operator=(const Parser97 &rhs) = delete;
 
     void init();
 };
