@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006-2007 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2006-2007 Thomas Zander <zander@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KODOCKREGISTRY_
@@ -22,8 +9,8 @@
 
 #include <QFont>
 
-#include "KoGenericRegistry.h"
 #include "KoDockFactoryBase.h"
+#include "KoGenericRegistry.h"
 
 #include "flake_export.h"
 
@@ -36,7 +23,7 @@
  *
  * @see KoCanvasObserverBase
  */
-class FLAKE_EXPORT KoDockRegistry : public KoGenericRegistry<KoDockFactoryBase*>
+class FLAKE_EXPORT KoDockRegistry : public KoGenericRegistry<KoDockFactoryBase *>
 {
 public:
     KoDockRegistry();
@@ -48,7 +35,6 @@ public:
      */
     static KoDockRegistry *instance();
 
-
     /**
      * @brief dockFontSize calculates a smallish font size for dock widgets to use
      * @return the point size in floating point.
@@ -56,13 +42,12 @@ public:
     static QFont dockFont();
 
 private:
-
-    KoDockRegistry(const KoDockRegistry&);
-    KoDockRegistry operator=(const KoDockRegistry&);
+    KoDockRegistry(const KoDockRegistry &) = delete;
+    KoDockRegistry operator=(const KoDockRegistry &) = delete;
     void init();
 
     class Private;
-    Private * const d;
+    Private *const d;
 };
 
 #endif
