@@ -1,41 +1,29 @@
 /* This file is part of the KDE project
-   Copyright (C) 2008 Thorsten Zachmann <zachmann@kde.org>
+   SPDX-FileCopyrightText: 2008 Thorsten Zachmann <zachmann@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "KoEventActionRegistry.h"
 
-#include <QHash>
 #include <QGlobalStatic>
+#include <QHash>
 
 #include <FlakeDebug.h>
 
-#include <KoXmlReader.h>
-#include <KoXmlNS.h>
-#include "KoEventActionFactoryBase.h"
 #include "KoEventAction.h"
+#include "KoEventActionFactoryBase.h"
 #include <KoPluginLoader.h>
-
+#include <KoXmlNS.h>
+#include <KoXmlReader.h>
 
 class KoEventActionRegistry::Singleton
 {
 public:
     Singleton()
-            : initDone(false) {}
+        : initDone(false)
+    {
+    }
 
     KoEventActionRegistry q;
     bool initDone;
@@ -46,15 +34,15 @@ Q_GLOBAL_STATIC(KoEventActionRegistry::Singleton, singleton)
 class Q_DECL_HIDDEN KoEventActionRegistry::Private
 {
 public:
-    QHash<QString, KoEventActionFactoryBase*> presentationEventActionFactories;
-    QHash<QString, KoEventActionFactoryBase*> presentationEventActions;
-    QHash<QString, KoEventActionFactoryBase*> scriptEventActionFactories;
+    QHash<QString, KoEventActionFactoryBase *> presentationEventActionFactories;
+    QHash<QString, KoEventActionFactoryBase *> presentationEventActions;
+    QHash<QString, KoEventActionFactoryBase *> scriptEventActionFactories;
 };
 
-KoEventActionRegistry * KoEventActionRegistry::instance()
+KoEventActionRegistry *KoEventActionRegistry::instance()
 {
-    KoEventActionRegistry * registry = &(singleton->q);
-    if (! singleton->initDone) {
+    KoEventActionRegistry *registry = &(singleton->q);
+    if (!singleton->initDone) {
         singleton->initDone = true;
         registry->init();
     }
@@ -62,7 +50,7 @@ KoEventActionRegistry * KoEventActionRegistry::instance()
 }
 
 KoEventActionRegistry::KoEventActionRegistry()
-        : d(new Private())
+    : d(new Private())
 {
 }
 
@@ -71,16 +59,16 @@ KoEventActionRegistry::~KoEventActionRegistry()
     delete d;
 }
 
-void KoEventActionRegistry::addPresentationEventAction(KoEventActionFactoryBase * factory)
+void KoEventActionRegistry::addPresentationEventAction(KoEventActionFactoryBase *factory)
 {
-    const QString & action = factory->action();
-    if (! action.isEmpty()) {
+    const QString &action = factory->action();
+    if (!action.isEmpty()) {
         d->presentationEventActionFactories.insert(factory->id(), factory);
         d->presentationEventActions.insert(action, factory);
     }
 }
 
-void KoEventActionRegistry::addScriptEventAction(KoEventActionFactoryBase * factory)
+void KoEventActionRegistry::addScriptEventAction(KoEventActionFactoryBase *factory)
 {
     d->scriptEventActionFactories.insert(factory->id(), factory);
 }
@@ -108,20 +96,21 @@ void KoEventActionRegistry::init()
     KoPluginLoader::load(QStringLiteral("calligra/scripteventactions"), config);
 }
 
-QSet<KoEventAction*> KoEventActionRegistry::createEventActionsFromOdf(const KoXmlElement & e, KoShapeLoadingContext & context) const
+QSet<KoEventAction *> KoEventActionRegistry::createEventActionsFromOdf(const KoXmlElement &e, KoShapeLoadingContext &context) const
 {
     QSet<KoEventAction *> eventActions;
 
     if (e.namespaceURI() == KoXmlNS::office && e.tagName() == "event-listeners") {
         KoXmlElement element;
-        forEachElement(element, e) {
+        forEachElement(element, e)
+        {
             if (element.tagName() == "event-listener") {
                 if (element.namespaceURI() == KoXmlNS::presentation) {
                     QString action(element.attributeNS(KoXmlNS::presentation, "action", QString()));
                     QHash<QString, KoEventActionFactoryBase *>::const_iterator it(d->presentationEventActions.find(action));
 
                     if (it != d->presentationEventActions.constEnd()) {
-                        KoEventAction * eventAction = it.value()->createEventAction();
+                        KoEventAction *eventAction = it.value()->createEventAction();
                         if (eventAction) {
                             if (eventAction->loadOdf(element, context)) {
                                 eventActions.insert(eventAction);
@@ -147,4 +136,3 @@ QSet<KoEventAction*> KoEventActionRegistry::createEventActionsFromOdf(const KoXm
 
     return eventActions;
 }
-
