@@ -1,39 +1,26 @@
 /* This file is part of the KDE project
- * Copyright (C) 2007, 2009-2010 Thomas Zander <zander@kde.org>
- * Copyright (C) 2010 Ko Gmbh <cbo@kogmbh.com>
- * Copyright (C) 2011 Matus Hanzes <matus.hanzes@ixonos.com>
- * Copyright (C) 2013 C. Boemann <cbo@boemann.dk>
+ * SPDX-FileCopyrightText: 2007, 2009-2010 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2010 Ko Gmbh <cbo@kogmbh.com>
+ * SPDX-FileCopyrightText: 2011 Matus Hanzes <matus.hanzes@ixonos.com>
+ * SPDX-FileCopyrightText: 2013 C. Boemann <cbo@boemann.dk>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "KoShapeAnchor.h"
-#include "KoStyleStack.h"
 #include "KoOdfLoadingContext.h"
+#include "KoStyleStack.h"
 
 #include <KoShapeContainer.h>
-#include <KoXmlWriter.h>
-#include <KoXmlReader.h>
-#include <KoXmlNS.h>
-#include <KoShapeSavingContext.h>
 #include <KoShapeLoadingContext.h>
+#include <KoShapeSavingContext.h>
+#include <KoXmlNS.h>
+#include <KoXmlReader.h>
+#include <KoXmlWriter.h>
 
+#include <FlakeDebug.h>
 #include <QRectF>
 #include <QTransform>
-#include <FlakeDebug.h>
 
 #include <KoGenChanges.h>
 
@@ -41,20 +28,19 @@ class Q_DECL_HIDDEN KoShapeAnchor::Private
 {
 public:
     Private(KoShape *s)
-            : shape(s)
-            , verticalPos(KoShapeAnchor::VTop)
-            , verticalRel(KoShapeAnchor::VLine)
-            , horizontalPos(KoShapeAnchor::HLeft)
-            , horizontalRel(KoShapeAnchor::HChar)
-            , flowWithText(true)
-            , anchorType(KoShapeAnchor::AnchorToCharacter)
-            , placementStrategy(0)
-            , pageNumber(-1)
-            , textLocation(0)
+        : shape(s)
+        , verticalPos(KoShapeAnchor::VTop)
+        , verticalRel(KoShapeAnchor::VLine)
+        , horizontalPos(KoShapeAnchor::HLeft)
+        , horizontalRel(KoShapeAnchor::HChar)
+        , flowWithText(true)
+        , anchorType(KoShapeAnchor::AnchorToCharacter)
+        , placementStrategy(nullptr)
+        , pageNumber(-1)
+        , textLocation(nullptr)
     {
     }
 
-
     QDebug printDebug(QDebug dbg) const
     {
 #ifndef NDEBUG
@@ -65,7 +51,7 @@ public:
         return dbg.space();
     }
 
-    KoShape * const shape;
+    KoShape *const shape;
     QPointF offset;
     KoShapeAnchor::VerticalPos verticalPos;
     KoShapeAnchor::VerticalRel verticalRel;
@@ -86,7 +72,7 @@ KoShapeAnchor::KoShapeAnchor(KoShape *shape)
 
 KoShapeAnchor::~KoShapeAnchor()
 {
-    if (d->placementStrategy != 0) {
+    if (d->placementStrategy != nullptr) {
         delete d->placementStrategy;
     }
 }
@@ -325,17 +311,13 @@ void KoShapeAnchor::saveOdf(KoShapeSavingContext &context) const
         shape()->setAdditionalStyleAttribute("style:flow-with-text", "false");
     }
 
-    if (shape()->parent()) {// an anchor may not yet have been layout-ed
-        QTransform parentMatrix = shape()->parent()->absoluteTransformation(0).inverted();
-        QTransform shapeMatrix = shape()->absoluteTransformation(0);
+    if (shape()->parent()) { // an anchor may not yet have been layout-ed
+        QTransform parentMatrix = shape()->parent()->absoluteTransformation(nullptr).inverted();
+        QTransform shapeMatrix = shape()->absoluteTransformation(nullptr);
 
-        qreal dx = d->offset.x() - shapeMatrix.dx()*parentMatrix.m11()
-                                   - shapeMatrix.dy()*parentMatrix.m21();
-        qreal dy = d->offset.y() - shapeMatrix.dx()*parentMatrix.m12()
-                                   - shapeMatrix.dy()*parentMatrix.m22();
-        context.addShapeOffset(shape(), QTransform(parentMatrix.m11(),parentMatrix.m12(),
-                                                parentMatrix.m21(),parentMatrix.m22(),
-                                                dx,dy));
+        qreal dx = d->offset.x() - shapeMatrix.dx() * parentMatrix.m11() - shapeMatrix.dy() * parentMatrix.m21();
+        qreal dy = d->offset.y() - shapeMatrix.dx() * parentMatrix.m12() - shapeMatrix.dy() * parentMatrix.m22();
+        context.addShapeOffset(shape(), QTransform(parentMatrix.m11(), parentMatrix.m12(), parentMatrix.m21(), parentMatrix.m22(), dx, dy));
     }
 
     shape()->saveOdf(context);
@@ -402,18 +384,18 @@ bool KoShapeAnchor::loadOdf(const KoXmlElement &element, KoShapeLoadingContext &
     styleStack.restore();
 
     // vertical-pos
-    if (verticalPos == "below") {//svg:y attribute is ignored
+    if (verticalPos == "below") { // svg:y attribute is ignored
         d->verticalPos = VBelow;
         d->offset.setY(0);
-    } else if (verticalPos == "bottom") {//svg:y attribute is ignored
+    } else if (verticalPos == "bottom") { // svg:y attribute is ignored
         d->verticalPos = VBottom;
         d->offset.setY(-shape()->size().height());
     } else if (verticalPos == "from-top") {
         d->verticalPos = VFromTop;
-    } else if (verticalPos == "middle") {//svg:y attribute is ignored
+    } else if (verticalPos == "middle") { // svg:y attribute is ignored
         d->verticalPos = VMiddle;
-        d->offset.setY(-(shape()->size().height()/2));
-    } else if (verticalPos == "top") {//svg:y attribute is ignored
+        d->offset.setY(-(shape()->size().height() / 2));
+    } else if (verticalPos == "top") { // svg:y attribute is ignored
         d->verticalPos = VTop;
         d->offset.setY(0);
     }
@@ -441,23 +423,23 @@ bool KoShapeAnchor::loadOdf(const KoXmlElement &element, KoShapeLoadingContext &
         d->verticalRel = VText;
 
     // horizontal-pos
-    if (horizontalPos == "center") {//svg:x attribute is ignored
+    if (horizontalPos == "center") { // svg:x attribute is ignored
         d->horizontalPos = HCenter;
-        d->offset.setX(-(shape()->size().width()/2));
+        d->offset.setX(-(shape()->size().width() / 2));
     } else if (horizontalPos == "from-inside") {
         d->horizontalPos = HFromInside;
     } else if (horizontalPos == "from-left") {
         d->horizontalPos = HFromLeft;
-    } else if (horizontalPos == "inside") {//svg:x attribute is ignored
+    } else if (horizontalPos == "inside") { // svg:x attribute is ignored
         d->horizontalPos = HInside;
         d->offset.setX(0);
-    } else if (horizontalPos == "left") {//svg:x attribute is ignored
+    } else if (horizontalPos == "left") { // svg:x attribute is ignored
         d->horizontalPos = HLeft;
         d->offset.setX(0);
-    }else if (horizontalPos == "outside") {//svg:x attribute is ignored
+    } else if (horizontalPos == "outside") { // svg:x attribute is ignored
         d->horizontalPos = HOutside;
         d->offset.setX(-shape()->size().width());
-    }else if (horizontalPos == "right") {//svg:x attribute is ignored
+    } else if (horizontalPos == "right") { // svg:x attribute is ignored
         d->horizontalPos = HRight;
         d->offset.setX(-shape()->size().width());
     }
