@@ -1,32 +1,19 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2006 Thomas Zander <zander@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 #ifndef KO_TOOL_MANAGER_P
 #define KO_TOOL_MANAGER_P
 
+#include <QHash>
 #include <QList>
 #include <QObject>
 #include <QString>
 #include <QTimer>
-#include <QHash>
 
-#include <QKeySequence>
 #include <QAction>
+#include <QKeySequence>
 
 #include "KoInputDevice.h"
 #include "KoToolManager.h"
@@ -66,7 +53,7 @@ public:
     void movedFocus(QWidget *from, QWidget *to);
     void updateCursor(const QCursor &cursor);
     void switchBackRequested();
-    void selectionChanged(const QList<KoShape*> &shapes);
+    void selectionChanged(const QList<KoShape *> &shapes);
     void currentLayerChanged(const KoShapeLayer *layer);
     void updateToolForProxy();
     void switchToolTemporaryRequested(const QString &id);
@@ -89,14 +76,13 @@ public:
 
     void switchToolByShortcut(QKeyEvent *event);
 
-
     KoToolManager *q;
 
-    QList<ToolHelper*> tools; // list of all available tools via their factories.
+    QList<ToolHelper *> tools; // list of all available tools via their factories.
 
-    QHash<KoToolBase*, int> uniqueToolIds; // for the changedTool signal
-    QHash<KoCanvasController*, QList<CanvasData*> > canvasses;
-    QHash<KoCanvasBase*, KoToolProxy*> proxies;
+    QHash<KoToolBase *, int> uniqueToolIds; // for the changedTool signal
+    QHash<KoCanvasController *, QList<CanvasData *>> canvasses;
+    QHash<KoCanvasBase *, KoToolProxy *> proxies;
 
     CanvasData *canvasData; // data about the active canvas.
 
@@ -133,7 +119,8 @@ public:
     KoToolBase *createTool(KoCanvasBase *canvas) const;
     ShortcutToolAction *createShortcutToolAction(QObject *parent);
     /// unique id, >= 0
-    int uniqueId() const {
+    int uniqueId() const
+    {
         return m_uniqueId;
     }
     /// QAction->shortcut() if it exists, otherwise KoToolFactoryBase::shortcut()
@@ -150,7 +137,7 @@ private Q_SLOTS:
     void shortcutToolActionUpdated();
 
 private:
-    KoToolFactoryBase * const m_toolFactory;
+    KoToolFactoryBase *const m_toolFactory;
     const int m_uniqueId;
     QKeySequence m_customShortcut;
     bool m_hasCustomShortcut;
@@ -165,11 +152,11 @@ class Connector : public QObject
 public:
     explicit Connector(KoShapeManager *parent);
 
-public Q_SLOTS:
-    void selectionChanged();
+private Q_SLOTS:
+    void slotSelectionChanged();
 
 Q_SIGNALS:
-    void selectionChanged(const QList<KoShape*> &shape);
+    void selectionChanged(const QList<KoShape *> &shape);
 
 private:
     KoShapeManager *m_shapeManager;
