@@ -1,37 +1,24 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006-2007 Thomas Zander <zander@kde.org>
- * Copyright (c) 2004 Boudewijn Rempt <boud@valdyas.org>
+ * SPDX-FileCopyrightText: 2006-2007 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2004 Boudewijn Rempt <boud@valdyas.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "KoToolRegistry.h"
 
 #include <FlakeDebug.h>
-#include <kconfiggroup.h>
-#include <ksharedconfig.h>
+#include <KConfigGroup>
+#include <KSharedConfig>
 
-#include "tools/KoCreateShapesToolFactory.h"
+#include "KoToolManager.h"
 #include "tools/KoCreateShapesTool.h"
+#include "tools/KoCreateShapesToolFactory.h"
+#include "tools/KoPanTool.h"
+#include "tools/KoPanToolFactory.h"
 #include "tools/KoPathToolFactory.h"
 #include "tools/KoZoomTool.h"
 #include "tools/KoZoomToolFactory.h"
-#include "tools/KoPanTool.h"
-#include "tools/KoPanToolFactory.h"
-#include "KoToolManager.h"
 #include <KoPluginLoader.h>
 
 #include <QGlobalStatic>
@@ -39,7 +26,7 @@
 Q_GLOBAL_STATIC(KoToolRegistry, s_instance)
 
 KoToolRegistry::KoToolRegistry()
-  : d(0)
+    : d(nullptr)
 {
 }
 
@@ -57,9 +44,9 @@ void KoToolRegistry::init()
     add(new KoZoomToolFactory());
     add(new KoPanToolFactory());
 
-    KConfigGroup cfg =  KSharedConfig::openConfig()->group("calligra");
+    KConfigGroup cfg = KSharedConfig::openConfig()->group("calligra");
     QStringList toolsBlacklist = cfg.readEntry("ToolsBlacklist", QStringList());
-    foreach (const QString& toolID, toolsBlacklist) {
+    foreach (const QString &toolID, toolsBlacklist) {
         delete value(toolID);
         remove(toolID);
     }
@@ -71,7 +58,7 @@ KoToolRegistry::~KoToolRegistry()
     qDeleteAll(values());
 }
 
-KoToolRegistry* KoToolRegistry::instance()
+KoToolRegistry *KoToolRegistry::instance()
 {
     if (!s_instance.exists()) {
         s_instance->init();
