@@ -1,27 +1,16 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006 Jan Hambrecht <jaham@gmx.net>
- * Copyright (C) 2006,2007 Thorsten Zachmann <zachmann@kde.org>
+ * SPDX-FileCopyrightText: 2006 Jan Hambrecht <jaham@gmx.net>
+ * SPDX-FileCopyrightText: 2006, 2007 Thorsten Zachmann <zachmann@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "KoPathBreakAtPointCommand.h"
 
 #include "KoPathPoint.h"
-#include <klocale.h>
+#include <KLocalizedString>
+
+#include <algorithm>
 
 /*
  * The algorithm to break a multiple open or closed subpaths is:
@@ -31,25 +20,24 @@
  * Not closed
  * - break from the back of the subpath
  */
-KoPathBreakAtPointCommand::KoPathBreakAtPointCommand(const QList<KoPathPointData> & pointDataList, KUndo2Command *parent)
-        : KUndo2Command(parent)
-        , m_deletePoints(true)
+KoPathBreakAtPointCommand::KoPathBreakAtPointCommand(const QList<KoPathPointData> &pointDataList, KUndo2Command *parent)
+    : KUndo2Command(parent)
+    , m_deletePoints(true)
 {
     QList<KoPathPointData> sortedPointDataList(pointDataList);
-    qSort(sortedPointDataList);
+    std::sort(sortedPointDataList.begin(), sortedPointDataList.end());
     setText(kundo2_i18n("Break subpath at points"));
 
     QList<KoPathPointData>::const_iterator it(sortedPointDataList.constBegin());
     for (; it != sortedPointDataList.constEnd(); ++it) {
-        KoPathShape * pathShape = it->pathShape;
-        KoPathPoint * point = pathShape->pointByIndex(it->pointIndex);
-        if(! point)
+        KoPathShape *pathShape = it->pathShape;
+        KoPathPoint *point = pathShape->pointByIndex(it->pointIndex);
+        if (!point)
             continue;
 
         // check if subpath is closed and the point is start or end point of the subpath
-        if(! pathShape->isClosedSubpath(it->pointIndex.first)) {
-            if(it->pointIndex.second == 0
-                || it->pointIndex.second == pathShape->subpathPointCount(it->pointIndex.first)) {
+        if (!pathShape->isClosedSubpath(it->pointIndex.first)) {
+            if (it->pointIndex.second == 0 || it->pointIndex.second == pathShape->subpathPointCount(it->pointIndex.first)) {
                 continue;
             }
         }
@@ -59,7 +47,7 @@ KoPathBreakAtPointCommand::KoPathBreakAtPointCommand(const QList<KoPathPointData
         m_closedIndex.push_back(KoPathPointIndex(-1, 0));
     }
 
-    KoPathPointData last(0, KoPathPointIndex(-1, -1));
+    KoPathPointData last(nullptr, KoPathPointIndex(-1, -1));
     for (int i = m_pointDataList.size() - 1; i >= 0; --i) {
         const KoPathPointData &current = m_pointDataList.at(i);
 
@@ -84,13 +72,13 @@ KoPathBreakAtPointCommand::~KoPathBreakAtPointCommand()
 void KoPathBreakAtPointCommand::redo()
 {
     KUndo2Command::redo();
-    KoPathPointData last(0, KoPathPointIndex(-1, -1));
+    KoPathPointData last(nullptr, KoPathPointIndex(-1, -1));
 
     // offset, needed when path was opened
     int offset = 0;
     for (int i = m_pointDataList.size() - 1; i >= 0; --i) {
-        const KoPathPointData & pd = m_pointDataList.at(i);
-        KoPathShape * pathShape = pd.pathShape;
+        const KoPathPointData &pd = m_pointDataList.at(i);
+        KoPathShape *pathShape = pd.pathShape;
 
         KoPathPointIndex pointIndex = pd.pointIndex;
         if (last.pathShape != pathShape || last.pointIndex.first != pointIndex.first) {
@@ -127,11 +115,11 @@ void KoPathBreakAtPointCommand::redo()
 void KoPathBreakAtPointCommand::undo()
 {
     KUndo2Command::undo();
-    KoPathShape * lastPathShape = 0;
+    KoPathShape *lastPathShape = nullptr;
 
     for (int i = 0; i < m_pointDataList.size(); ++i) {
-        const KoPathPointData & pd = m_pointDataList.at(i);
-        KoPathShape * pathShape = pd.pathShape;
+        const KoPathPointData &pd = m_pointDataList.at(i);
+        KoPathShape *pathShape = pd.pathShape;
         KoPathPointIndex pointIndex = pd.pointIndex;
         ++pointIndex.second;
         if (m_closedIndex.at(i).first != -1) {
