@@ -1,50 +1,37 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2006 Thomas Zander <zander@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "KoShapeReorderCommand.h"
 #include "KoShape.h"
-#include "KoShape_p.h"
-#include "KoShapeManager.h"
 #include "KoShapeContainer.h"
+#include "KoShapeManager.h"
+#include "KoShape_p.h"
 
-#include <klocalizedstring.h>
 #include <FlakeDebug.h>
-#include <limits.h>
+#include <KLocalizedString>
 #include <algorithm>
-
+#include <limits.h>
 
 class KoShapeReorderCommandPrivate
 {
 public:
-    KoShapeReorderCommandPrivate(const QList<KoShape*> &s, QList<int> &ni)
-        : shapes(s), newIndexes(ni)
+    KoShapeReorderCommandPrivate(const QList<KoShape *> &s, QList<int> &ni)
+        : shapes(s)
+        , newIndexes(ni)
     {
     }
 
-    QList<KoShape*> shapes;
+    QList<KoShape *> shapes;
     QList<int> previousIndexes;
     QList<int> newIndexes;
 };
 
-KoShapeReorderCommand::KoShapeReorderCommand(const QList<KoShape*> &shapes, QList<int> &newIndexes, KUndo2Command *parent)
-    : KUndo2Command(parent),
-    d(new KoShapeReorderCommandPrivate(shapes, newIndexes))
+KoShapeReorderCommand::KoShapeReorderCommand(const QList<KoShape *> &shapes, QList<int> &newIndexes, KUndo2Command *parent)
+    : KUndo2Command(parent)
+    , d(new KoShapeReorderCommandPrivate(shapes, newIndexes))
 {
     Q_ASSERT(shapes.count() == newIndexes.count());
     foreach (KoShape *shape, shapes)
@@ -78,26 +65,25 @@ void KoShapeReorderCommand::undo()
     }
 }
 
-static void prepare(KoShape *s, QHash<KoShape*, QList<KoShape*> > &newOrder, KoShapeManager *manager, KoShapeReorderCommand::MoveShapeType move)
+static void prepare(KoShape *s, QHash<KoShape *, QList<KoShape *>> &newOrder, KoShapeManager *manager, KoShapeReorderCommand::MoveShapeType move)
 {
     KoShapeContainer *parent = s->parent();
-    QHash<KoShape*, QList<KoShape*> >::iterator it(newOrder.find(parent));
+    QHash<KoShape *, QList<KoShape *>>::iterator it(newOrder.find(parent));
     if (it == newOrder.end()) {
-        QList<KoShape*> children;
-        if (parent != 0) {
+        QList<KoShape *> children;
+        if (parent != nullptr) {
             children = parent->shapes();
-        }
-        else {
+        } else {
             // get all toplevel shapes
             children = manager->topLevelShapes();
         }
         std::sort(children.begin(), children.end(), KoShape::compareShapeZIndex);
         // the append and prepend are needed so that the raise/lower of all shapes works as expected.
-        children.append(0);
-        children.prepend(0);
+        children.append(nullptr);
+        children.prepend(nullptr);
         it = newOrder.insert(parent, children);
     }
-    QList<KoShape *> & shapes(newOrder[parent]);
+    QList<KoShape *> &shapes(newOrder[parent]);
     int index = shapes.indexOf(s);
     if (index != -1) {
         shapes.removeAt(index);
@@ -119,58 +105,54 @@ static void prepare(KoShape *s, QHash<KoShape*, QList<KoShape*> > &newOrder, KoS
             index = 0;
             break;
         }
-        shapes.insert(index,s);
+        shapes.insert(index, s);
     }
 }
 
 // static
-KoShapeReorderCommand *KoShapeReorderCommand::createCommand(const QList<KoShape*> &shapes, KoShapeManager *manager, MoveShapeType move, KUndo2Command *parent)
+KoShapeReorderCommand *KoShapeReorderCommand::createCommand(const QList<KoShape *> &shapes, KoShapeManager *manager, MoveShapeType move, KUndo2Command *parent)
 {
     QList<int> newIndexes;
-    QList<KoShape*> changedShapes;
-    QHash<KoShape*, QList<KoShape*> > newOrder;
-    QList<KoShape*> sortedShapes(shapes);
+    QList<KoShape *> changedShapes;
+    QHash<KoShape *, QList<KoShape *>> newOrder;
+    QList<KoShape *> sortedShapes(shapes);
     std::sort(sortedShapes.begin(), sortedShapes.end(), KoShape::compareShapeZIndex);
     if (move == BringToFront || move == LowerShape) {
         for (int i = 0; i < sortedShapes.size(); ++i) {
             prepare(sortedShapes.at(i), newOrder, manager, move);
         }
-    }
-    else {
+    } else {
         for (int i = sortedShapes.size() - 1; i >= 0; --i) {
             prepare(sortedShapes.at(i), newOrder, manager, move);
         }
     }
 
-    QHash<KoShape*, QList<KoShape*> >::ConstIterator newIt(newOrder.constBegin());
-    for (; newIt!= newOrder.constEnd(); ++newIt) {
-        QList<KoShape*> order(newIt.value());
-        order.removeAll(0);
+    QHash<KoShape *, QList<KoShape *>>::ConstIterator newIt(newOrder.constBegin());
+    for (; newIt != newOrder.constEnd(); ++newIt) {
+        QList<KoShape *> order(newIt.value());
+        order.removeAll(nullptr);
         int index = -KoShapePrivate::MaxZIndex - 1; // set minimum zIndex
         int pos = 0;
         for (; pos < order.size(); ++pos) {
             if (order[pos]->zIndex() > index) {
                 index = order[pos]->zIndex();
-            }
-            else {
+            } else {
                 break;
             }
         }
 
         if (pos == order.size()) {
-            //nothing needs to be done
+            // nothing needs to be done
             continue;
-        }
-        else if (pos <= order.size() / 2) {
+        } else if (pos <= order.size() / 2) {
             // new index for the front
             int startIndex = order[pos]->zIndex() - pos;
             for (int i = 0; i < pos; ++i) {
                 changedShapes.append(order[i]);
                 newIndexes.append(startIndex++);
             }
-        }
-        else {
-            //new index for the end
+        } else {
+            // new index for the end
             for (int i = pos; i < order.size(); ++i) {
                 changedShapes.append(order[i]);
                 newIndexes.append(++index);
@@ -178,5 +160,5 @@ KoShapeReorderCommand *KoShapeReorderCommand::createCommand(const QList<KoShape*
         }
     }
     Q_ASSERT(changedShapes.count() == newIndexes.count());
-    return changedShapes.isEmpty() ? 0: new KoShapeReorderCommand(changedShapes, newIndexes, parent);
+    return changedShapes.isEmpty() ? nullptr : new KoShapeReorderCommand(changedShapes, newIndexes, parent);
 }
