@@ -1,23 +1,10 @@
 /* This file is part of the KDE project
  *
- * Copyright (C) 2006 Thomas Zander <zander@kde.org>
- * Copyright (C) 2006-2008 Jan Hambrecht <jaham@gmx.net>
- * Copyright (C) 2012 Inge Wallin <inge@lysator.liu.se>
+ * SPDX-FileCopyrightText: 2006 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2006-2008 Jan Hambrecht <jaham@gmx.net>
+ * SPDX-FileCopyrightText: 2012 Inge Wallin <inge@lysator.liu.se>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KOSHAPESTROKECOMMAND_H
@@ -25,8 +12,8 @@
 
 #include "flake_export.h"
 
-#include <kundo2command.h>
 #include <QList>
+#include <kundo2command.h>
 
 class KoShape;
 class KoShapeStrokeModel;
@@ -41,7 +28,7 @@ public:
      * @param stroke the new stroke, the same for all given shapes
      * @param parent the parent command used for macro commands
      */
-    KoShapeStrokeCommand(const QList<KoShape*> &shapes, KoShapeStrokeModel *stroke, KUndo2Command *parent = 0);
+    KoShapeStrokeCommand(const QList<KoShape *> &shapes, KoShapeStrokeModel *stroke, KUndo2Command *parent = nullptr);
 
     /**
      * Command to set new shape strokes.
@@ -49,7 +36,7 @@ public:
      * @param strokes the new strokes, one for each shape
      * @param parent the parent command used for macro commands
      */
-    KoShapeStrokeCommand(const QList<KoShape*> &shapes, const QList<KoShapeStrokeModel*> &strokes, KUndo2Command *parent = 0);
+    KoShapeStrokeCommand(const QList<KoShape *> &shapes, const QList<KoShapeStrokeModel *> &strokes, KUndo2Command *parent = nullptr);
 
     /**
      * Command to set a new shape stroke.
@@ -57,16 +44,17 @@ public:
      * @param stroke the new stroke
      * @param parent the parent command used for macro commands
      */
-    KoShapeStrokeCommand(KoShape* shape, KoShapeStrokeModel *stroke, KUndo2Command *parent = 0);
+    KoShapeStrokeCommand(KoShape *shape, KoShapeStrokeModel *stroke, KUndo2Command *parent = nullptr);
 
     ~KoShapeStrokeCommand() override;
     /// redo the command
     void redo() override;
     /// revert the actions done in redo
     void undo() override;
+
 private:
     class Private;
-    Private * const d;
+    Private *const d;
 };
 
 #endif
