@@ -1,44 +1,29 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006 Jan Hambrecht <jaham@gmx.net>
- * Copyright (C) 2006,2007 Thorsten Zachmann <zachmann@kde.org>
+ * SPDX-FileCopyrightText: 2006 Jan Hambrecht <jaham@gmx.net>
+ * SPDX-FileCopyrightText: 2006, 2007 Thorsten Zachmann <zachmann@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "KoSubpathJoinCommand.h"
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 KoSubpathJoinCommand::KoSubpathJoinCommand(const KoPathPointData &pointData1, const KoPathPointData &pointData2, KUndo2Command *parent)
-        : KUndo2Command(parent)
-        , m_pointData1(pointData1)
-        , m_pointData2(pointData2)
-        , m_splitIndex(KoPathPointIndex(-1, -1))
-        , m_oldProperties1(KoPathPoint::Normal)
-        , m_oldProperties2(KoPathPoint::Normal)
-        , m_reverse(0)
+    : KUndo2Command(parent)
+    , m_pointData1(pointData1)
+    , m_pointData2(pointData2)
+    , m_splitIndex(KoPathPointIndex(-1, -1))
+    , m_oldProperties1(KoPathPoint::Normal)
+    , m_oldProperties2(KoPathPoint::Normal)
+    , m_reverse(0)
 {
     Q_ASSERT(m_pointData1.pathShape == m_pointData2.pathShape);
-    KoPathShape * pathShape = m_pointData1.pathShape;
+    KoPathShape *pathShape = m_pointData1.pathShape;
     Q_ASSERT(!pathShape->isClosedSubpath(m_pointData1.pointIndex.first));
-    Q_ASSERT(m_pointData1.pointIndex.second == 0 ||
-             m_pointData1.pointIndex.second == pathShape->subpathPointCount(m_pointData1.pointIndex.first) - 1);
+    Q_ASSERT(m_pointData1.pointIndex.second == 0 || m_pointData1.pointIndex.second == pathShape->subpathPointCount(m_pointData1.pointIndex.first) - 1);
     Q_ASSERT(!pathShape->isClosedSubpath(m_pointData2.pointIndex.first));
-    Q_ASSERT(m_pointData2.pointIndex.second == 0 ||
-             m_pointData2.pointIndex.second == pathShape->subpathPointCount(m_pointData2.pointIndex.first) - 1);
-    //TODO check that points are not the same
+    Q_ASSERT(m_pointData2.pointIndex.second == 0 || m_pointData2.pointIndex.second == pathShape->subpathPointCount(m_pointData2.pointIndex.first) - 1);
+    // TODO check that points are not the same
 
     if (m_pointData2 < m_pointData1)
         qSwap(m_pointData1, m_pointData2);
@@ -53,8 +38,8 @@ KoSubpathJoinCommand::KoSubpathJoinCommand(const KoPathPointData &pointData1, co
         setText(kundo2_i18n("Join subpaths"));
     }
 
-    KoPathPoint * point1 = pathShape->pointByIndex(m_pointData1.pointIndex);
-    KoPathPoint * point2 = pathShape->pointByIndex(m_pointData2.pointIndex);
+    KoPathPoint *point1 = pathShape->pointByIndex(m_pointData1.pointIndex);
+    KoPathPoint *point2 = pathShape->pointByIndex(m_pointData2.pointIndex);
 
     m_oldControlPoint1 = QPointF(pathShape->shapeToDocument(m_reverse & 1 ? point1->controlPoint1() : point1->controlPoint2()));
     m_oldControlPoint2 = QPointF(pathShape->shapeToDocument(m_reverse & 2 ? point2->controlPoint1() : point2->controlPoint2()));
@@ -62,21 +47,19 @@ KoSubpathJoinCommand::KoSubpathJoinCommand(const KoPathPointData &pointData1, co
     m_oldProperties2 = point2->properties();
 }
 
-KoSubpathJoinCommand::~KoSubpathJoinCommand()
-{
-}
+KoSubpathJoinCommand::~KoSubpathJoinCommand() = default;
 
 void KoSubpathJoinCommand::redo()
 {
     KUndo2Command::redo();
-    KoPathShape * pathShape = m_pointData1.pathShape;
+    KoPathShape *pathShape = m_pointData1.pathShape;
 
     bool closeSubpath = m_pointData1.pointIndex.first == m_pointData2.pointIndex.first;
 
-    KoPathPoint * point1 = pathShape->pointByIndex(m_pointData1.pointIndex);
-    KoPathPoint * point2 = pathShape->pointByIndex(m_pointData2.pointIndex);
+    KoPathPoint *point1 = pathShape->pointByIndex(m_pointData1.pointIndex);
+    KoPathPoint *point2 = pathShape->pointByIndex(m_pointData2.pointIndex);
 
-    // if the endpoint is has a control point create a contol point for the new segment to be
+    // if the endpoint is has a control point create a control point for the new segment to be
     // at the symmetric position to the exiting one
     if (m_reverse & ReverseFirst || closeSubpath) {
         if (point1->activeControlPoint2())
@@ -110,7 +93,7 @@ void KoSubpathJoinCommand::redo()
 void KoSubpathJoinCommand::undo()
 {
     KUndo2Command::undo();
-    KoPathShape * pathShape = m_pointData1.pathShape;
+    KoPathShape *pathShape = m_pointData1.pathShape;
     pathShape->update();
     if (m_pointData1.pointIndex.first == m_pointData2.pointIndex.first) {
         pathShape->openSubpath(m_pointData1.pointIndex);
@@ -125,8 +108,8 @@ void KoSubpathJoinCommand::undo()
             pathShape->reverseSubpath(m_pointData1.pointIndex.first);
         }
     }
-    KoPathPoint * point1 = pathShape->pointByIndex(m_pointData1.pointIndex);
-    KoPathPoint * point2 = pathShape->pointByIndex(m_pointData2.pointIndex);
+    KoPathPoint *point1 = pathShape->pointByIndex(m_pointData1.pointIndex);
+    KoPathPoint *point2 = pathShape->pointByIndex(m_pointData2.pointIndex);
 
     // restore the old end points
     if (m_reverse & ReverseFirst)
@@ -146,4 +129,3 @@ void KoSubpathJoinCommand::undo()
     pathShape->normalize();
     pathShape->update();
 }
-
