@@ -1,27 +1,15 @@
 /*
  *  This file is part of Calligra tests
  *
- *  Copyright (C) 2018 Dag Andersen <danders@get2net.dk>
+ *  SPDX-FileCopyrightText: 2018 Dag Andersen <danders@get2net.dk>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 #include "TestAllowedInteraction.h"
 #include <MockShapes.h>
 
-#include <KoSelection.h>
 #include <FlakeDebug.h>
+#include <KoSelection.h>
 
 #include <QTest>
 
@@ -37,7 +25,7 @@ void TestAllowedInteraction::testVisible()
 
     KoShapeContainer *parent = new MockContainer();
     parent->addShape(shape);
-    
+
     parent->setVisible(false);
     QVERIFY(!shape->isVisible(true));
     parent->setVisible(true);
@@ -47,7 +35,7 @@ void TestAllowedInteraction::testVisible()
 void TestAllowedInteraction::testSelectable()
 {
     MockShape *shape = new MockShape();
-    
+
     QVERIFY(shape->isSelectable());
     shape->setSelectable(false);
     QVERIFY(!shape->isSelectable());
@@ -59,7 +47,7 @@ void TestAllowedInteraction::testSelectable()
     QVERIFY(shape->isSelectable());
     shape->setVisible(true);
     QVERIFY(shape->isSelectable());
-    
+
     KoShapeContainer *parent = new MockContainer();
     parent->addShape(shape);
 
@@ -78,28 +66,28 @@ void TestAllowedInteraction::testSelectable()
 void TestAllowedInteraction::testDeletable()
 {
     MockShape *shape = new MockShape();
-    
+
     QVERIFY(shape->isDeletable());
     shape->setDeletable(false);
     QVERIFY(!shape->isDeletable());
     shape->setDeletable(true);
     QVERIFY(shape->isDeletable());
-    
+
     // visible does not affect isDeletable
     shape->setVisible(false);
     QVERIFY(shape->isDeletable());
     shape->setVisible(true);
     QVERIFY(shape->isDeletable());
-    
+
     KoShapeContainer *parent = new MockContainer();
     parent->addShape(shape);
-    
+
     // parent does not affect isDeletable
     parent->setDeletable(false);
     QVERIFY(shape->isDeletable());
     parent->setDeletable(true);
     QVERIFY(shape->isDeletable());
-    
+
     parent->setVisible(false);
     QVERIFY(shape->isDeletable());
     parent->setDeletable(true);
@@ -109,7 +97,7 @@ void TestAllowedInteraction::testDeletable()
 void TestAllowedInteraction::testGeometryProtected()
 {
     MockShape *shape = new MockShape();
-    
+
     QVERIFY(!shape->isGeometryProtected());
     shape->setGeometryProtected(true);
     QVERIFY(shape->isGeometryProtected());
@@ -124,13 +112,13 @@ void TestAllowedInteraction::testGeometryProtected()
 
     KoShapeContainer *parent = new MockContainer();
     parent->addShape(shape);
-    
+
     // parent does not affect isGeometryProtected
     parent->setGeometryProtected(false);
     QVERIFY(!shape->isGeometryProtected());
     parent->setGeometryProtected(true);
     QVERIFY(!shape->isGeometryProtected());
-    
+
     parent->setVisible(false);
     QVERIFY(!shape->isGeometryProtected());
     parent->setVisible(true);
@@ -140,28 +128,28 @@ void TestAllowedInteraction::testGeometryProtected()
 void TestAllowedInteraction::testContentProtected()
 {
     MockShape *shape = new MockShape();
-    
+
     QVERIFY(!shape->isContentProtected());
     shape->setContentProtected(true);
     QVERIFY(shape->isContentProtected());
     shape->setContentProtected(false);
     QVERIFY(!shape->isContentProtected());
-    
+
     // visible does not affect isContentProtected
     shape->setVisible(false);
     QVERIFY(!shape->isContentProtected());
     shape->setVisible(true);
     QVERIFY(!shape->isContentProtected());
-    
+
     KoShapeContainer *parent = new MockContainer();
     parent->addShape(shape);
-    
+
     // parent does not affect isContentProtected
     parent->setContentProtected(true);
     QVERIFY(!shape->isContentProtected());
     parent->setContentProtected(false);
     QVERIFY(!shape->isContentProtected());
-    
+
     parent->setVisible(false);
     QVERIFY(!shape->isContentProtected());
     parent->setVisible(true);
@@ -171,7 +159,7 @@ void TestAllowedInteraction::testContentProtected()
 void TestAllowedInteraction::testEditable()
 {
     MockShape *shape = new MockShape();
-    
+
     QVERIFY(shape->isSelectable());
     shape->setGeometryProtected(true);
     QVERIFY(!shape->isEditable());
@@ -185,13 +173,13 @@ void TestAllowedInteraction::testEditable()
 
     KoShapeContainer *parent = new MockContainer();
     parent->addShape(shape);
-    
+
     parent->setGeometryProtected(true);
     QEXPECT_FAIL("", "Should check parent according to api doc", Continue);
     QVERIFY(!shape->isEditable());
     parent->setGeometryProtected(false);
     QVERIFY(shape->isEditable());
-    
+
     parent->setVisible(false);
     QEXPECT_FAIL("", "Should check parent according to api doc", Continue);
     QVERIFY(!shape->isEditable());
@@ -214,7 +202,7 @@ void TestAllowedInteraction::testShape()
     QVERIFY(!shape->allowedInteractions().testFlag(KoShape::ResizeAllowed));
     shape->setAllowedInteractions(shape->allowedInteractions().setFlag(KoShape::ResizeAllowed, true));
     QVERIFY(shape->allowedInteractions().testFlag(KoShape::ResizeAllowed));
-    
+
     QVERIFY(shape->allowedInteractions().testFlag(KoShape::ShearingAllowed));
     shape->setAllowedInteractions(shape->allowedInteractions().setFlag(KoShape::ShearingAllowed, false));
     QVERIFY(!shape->allowedInteractions().testFlag(KoShape::ShearingAllowed));
@@ -226,7 +214,7 @@ void TestAllowedInteraction::testShape()
     QVERIFY(!shape->allowedInteractions().testFlag(KoShape::RotationAllowed));
     shape->setAllowedInteractions(shape->allowedInteractions().setFlag(KoShape::RotationAllowed, true));
     QVERIFY(shape->allowedInteractions().testFlag(KoShape::RotationAllowed));
-    
+
     QVERIFY(shape->allowedInteractions().testFlag(KoShape::SelectionAllowed));
     shape->setAllowedInteractions(shape->allowedInteractions().setFlag(KoShape::SelectionAllowed, false));
     QVERIFY(!shape->allowedInteractions().testFlag(KoShape::SelectionAllowed));
@@ -250,13 +238,13 @@ void TestAllowedInteraction::testShape()
     QVERIFY(!shape->isSelectable());
     shape->setSelectable(true);
     QVERIFY(shape->isSelectable());
-    
+
     QVERIFY(shape->isDeletable());
     shape->setDeletable(false);
     QVERIFY(!shape->isDeletable());
     shape->setDeletable(true);
     QVERIFY(shape->isDeletable());
-    
+
     QVERIFY(!shape->isGeometryProtected());
     shape->setGeometryProtected(true);
     QVERIFY(shape->isGeometryProtected());
@@ -276,13 +264,12 @@ void TestAllowedInteraction::testShape()
     shape->setAllowedInteractions(shape->allowedInteractions().setFlag(KoShape::MoveAllowed, true));
     shape->setAllowedInteractions(shape->allowedInteractions().setFlag(KoShape::ResizeAllowed, true));
     QVERIFY(!shape->isGeometryProtected());
-    
+
     QVERIFY(!shape->isContentProtected());
     shape->setContentProtected(true);
     QVERIFY(shape->isContentProtected());
     shape->setContentProtected(false);
     QVERIFY(!shape->isContentProtected());
-
 }
 
 void TestAllowedInteraction::testParentAllowedInteractions()
@@ -292,7 +279,7 @@ void TestAllowedInteraction::testParentAllowedInteractions()
     QVERIFY(shape->allowedInteractions() == parent->allowedInteractions(shape));
     parent->addShape(shape);
     QVERIFY(shape->allowedInteractions() == parent->allowedInteractions(shape));
-    parent->setAllowedInteractions(0);
+    parent->setAllowedInteractions({});
     QVERIFY(shape->allowedInteractions() == parent->allowedInteractions(shape));
     QVERIFY(!(shape->allowedInteractions() & KoShape::MoveAllowed));
     QVERIFY(!(shape->allowedInteractions() & KoShape::ResizeAllowed));
@@ -334,43 +321,43 @@ void TestAllowedInteraction::testParentAllowedInteraction()
 
     parent->setAllowedInteraction(KoShape::MoveAllowed, true);
     QVERIFY(shape->allowedInteraction(KoShape::MoveAllowed));
-    
+
     parent->setAllowedInteraction(KoShape::ResizeAllowed, true);
     QVERIFY(shape->allowedInteraction(KoShape::ResizeAllowed));
-    
+
     parent->setAllowedInteraction(KoShape::ShearingAllowed, true);
     QVERIFY(shape->allowedInteraction(KoShape::ShearingAllowed));
-    
+
     parent->setAllowedInteraction(KoShape::RotationAllowed, true);
     QVERIFY(shape->allowedInteraction(KoShape::RotationAllowed));
-    
+
     parent->setAllowedInteraction(KoShape::SelectionAllowed, true);
     QVERIFY(shape->allowedInteraction(KoShape::SelectionAllowed));
-    
+
     parent->setAllowedInteraction(KoShape::ContentChangeAllowed, true);
     QVERIFY(shape->allowedInteraction(KoShape::ContentChangeAllowed));
-    
+
     parent->setAllowedInteraction(KoShape::DeletionAllowed, true);
     QVERIFY(shape->allowedInteraction(KoShape::DeletionAllowed));
-    
+
     parent->setAllowedInteraction(KoShape::MoveAllowed, false);
     QVERIFY(!shape->allowedInteraction(KoShape::MoveAllowed));
-    
+
     parent->setAllowedInteraction(KoShape::ResizeAllowed, false);
     QVERIFY(!shape->allowedInteraction(KoShape::ResizeAllowed));
-    
+
     parent->setAllowedInteraction(KoShape::ShearingAllowed, false);
     QVERIFY(!shape->allowedInteraction(KoShape::ShearingAllowed));
-    
+
     parent->setAllowedInteraction(KoShape::RotationAllowed, false);
     QVERIFY(!shape->allowedInteraction(KoShape::RotationAllowed));
-    
+
     parent->setAllowedInteraction(KoShape::SelectionAllowed, false);
     QVERIFY(!shape->allowedInteraction(KoShape::SelectionAllowed));
-    
+
     parent->setAllowedInteraction(KoShape::ContentChangeAllowed, false);
     QVERIFY(!shape->allowedInteraction(KoShape::ContentChangeAllowed));
-    
+
     parent->setAllowedInteraction(KoShape::DeletionAllowed, false);
     QVERIFY(!shape->allowedInteraction(KoShape::DeletionAllowed));
 }
@@ -386,7 +373,7 @@ void TestAllowedInteraction::testGrandParentAllowedInteractions()
     grandParent->addShape(parent);
     QVERIFY(shape->allowedInteractions() == parent->allowedInteractions(shape));
 
-    grandParent->setAllowedInteractions(0);
+    grandParent->setAllowedInteractions({});
     QVERIFY(shape->allowedInteractions() == grandParent->allowedInteractions());
     QVERIFY(!(shape->allowedInteractions() & KoShape::MoveAllowed));
     QVERIFY(!(shape->allowedInteractions() & KoShape::ResizeAllowed));
@@ -395,25 +382,25 @@ void TestAllowedInteraction::testGrandParentAllowedInteractions()
     QVERIFY(!(shape->allowedInteractions() & KoShape::SelectionAllowed));
     QVERIFY(!(shape->allowedInteractions() & KoShape::ContentChangeAllowed));
     QVERIFY(!(shape->allowedInteractions() & KoShape::DeletionAllowed));
-    
+
     grandParent->setAllowedInteractions(KoShape::MoveAllowed);
     QVERIFY(shape->allowedInteractions() & KoShape::MoveAllowed);
-    
+
     grandParent->setAllowedInteractions(KoShape::ResizeAllowed);
     QVERIFY(shape->allowedInteractions() & KoShape::ResizeAllowed);
-    
+
     grandParent->setAllowedInteractions(KoShape::ShearingAllowed);
     QVERIFY(shape->allowedInteractions() & KoShape::ShearingAllowed);
-    
+
     grandParent->setAllowedInteractions(KoShape::RotationAllowed);
     QVERIFY(shape->allowedInteractions() & KoShape::RotationAllowed);
-    
+
     grandParent->setAllowedInteractions(KoShape::SelectionAllowed);
     QVERIFY(shape->allowedInteractions() & KoShape::SelectionAllowed);
-    
+
     grandParent->setAllowedInteractions(KoShape::ContentChangeAllowed);
     QVERIFY(shape->allowedInteractions() & KoShape::ContentChangeAllowed);
-    
+
     grandParent->setAllowedInteractions(KoShape::DeletionAllowed);
     QVERIFY(shape->allowedInteractions() & KoShape::DeletionAllowed);
 }
@@ -428,46 +415,46 @@ void TestAllowedInteraction::testGrandParentAllowedInteraction()
     grandParent->addShape(parent);
 
     QVERIFY(shape->allowedInteractions() == grandParent->allowedInteractions());
-    
+
     grandParent->setAllowedInteraction(KoShape::MoveAllowed, true);
     QVERIFY(shape->allowedInteraction(KoShape::MoveAllowed));
-    
+
     grandParent->setAllowedInteraction(KoShape::ResizeAllowed, true);
     QVERIFY(shape->allowedInteraction(KoShape::ResizeAllowed));
-    
+
     grandParent->setAllowedInteraction(KoShape::ShearingAllowed, true);
     QVERIFY(shape->allowedInteraction(KoShape::ShearingAllowed));
-    
+
     grandParent->setAllowedInteraction(KoShape::RotationAllowed, true);
     QVERIFY(shape->allowedInteraction(KoShape::RotationAllowed));
-    
+
     grandParent->setAllowedInteraction(KoShape::SelectionAllowed, true);
     QVERIFY(shape->allowedInteraction(KoShape::SelectionAllowed));
-    
+
     grandParent->setAllowedInteraction(KoShape::ContentChangeAllowed, true);
     QVERIFY(shape->allowedInteraction(KoShape::ContentChangeAllowed));
-    
+
     grandParent->setAllowedInteraction(KoShape::DeletionAllowed, true);
     QVERIFY(shape->allowedInteraction(KoShape::DeletionAllowed));
-    
+
     grandParent->setAllowedInteraction(KoShape::MoveAllowed, false);
     QVERIFY(!shape->allowedInteraction(KoShape::MoveAllowed));
-    
+
     grandParent->setAllowedInteraction(KoShape::ResizeAllowed, false);
     QVERIFY(!shape->allowedInteraction(KoShape::ResizeAllowed));
-    
+
     grandParent->setAllowedInteraction(KoShape::ShearingAllowed, false);
     QVERIFY(!shape->allowedInteraction(KoShape::ShearingAllowed));
-    
+
     grandParent->setAllowedInteraction(KoShape::RotationAllowed, false);
     QVERIFY(!shape->allowedInteraction(KoShape::RotationAllowed));
-    
+
     grandParent->setAllowedInteraction(KoShape::SelectionAllowed, false);
     QVERIFY(!shape->allowedInteraction(KoShape::SelectionAllowed));
-    
+
     grandParent->setAllowedInteraction(KoShape::ContentChangeAllowed, false);
     QVERIFY(!shape->allowedInteraction(KoShape::ContentChangeAllowed));
-    
+
     grandParent->setAllowedInteraction(KoShape::DeletionAllowed, false);
     QVERIFY(!shape->allowedInteraction(KoShape::DeletionAllowed));
 }
