@@ -1,33 +1,20 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006 Thomas Zander <zander@kde.org>
- * Copyright (C) 2006 Thorsten Zachmann <zachmann@kde.org>
+ * SPDX-FileCopyrightText: 2006 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2006 Thorsten Zachmann <zachmann@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "KoCreateShapeStrategy.h"
-#include "KoShapeRubberSelectStrategy_p.h"
-#include "KoCreateShapesTool.h"
-#include "KoShape.h"
-#include "KoShapeRegistry.h"
-#include "KoShapeManager.h"
 #include "KoCanvasBase.h"
+#include "KoCreateShapesTool.h"
 #include "KoSelection.h"
-#include "KoShapeFactoryBase.h"
+#include "KoShape.h"
 #include "KoShapeController.h"
+#include "KoShapeFactoryBase.h"
+#include "KoShapeManager.h"
+#include "KoShapeRegistry.h"
+#include "KoShapeRubberSelectStrategy_p.h"
 #include "KoViewConverter.h"
 
 #include <QPainter>
@@ -35,9 +22,9 @@
 #include <FlakeDebug.h>
 
 KoCreateShapeStrategy::KoCreateShapeStrategy(KoCreateShapesTool *tool, const QPointF &clicked)
-        : KoShapeRubberSelectStrategy(tool, clicked, tool->canvas()->snapToGrid())
+    : KoShapeRubberSelectStrategy(tool, clicked, tool->canvas()->snapToGrid())
 {
-    KoCreateShapesTool *parent = static_cast<KoCreateShapesTool*>(d_ptr->tool);
+    KoCreateShapesTool *parent = static_cast<KoCreateShapesTool *>(d_ptr->tool);
     KoShapeFactoryBase *factory = KoShapeRegistry::instance()->value(parent->shapeId());
     if (factory) {
         const KoProperties *props = parent->shapeProperties();
@@ -54,14 +41,14 @@ KoCreateShapeStrategy::KoCreateShapeStrategy(KoCreateShapesTool *tool, const QPo
     }
 }
 
-KUndo2Command* KoCreateShapeStrategy::createCommand()
+KUndo2Command *KoCreateShapeStrategy::createCommand()
 {
     Q_D(KoShapeRubberSelectStrategy);
-    KoCreateShapesTool *parent = static_cast<KoCreateShapesTool*>(d_ptr->tool);
+    KoCreateShapesTool *parent = static_cast<KoCreateShapesTool *>(d_ptr->tool);
     KoShapeFactoryBase *factory = KoShapeRegistry::instance()->value(parent->shapeId());
-    if (! factory) {
+    if (!factory) {
         warnFlake << "Application requested a shape that is not registered" << parent->shapeId();
-        return 0;
+        return nullptr;
     }
 
     const KoProperties *props = parent->shapeProperties();
@@ -80,7 +67,7 @@ KUndo2Command* KoCreateShapeStrategy::createCommand()
     if (newSize.width() > 1.0 && newSize.height() > 1.0)
         shape->setSize(newSize);
 
-    KUndo2Command * cmd = parent->canvas()->shapeController()->addShape(shape);
+    KUndo2Command *cmd = parent->canvas()->shapeController()->addShape(shape);
     if (cmd) {
         KoSelection *selection = parent->canvas()->shapeManager()->selection();
         selection->deselectAll();
@@ -105,7 +92,7 @@ void KoCreateShapeStrategy::paint(QPainter &painter, const KoViewConverter &conv
         painter.save();
         painter.setRenderHint(QPainter::Antialiasing, false);
 
-        QColor selectColor(Qt::blue);   // TODO make configurable
+        QColor selectColor(Qt::blue); // TODO make configurable
         selectColor.setAlphaF(0.5);
         QBrush sb(selectColor, Qt::SolidPattern);
         painter.setPen(QPen(sb, 0));
@@ -132,6 +119,6 @@ void KoCreateShapeStrategy::handleMouseMove(const QPointF &point, Qt::KeyboardMo
 {
     Q_D(KoShapeRubberSelectStrategy);
     KoShapeRubberSelectStrategy::handleMouseMove(point, modifiers);
-    if (! m_outline.isEmpty())
+    if (!m_outline.isEmpty())
         d->tool->canvas()->updateCanvas(d->selectedRect());
 }
