@@ -1,39 +1,27 @@
 /* This file is part of the KDE project
  *
- * Copyright (C) 2006-2007 Thomas Zander <zander@kde.org>
- * Copyright (C) 2006 Thorsten Zachmann <zachmann@kde.org>
+ * SPDX-FileCopyrightText: 2006-2007 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2006 Thorsten Zachmann <zachmann@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "KoZoomTool.h"
 
 #include <QStandardPaths>
 
-#include "KoZoomStrategy.h"
-#include "KoZoomToolWidget.h"
-#include "KoPointerEvent.h"
 #include "KoCanvasBase.h"
 #include "KoCanvasController.h"
+#include "KoPointerEvent.h"
+#include "KoZoomStrategy.h"
+#include "KoZoomToolWidget.h"
 
 #include <FlakeDebug.h>
 
 KoZoomTool::KoZoomTool(KoCanvasBase *canvas)
-        : KoInteractionTool(canvas),
-        m_temporary(false), m_zoomInMode(true)
+    : KoInteractionTool(canvas)
+    , m_temporary(false)
+    , m_zoomInMode(true)
 {
     QPixmap inPixmap, outPixmap;
     inPixmap.load(QStandardPaths::locate(QStandardPaths::GenericDataLocation, "calligra/cursors/zoom_in_cursor.png"));
@@ -52,7 +40,7 @@ void KoZoomTool::mouseReleaseEvent(KoPointerEvent *event)
 {
     KoInteractionTool::mouseReleaseEvent(event);
     if (m_temporary) {
-        emit KoToolBase::done();
+        Q_EMIT KoToolBase::done();
     }
 }
 
@@ -81,7 +69,7 @@ void KoZoomTool::keyReleaseEvent(QKeyEvent *event)
     KoInteractionTool::keyReleaseEvent(event);
 }
 
-void KoZoomTool::activate(ToolActivation toolActivation, const QSet<KoShape*> &)
+void KoZoomTool::activate(ToolActivation toolActivation, const QSet<KoShape *> &)
 {
     m_temporary = toolActivation == TemporaryActivation;
     updateCursor(false);
