@@ -1,34 +1,20 @@
 /* This file is part of the KDE project
-   Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
-   Copyright     2007       David Faure <faure@kde.org>
+   SPDX-FileCopyrightText: 1998, 1999 Torben Weis <weis@kde.org>
+   SPDX-FileCopyrightText: 2007 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef __ko_document_entry_h__
 #define __ko_document_entry_h__
 
+#include <KPluginMetaData>
 #include <QList>
-#include <QString>
 #include <QSharedPointer>
-#include <QPluginLoader>
+#include <QString>
 
 #include "komain_export.h"
 
-class QStringList;
 class KoDocument;
 class KoPart;
 
@@ -38,7 +24,6 @@ class KoPart;
  */
 class KOMAIN_EXPORT KoDocumentEntry
 {
-
 public:
     /**
      * Represents an invalid entry (as returned by queryByMimeType for instance)
@@ -46,9 +31,9 @@ public:
     explicit KoDocumentEntry();
     /**
      * Represents a valid entry
-     * @param loader pluginloader for the service, KoDocumentEntry takes ownership
+     * @param metaData plugin metadata for the service
      */
-    explicit KoDocumentEntry(QPluginLoader *loader);
+    explicit KoDocumentEntry(const KPluginMetaData &metaData);
     ~KoDocumentEntry();
 
     QJsonObject metaData() const;
@@ -73,13 +58,13 @@ public:
     /**
      *  @return TRUE if the document can handle the requested mimetype.
      */
-    bool supportsMimeType(const QString & _mimetype) const;
+    bool supportsMimeType(const QString &_mimetype) const;
 
     /**
      *  Uses the factory of the component to create
      *  a part. If that is not possible, 0 is returned.
      */
-    KoPart *createKoPart(QString* errorMsg = 0) const;
+    KoPart *createKoPart(QString *errorMsg = nullptr) const;
 
     /**
      *  This function will query ksycoca to find all available components for the requested mimetype.
@@ -89,7 +74,7 @@ public:
      *                 You can use it to set additional restrictions on the available
      *                 components.
      */
-    static QList<KoDocumentEntry> query(const QString &  mimetype = QString());
+    static QList<KoDocumentEntry> query(const QString &mimetype = QString());
 
     /**
      *  This is a convenience function.
@@ -97,10 +82,10 @@ public:
      *  @return a document entry for the Calligra component that supports
      *          the requested mimetype and fits the user best.
      */
-    static KoDocumentEntry queryByMimeType(const QString & mimetype);
+    static KoDocumentEntry queryByMimeType(const QString &mimetype);
 
 private:
-    QSharedPointer<QPluginLoader> m_loader;
+    KPluginMetaData m_metaData;
 };
 
 #endif
