@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
  *
- * Copyright (c) 2012 Arjen Hiemstra <ahiemstra@heimr.nl>
+ * SPDX-FileCopyrightText: 2012 Arjen Hiemstra <ahiemstra@heimr.nl>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KOFINDSTYLE_H
@@ -24,8 +11,8 @@
 #include "KoFindBase.h"
 
 #include <QMetaType>
-#include <QTextDocument>
 #include <QTextCursor>
+#include <QTextDocument>
 
 #include "komain_export.h"
 
@@ -55,7 +42,7 @@ public:
     /**
      * Constructor.
      */
-    explicit KoFindStyle(QObject* parent = 0);
+    explicit KoFindStyle(QObject *parent = nullptr);
     /**
      * Destructor.
      */
@@ -64,13 +51,13 @@ public:
     /**
      * Return the list of documents currently being used for searching.
      */
-    QList<QTextDocument*> documents() const;
+    QList<QTextDocument *> documents() const;
     /**
      * Set the list of documents to use for searching.
      *
      * \param list A list of document to search through.
      */
-    void setDocuments(const QList<QTextDocument*> &list);
+    void setDocuments(const QList<QTextDocument *> &list);
 
     /**
      * Reimplemented from KoFindBase::clearMatches()
@@ -83,15 +70,15 @@ protected:
      *
      * \note Replace is currently not supported in this class.
      */
-    void replaceImplementation(const KoFindMatch& match, const QVariant& value) override;
+    void replaceImplementation(const KoFindMatch &match, const QVariant &value) override;
     /**
      * Reimplemented from KoFindBase::findImplementation()
      */
-    void findImplementation(const QString& pattern, KoFindBase::KoFindMatchList& matchList) override;
+    void findImplementation(const QString &pattern, KoFindBase::KoFindMatchList &matchList) override;
 
 private:
     class Private;
-    Private * const d;
+    Private *const d;
 };
 
 #endif // KOFINDSTYLE_H
