@@ -1,30 +1,18 @@
 /* This file is part of the KDE libraries
-   Copyright (C) 2009 Thomas Zander <zander@kde.org>
+   SPDX-FileCopyrightText: 2009 Thomas Zander <zander@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "KoStandardAction.h"
 
-#include <kactioncollection.h>
+#include <KActionCollection>
+#include <KLocalizedString>
 #include <ktoggleaction.h>
-#include <klocalizedstring.h>
 
 QAction *KoStandardAction::create(StandardAction id, const QObject *recvr, const char *slot, QObject *parent)
 {
-    QAction *newAction = 0;
+    QAction *newAction = nullptr;
 
     switch (id) {
     case ShowGuides: {
@@ -34,7 +22,7 @@ QAction *KoStandardAction::create(StandardAction id, const QObject *recvr, const
         break;
     }
     case ActionNone:
-        return 0;
+        return nullptr;
     }
 
     Q_ASSERT(newAction);
@@ -50,17 +38,17 @@ QAction *KoStandardAction::create(StandardAction id, const QObject *recvr, const
     return newAction;
 }
 
-const char* KoStandardAction::name(StandardAction id)
+const char *KoStandardAction::name(StandardAction id)
 {
     switch (id) {
     case ShowGuides:
         return "view_show_guides";
     default:
-        return 0;
+        return nullptr;
     };
 }
 
 KToggleAction *KoStandardAction::showGuides(const QObject *receiver, const char *slot, QObject *parent)
 {
-    return static_cast<KToggleAction*>(create(ShowGuides, receiver, slot, parent));
+    return static_cast<KToggleAction *>(create(ShowGuides, receiver, slot, parent));
 }
