@@ -1,75 +1,62 @@
 /* This file is part of the KDE project
-Copyright (C) 2002, 2003 Laurent Montel <lmontel@mandrakesoft.com>
-Copyright (C) 2006-2007 Jan Hambrecht <jaham@gmx.net>
+SPDX-FileCopyrightText: 2002, 2003 Laurent Montel <lmontel@mandrakesoft.com>
+SPDX-FileCopyrightText: 2006-2007 Jan Hambrecht <jaham@gmx.net>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Library General Public
-License as published by the Free Software Foundation; either
-version 2 of the License, or (at your option) any later version.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Library General Public License for more details.
-
-You should have received a copy of the GNU Library General Public License
-along with this library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-* Boston, MA 02110-1301, USA.
+SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "KoConfigDocumentPage.h"
 
+#include <KoComponentData.h>
 #include <KoDocument.h>
 #include <KoPart.h>
-#include <KoComponentData.h>
 
-#include <klocalizedstring.h>
-#include <kconfig.h>
-#include <kconfiggroup.h>
+#include <KConfig>
+#include <KConfigGroup>
+#include <KLocalizedString>
 
-#include <QFormLayout>
 #include <QCheckBox>
+#include <QFormLayout>
 #include <QGroupBox>
 #include <QSpinBox>
 
 class Q_DECL_HIDDEN KoConfigDocumentPage::Private
 {
 public:
-    Private(KoDocument* doc)
-    : doc(doc)
-    {}
+    Private(KoDocument *doc)
+        : doc(doc)
+    {
+    }
 
-    KoDocument* doc;
+    KoDocument *doc;
     KSharedConfigPtr config;
 
-    QSpinBox* autoSave;
+    QSpinBox *autoSave;
     int oldAutoSave;
     QCheckBox *createBackupFile;
     bool oldBackupFile;
 };
 
-KoConfigDocumentPage::KoConfigDocumentPage(KoDocument* doc, char* name)
-: d(new Private(doc))
+KoConfigDocumentPage::KoConfigDocumentPage(KoDocument *doc, char *name)
+    : d(std::make_unique<Private>(doc))
 {
     setObjectName(name);
 
     d->config = d->doc->documentPart()->componentData().config();
 
-    QGroupBox* gbDocumentSettings = new QGroupBox(i18n("Document Settings"), this);
-    QFormLayout *layout = new QFormLayout(gbDocumentSettings);
+    auto layout = new QFormLayout;
 
     d->oldAutoSave = doc->defaultAutoSave() / 60;
 
     d->oldBackupFile = true;
 
-    if(d->config->hasGroup("Interface")) {
+    if (d->config->hasGroup("Interface")) {
         KConfigGroup interfaceGroup = d->config->group("Interface");
         d->oldAutoSave = interfaceGroup.readEntry("AutoSave", d->oldAutoSave);
         d->oldBackupFile = interfaceGroup.readEntry("BackupFile", d->oldBackupFile);
     }
 
-    d->autoSave = new QSpinBox(gbDocumentSettings);
+    d->autoSave = new QSpinBox(this);
     d->autoSave->setRange(0, 60);
     d->autoSave->setSingleStep(1);
     d->autoSave->setSpecialValueText(i18n("No autosave"));
@@ -77,15 +64,17 @@ KoConfigDocumentPage::KoConfigDocumentPage(KoDocument* doc, char* name)
     d->autoSave->setValue(d->oldAutoSave);
     layout->addRow(i18n("Autosave interval:"), d->autoSave);
 
-    d->createBackupFile = new QCheckBox(gbDocumentSettings);
+    d->createBackupFile = new QCheckBox(this);
     d->createBackupFile->setChecked(d->oldBackupFile);
     layout->addRow(i18n("Create backup file:"), d->createBackupFile);
+
+    auto hbox = new QHBoxLayout(this);
+    hbox->addStretch();
+    hbox->addLayout(layout);
+    hbox->addStretch();
 }
 
-KoConfigDocumentPage::~KoConfigDocumentPage()
-{
-    delete d;
-}
+KoConfigDocumentPage::~KoConfigDocumentPage() = default;
 
 void KoConfigDocumentPage::apply()
 {
