@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
-   Copyright (C) 1998, 1999, 2000 Torben Weis <weis@kde.org>
-   Copyright (C) 2004 David Faure <faure@kde.org>
+   SPDX-FileCopyrightText: 1998, 1999, 2000 Torben Weis <weis@kde.org>
+   SPDX-FileCopyrightText: 2004 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "KoDocumentInfo.h"
@@ -24,40 +11,53 @@
 #include "KoOdfWriteStore.h"
 #include "KoXmlNS.h"
 
-#include <QDateTime>
 #include <KoStoreDevice.h>
 #include <KoXmlWriter.h>
+#include <QDateTime>
 
-#include <kconfig.h>
-#include <kconfiggroup.h>
+#include <KConfig>
+#include <KConfigGroup>
+#include <KEMailSettings>
+#include <KLocalizedString>
+#include <KUser>
 #include <OdfDebug.h>
-#include <klocalizedstring.h>
-#include <kuser.h>
-#include <kemailsettings.h>
 
-#include <CalligraVersionWrapper.h>
+#include "calligra-version.h"
 
-
-KoDocumentInfo::KoDocumentInfo(QObject *parent) : QObject(parent)
+KoDocumentInfo::KoDocumentInfo(QObject *parent)
+    : QObject(parent)
 {
-    m_aboutTags << "title" << "description" << "subject" << "comments"
-    << "keyword" << "initial-creator" << "editing-cycles"
-    << "date" << "creation-date" << "language";
+    m_aboutTags << "title"
+                << "description"
+                << "subject"
+                << "comments"
+                << "keyword"
+                << "initial-creator"
+                << "editing-cycles"
+                << "date"
+                << "creation-date"
+                << "language";
 
-    m_authorTags << "creator" << "initial" << "author-title"
-    << "email" << "telephone" << "telephone-work"
-    << "fax" << "country" << "postal-code" << "city"
-    << "street" << "position" << "company";
+    m_authorTags << "creator"
+                 << "initial"
+                 << "author-title"
+                 << "email"
+                 << "telephone"
+                 << "telephone-work"
+                 << "fax"
+                 << "country"
+                 << "postal-code"
+                 << "city"
+                 << "street"
+                 << "position"
+                 << "company";
 
     setAboutInfo("editing-cycles", "0");
     setAboutInfo("initial-creator", i18n("Unknown"));
-    setAboutInfo("creation-date", QDateTime::currentDateTime()
-                 .toString(Qt::ISODate));
+    setAboutInfo("creation-date", QDateTime::currentDateTime().toString(Qt::ISODate));
 }
 
-KoDocumentInfo::~KoDocumentInfo()
-{
-}
+KoDocumentInfo::~KoDocumentInfo() = default;
 
 bool KoDocumentInfo::load(const KoXmlDocument &doc)
 {
@@ -103,7 +103,6 @@ QDomDocument KoDocumentInfo::save(QDomDocument &doc)
     if (!s.isNull())
         doc.documentElement().appendChild(s);
 
-
     if (doc.documentElement().isNull())
         return QDomDocument();
 
@@ -115,13 +114,11 @@ bool KoDocumentInfo::saveOasis(KoStore *store)
     updateParametersAndBumpNumCycles();
 
     KoStoreDevice dev(store);
-    KoXmlWriter* xmlWriter = KoOdfWriteStore::createOasisXmlWriter(&dev,
-                             "office:document-meta");
+    KoXmlWriter *xmlWriter = KoOdfWriteStore::createOasisXmlWriter(&dev, "office:document-meta");
     xmlWriter->startElement("office:meta");
 
     xmlWriter->startElement("meta:generator");
-    xmlWriter->addTextNode(QString("Calligra/%1")
-                           .arg(CalligraVersionWrapper::versionString()));
+    xmlWriter->addTextNode(QString("Calligra/%1").arg(CALLIGRA_VERSION_STRING));
     xmlWriter->endElement();
 
     if (!saveOasisAboutInfo(*xmlWriter))
@@ -156,7 +153,7 @@ void KoDocumentInfo::setActiveAuthorInfo(const QString &info, const QString &dat
     } else {
         m_authorInfo.insert(info, data);
     }
-    emit infoUpdated(info, data);
+    Q_EMIT infoUpdated(info, data);
 }
 
 QString KoDocumentInfo::authorInfo(const QString &info) const
@@ -164,7 +161,7 @@ QString KoDocumentInfo::authorInfo(const QString &info) const
     if (!m_authorTags.contains(info))
         return QString();
 
-    return m_authorInfo[ info ];
+    return m_authorInfo[info];
 }
 
 void KoDocumentInfo::setAboutInfo(const QString &info, const QString &data)
@@ -173,7 +170,7 @@ void KoDocumentInfo::setAboutInfo(const QString &info, const QString &data)
         return;
 
     m_aboutInfo.insert(info, data);
-    emit infoUpdated(info, data);
+    Q_EMIT infoUpdated(info, data);
 }
 
 QString KoDocumentInfo::aboutInfo(const QString &info) const
@@ -187,7 +184,7 @@ QString KoDocumentInfo::aboutInfo(const QString &info) const
 
 bool KoDocumentInfo::saveOasisAuthorInfo(KoXmlWriter &xmlWriter)
 {
-    foreach(const QString & tag, m_authorTags) {
+    foreach (const QString &tag, m_authorTags) {
         if (!authorInfo(tag).isEmpty() && tag == "creator") {
             xmlWriter.startElement("dc:creator");
             xmlWriter.addTextNode(authorInfo("creator"));
@@ -215,8 +212,7 @@ bool KoDocumentInfo::loadOasisAuthorInfo(const KoXmlNode &metaDoc)
             continue;
 
         KoXmlElement e = n.toElement();
-        if (!(e.namespaceURI() == KoXmlNS::meta &&
-                e.localName() == "user-defined" && !e.text().isEmpty()))
+        if (!(e.namespaceURI() == KoXmlNS::meta && e.localName() == "user-defined" && !e.text().isEmpty()))
             continue;
 
         QString name = e.attributeNS(KoXmlNS::meta, "name", QString());
@@ -248,7 +244,7 @@ QDomElement KoDocumentInfo::saveAuthorInfo(QDomDocument &doc)
     QDomElement e = doc.createElement("author");
     QDomElement t;
 
-    foreach(const QString &tag, m_authorTags) {
+    foreach (const QString &tag, m_authorTags) {
         if (tag == "creator")
             t = doc.createElement("full-name");
         else
@@ -263,16 +259,15 @@ QDomElement KoDocumentInfo::saveAuthorInfo(QDomDocument &doc)
 
 bool KoDocumentInfo::saveOasisAboutInfo(KoXmlWriter &xmlWriter)
 {
-    foreach(const QString &tag, m_aboutTags) {
+    foreach (const QString &tag, m_aboutTags) {
         if (!aboutInfo(tag).isEmpty() || tag == "title") {
             if (tag == "keyword") {
-                foreach(const QString & tmp, aboutInfo("keyword").split(m_keywordSeparator)) {
+                foreach (const QString &tmp, aboutInfo("keyword").split(m_keywordSeparator)) {
                     xmlWriter.startElement("meta:keyword");
                     xmlWriter.addTextNode(tmp);
                     xmlWriter.endElement();
                 }
-            } else if (tag == "title" || tag == "description" || tag == "subject" ||
-                       tag == "date" || tag == "language") {
+            } else if (tag == "title" || tag == "description" || tag == "subject" || tag == "date" || tag == "language") {
                 QByteArray elementName(QString("dc:" + tag).toLatin1());
                 xmlWriter.startElement(elementName.constData());
                 xmlWriter.addTextNode(aboutInfo(tag));
@@ -293,35 +288,35 @@ bool KoDocumentInfo::loadOasisAboutInfo(const KoXmlNode &metaDoc)
 {
     QStringList keywords;
     KoXmlElement e;
-    forEachElement(e, metaDoc) {
+    forEachElement(e, metaDoc)
+    {
         QString tag(e.localName());
-        if (! m_aboutTags.contains(tag) && tag != "generator") {
+        if (!m_aboutTags.contains(tag) && tag != "generator") {
             continue;
         }
 
-        //debugOdf<<"localName="<<e.localName();
+        // debugOdf<<"localName="<<e.localName();
         if (tag == "keyword") {
             if (!e.text().isEmpty())
                 keywords << e.text().trimmed();
         } else if (tag == "description") {
-            //this is the odf way but add meta:comment if is already loaded
-            KoXmlElement e  = KoXml::namedItemNS(metaDoc, KoXmlNS::dc, tag);
+            // this is the odf way but add meta:comment if is already loaded
+            KoXmlElement e = KoXml::namedItemNS(metaDoc, KoXmlNS::dc, tag);
             if (!e.isNull() && !e.text().isEmpty())
                 setAboutInfo("description", aboutInfo("description") + e.text().trimmed());
         } else if (tag == "comments") {
-            //this was the old way so add it to dc:description
-            KoXmlElement e  = KoXml::namedItemNS(metaDoc, KoXmlNS::meta, tag);
+            // this was the old way so add it to dc:description
+            KoXmlElement e = KoXml::namedItemNS(metaDoc, KoXmlNS::meta, tag);
             if (!e.isNull() && !e.text().isEmpty())
                 setAboutInfo("description", aboutInfo("description") + e.text().trimmed());
-        } else if (tag == "title"|| tag == "subject"
-                   || tag == "date" || tag == "language") {
-            KoXmlElement e  = KoXml::namedItemNS(metaDoc, KoXmlNS::dc, tag);
+        } else if (tag == "title" || tag == "subject" || tag == "date" || tag == "language") {
+            KoXmlElement e = KoXml::namedItemNS(metaDoc, KoXmlNS::dc, tag);
             if (!e.isNull() && !e.text().isEmpty())
                 setAboutInfo(tag, e.text().trimmed());
         } else if (tag == "generator") {
             setOriginalGenerator(e.text().trimmed());
         } else {
-            KoXmlElement e  = KoXml::namedItemNS(metaDoc, KoXmlNS::meta, tag);
+            KoXmlElement e = KoXml::namedItemNS(metaDoc, KoXmlNS::meta, tag);
             if (!e.isNull() && !e.text().isEmpty())
                 setAboutInfo(tag, e.text().trimmed());
         }
@@ -357,7 +352,7 @@ QDomElement KoDocumentInfo::saveAboutInfo(QDomDocument &doc)
     QDomElement e = doc.createElement("about");
     QDomElement t;
 
-    foreach(const QString &tag, m_aboutTags) {
+    foreach (const QString &tag, m_aboutTags) {
         if (tag == "comments") {
             t = doc.createElement("abstract");
             e.appendChild(t);
@@ -374,7 +369,7 @@ QDomElement KoDocumentInfo::saveAboutInfo(QDomDocument &doc)
 
 void KoDocumentInfo::updateParametersAndBumpNumCycles()
 {
-    KoDocumentBase *doc = dynamic_cast< KoDocumentBase *>(parent());
+    KoDocumentBase *doc = dynamic_cast<KoDocumentBase *>(parent());
     if (doc && doc->isAutosaving()) {
         return;
     }
@@ -387,7 +382,7 @@ void KoDocumentInfo::updateParametersAndBumpNumCycles()
 
 void KoDocumentInfo::updateParameters()
 {
-    KoDocumentBase *doc = dynamic_cast< KoDocumentBase *>(parent());
+    KoDocumentBase *doc = dynamic_cast<KoDocumentBase *>(parent());
     if (doc && (!doc->isModified() && !doc->isEmpty())) {
         return;
     }
@@ -410,8 +405,8 @@ void KoDocumentInfo::updateParameters()
         setActiveAuthorInfo("telephone", cgs.readEntry("telephone"));
         setActiveAuthorInfo("telephone-work", cgs.readEntry("telephone-work"));
         setActiveAuthorInfo("fax", cgs.readEntry("fax"));
-        setActiveAuthorInfo("country",cgs.readEntry("country"));
-        setActiveAuthorInfo("postal-code",cgs.readEntry("postal-code"));
+        setActiveAuthorInfo("country", cgs.readEntry("country"));
+        setActiveAuthorInfo("postal-code", cgs.readEntry("postal-code"));
         setActiveAuthorInfo("city", cgs.readEntry("city"));
         setActiveAuthorInfo("street", cgs.readEntry("street"));
         setActiveAuthorInfo("position", cgs.readEntry("position"));
@@ -441,8 +436,8 @@ void KoDocumentInfo::updateParameters()
         setActiveAuthorInfo("company", "");
     }
 
-    //alllow author info set programatically to override info from author profile
-    foreach(const QString &tag, m_authorTags) {
+    // allow author info set programmatically to override info from author profile
+    foreach (const QString &tag, m_authorTags) {
         if (m_authorInfoOverride.contains(tag)) {
             setActiveAuthorInfo(tag, m_authorInfoOverride.value(tag));
         }
