@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
- * Copyright (C) 2008 Fredy Yanardi <fyanardi@gmail.com>
+ * SPDX-FileCopyrightText: 2008 Fredy Yanardi <fyanardi@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KOPAPAGETHUMBNAILMODEL_H
@@ -29,7 +16,7 @@ class KoPAView;
 class KoPAPageBase;
 
 /**
- * Model class for the page thumbnails widget. This class is intented as a simple model to
+ * Model class for the page thumbnails widget. This class is intended as a simple model to
  * create a list view of available pages. Example usage is widget for choosing master page
  * and slide/page sorter widget.
  *
@@ -40,7 +27,7 @@ class KOPAGEAPP_EXPORT KoPAPageThumbnailModel : public QAbstractListModel
     Q_OBJECT
 
 public:
-    explicit KoPAPageThumbnailModel(const QList<KoPAPageBase *> &pages, QObject *parent = 0);
+    explicit KoPAPageThumbnailModel(const QList<KoPAPageBase *> &pages, QObject *parent = nullptr);
     ~KoPAPageThumbnailModel() override;
 
     // from QAbstractItemModel
