@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
  * Copyright ( C ) 2007 Thorsten Zachmann <zachmann@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KOPAVIEWMODE_H
@@ -45,27 +32,26 @@ class KUndo2Command;
 
 class KOPAGEAPP_EXPORT KoPAViewMode : public QObject
 {
-
     Q_OBJECT
 public:
-    KoPAViewMode(KoPAViewBase * view, KoPACanvasBase * canvas, const QString& name = QString());
+    KoPAViewMode(KoPAViewBase *view, KoPACanvasBase *canvas, const QString &name = QString());
     ~KoPAViewMode() override;
 
-    virtual void paint(KoPACanvasBase* canvas, QPainter& painter, const QRectF &paintRect) = 0;
-    //virtual void paintEvent( KoPACanvas * canvas, QPaintEvent* event ) = 0;
-    virtual void tabletEvent( QTabletEvent *event, const QPointF &point ) = 0;
-    virtual void mousePressEvent( QMouseEvent *event, const QPointF &point ) = 0;
-    virtual void mouseDoubleClickEvent( QMouseEvent *event, const QPointF &point ) = 0;
-    virtual void mouseMoveEvent( QMouseEvent *event, const QPointF &point ) = 0;
-    virtual void mouseReleaseEvent( QMouseEvent *event, const QPointF &point ) = 0;
-    virtual void shortcutOverrideEvent( QKeyEvent *event ) = 0;
-    virtual void keyPressEvent( QKeyEvent *event ) = 0;
-    virtual void keyReleaseEvent( QKeyEvent *event ) = 0;
-    virtual void wheelEvent( QWheelEvent * event, const QPointF &point ) = 0;
+    virtual void paint(KoPACanvasBase *canvas, QPainter &painter, const QRectF &paintRect) = 0;
+    // virtual void paintEvent( KoPACanvas * canvas, QPaintEvent* event ) = 0;
+    virtual void tabletEvent(QTabletEvent *event, const QPointF &point) = 0;
+    virtual void mousePressEvent(QMouseEvent *event, const QPointF &point) = 0;
+    virtual void mouseDoubleClickEvent(QMouseEvent *event, const QPointF &point) = 0;
+    virtual void mouseMoveEvent(QMouseEvent *event, const QPointF &point) = 0;
+    virtual void mouseReleaseEvent(QMouseEvent *event, const QPointF &point) = 0;
+    virtual void shortcutOverrideEvent(QKeyEvent *event) = 0;
+    virtual void keyPressEvent(QKeyEvent *event) = 0;
+    virtual void keyReleaseEvent(QKeyEvent *event) = 0;
+    virtual void wheelEvent(QWheelEvent *event, const QPointF &point) = 0;
     /**
      * The default implementation ignores this event
      */
-    virtual void closeEvent( QCloseEvent * event );
+    virtual void closeEvent(QCloseEvent *event);
 
     /**
      * @brief Switch the active view mode to work on master/normal pages
@@ -75,7 +61,7 @@ public:
      *
      * @param master if true work on master pages, if false work on normal pages
      */
-    virtual void setMasterMode( bool master );
+    virtual void setMasterMode(bool master);
 
     /**
      * @brief Check if the active view mode works on master/normal pages
@@ -94,7 +80,7 @@ public:
      * @param previousViewMode the view mode which was active before the
      *        activation of this view mode;
      */
-    virtual void activate( KoPAViewMode * previousViewMode );
+    virtual void activate(KoPAViewMode *previousViewMode);
 
     /**
      * @brief This method is called when the view mode is deactivated
@@ -108,14 +94,14 @@ public:
      *
      * @return canvas canvas used by the view mode
      */
-    KoPACanvasBase * canvas() const;
+    KoPACanvasBase *canvas() const;
 
     /**
      * @brief Get the view
      *
      * @return view view used by the view mode
      */
-    KoPAViewBase * view() const;
+    KoPAViewBase *view() const;
 
     /**
      * @brief Get the view mode's implementation of view converter
@@ -124,12 +110,11 @@ public:
      *
      * @return the view converter used in the view mode
      */
-    virtual KoViewConverter * viewConverter( KoPACanvasBase * canvas );
-
+    virtual KoViewConverter *viewConverter(KoPACanvasBase *canvas);
 
     virtual const KoPageLayout &activePageLayout() const;
 
-    virtual void changePageLayout( const KoPageLayout &pageLayout, bool applyToDocument, KUndo2Command *parent = 0 );
+    virtual void changePageLayout(const KoPageLayout &pageLayout, bool applyToDocument, KUndo2Command *parent = nullptr);
 
     QPointF origin();
 
@@ -147,7 +132,7 @@ public Q_SLOTS:
      *
      * @param shape the new shape added to the document
      */
-    virtual void addShape( KoShape *shape );
+    virtual void addShape(KoShape *shape);
 
     /**
      * @brief Update the view when a shape is removed from the document
@@ -157,7 +142,7 @@ public Q_SLOTS:
      *
      * @param shape the shape removed from the document
      */
-    virtual void removeShape( KoShape *shape );
+    virtual void removeShape(KoShape *shape);
 
     /**
      * @brief Update the view based on the active page
@@ -170,12 +155,12 @@ public Q_SLOTS:
      *
      * @param page the new page to be updated on the view mode
      */
-    virtual void updateActivePage(KoPAPageBase * page);
+    virtual void updateActivePage(KoPAPageBase *page);
 
 protected:
-    KoPACanvasBase * m_canvas;
-    KoToolProxy * m_toolProxy;
-    KoPAViewBase * m_view;
+    KoPACanvasBase *m_canvas;
+    KoToolProxy *m_toolProxy;
+    KoPAViewBase *m_view;
     QPointF m_origin;
     QString m_name;
 };
