@@ -1,30 +1,16 @@
 /*
- *  Copyright (c) 2005 Boudewijn Rempt <boud@valdyas.org>
- *  Copyright (C) 2007 Thomas Zander <zander@kde.org>
+ *  SPDX-FileCopyrightText: 2005 Boudewijn Rempt <boud@valdyas.org>
+ *  SPDX-FileCopyrightText: 2007 Thomas Zander <zander@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
-*/
+ * SPDX-License-Identifier: LGPL-2.0-or-later
+ */
 #ifndef KOCOLOR_H
 #define KOCOLOR_H
 
+#include "KoColorConversionTransformation.h"
+#include "pigment_export.h"
 #include <QColor>
 #include <QMetaType>
-#include "pigment_export.h"
-#include "KoColorConversionTransformation.h"
-
 
 class QDomDocument;
 class QDomElement;
@@ -38,7 +24,6 @@ class KoColorSpace;
  */
 class PIGMENTCMS_EXPORT KoColor
 {
-
 public:
     /// Create an empty KoColor. It will be valid, but also black and transparent
     KoColor();
@@ -46,19 +31,19 @@ public:
     ~KoColor();
 
     /// Create a null KoColor. It will be valid, but all channels will be set to 0
-    explicit KoColor(const KoColorSpace * colorSpace);
+    explicit KoColor(const KoColorSpace *colorSpace);
     /// Create a KoColor from a QColor. The QColor is immediately converted to native. The QColor
     /// is assumed to have the current monitor profile.
-    KoColor(const QColor & color, const KoColorSpace * colorSpace);
+    KoColor(const QColor &color, const KoColorSpace *colorSpace);
 
     /// Create a KoColor using a native color strategy. The data is copied.
-    KoColor(const quint8 * data, const KoColorSpace * colorSpace);
+    KoColor(const quint8 *data, const KoColorSpace *colorSpace);
 
     /// Create a KoColor by converting src into another colorspace
-    KoColor(const KoColor &src, const KoColorSpace * colorSpace);
+    KoColor(const KoColor &src, const KoColorSpace *colorSpace);
 
     /// Copy constructor -- deep copies the colors.
-    KoColor(const KoColor & rhs);
+    KoColor(const KoColor &rhs);
 
     /**
      * assignment operator to copy the data from the param color into this one.
@@ -70,27 +55,26 @@ public:
     bool operator==(const KoColor &other) const;
 
     /// return the current colorSpace
-    const KoColorSpace * colorSpace() const;
+    const KoColorSpace *colorSpace() const;
 
     /// return the current profile
-    const KoColorProfile *  profile() const;
+    const KoColorProfile *profile() const;
 
     /// Convert this KoColor to the specified colorspace. If the specified colorspace is the
     /// same as the original colorspace, do nothing. Returns the converted KoColor.
-    void convertTo(const KoColorSpace * cs,
+    void convertTo(const KoColorSpace *cs,
                    KoColorConversionTransformation::Intent renderingIntent,
                    KoColorConversionTransformation::ConversionFlags conversionFlags);
 
-    void convertTo(const KoColorSpace * cs);
-
+    void convertTo(const KoColorSpace *cs);
 
     /// Replace the existing color data, and colorspace with the specified data.
     /// The data is copied.
-    void setColor(const quint8 * data, const KoColorSpace * colorSpace = 0);
+    void setColor(const quint8 *data, const KoColorSpace *colorSpace = nullptr);
 
     /// Convert the color from src and replace the value of the current color with the converted data.
     /// Don't convert the color if src and this have the same colorspace.
-    void fromKoColor(const KoColor& src);
+    void fromKoColor(const KoColor &src);
 
     /// a convenience method for the above.
     void toQColor(QColor *c) const;
@@ -108,23 +92,23 @@ public:
     quint8 opacityU8() const;
     qreal opacityF() const;
 
-// what about making the next two methods static factory methods?
+    // what about making the next two methods static factory methods?
     /// Convenient function for converting from a QColor
-    void fromQColor(const QColor& c) const;
+    void fromQColor(const QColor &c) const;
 
     /**
      * @return the buffer associated with this color object to be used with the
      *         transformation object created by the color space of this KoColor
      *         or to copy to a different buffer from the same color space
      */
-    quint8 * data();
+    quint8 *data();
 
     /**
      * @return the buffer associated with this color object to be used with the
      *         transformation object created by the color space of this KoColor
      *         or to copy to a different buffer from the same color space
      */
-    const quint8 * data() const;
+    const quint8 *data() const;
 
     /**
      * Serialize this color following Create's swatch color specification available
@@ -138,7 +122,7 @@ public:
      *                 element is <color />
      * @param doc is the document containing colorElt
      */
-    void toXML(QDomDocument& doc, QDomElement& colorElt) const;
+    void toXML(QDomDocument &doc, QDomElement &colorElt) const;
 
     /**
      * Unserialize a color following Create's swatch color specification available
@@ -154,7 +138,7 @@ public:
      * @return the unserialize color, or an empty color object if the function failed
      *         to unserialize the color
      */
-    static KoColor fromXML(const QDomElement& elt, const QString & bitDepthId, const QHash<QString, QString> & aliases);
+    static KoColor fromXML(const QDomElement &elt, const QString &bitDepthId, const QHash<QString, QString> &aliases);
 
     static QString toQString(const KoColor &color);
 
@@ -165,7 +149,7 @@ public:
 
 private:
     class Private;
-    Private * const d;
+    Private *const d;
 };
 
 Q_DECLARE_METATYPE(KoColor)
