@@ -1,21 +1,8 @@
 /*
- *  Copyright (c) 2007 Cyrille Berger <cberger@cberger.net>
+ *  SPDX-FileCopyrightText: 2007 Cyrille Berger <cberger@cberger.net>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
-*/
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
 
 #ifndef _KO_COLOR_CONVERSION_TRANSFORMATION_FACTORY_H_
 #define _KO_COLOR_CONVERSION_TRANSFORMATION_FACTORY_H_
@@ -23,8 +10,8 @@
 class KoColorSpace;
 class KoColorConversionTransformation;
 
-#include <QString>
 #include <KoColorConversionTransformationAbstractFactory.h>
+#include <QString>
 
 /**
  * Factory to create a color transformation between two colorsapces.
@@ -44,7 +31,12 @@ public:
      * @param _srcProfile name of the source profile, or empty if any profile
      * @param _dstProfile name of the destination profile, or empty if any profile
      */
-    KoColorConversionTransformationFactory(const QString &_srcModelId, const QString &_srcDepthId, const QString &_srcProfile, const QString &_dstModelId, const QString &_dstDepthId, const QString &_dstProfile);
+    KoColorConversionTransformationFactory(const QString &_srcModelId,
+                                           const QString &_srcDepthId,
+                                           const QString &_srcProfile,
+                                           const QString &_dstModelId,
+                                           const QString &_dstDepthId,
+                                           const QString &_dstProfile);
     ~KoColorConversionTransformationFactory() override;
     /**
      * @return true if this factory creates a color conversion transformation which
@@ -57,6 +49,7 @@ public:
      * conserve the dynamic range of the color.
      */
     virtual bool conserveDynamicRange() const = 0;
+
 public:
     /**
      * @return the id of the source color model
@@ -84,20 +77,22 @@ public:
      *         means all profiles can be used)
      */
     QString dstProfile() const;
+
 protected:
     /**
      * @param srcCS source color space
      * @return true if the color space given as argument can be used as a source colorspace
      */
-    bool canBeSource(const KoColorSpace* srcCS) const;
+    bool canBeSource(const KoColorSpace *srcCS) const;
     /**
      * @param dstCS destination color space
      * @return true if the color space given as argument can be used as a destination colorspace
      */
-    bool canBeDestination(const KoColorSpace* dstCS) const;
+    bool canBeDestination(const KoColorSpace *dstCS) const;
+
 private:
     struct Private;
-    Private* const d;
+    Private *const d;
 };
 
 #endif
