@@ -1,21 +1,8 @@
 /*
- *  Copyright (c) 2006,2007,2010 Cyrille Berger <cberger@cberger.bet
+ *  SPDX-FileCopyrightText: 2006, 2007, 2010 Cyrille Berger <cberger@cberger.bet
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
-*/
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
 
 #ifndef KOCOLORSPACEMATHS_H_
 #define KOCOLORSPACEMATHS_H_
@@ -23,10 +10,10 @@
 #include <cmath>
 #include <limits>
 
-#include "pigment_export.h"
-#include <KoIntegerMaths.h>
 #include "KoChannelInfo.h"
 #include "KoLut.h"
+#include "pigment_export.h"
+#include <KoIntegerMaths.h>
 
 #undef _T
 
@@ -165,21 +152,21 @@ public:
 #ifdef Q_CC_MSVC
 // MSVC do not have lrint
 
-const double _double2fixmagic = 68719476736.0*1.5;
-const qint32 _shiftamt        = 16;                    //16.16 fixed point representation,
+const double _double2fixmagic = 68719476736.0 * 1.5;
+const qint32 _shiftamt = 16; // 16.16 fixed point representation,
 
 #if Q_BYTE_ORDER == Q_BIG_ENDIAN
-        #define iexp_                           0
-        #define iman_                           1
+#define iexp_ 0
+#define iman_ 1
 #else
-        #define iexp_                           1
-        #define iman_                           0
-#endif //BigEndian_
+#define iexp_ 1
+#define iman_ 0
+#endif // BigEndian_
 
 inline int float2int(double val)
 {
     val = val + _double2fixmagic;
-    return ((int*)&val)[iman_] >> _shiftamt; 
+    return ((int *)&val)[iman_] >> _shiftamt;
 }
 
 inline int float2int(float val)
@@ -203,16 +190,15 @@ inline int float2int(double x)
 
 template<typename _T_>
 struct KoIntegerToFloat {
-  inline float operator()(_T_ f) const
-  {
-    return f / float(KoColorSpaceMathsTraits<_T_>::max);
-  }
+    inline float operator()(_T_ f) const
+    {
+        return f / float(KoColorSpaceMathsTraits<_T_>::max);
+    }
 };
 
 struct KoLuts {
-
-  static PIGMENTCMS_EXPORT const Ko::FullLut< KoIntegerToFloat<quint16>, float, quint16> Uint16ToFloat;
-  static PIGMENTCMS_EXPORT const Ko::FullLut< KoIntegerToFloat<quint8>, float, quint8> Uint8ToFloat;
+    static PIGMENTCMS_EXPORT const Ko::FullLut<KoIntegerToFloat<quint16>, float, quint16> Uint16ToFloat;
+    static PIGMENTCMS_EXPORT const Ko::FullLut<KoIntegerToFloat<quint8>, float, quint8> Uint8ToFloat;
 };
 
 /**
@@ -224,20 +210,22 @@ struct KoLuts {
  * @param _Tdst some other numerical type with an existing trait, it is
  *              only needed if different of _T
  */
-template < typename _T, typename _Tdst = _T >
+template<typename _T, typename _Tdst = _T>
 class KoColorSpaceMaths
 {
     typedef KoColorSpaceMathsTraits<_T> traits;
     typedef typename traits::compositetype src_compositetype;
     typedef typename KoColorSpaceMathsTraits<_Tdst>::compositetype dst_compositetype;
-    
+
 public:
-    inline static _Tdst multiply(_T a, _Tdst b) {
-        return (dst_compositetype(a)*b) /  KoColorSpaceMathsTraits<_Tdst>::unitValue;
+    inline static _Tdst multiply(_T a, _Tdst b)
+    {
+        return (dst_compositetype(a) * b) / KoColorSpaceMathsTraits<_Tdst>::unitValue;
     }
-    
-    inline static _Tdst multiply(_T a, _Tdst b, _Tdst c) {
-        return (dst_compositetype(a)*b*c) / (dst_compositetype(KoColorSpaceMathsTraits<_Tdst>::unitValue) * KoColorSpaceMathsTraits<_T>::unitValue);
+
+    inline static _Tdst multiply(_T a, _Tdst b, _Tdst c)
+    {
+        return (dst_compositetype(a) * b * c) / (dst_compositetype(KoColorSpaceMathsTraits<_Tdst>::unitValue) * KoColorSpaceMathsTraits<_T>::unitValue);
     }
 
     /**
@@ -245,15 +233,17 @@ public:
      * @param a
      * @param b
      */
-    inline static dst_compositetype divide(_T a, _Tdst b) {
-        return (dst_compositetype(a) *  KoColorSpaceMathsTraits<_Tdst>::unitValue) / b;
+    inline static dst_compositetype divide(_T a, _Tdst b)
+    {
+        return (dst_compositetype(a) * KoColorSpaceMathsTraits<_Tdst>::unitValue) / b;
     }
-    
+
     /**
      * Inversion : unitValue - a
      * @param a
      */
-    inline static _T invert(_T a) {
+    inline static _T invert(_T a)
+    {
         return traits::unitValue - a;
     }
 
@@ -263,7 +253,8 @@ public:
      * @param b
      * @param alpha
      */
-    inline static _T blend(_T a, _T b, _T alpha) {
+    inline static _T blend(_T a, _T b, _T alpha)
+    {
         src_compositetype c = ((src_compositetype(a) - b) * alpha) / traits::unitValue;
         return c + b;
     }
@@ -271,11 +262,13 @@ public:
     /**
      * This function will scale a value of type _T to fit into a _Tdst.
      */
-    inline static _Tdst scaleToA(_T a) {
+    inline static _Tdst scaleToA(_T a)
+    {
         return _Tdst(dst_compositetype(a) * KoColorSpaceMathsTraits<_Tdst>::unitValue / KoColorSpaceMathsTraits<_T>::unitValue);
     }
 
-    inline static dst_compositetype clamp(dst_compositetype val) {
+    inline static dst_compositetype clamp(dst_compositetype val)
+    {
         return qBound<dst_compositetype>(KoColorSpaceMathsTraits<_Tdst>::min, val, KoColorSpaceMathsTraits<_Tdst>::max);
     }
 
@@ -283,7 +276,8 @@ public:
      * Clamps the composite type on higher border only. That is a fast path
      * for scale-only transformations
      */
-    inline static _Tdst clampAfterScale(dst_compositetype val) {
+    inline static _Tdst clampAfterScale(dst_compositetype val)
+    {
         return qMin<dst_compositetype>(val, KoColorSpaceMathsTraits<_Tdst>::max);
     }
 };
@@ -398,7 +392,7 @@ inline float KoColorSpaceMaths<half, float>::scaleToA(half a)
 template<>
 inline half KoColorSpaceMaths<float, half>::scaleToA(float a)
 {
-    return (half) a;
+    return (half)a;
 }
 
 template<>
@@ -411,7 +405,7 @@ inline quint8 KoColorSpaceMaths<half, quint8>::scaleToA(half a)
 template<>
 inline half KoColorSpaceMaths<quint8, half>::scaleToA(quint8 a)
 {
-    return a *(1.0 / 255.0);
+    return a * (1.0 / 255.0);
 }
 template<>
 inline quint16 KoColorSpaceMaths<half, quint16>::scaleToA(half a)
@@ -423,7 +417,7 @@ inline quint16 KoColorSpaceMaths<half, quint16>::scaleToA(half a)
 template<>
 inline half KoColorSpaceMaths<quint16, half>::scaleToA(quint16 a)
 {
-    return a *(1.0 / 0xFFFF);
+    return a * (1.0 / 0xFFFF);
 }
 
 template<>
@@ -444,7 +438,6 @@ inline double KoColorSpaceMaths<half>::clamp(double a)
     return a;
 }
 
-
 #endif
 
 //------------------------------ quint8 specialization ------------------------------//
@@ -455,7 +448,6 @@ inline quint8 KoColorSpaceMaths<quint8>::multiply(quint8 a, quint8 b)
     return (quint8)UINT8_MULT(a, b);
 }
 
-
 template<>
 inline quint8 KoColorSpaceMaths<quint8>::multiply(quint8 a, quint8 b, quint8 c)
 {
@@ -463,8 +455,7 @@ inline quint8 KoColorSpaceMaths<quint8>::multiply(quint8 a, quint8 b, quint8 c)
 }
 
 template<>
-inline KoColorSpaceMathsTraits<quint8>::compositetype
-KoColorSpaceMaths<quint8>::divide(quint8 a, quint8 b)
+inline KoColorSpaceMathsTraits<quint8>::compositetype KoColorSpaceMaths<quint8>::divide(quint8 a, quint8 b)
 {
     return UINT8_DIVIDE(a, b);
 }
@@ -490,8 +481,7 @@ inline quint16 KoColorSpaceMaths<quint16>::multiply(quint16 a, quint16 b)
 }
 
 template<>
-inline KoColorSpaceMathsTraits<quint16>::compositetype
-KoColorSpaceMaths<quint16>::divide(quint16 a, quint16 b)
+inline KoColorSpaceMathsTraits<quint16>::compositetype KoColorSpaceMaths<quint16>::divide(quint16 a, quint16 b)
 {
     return UINT16_DIVIDE(a, b);
 }
@@ -504,7 +494,6 @@ inline quint16 KoColorSpaceMaths<quint16>::invert(quint16 a)
 
 //------------------------------ various specialization ------------------------------//
 
-
 // TODO: use more functions from KoIntegersMaths to do the computation
 
 /// This specialization is needed because the default implementation won't work when scaling up
@@ -520,7 +509,6 @@ inline quint8 KoColorSpaceMaths<quint16, quint8>::scaleToA(quint16 a)
     return UINT16_TO_UINT8(a);
 }
 
-
 // Due to once again a bug in gcc, there is the need for those specialized functions:
 
 template<>
@@ -543,141 +531,175 @@ inline float KoColorSpaceMaths<float, float>::scaleToA(float a)
 
 namespace Arithmetic
 {
-    const static qreal pi = 3.14159265358979323846;
-    
-    template<class T>
-    inline T mul(T a, T b) { return KoColorSpaceMaths<T>::multiply(a, b); }
-    
-    template<class T>
-    inline T mul(T a, T b, T c) { return KoColorSpaceMaths<T>::multiply(a, b, c); }
-    
+const static qreal pi = 3.14159265358979323846;
+
+template<class T>
+inline T mul(T a, T b)
+{
+    return KoColorSpaceMaths<T>::multiply(a, b);
+}
+
+template<class T>
+inline T mul(T a, T b, T c)
+{
+    return KoColorSpaceMaths<T>::multiply(a, b, c);
+}
+
 //     template<class T>
 //     inline T mul(T a, T b) {
 //         typedef typename KoColorSpaceMathsTraits<T>::compositetype composite_type;
 //         return T(composite_type(a) * b / KoColorSpaceMathsTraits<T>::unitValue);
 //     }
-//     
+//
 //     template<class T>
 //     inline T mul(T a, T b, T c) {
 //         typedef typename KoColorSpaceMathsTraits<T>::compositetype composite_type;
 //         return T((composite_type(a) * b * c) / (composite_type(KoColorSpaceMathsTraits<T>::unitValue) * KoColorSpaceMathsTraits<T>::unitValue));
 //     }
-    
-    template<class T>
-    inline T inv(T a) { return KoColorSpaceMaths<T>::invert(a); }
-    
-    template<class T>
-    inline T lerp(T a, T b, T alpha) { return KoColorSpaceMaths<T>::blend(b, a, alpha); }
-    
-    template<class TRet, class T>
-    inline TRet scale(T a) { return KoColorSpaceMaths<T,TRet>::scaleToA(a); }
-    
-    template<class T>
-    inline typename KoColorSpaceMathsTraits<T>::compositetype
-    div(T a, T b) { return KoColorSpaceMaths<T>::divide(a, b); }
-    
-    template<class T>
-    inline T clamp(typename KoColorSpaceMathsTraits<T>::compositetype a) {
-        return KoColorSpaceMaths<T>::clamp(a);
-    }
-    
-    template<class T>
-    inline T min(T a, T b, T c) {
-        b = (a < b) ? a : b;
-        return (b < c) ? b : c;
-    }
-    
-    template<class T>
-    inline T max(T a, T b, T c) {
-        b = (a > b) ? a : b;
-        return (b > c) ? b : c;
-    }
-    
-    template<class T>
-    inline T zeroValue() { return KoColorSpaceMathsTraits<T>::zeroValue; }
-    
-    template<class T>
-    inline T halfValue() { return KoColorSpaceMathsTraits<T>::halfValue; }
-    
-    template<class T>
-    inline T unitValue() { return KoColorSpaceMathsTraits<T>::unitValue; }
-    
-    template<class T>
-    inline T unionShapeOpacity(T a, T b) {
-        typedef typename KoColorSpaceMathsTraits<T>::compositetype composite_type;
-        return T(composite_type(a) + b - mul(a,b));
-    }
-    
-    template<class T>
-    inline T blend(T src, T srcAlpha, T dst, T dstAlpha, T cfValue) {
-        return mul(inv(srcAlpha), dstAlpha, dst) + mul(inv(dstAlpha), srcAlpha, src) + mul(dstAlpha, srcAlpha, cfValue);
-    }
+
+template<class T>
+inline T inv(T a)
+{
+    return KoColorSpaceMaths<T>::invert(a);
 }
 
-struct HSYType
+template<class T>
+inline T lerp(T a, T b, T alpha)
 {
+    return KoColorSpaceMaths<T>::blend(b, a, alpha);
+}
+
+template<class TRet, class T>
+inline TRet scale(T a)
+{
+    return KoColorSpaceMaths<T, TRet>::scaleToA(a);
+}
+
+template<class T>
+inline typename KoColorSpaceMathsTraits<T>::compositetype div(T a, T b)
+{
+    return KoColorSpaceMaths<T>::divide(a, b);
+}
+
+template<class T>
+inline T clamp(typename KoColorSpaceMathsTraits<T>::compositetype a)
+{
+    return KoColorSpaceMaths<T>::clamp(a);
+}
+
+template<class T>
+inline T min(T a, T b, T c)
+{
+    b = (a < b) ? a : b;
+    return (b < c) ? b : c;
+}
+
+template<class T>
+inline T max(T a, T b, T c)
+{
+    b = (a > b) ? a : b;
+    return (b > c) ? b : c;
+}
+
+template<class T>
+inline T zeroValue()
+{
+    return KoColorSpaceMathsTraits<T>::zeroValue;
+}
+
+template<class T>
+inline T halfValue()
+{
+    return KoColorSpaceMathsTraits<T>::halfValue;
+}
+
+template<class T>
+inline T unitValue()
+{
+    return KoColorSpaceMathsTraits<T>::unitValue;
+}
+
+template<class T>
+inline T unionShapeOpacity(T a, T b)
+{
+    typedef typename KoColorSpaceMathsTraits<T>::compositetype composite_type;
+    return T(composite_type(a) + b - mul(a, b));
+}
+
+template<class T>
+inline T blend(T src, T srcAlpha, T dst, T dstAlpha, T cfValue)
+{
+    return mul(inv(srcAlpha), dstAlpha, dst) + mul(inv(dstAlpha), srcAlpha, src) + mul(dstAlpha, srcAlpha, cfValue);
+}
+}
+
+struct HSYType {
     template<class TReal>
-    inline static TReal getLightness(TReal r, TReal g, TReal b) {
-        return TReal(0.299)*r + TReal(0.587)*g + TReal(0.114)*b;
+    inline static TReal getLightness(TReal r, TReal g, TReal b)
+    {
+        return TReal(0.299) * r + TReal(0.587) * g + TReal(0.114) * b;
     }
-    
+
     template<class TReal>
-    inline static TReal getSaturation(TReal r, TReal g, TReal b) {
-        return Arithmetic::max(r,g,b) - Arithmetic::min(r,g,b);
+    inline static TReal getSaturation(TReal r, TReal g, TReal b)
+    {
+        return Arithmetic::max(r, g, b) - Arithmetic::min(r, g, b);
     }
 };
 
-struct HSIType
-{
+struct HSIType {
     template<class TReal>
-    inline static TReal getLightness(TReal r, TReal g, TReal b) {
+    inline static TReal getLightness(TReal r, TReal g, TReal b)
+    {
         return (r + g + b) * TReal(0.33333333333333333333); // (r + g + b) / 3.0
     }
-    
+
     template<class TReal>
-    inline static TReal getSaturation(TReal r, TReal g, TReal b) {
-        TReal max    = Arithmetic::max(r, g, b);
-        TReal min    = Arithmetic::min(r, g, b);
+    inline static TReal getSaturation(TReal r, TReal g, TReal b)
+    {
+        TReal max = Arithmetic::max(r, g, b);
+        TReal min = Arithmetic::min(r, g, b);
         TReal chroma = max - min;
-        
-        return (chroma > std::numeric_limits<TReal>::epsilon()) ?
-            (TReal(1.0) - min / getLightness(r, g, b)) : TReal(0.0);
+
+        return (chroma > std::numeric_limits<TReal>::epsilon()) ? (TReal(1.0) - min / getLightness(r, g, b)) : TReal(0.0);
     }
 };
 
-struct HSLType
-{
+struct HSLType {
     template<class TReal>
-    inline static TReal getLightness(TReal r, TReal g, TReal b) {
+    inline static TReal getLightness(TReal r, TReal g, TReal b)
+    {
         TReal max = Arithmetic::max(r, g, b);
         TReal min = Arithmetic::min(r, g, b);
         return (max + min) * TReal(0.5);
     }
-    
+
     template<class TReal>
-    inline static TReal getSaturation(TReal r, TReal g, TReal b) {
-        TReal max    = Arithmetic::max(r, g, b);
-        TReal min    = Arithmetic::min(r, g, b);
+    inline static TReal getSaturation(TReal r, TReal g, TReal b)
+    {
+        TReal max = Arithmetic::max(r, g, b);
+        TReal min = Arithmetic::min(r, g, b);
         TReal chroma = max - min;
-        TReal light  = (max + min) * TReal(0.5);
-        TReal div    = TReal(1.0) - std::abs(TReal(2.0)*light - TReal(1.0));
-        
-        if(div > std::numeric_limits<TReal>::epsilon())
+        TReal light = (max + min) * TReal(0.5);
+        TReal div = TReal(1.0) - std::abs(TReal(2.0) * light - TReal(1.0));
+
+        if (div > std::numeric_limits<TReal>::epsilon())
             return chroma / div;
-        
+
         return TReal(1.0);
     }
 };
 
-struct HSVType
-{
+struct HSVType {
     template<class TReal>
-    inline static TReal getLightness(TReal r, TReal g, TReal b) {
-        return Arithmetic::max(r,g,b);
+    inline static TReal getLightness(TReal r, TReal g, TReal b)
+    {
+        return Arithmetic::max(r, g, b);
     }
-    
+
     template<class TReal>
-    inline static TReal getSaturation(TReal r, TReal g, TReal b) {
+    inline static TReal getSaturation(TReal r, TReal g, TReal b)
+    {
         TReal max = Arithmetic::max(r, g, b);
         TReal min = Arithmetic::min(r, g, b);
         return (max == TReal(0.0)) ? TReal(0.0) : (max - min) / max;
@@ -685,37 +707,38 @@ struct HSVType
 };
 
 template<class TReal>
-TReal getHue(TReal r, TReal g, TReal b) {
-    TReal min    = Arithmetic::min(r, g, b);
-    TReal max    = Arithmetic::max(r, g, b);
+TReal getHue(TReal r, TReal g, TReal b)
+{
+    TReal min = Arithmetic::min(r, g, b);
+    TReal max = Arithmetic::max(r, g, b);
     TReal chroma = max - min;
-    
+
     TReal hue = TReal(-1.0);
-    
-    if(chroma > std::numeric_limits<TReal>::epsilon()) {
-        
-//         return atan2(TReal(2.0)*r - g - b, TReal(1.73205080756887729353)*(g - b));
-        
-        if(max == r) // between yellow and magenta
+
+    if (chroma > std::numeric_limits<TReal>::epsilon()) {
+        //         return atan2(TReal(2.0)*r - g - b, TReal(1.73205080756887729353)*(g - b));
+
+        if (max == r) // between yellow and magenta
             hue = (g - b) / chroma;
-        else if(max == g) // between cyan and yellow
+        else if (max == g) // between cyan and yellow
             hue = TReal(2.0) + (b - r) / chroma;
-        else if(max == b) // between magenta and cyan
+        else if (max == b) // between magenta and cyan
             hue = TReal(4.0) + (r - g) / chroma;
-        
-        if(hue < -std::numeric_limits<TReal>::epsilon())
+
+        if (hue < -std::numeric_limits<TReal>::epsilon())
             hue += TReal(6.0);
-        
+
         hue /= TReal(6.0);
     }
-    
-//     hue = (r == max) ? (b-g) : (g == max) ? TReal(2.0)+(r-b) : TReal(4.0)+(g-r);
-    
+
+    //     hue = (r == max) ? (b-g) : (g == max) ? TReal(2.0)+(r-b) : TReal(4.0)+(g-r);
+
     return hue;
 }
 
 template<class TReal>
-void getRGB(TReal& r, TReal& g, TReal& b, TReal hue) {
+void getRGB(TReal &r, TReal &g, TReal &b, TReal hue)
+{
     // 0 red    -> (1,0,0)
     // 1 yellow -> (1,1,0)
     // 2 green  -> (0,1,0)
@@ -723,107 +746,121 @@ void getRGB(TReal& r, TReal& g, TReal& b, TReal hue) {
     // 4 blue   -> (0,0,1)
     // 5 maenta -> (1,0,1)
     // 6 red    -> (1,0,0)
-    
-    if(hue < -std::numeric_limits<TReal>::epsilon()) {
+
+    if (hue < -std::numeric_limits<TReal>::epsilon()) {
         r = g = b = TReal(0.0);
         return;
     }
-    
-    int   i = int(hue * TReal(6.0));
+
+    int i = int(hue * TReal(6.0));
     TReal x = hue * TReal(6.0) - i;
     TReal y = TReal(1.0) - x;
-    
-    switch(i % 6){
-        case 0: { r=TReal(1.0), g=x         , b=TReal(0.0); } break;
-        case 1: { r=y         , g=TReal(1.0), b=TReal(0.0); } break;
-        case 2: { r=TReal(0.0), g=TReal(1.0), b=x         ; } break;
-        case 3: { r=TReal(0.0), g=y         , b=TReal(1.0); } break;
-        case 4: { r=x         , g=TReal(0.0), b=TReal(1.0); } break;
-        case 5: { r=TReal(1.0), g=TReal(0.0), b=y         ; } break;
+
+    switch (i % 6) {
+    case 0: {
+        r = TReal(1.0), g = x, b = TReal(0.0);
+    } break;
+    case 1: {
+        r = y, g = TReal(1.0), b = TReal(0.0);
+    } break;
+    case 2: {
+        r = TReal(0.0), g = TReal(1.0), b = x;
+    } break;
+    case 3: {
+        r = TReal(0.0), g = y, b = TReal(1.0);
+    } break;
+    case 4: {
+        r = x, g = TReal(0.0), b = TReal(1.0);
+    } break;
+    case 5: {
+        r = TReal(1.0), g = TReal(0.0), b = y;
+    } break;
     }
 }
 
 template<class HSXType, class TReal>
-inline static TReal getLightness(TReal r, TReal g, TReal b) {
+inline static TReal getLightness(TReal r, TReal g, TReal b)
+{
     return HSXType::getLightness(r, g, b);
 }
 
 template<class HSXType, class TReal>
-inline void addLightness(TReal& r, TReal& g, TReal& b, TReal light)
+inline void addLightness(TReal &r, TReal &g, TReal &b, TReal light)
 {
     using namespace Arithmetic;
-    
+
     r += light;
     g += light;
     b += light;
-    
+
     TReal l = HSXType::getLightness(r, g, b);
     TReal n = min(r, g, b);
     TReal x = max(r, g, b);
-    
-    if(n < TReal(0.0)) {
-        TReal iln = TReal(1.0) / (l-n);
-        r = l + ((r-l) * l) * iln;
-        g = l + ((g-l) * l) * iln;
-        b = l + ((b-l) * l) * iln;
+
+    if (n < TReal(0.0)) {
+        TReal iln = TReal(1.0) / (l - n);
+        r = l + ((r - l) * l) * iln;
+        g = l + ((g - l) * l) * iln;
+        b = l + ((b - l) * l) * iln;
     }
-    
-    if(x > TReal(1.0) && (x-l) > std::numeric_limits<TReal>::epsilon()) {
-        TReal il  = TReal(1.0) - l;
+
+    if (x > TReal(1.0) && (x - l) > std::numeric_limits<TReal>::epsilon()) {
+        TReal il = TReal(1.0) - l;
         TReal ixl = TReal(1.0) / (x - l);
-        r = l + ((r-l) * il) * ixl;
-        g = l + ((g-l) * il) * ixl;
-        b = l + ((b-l) * il) * ixl;
+        r = l + ((r - l) * il) * ixl;
+        g = l + ((g - l) * il) * ixl;
+        b = l + ((b - l) * il) * ixl;
     }
 }
 
 template<class HSXType, class TReal>
-inline void setLightness(TReal& r, TReal& g, TReal& b, TReal light)
+inline void setLightness(TReal &r, TReal &g, TReal &b, TReal light)
 {
-    addLightness<HSXType>(r,g,b, light - HSXType::getLightness(r,g,b));
+    addLightness<HSXType>(r, g, b, light - HSXType::getLightness(r, g, b));
 }
 
 template<class HSXType, class TReal>
-inline static TReal getSaturation(TReal r, TReal g, TReal b) {
+inline static TReal getSaturation(TReal r, TReal g, TReal b)
+{
     return HSXType::getSaturation(r, g, b);
 }
 
 template<class HSXType, class TReal>
-inline void setSaturation(TReal& r, TReal& g, TReal& b, TReal sat)
+inline void setSaturation(TReal &r, TReal &g, TReal &b, TReal sat)
 {
-    int   min    = 0;
-    int   mid    = 1;
-    int   max    = 2;
+    int min = 0;
+    int mid = 1;
+    int max = 2;
     TReal rgb[3] = {r, g, b};
-    
-    if(rgb[mid] < rgb[min]) {
+
+    if (rgb[mid] < rgb[min]) {
         int tmp = min;
         min = mid;
         mid = tmp;
     }
-    
-    if(rgb[max] < rgb[mid]) {
+
+    if (rgb[max] < rgb[mid]) {
         int tmp = mid;
         mid = max;
         max = tmp;
     }
-    
-    if(rgb[mid] < rgb[min]) {
+
+    if (rgb[mid] < rgb[min]) {
         int tmp = min;
         min = mid;
         mid = tmp;
     }
-    
-    if((rgb[max] - rgb[min]) > TReal(0.0)) {
-        rgb[mid] = ((rgb[mid]-rgb[min]) * sat) / (rgb[max]-rgb[min]);
+
+    if ((rgb[max] - rgb[min]) > TReal(0.0)) {
+        rgb[mid] = ((rgb[mid] - rgb[min]) * sat) / (rgb[max] - rgb[min]);
         rgb[max] = sat;
         rgb[min] = TReal(0.0);
-        
+
         r = rgb[0];
         g = rgb[1];
         b = rgb[2];
-    }
-    else r = g = b = TReal(0.0);
+    } else
+        r = g = b = TReal(0.0);
 }
 
 #endif
