@@ -1,8 +1,8 @@
 #include "KoSectionModel.h"
 
-#include <climits>
-#include <KoTextDocument.h>
 #include <KLocalizedString>
+#include <KoTextDocument.h>
+#include <climits>
 
 KoSectionModel::KoSectionModel(QTextDocument *doc)
     : QAbstractItemModel()
@@ -13,7 +13,7 @@ KoSectionModel::KoSectionModel(QTextDocument *doc)
 
 KoSectionModel::~KoSectionModel()
 {
-    foreach(KoSection *sec, m_registeredSections) {
+    foreach (KoSection *sec, m_registeredSections) {
         delete sec; // This will delete associated KoSectionEnd in KoSection destructor
     }
 }
@@ -21,7 +21,7 @@ KoSectionModel::~KoSectionModel()
 KoSection *KoSectionModel::createSection(const QTextCursor &cursor, KoSection *parent, const QString &name)
 {
     if (!isValidNewName(name)) {
-        return 0;
+        return nullptr;
     }
 
     KoSection *result = new KoSection(cursor, name, parent);
@@ -55,7 +55,7 @@ KoSectionEnd *KoSectionModel::createSectionEnd(KoSection *section)
 KoSection *KoSectionModel::sectionAtPosition(int pos) const
 {
     // TODO: Rewrite it by traversing Model as tree
-    KoSection *result = 0;
+    KoSection *result = nullptr;
     int level = -1; // Seeking the section with maximum level
     QHash<QString, KoSection *>::ConstIterator it = m_sectionNames.begin();
     for (; it != m_sectionNames.end(); ++it) {
@@ -94,8 +94,8 @@ bool KoSectionModel::setName(KoSection *section, const QString &name)
 {
     if (section->name() == name || isValidNewName(name)) {
         section->setName(name);
-        //TODO: we don't have name in columns, but need something to notify views about change
-        emit dataChanged(m_modelIndex[section], m_modelIndex[section]);
+        // TODO: we don't have name in columns, but need something to notify views about change
+        Q_EMIT dataChanged(m_modelIndex[section], m_modelIndex[section]);
         return true;
     }
     return false;
@@ -159,7 +159,7 @@ int KoSectionModel::rowCount(const QModelIndex &parent) const
     return static_cast<KoSection *>(parent.internalPointer())->children().size();
 }
 
-int KoSectionModel::columnCount(const QModelIndex &/*parent*/) const
+int KoSectionModel::columnCount(const QModelIndex & /*parent*/) const
 {
     return 1;
 }
