@@ -1,24 +1,11 @@
 /* This file is part of the KDE project
- * Copyright (C) 2008 Girish Ramakrishnan <girish@forwardbias.in>
- * Copyright (C) 2009 Thomas Zander <zander@kde.org>
- * Copyright (C) 2008 Pierre Stirnweiss \pierre.stirnweiss_calligra@gadz.org>
- * Copyright (C) 2011-2012 C. Boemann <cbo@boemann.dk>
- * Copyright (C) 2014-2015 Denis Kuplyakov <dener.kup@gmail.com>
+ * SPDX-FileCopyrightText: 2008 Girish Ramakrishnan <girish@forwardbias.in>
+ * SPDX-FileCopyrightText: 2009 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2008 Pierre Stirnweiss \pierre.stirnweiss_calligra@gadz.org>
+ * SPDX-FileCopyrightText: 2011-2012 C. Boemann <cbo@boemann.dk>
+ * SPDX-FileCopyrightText: 2014-2015 Denis Kuplyakov <dener.kup@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "KoTextDocument.h"
@@ -32,20 +19,20 @@
 
 #include <kundo2stack.h>
 
-#include "KoText.h"
-#include "KoTextEditor.h"
-#include "styles/KoStyleManager.h"
-#include "OdfTextTrackStyles.h"
-#include "KoTextRangeManager.h"
 #include "KoInlineTextObjectManager.h"
 #include "KoList.h"
 #include "KoOdfLineNumberingConfiguration.h"
+#include "KoText.h"
+#include "KoTextEditor.h"
+#include "KoTextRangeManager.h"
+#include "OdfTextTrackStyles.h"
 #include "changetracker/KoChangeTracker.h"
-#include <KoShapeController.h>
+#include "styles/KoStyleManager.h"
 #include <KoSectionModel.h>
+#include <KoShapeController.h>
 
 Q_DECLARE_METATYPE(QAbstractTextDocumentLayout::Selection)
-Q_DECLARE_METATYPE(QTextFrame*)
+Q_DECLARE_METATYPE(QTextFrame *)
 Q_DECLARE_METATYPE(QTextCharFormat)
 Q_DECLARE_METATYPE(QTextBlockFormat)
 
@@ -86,16 +73,14 @@ KoTextDocument::KoTextDocument(QPointer<QTextDocument> document)
     Q_ASSERT(m_document);
 }
 
-KoTextDocument::~KoTextDocument()
-{
-}
+KoTextDocument::~KoTextDocument() = default;
 
 QTextDocument *KoTextDocument::document() const
 {
     return m_document;
 }
 
-void KoTextDocument::setTextEditor (KoTextEditor* textEditor)
+void KoTextDocument::setTextEditor(KoTextEditor *textEditor)
 {
     Q_ASSERT(textEditor->document() == m_document);
 
@@ -104,7 +89,7 @@ void KoTextDocument::setTextEditor (KoTextEditor* textEditor)
     m_document->addResource(KoTextDocument::TextEditor, TextEditorURL, v);
 }
 
-KoTextEditor* KoTextDocument::textEditor() const
+KoTextEditor *KoTextDocument::textEditor() const
 {
     QVariant resource = m_document->resource(KoTextDocument::TextEditor, TextEditorURL);
     return resource.value<KoTextEditor *>();
@@ -153,9 +138,8 @@ KoChangeTracker *KoTextDocument::changeTracker() const
     QVariant resource = m_document->resource(KoTextDocument::ChangeTrackerResource, ChangeTrackerURL);
     if (resource.isValid()) {
         return resource.value<KoChangeTracker *>();
-    }
-    else {
-        return 0;
+    } else {
+        return nullptr;
     }
 }
 
@@ -171,9 +155,8 @@ KoShapeController *KoTextDocument::shapeController() const
     QVariant resource = m_document->resource(KoTextDocument::ShapeController, ShapeControllerUrl);
     if (resource.isValid()) {
         return resource.value<KoShapeController *>();
-    }
-    else {
-        return 0;
+    } else {
+        return nullptr;
     }
 }
 
@@ -187,8 +170,7 @@ void KoTextDocument::setLineNumberingConfiguration(KoOdfLineNumberingConfigurati
 
 KoOdfLineNumberingConfiguration *KoTextDocument::lineNumberingConfiguration() const
 {
-    return m_document->resource(KoTextDocument::LineNumberingConfiguration, LineNumberingConfigurationURL)
-            .value<KoOdfLineNumberingConfiguration*>();
+    return m_document->resource(KoTextDocument::LineNumberingConfiguration, LineNumberingConfigurationURL).value<KoOdfLineNumberingConfiguration *>();
 }
 
 void KoTextDocument::setHeadingList(KoList *headingList)
@@ -207,14 +189,14 @@ KoList *KoTextDocument::headingList() const
 void KoTextDocument::setUndoStack(KUndo2Stack *undoStack)
 {
     QVariant v;
-    v.setValue<void*>(undoStack);
+    v.setValue<void *>(undoStack);
     m_document->addResource(KoTextDocument::UndoStack, UndoStackURL, v);
 }
 
 KUndo2Stack *KoTextDocument::undoStack() const
 {
     QVariant resource = m_document->resource(KoTextDocument::UndoStack, UndoStackURL);
-    return static_cast<KUndo2Stack*>(resource.value<void*>());
+    return static_cast<KUndo2Stack *>(resource.value<void *>());
 }
 
 void KoTextDocument::setLists(const QList<KoList *> &lists)
@@ -227,7 +209,7 @@ void KoTextDocument::setLists(const QList<KoList *> &lists)
 QList<KoList *> KoTextDocument::lists() const
 {
     QVariant resource = m_document->resource(KoTextDocument::Lists, ListsURL);
-    return resource.value<QList<KoList *> >();
+    return resource.value<QList<KoList *>>();
 }
 
 void KoTextDocument::addList(KoList *list)
@@ -254,30 +236,30 @@ KoList *KoTextDocument::list(const QTextBlock &block) const
 {
     QTextList *textList = block.textList();
     if (!textList)
-        return 0;
+        return nullptr;
     return list(textList);
 }
 
 KoList *KoTextDocument::list(QTextList *textList) const
 {
     if (!textList) {
-        return 0;
+        return nullptr;
     }
     // FIXME: this is horrible.
-    foreach(KoList *l, lists()) {
+    foreach (KoList *l, lists()) {
         if (l->textLists().contains(textList))
             return l;
     }
-    return 0;
+    return nullptr;
 }
 
 KoList *KoTextDocument::list(KoListStyle::ListIdType listId) const
 {
-    foreach(KoList *l, lists()) {
+    foreach (KoList *l, lists()) {
         if (l->textListIds().contains(listId))
             return l;
     }
-    return 0;
+    return nullptr;
 }
 
 void KoTextDocument::clearText()
@@ -287,40 +269,40 @@ void KoTextDocument::clearText()
     cursor.removeSelectedText();
 }
 
-QVector< QAbstractTextDocumentLayout::Selection > KoTextDocument::selections() const
+QVector<QAbstractTextDocumentLayout::Selection> KoTextDocument::selections() const
 {
     QVariant resource = m_document->resource(KoTextDocument::Selections, SelectionsURL);
     QVariantList variants = resource.toList();
 
     QVector<QAbstractTextDocumentLayout::Selection> selections;
-    foreach(const QVariant &variant, variants) {
+    foreach (const QVariant &variant, variants) {
         selections.append(variant.value<QAbstractTextDocumentLayout::Selection>());
     }
 
     return selections;
 }
 
-void KoTextDocument::setSelections(const QVector< QAbstractTextDocumentLayout::Selection >& selections)
+void KoTextDocument::setSelections(const QVector<QAbstractTextDocumentLayout::Selection> &selections)
 {
     QVariantList variants;
-    foreach(const QAbstractTextDocumentLayout::Selection &selection, selections) {
+    foreach (const QAbstractTextDocumentLayout::Selection &selection, selections) {
         variants.append(QVariant::fromValue<QAbstractTextDocumentLayout::Selection>(selection));
     }
 
-    m_document->addResource(KoTextDocument::Selections, SelectionsURL, variants);
+    if (!variants.isEmpty()) {
+        m_document->addResource(KoTextDocument::Selections, SelectionsURL, variants);
+    }
 }
 
 KoInlineTextObjectManager *KoTextDocument::inlineTextObjectManager() const
 {
-    QVariant resource = m_document->resource(KoTextDocument::InlineTextManager,
-            InlineObjectTextManagerURL);
+    QVariant resource = m_document->resource(KoTextDocument::InlineTextManager, InlineObjectTextManagerURL);
     return resource.value<KoInlineTextObjectManager *>();
 }
 
 KoTextRangeManager *KoTextDocument::textRangeManager() const
 {
-    QVariant resource = m_document->resource(KoTextDocument::TextRangeManager,
-            TextRangeManagerURL);
+    QVariant resource = m_document->resource(KoTextDocument::TextRangeManager, TextRangeManagerURL);
     return resource.value<KoTextRangeManager *>();
 }
 
@@ -399,7 +381,7 @@ void KoTextDocument::setFrameBlockFormat(const QTextBlockFormat &format)
     m_document->addResource(KoTextDocument::FrameBlockFormat, FrameBlockFormatUrl, QVariant::fromValue(format));
 }
 
-KoSectionModel* KoTextDocument::sectionModel()
+KoSectionModel *KoTextDocument::sectionModel()
 {
     QVariant resource = m_document->resource(KoTextDocument::SectionModel, SectionModelUrl);
     if (!resource.isValid()) {
