@@ -1,87 +1,81 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006-2009 Thomas Zander <zander@kde.org>
- * Copyright (C) 2008 Thorsten Zachmann <zachmann@kde.org>
- * Copyright (C) 2008 Roopesh Chander <roop@forwardbias.in>
- * Copyright (C) 2008 Girish Ramakrishnan <girish@forwardbias.in>
- * Copyright (C) 2009 KO GmbH <cbo@kogmbh.com>
- * Copyright 2012 Friedrich W. H. Kossebau <kossebau@kde.org>
+ * SPDX-FileCopyrightText: 2006-2009 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2008 Thorsten Zachmann <zachmann@kde.org>
+ * SPDX-FileCopyrightText: 2008 Roopesh Chander <roop@forwardbias.in>
+ * SPDX-FileCopyrightText: 2008 Girish Ramakrishnan <girish@forwardbias.in>
+ * SPDX-FileCopyrightText: 2009 KO GmbH <cbo@kogmbh.com>
+ * SPDX-FileCopyrightText: 2012 Friedrich W. H. Kossebau <kossebau@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 #include "KoSectionStyle.h"
 
-#include <KoGenStyle.h>
 #include "Styles_p.h"
+#include <KoGenStyle.h>
 
+#include <QBuffer>
 #include <QTextFrame>
 #include <QTextFrameFormat>
-#include <QBuffer>
 
 #include <KoColumns.h>
-#include <KoUnit.h>
-#include <KoStyleStack.h>
 #include <KoOdfLoadingContext.h>
+#include <KoStyleStack.h>
+#include <KoUnit.h>
 #include <KoXmlNS.h>
 #include <KoXmlWriter.h>
 
 #include "TextDebug.h"
 
-
 Q_DECLARE_METATYPE(QVector<KoColumns::ColumnDatum>)
 
 class Q_DECL_HIDDEN KoSectionStyle::Private
 {
 public:
-    Private() : parentStyle(0) {}
-
-    ~Private() {
+    Private()
+        : parentStyle(nullptr)
+    {
     }
 
-    void setProperty(int key, const QVariant &value) {
+    ~Private() = default;
+
+    void setProperty(int key, const QVariant &value)
+    {
         stylesPrivate.add(key, value);
     }
-    int propertyInt(int key) const {
+    int propertyInt(int key) const
+    {
         QVariant variant = stylesPrivate.value(key);
         if (variant.isNull())
             return 0;
         return variant.toInt();
     }
-    bool propertyBoolean(int key) const {
+    bool propertyBoolean(int key) const
+    {
         QVariant variant = stylesPrivate.value(key);
         if (variant.isNull())
             return false;
         return variant.toBool();
     }
-    qreal propertyDouble(int key) const {
+    qreal propertyDouble(int key) const
+    {
         QVariant variant = stylesPrivate.value(key);
         if (variant.isNull())
             return 0.0;
         return variant.toDouble();
     }
-    QColor propertyColor(int key) const {
+    QColor propertyColor(int key) const
+    {
         QVariant variant = stylesPrivate.value(key);
         if (variant.isNull())
             return QColor();
         return variant.value<QColor>();
     }
-    QVector<KoColumns::ColumnDatum> propertyColumnData() const{
+    QVector<KoColumns::ColumnDatum> propertyColumnData() const
+    {
         QVariant variant = stylesPrivate.value(ColumnData);
         if (variant.isNull())
             return QVector<KoColumns::ColumnDatum>();
-        return variant.value<QVector<KoColumns::ColumnDatum> >();
+        return variant.value<QVector<KoColumns::ColumnDatum>>();
     }
 
     QString name;
@@ -90,13 +84,14 @@ public:
 };
 
 KoSectionStyle::KoSectionStyle(QObject *parent)
-        : QObject(parent), d(new Private())
+    : QObject(parent)
+    , d(new Private())
 {
 }
 
 KoSectionStyle::KoSectionStyle(const QTextFrameFormat &sectionFormat, QObject *parent)
-        : QObject(parent),
-        d(new Private())
+    : QObject(parent)
+    , d(new Private())
 {
     d->stylesPrivate = sectionFormat.properties();
 }
@@ -218,7 +213,7 @@ qreal KoSectionStyle::columnGapWidth() const
 
 void KoSectionStyle::setColumnData(const QVector<KoColumns::ColumnDatum> &columnData)
 {
-    setProperty(ColumnData, QVariant::fromValue<QVector<KoColumns::ColumnDatum> >(columnData));
+    setProperty(ColumnData, QVariant::fromValue<QVector<KoColumns::ColumnDatum>>(columnData));
 }
 
 QVector<KoColumns::ColumnDatum> KoSectionStyle::columnData() const
@@ -256,7 +251,7 @@ qreal KoSectionStyle::separatorWidth() const
     return d->propertyDouble(SeparatorWidth);
 }
 
-void KoSectionStyle::setSeparatorHeight( int separatorHeight)
+void KoSectionStyle::setSeparatorHeight(int separatorHeight)
 {
     setProperty(SeparatorHeight, separatorHeight);
 }
@@ -276,7 +271,6 @@ KoColumns::SeparatorVerticalAlignment KoSectionStyle::separatorVerticalAlignment
     return static_cast<KoColumns::SeparatorVerticalAlignment>(d->propertyInt(SeparatorVerticalAlignment));
 }
 
-
 KoSectionStyle *KoSectionStyle::parentStyle() const
 {
     return d->parentStyle;
@@ -292,7 +286,7 @@ void KoSectionStyle::setName(const QString &name)
     if (name == d->name)
         return;
     d->name = name;
-    emit nameChanged(name);
+    Q_EMIT nameChanged(name);
 }
 
 int KoSectionStyle::styleId() const
@@ -305,7 +299,6 @@ void KoSectionStyle::setStyleId(int id)
     setProperty(StyleId, id);
 }
 
-
 KoText::Direction KoSectionStyle::textProgressionDirection() const
 {
     return static_cast<KoText::Direction>(d->propertyInt(TextProgressionDirection));
@@ -348,15 +341,15 @@ void KoSectionStyle::loadOdf(const KoXmlElement *element, KoOdfLoadingContext &c
     context.styleStack().save();
     // Load all parents - only because we don't support inheritance.
     QString family = element->attributeNS(KoXmlNS::style, "family", "section");
-    context.addStyles(element, family.toLocal8Bit().constData());   // Load all parents - only because we don't support inheritance.
+    context.addStyles(element, family.toLocal8Bit().constData()); // Load all parents - only because we don't support inheritance.
 
-    context.styleStack().setTypeProperties("section");   // load all style attributes from "style:section-properties"
+    context.styleStack().setTypeProperties("section"); // load all style attributes from "style:section-properties"
 
     KoStyleStack &styleStack = context.styleStack();
 
     // in 1.6 this was defined at KoParagLayout::loadOasisParagLayout(KoParagLayout&, KoOasisContext&)
 
-    if (styleStack.hasProperty(KoXmlNS::style, "writing-mode")) {     // http://www.w3.org/TR/2004/WD-xsl11-20041216/#writing-mode
+    if (styleStack.hasProperty(KoXmlNS::style, "writing-mode")) { // http://www.w3.org/TR/2004/WD-xsl11-20041216/#writing-mode
         QString writingMode = styleStack.property(KoXmlNS::style, "writing-mode");
         setTextProgressionDirection(KoText::directionFromString(writingMode));
     }
@@ -369,7 +362,6 @@ void KoSectionStyle::loadOdf(const KoXmlElement *element, KoOdfLoadingContext &c
     if (hasMarginRight)
         setRightMargin(KoUnit::parseValue(styleStack.property(KoXmlNS::fo, "margin-right")));
 
-
     // The fo:background-color attribute specifies the background color of a paragraph.
     if (styleStack.hasProperty(KoXmlNS::fo, "background-color")) {
         const QString bgcolor = styleStack.property(KoXmlNS::fo, "background-color");
@@ -397,9 +389,9 @@ void KoSectionStyle::loadOdf(const KoXmlElement *element, KoOdfLoadingContext &c
             QVector<KoColumns::ColumnDatum> columnData;
 
             KoXmlElement columnElement;
-            forEachElement(columnElement, columns) {
-                if(columnElement.localName() != QLatin1String("column") ||
-                columnElement.namespaceURI() != KoXmlNS::style)
+            forEachElement(columnElement, columns)
+            {
+                if (columnElement.localName() != QLatin1String("column") || columnElement.namespaceURI() != KoXmlNS::style)
                     continue;
 
                 KoColumns::ColumnDatum datum;
@@ -417,13 +409,13 @@ void KoSectionStyle::loadOdf(const KoXmlElement *element, KoOdfLoadingContext &c
                 columnData.append(datum);
             }
 
-            if (! columnData.isEmpty()) {
+            if (!columnData.isEmpty()) {
                 setColumnData(columnData);
             }
         }
 
         KoXmlElement columnSep = KoXml::namedItemNS(columns, KoXmlNS::style, "column-sep");
-        if (! columnSep.isNull()) {
+        if (!columnSep.isNull()) {
             if (columnSep.hasAttributeNS(KoXmlNS::style, "style"))
                 setSeparatorStyle(KoColumns::parseSeparatorStyle(columnSep.attributeNS(KoXmlNS::style, "style")));
             if (columnSep.hasAttributeNS(KoXmlNS::style, "width"))
@@ -433,15 +425,13 @@ void KoSectionStyle::loadOdf(const KoXmlElement *element, KoOdfLoadingContext &c
             if (columnSep.hasAttributeNS(KoXmlNS::style, "color"))
                 setSeparatorColor(KoColumns::parseSeparatorColor(columnSep.attributeNS(KoXmlNS::style, "color")));
             if (columnSep.hasAttributeNS(KoXmlNS::style, "vertical-align"))
-                setSeparatorVerticalAlignment(
-                    KoColumns::parseSeparatorVerticalAlignment(columnSep.attributeNS(KoXmlNS::style, "vertical-align")));
+                setSeparatorVerticalAlignment(KoColumns::parseSeparatorVerticalAlignment(columnSep.attributeNS(KoXmlNS::style, "vertical-align")));
         }
     }
 
     styleStack.restore();
 }
 
-
 void KoSectionStyle::copyProperties(const KoSectionStyle *style)
 {
     d->stylesPrivate = style->d->stylesPrivate;
@@ -466,7 +456,6 @@ void KoSectionStyle::removeDuplicates(const KoSectionStyle &other)
     d->stylesPrivate.removeDuplicates(other.d->stylesPrivate);
 }
 
-
 void KoSectionStyle::saveOdf(KoGenStyle &style)
 {
     // only custom style have a displayname. automatic styles don't have a name set.
@@ -477,7 +466,7 @@ void KoSectionStyle::saveOdf(KoGenStyle &style)
     QList<int> columnsKeys;
 
     QList<int> keys = d->stylesPrivate.keys();
-    foreach(int key, keys) {
+    foreach (int key, keys) {
         switch (key) {
         case KoSectionStyle::TextProgressionDirection: {
             int directionValue = 0;
@@ -527,7 +516,7 @@ void KoSectionStyle::saveOdf(KoGenStyle &style)
     if (!columnsKeys.isEmpty()) {
         QBuffer buffer;
         buffer.open(QIODevice::WriteOnly);
-        KoXmlWriter elementWriter(&buffer);    // TODO pass indentation level
+        KoXmlWriter elementWriter(&buffer); // TODO pass indentation level
 
         elementWriter.startElement("style:columns");
         // seems these two are mandatory
@@ -538,27 +527,22 @@ void KoSectionStyle::saveOdf(KoGenStyle &style)
 
         if (!columnsKeys.isEmpty()) {
             elementWriter.startElement("style:column-sep");
-            foreach(int key, columnsKeys) {
+            foreach (int key, columnsKeys) {
                 switch (key) {
                 case SeparatorStyle:
-                    elementWriter.addAttribute("style:style",
-                                               KoColumns::separatorStyleString(separatorStyle()));
+                    elementWriter.addAttribute("style:style", KoColumns::separatorStyleString(separatorStyle()));
                     break;
                 case SeparatorColor:
-                    elementWriter.addAttribute("style:color",
-                                               separatorColor().name());
+                    elementWriter.addAttribute("style:color", separatorColor().name());
                     break;
                 case SeparatorVerticalAlignment:
-                    elementWriter.addAttribute("style:vertical-align",
-                                               KoColumns::separatorVerticalAlignmentString(separatorVerticalAlignment()));
+                    elementWriter.addAttribute("style:vertical-align", KoColumns::separatorVerticalAlignmentString(separatorVerticalAlignment()));
                     break;
                 case SeparatorWidth:
-                    elementWriter.addAttributePt("style:width",
-                                                 separatorWidth());
+                    elementWriter.addAttributePt("style:width", separatorWidth());
                     break;
                 case SeparatorHeight:
-                    elementWriter.addAttribute("style:height",
-                                               QString::fromLatin1("%1%").arg(separatorHeight()));
+                    elementWriter.addAttribute("style:height", QString::fromLatin1("%1%").arg(separatorHeight()));
                     break;
                 }
             }
