@@ -1,77 +1,65 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006, 2009 Thomas Zander <zander@kde.org>
- * Copyright (C) 2007 Sebastian Sauer <mail@dipe.org>
- * Copyright (C) 2007 Pierre Ducroquet <pinaraf@gmail.com>
- * Copyright (C) 2008 Girish Ramakrishnan <girish@forwardbias.in>
- * Copyright (C) 2009 KO GmbH <cbo@kogmbh.com>
+ * SPDX-FileCopyrightText: 2006, 2009 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2007 Sebastian Sauer <mail@dipe.org>
+ * SPDX-FileCopyrightText: 2007 Pierre Ducroquet <pinaraf@gmail.com>
+ * SPDX-FileCopyrightText: 2008 Girish Ramakrishnan <girish@forwardbias.in>
+ * SPDX-FileCopyrightText: 2009 KO GmbH <cbo@kogmbh.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "KoStyleManager.h"
 
-#include "KoParagraphStyle.h"
 #include "KoCharacterStyle.h"
-#include "KoListStyle.h"
 #include "KoListLevelProperties.h"
-#include "KoTableStyle.h"
+#include "KoListStyle.h"
+#include "KoParagraphStyle.h"
+#include "KoSectionStyle.h"
+#include "KoTableCellStyle.h"
 #include "KoTableColumnStyle.h"
 #include "KoTableRowStyle.h"
-#include "KoTableCellStyle.h"
-#include "KoSectionStyle.h"
-#include "commands/ChangeStylesMacroCommand.h"
+#include "KoTableStyle.h"
 #include "KoTextDocument.h"
 #include "KoTextTableTemplate.h"
+#include "commands/ChangeStylesMacroCommand.h"
 
-#include <KoOdfBibliographyConfiguration.h>
 #include <KoGenStyle.h>
 #include <KoGenStyles.h>
+#include <KoOdfBibliographyConfiguration.h>
+#include <KoOdfNumberDefinition.h>
 #include <KoShapeSavingContext.h>
 #include <KoTextSharedSavingData.h>
 #include <KoXmlWriter.h>
-#include <KoOdfNumberDefinition.h>
 
 #include <kundo2stack.h>
 
-#include <QUrl>
-#include <QBuffer>
 #include "TextDebug.h"
-#include <klocalizedstring.h>
+#include <KLocalizedString>
+#include <QBuffer>
+#include <QUrl>
 
 class Q_DECL_HIDDEN KoStyleManager::Private
 {
 public:
     Private()
-        : defaultCharacterStyle(0)
-        , defaultParagraphStyle(0)
-        , defaultListStyle(0)
-        , defaultOutlineStyle(0)
-        , outlineStyle(0)
+        : defaultCharacterStyle(nullptr)
+        , defaultParagraphStyle(nullptr)
+        , defaultListStyle(nullptr)
+        , defaultOutlineStyle(nullptr)
+        , outlineStyle(nullptr)
     {
     }
 
-    ~Private() {
+    ~Private()
+    {
         qDeleteAll(automaticListStyles);
     }
 
     static int s_stylesNumber; // For giving out unique numbers to the styles for referencing
 
-    QHash<int, KoCharacterStyle*> charStyles;
-    QHash<int, KoParagraphStyle*> paragStyles;
-    QHash<int, KoListStyle*> listStyles;
+    QHash<int, KoCharacterStyle *> charStyles;
+    QHash<int, KoParagraphStyle *> paragStyles;
+    QHash<int, KoListStyle *> listStyles;
     QHash<int, KoListStyle *> automaticListStyles;
     QHash<int, KoTableStyle *> tableStyles;
     QHash<int, KoTableColumnStyle *> tableColumnStyles;
@@ -100,7 +88,8 @@ public:
 int KoStyleManager::Private::s_stylesNumber = 100;
 
 KoStyleManager::KoStyleManager(QObject *parent)
-        : QObject(parent), d(new Private())
+    : QObject(parent)
+    , d(new Private())
 {
     d->defaultCharacterStyle = new KoCharacterStyle(this);
     d->defaultCharacterStyle->setName(i18n("Default"));
@@ -112,7 +101,7 @@ KoStyleManager::KoStyleManager(QObject *parent)
 
     add(d->defaultParagraphStyle);
 
-    //TODO: also use the defaultstyles.xml mechanism. see KoOdfLoadingContext and KoTextSharedLoadingData
+    // TODO: also use the defaultstyles.xml mechanism. see KoOdfLoadingContext and KoTextSharedLoadingData
     d->defaultListStyle = new KoListStyle(this);
     const int margin = 10; // we specify the margin for the default list style(Note: Even ChangeListCommand has this value)
     const int maxListLevel = 10;
@@ -125,14 +114,14 @@ KoStyleManager::KoStyleManager(QObject *parent)
         llp.setListItemSuffix(".");
         llp.setAlignmentMode(true);
         llp.setLabelFollowedBy(KoListStyle::ListTab);
-        llp.setTabStopPosition(margin*(level+2));
-        llp.setMargin(margin*(level+1));
+        llp.setTabStopPosition(margin * (level + 2));
+        llp.setMargin(margin * (level + 1));
         llp.setTextIndent(margin);
 
         d->defaultListStyle->setLevelProperties(llp);
     }
 
-    //default styles for ToCs
+    // default styles for ToCs
     int maxOutLineLevel = 10;
     for (int outlineLevel = 1; outlineLevel <= maxOutLineLevel; outlineLevel++) {
         KoParagraphStyle *style = new KoParagraphStyle();
@@ -181,7 +170,7 @@ KoStyleManager::KoStyleManager(QObject *parent)
     add(cStyle);
     d->endNotesConfiguration->setCitationTextStyle(cStyle);
 
-    d->bibliographyConfiguration = 0;
+    d->bibliographyConfiguration = nullptr;
 }
 
 KoStyleManager::~KoStyleManager()
@@ -206,12 +195,11 @@ void KoStyleManager::saveOdfDefaultStyles(KoShapeSavingContext &context)
     if (!tstyle.isEmpty()) {
         context.mainStyles().insert(tstyle);
     }
-
 }
 
 void KoStyleManager::saveReferredStylesToOdf(KoShapeSavingContext &context)
 {
-    KoTextSharedSavingData *textSharedSavingData = 0;
+    KoTextSharedSavingData *textSharedSavingData = nullptr;
     // we need KoTextSharedSavingData, so create it if not already there
     if (!(textSharedSavingData = dynamic_cast<KoTextSharedSavingData *>(context.sharedData(KOTEXT_SHARED_SAVING_ID)))) {
         textSharedSavingData = new KoTextSharedSavingData;
@@ -219,12 +207,12 @@ void KoStyleManager::saveReferredStylesToOdf(KoShapeSavingContext &context)
     }
 
     QSet<KoParagraphStyle *> savedParaStyles;
-    QVector<KoGenStyles::NamedStyle>  namedStyles = context.mainStyles().styles(KoGenStyle::ParagraphAutoStyle);
+    QVector<KoGenStyles::NamedStyle> namedStyles = context.mainStyles().styles(KoGenStyle::ParagraphAutoStyle);
     namedStyles += context.mainStyles().styles(KoGenStyle::ParagraphStyle);
-    foreach(const KoGenStyles::NamedStyle &namedStyle, namedStyles) {
-        KoParagraphStyle *paraStyle = 0;
+    foreach (const KoGenStyles::NamedStyle &namedStyle, namedStyles) {
+        KoParagraphStyle *paraStyle = nullptr;
         // first find the parent style
-        foreach(KoParagraphStyle *p, d->paragStyles) {
+        foreach (KoParagraphStyle *p, d->paragStyles) {
             QString name(QString(QUrl::toPercentEncoding(p->name(), "", " ")).replace('%', '_'));
 
             if (name == namedStyle.style->parentName()) {
@@ -249,10 +237,10 @@ void KoStyleManager::saveReferredStylesToOdf(KoShapeSavingContext &context)
     namedStyles = context.mainStyles().styles(KoGenStyle::TextAutoStyle);
     namedStyles += context.mainStyles().styles(KoGenStyle::TextStyle);
 
-    foreach(const KoGenStyles::NamedStyle &namedStyle, namedStyles) {
-        KoCharacterStyle *charStyle = 0;
+    foreach (const KoGenStyles::NamedStyle &namedStyle, namedStyles) {
+        KoCharacterStyle *charStyle = nullptr;
         // first find the parent style
-        foreach(KoCharacterStyle *c, d->charStyles) {
+        foreach (KoCharacterStyle *c, d->charStyles) {
             QString name(QString(QUrl::toPercentEncoding(c->name(), "", " ")).replace('%', '_'));
 
             if (name == namedStyle.style->parentName()) {
@@ -262,7 +250,7 @@ void KoStyleManager::saveReferredStylesToOdf(KoShapeSavingContext &context)
         }
         // next save it and also parents to the parent
         while (charStyle && !savedCharStyles.contains(charStyle)) {
-           QString name(QString(QUrl::toPercentEncoding(charStyle->name(), "", " ")).replace('%', '_'));
+            QString name(QString(QUrl::toPercentEncoding(charStyle->name(), "", " ")).replace('%', '_'));
             KoGenStyle style(KoGenStyle::TextStyle, "text");
             charStyle->saveOdf(style);
             QString newName = context.mainStyles().insert(style, name, KoGenStyles::DontAddNumberToName);
@@ -276,7 +264,7 @@ void KoStyleManager::saveReferredStylesToOdf(KoShapeSavingContext &context)
 
 void KoStyleManager::saveOdf(KoShapeSavingContext &context)
 {
-    KoTextSharedSavingData *textSharedSavingData = 0;
+    KoTextSharedSavingData *textSharedSavingData = nullptr;
     if (!(textSharedSavingData = dynamic_cast<KoTextSharedSavingData *>(context.sharedData(KOTEXT_SHARED_SAVING_ID)))) {
         textSharedSavingData = new KoTextSharedSavingData;
         context.addSharedData(KOTEXT_SHARED_SAVING_ID, textSharedSavingData);
@@ -285,8 +273,8 @@ void KoStyleManager::saveOdf(KoShapeSavingContext &context)
     saveOdfDefaultStyles(context);
 
     // don't save character styles that are already saved as part of a paragraph style
-    QHash<KoParagraphStyle*, QString> savedNames;
-    foreach(KoParagraphStyle *paragraphStyle, d->paragStyles) {
+    QHash<KoParagraphStyle *, QString> savedNames;
+    foreach (KoParagraphStyle *paragraphStyle, d->paragStyles) {
         if (paragraphStyle == d->defaultParagraphStyle)
             continue;
 
@@ -302,7 +290,7 @@ void KoStyleManager::saveOdf(KoShapeSavingContext &context)
         savedNames.insert(paragraphStyle, newName);
     }
 
-    foreach(KoParagraphStyle *p, d->paragStyles) {
+    foreach (KoParagraphStyle *p, d->paragStyles) {
         if (p->nextStyle() > 0 && savedNames.contains(p) && paragraphStyle(p->nextStyle())) {
             KoParagraphStyle *next = paragraphStyle(p->nextStyle());
             if (next == p) // this is the default
@@ -311,7 +299,7 @@ void KoStyleManager::saveOdf(KoShapeSavingContext &context)
         }
     }
 
-    foreach(KoCharacterStyle *characterStyle, d->charStyles) {
+    foreach (KoCharacterStyle *characterStyle, d->charStyles) {
         if (characterStyle == d->defaultCharacterStyle)
             continue;
 
@@ -326,7 +314,7 @@ void KoStyleManager::saveOdf(KoShapeSavingContext &context)
         textSharedSavingData->setStyleName(characterStyle->styleId(), newName);
     }
 
-    foreach(KoListStyle *listStyle, d->listStyles) {
+    foreach (KoListStyle *listStyle, d->listStyles) {
         if (listStyle == d->defaultListStyle)
             continue;
         QString name(QString(QUrl::toPercentEncoding(listStyle->name(), "", " ")).replace('%', '_'));
@@ -340,40 +328,40 @@ void KoStyleManager::saveOdf(KoShapeSavingContext &context)
         textSharedSavingData->setStyleName(listStyle->styleId(), newName);
     }
 
-    foreach(KoTableStyle *tableStyle, d->tableStyles) {
+    foreach (KoTableStyle *tableStyle, d->tableStyles) {
         QString name(QString(QUrl::toPercentEncoding(tableStyle->name(), "", " ")).replace('%', '_'));
         if (name.isEmpty())
-            name = 'T'; //TODO is this correct?
+            name = 'T'; // TODO is this correct?
 
         KoGenStyle style(KoGenStyle::TableStyle, "table");
         tableStyle->saveOdf(style);
         context.mainStyles().insert(style, name, KoGenStyles::DontAddNumberToName);
     }
 
-    foreach(KoTableColumnStyle *tableColumnStyle, d->tableColumnStyles) {
+    foreach (KoTableColumnStyle *tableColumnStyle, d->tableColumnStyles) {
         QString name(QString(QUrl::toPercentEncoding(tableColumnStyle->name(), "", " ")).replace('%', '_'));
         if (name.isEmpty())
-            name = 'T'; //TODO is this correct?
+            name = 'T'; // TODO is this correct?
 
         KoGenStyle style(KoGenStyle::TableColumnStyle, "table-column");
         tableColumnStyle->saveOdf(style);
         context.mainStyles().insert(style, name, KoGenStyles::DontAddNumberToName);
     }
 
-    foreach(KoTableRowStyle *tableRowStyle, d->tableRowStyles) {
+    foreach (KoTableRowStyle *tableRowStyle, d->tableRowStyles) {
         QString name(QString(QUrl::toPercentEncoding(tableRowStyle->name(), "", " ")).replace('%', '_'));
         if (name.isEmpty())
-            name = 'T'; //TODO is this correct?
+            name = 'T'; // TODO is this correct?
 
         KoGenStyle style(KoGenStyle::TableRowStyle, "table-row");
         tableRowStyle->saveOdf(style);
         context.mainStyles().insert(style, name, KoGenStyles::DontAddNumberToName);
     }
 
-    foreach(KoTableCellStyle *tableCellStyle, d->tableCellStyles) {
+    foreach (KoTableCellStyle *tableCellStyle, d->tableCellStyles) {
         QString name(QString(QUrl::toPercentEncoding(tableCellStyle->name(), "", " ")).replace('%', '_'));
         if (name.isEmpty())
-            name = "T."; //TODO is this correct?
+            name = "T."; // TODO is this correct?
 
         KoGenStyle style(KoGenStyle::TableCellStyle, "table-cell");
         tableCellStyle->saveOdf(style, context);
@@ -381,17 +369,17 @@ void KoStyleManager::saveOdf(KoShapeSavingContext &context)
         textSharedSavingData->setStyleName(tableCellStyle->styleId(), newName);
     }
 
-    foreach(KoSectionStyle *sectionStyle, d->sectionStyles) {
+    foreach (KoSectionStyle *sectionStyle, d->sectionStyles) {
         QString name(QString(QUrl::toPercentEncoding(sectionStyle->name(), "", " ")).replace('%', '_'));
         if (name.isEmpty())
-            name = "T."; //TODO is this correct?
+            name = "T."; // TODO is this correct?
 
         KoGenStyle style(KoGenStyle::SectionStyle, "section");
         sectionStyle->saveOdf(style);
         context.mainStyles().insert(style, name, KoGenStyles::DontAddNumberToName);
     }
 
-    //save note configuration in styles.xml
+    // save note configuration in styles.xml
     if (d->footNotesConfiguration) {
         QBuffer xmlBufferFootNote;
         KoXmlWriter xmlWriter(&xmlBufferFootNote);
@@ -423,7 +411,7 @@ void KoStyleManager::saveOdf(KoShapeSavingContext &context)
         context.mainStyles().insert(style, name, KoGenStyles::DontAddNumberToName);
     }
 
-    foreach(KoTextTableTemplate *textTableTemplate, d->tableTemplates) {
+    foreach (KoTextTableTemplate *textTableTemplate, d->tableTemplates) {
         QBuffer xmlBufferTableTemplate;
         KoXmlWriter xmlWriter(&xmlBufferTableTemplate);
         textTableTemplate->saveOdf(&xmlWriter, textSharedSavingData);
@@ -443,15 +431,15 @@ void KoStyleManager::add(KoCharacterStyle *style)
     style->setStyleId(d->s_stylesNumber);
     d->charStyles.insert(d->s_stylesNumber, style);
 
-    if (style != defaultCharacterStyle()) { //defaultStyle should not be user visible
+    if (style != defaultCharacterStyle()) { // defaultStyle should not be user visible
         if (style->isApplied() && !d->m_usedCharacterStyles.contains(d->s_stylesNumber)) {
             d->m_usedCharacterStyles.append(d->s_stylesNumber);
         }
-        connect(style, SIGNAL(styleApplied(const KoCharacterStyle*)), this, SLOT(slotAppliedStyle(const KoCharacterStyle*)));
+        connect(style, &KoCharacterStyle::styleApplied, this, &KoStyleManager::slotAppliedCharacterStyle);
     }
 
     ++d->s_stylesNumber;
-    emit styleAdded(style);
+    Q_EMIT characterStyleAdded(style);
 }
 
 void KoStyleManager::add(KoParagraphStyle *style)
@@ -475,15 +463,15 @@ void KoStyleManager::add(KoParagraphStyle *style)
             add(root);
     }
 
-    if (style != defaultParagraphStyle()) { //defaultStyle should not be user visible
+    if (style != defaultParagraphStyle()) { // defaultStyle should not be user visible
         if (style->isApplied() && !d->m_usedParagraphStyles.contains(d->s_stylesNumber)) {
             d->m_usedParagraphStyles.append(d->s_stylesNumber);
         }
-        connect(style, SIGNAL(styleApplied(const KoParagraphStyle*)), this, SLOT(slotAppliedStyle(const KoParagraphStyle*)));
+        connect(style, &KoParagraphStyle::styleApplied, this, &KoStyleManager::slotAppliedParagraphStyle);
     }
 
     ++d->s_stylesNumber;
-    emit styleAdded(style);
+    Q_EMIT paragraphStyleAdded(style);
 }
 
 void KoStyleManager::add(KoListStyle *style)
@@ -495,7 +483,7 @@ void KoStyleManager::add(KoListStyle *style)
     d->listStyles.insert(d->s_stylesNumber, style);
 
     ++d->s_stylesNumber;
-    emit styleAdded(style);
+    Q_EMIT listStyleAdded(style);
 }
 
 void KoStyleManager::addAutomaticListStyle(KoListStyle *style)
@@ -515,7 +503,7 @@ void KoStyleManager::add(KoTableStyle *style)
     style->setStyleId(d->s_stylesNumber);
     d->tableStyles.insert(d->s_stylesNumber, style);
     ++d->s_stylesNumber;
-    emit styleAdded(style);
+    Q_EMIT tableStyleAdded(style);
 }
 
 void KoStyleManager::add(KoTableColumnStyle *style)
@@ -525,7 +513,7 @@ void KoStyleManager::add(KoTableColumnStyle *style)
     style->setStyleId(d->s_stylesNumber);
     d->tableColumnStyles.insert(d->s_stylesNumber, style);
     ++d->s_stylesNumber;
-    emit styleAdded(style);
+    Q_EMIT tableColumnStyleAdded(style);
 }
 
 void KoStyleManager::add(KoTableRowStyle *style)
@@ -535,7 +523,7 @@ void KoStyleManager::add(KoTableRowStyle *style)
     style->setStyleId(d->s_stylesNumber);
     d->tableRowStyles.insert(d->s_stylesNumber, style);
     ++d->s_stylesNumber;
-    emit styleAdded(style);
+    Q_EMIT tableRowStyleAdded(style);
 }
 
 void KoStyleManager::add(KoTableCellStyle *style)
@@ -546,7 +534,7 @@ void KoStyleManager::add(KoTableCellStyle *style)
     style->setStyleId(d->s_stylesNumber);
     d->tableCellStyles.insert(d->s_stylesNumber, style);
     ++d->s_stylesNumber;
-    emit styleAdded(style);
+    Q_EMIT tableCellStyleAdded(style);
 }
 
 void KoStyleManager::add(KoSectionStyle *style)
@@ -557,7 +545,7 @@ void KoStyleManager::add(KoSectionStyle *style)
     style->setStyleId(d->s_stylesNumber);
     d->sectionStyles.insert(d->s_stylesNumber, style);
     ++d->s_stylesNumber;
-    emit styleAdded(style);
+    Q_EMIT sectionStyleAdded(style);
 }
 
 void KoStyleManager::add(KoTextTableTemplate *tableTemplate)
@@ -573,16 +561,16 @@ void KoStyleManager::add(KoTextTableTemplate *tableTemplate)
     ++d->s_stylesNumber;
 }
 
-void KoStyleManager::slotAppliedStyle(const KoParagraphStyle *style)
+void KoStyleManager::slotAppliedParagraphStyle(const KoParagraphStyle *style)
 {
     d->m_usedParagraphStyles.append(style->styleId());
-    emit styleApplied(style);
+    Q_EMIT paragraphStyleApplied(style);
 }
 
-void KoStyleManager::slotAppliedStyle(const KoCharacterStyle *style)
+void KoStyleManager::slotAppliedCharacterStyle(const KoCharacterStyle *style)
 {
     d->m_usedCharacterStyles.append(style->styleId());
-    emit styleApplied(style);
+    Q_EMIT characterStyleApplied(style);
 }
 
 void KoStyleManager::setNotesConfiguration(KoOdfNotesConfiguration *notesConfiguration)
@@ -607,8 +595,9 @@ void KoStyleManager::remove(KoCharacterStyle *style)
         return;
     }
 
-    if (d->charStyles.remove(style->styleId()))
-        emit styleRemoved(style);
+    if (d->charStyles.remove(style->styleId())) {
+        Q_EMIT characterStyleRemoved(style);
+    }
 }
 
 void KoStyleManager::remove(KoParagraphStyle *style)
@@ -617,8 +606,9 @@ void KoStyleManager::remove(KoParagraphStyle *style)
         return;
     }
 
-    if (d->paragStyles.remove(style->styleId()))
-        emit styleRemoved(style);
+    if (d->paragStyles.remove(style->styleId())) {
+        Q_EMIT paragraphStyleRemoved(style);
+    }
 }
 
 void KoStyleManager::remove(KoListStyle *style)
@@ -627,8 +617,9 @@ void KoStyleManager::remove(KoListStyle *style)
         return;
     }
 
-    if (d->listStyles.remove(style->styleId()))
-        emit styleRemoved(style);
+    if (d->listStyles.remove(style->styleId())) {
+        Q_EMIT listStyleRemoved(style);
+    }
 }
 
 void KoStyleManager::remove(KoTableStyle *style)
@@ -637,8 +628,9 @@ void KoStyleManager::remove(KoTableStyle *style)
         return;
     }
 
-    if (d->tableStyles.remove(style->styleId()))
-        emit styleRemoved(style);
+    if (d->tableStyles.remove(style->styleId())) {
+        Q_EMIT tableStyleRemoved(style);
+    }
 }
 
 void KoStyleManager::remove(KoTableColumnStyle *style)
@@ -647,8 +639,9 @@ void KoStyleManager::remove(KoTableColumnStyle *style)
         return;
     }
 
-    if (d->tableColumnStyles.remove(style->styleId()))
-        emit styleRemoved(style);
+    if (d->tableColumnStyles.remove(style->styleId())) {
+        Q_EMIT tableColumnStyleRemoved(style);
+    }
 }
 
 void KoStyleManager::remove(KoTableRowStyle *style)
@@ -657,8 +650,9 @@ void KoStyleManager::remove(KoTableRowStyle *style)
         return;
     }
 
-    if (d->tableRowStyles.remove(style->styleId()))
-        emit styleRemoved(style);
+    if (d->tableRowStyles.remove(style->styleId())) {
+        Q_EMIT tableRowStyleRemoved(style);
+    }
 }
 
 void KoStyleManager::remove(KoTableCellStyle *style)
@@ -667,8 +661,9 @@ void KoStyleManager::remove(KoTableCellStyle *style)
         return;
     }
 
-    if (d->tableCellStyles.remove(style->styleId()))
-        emit styleRemoved(style);
+    if (d->tableCellStyles.remove(style->styleId())) {
+        Q_EMIT tableCellStyleRemoved(style);
+    }
 }
 
 void KoStyleManager::remove(KoSectionStyle *style)
@@ -677,8 +672,9 @@ void KoStyleManager::remove(KoSectionStyle *style)
         return;
     }
 
-    if (d->sectionStyles.remove(style->styleId()))
-        emit styleRemoved(style);
+    if (d->sectionStyles.remove(style->styleId())) {
+        Q_EMIT sectionStyleRemoved(style);
+    }
 }
 
 void KoStyleManager::alteredStyle(const KoParagraphStyle *newStyle)
@@ -694,12 +690,12 @@ void KoStyleManager::alteredStyle(const KoParagraphStyle *newStyle)
         return;
     }
     KoParagraphStyle *style = paragraphStyle(id);
-    emit styleHasChanged(id, style, newStyle);
+    Q_EMIT paragraphStyleHasChanged(id, style, newStyle);
 
     // check if anyone that uses 'style' as a parent needs to be flagged as changed as well.
-    foreach(const KoParagraphStyle *ps, d->paragStyles) {
+    foreach (const KoParagraphStyle *ps, d->paragStyles) {
         if (ps->parentStyle() == style)
-            alteredStyle(ps); //since it's our own copy it will only be flagged
+            alteredStyle(ps); // since it's our own copy it will only be flagged
     }
 }
 
@@ -716,12 +712,12 @@ void KoStyleManager::alteredStyle(const KoCharacterStyle *newStyle)
         return;
     }
     KoCharacterStyle *style = characterStyle(id);
-    emit styleHasChanged(id, style, newStyle);
+    Q_EMIT characterStyleHasChanged(id, style, newStyle);
 
     // check if anyone that uses 'style' as a parent needs to be flagged as changed as well.
-    foreach(const KoCharacterStyle *cs, d->charStyles) {
+    foreach (const KoCharacterStyle *cs, d->charStyles) {
         if (cs->parentStyle() == style)
-            alteredStyle(cs); //since it's our own copy it will only be flagged
+            alteredStyle(cs); // since it's our own copy it will only be flagged
     }
 }
 
@@ -737,7 +733,7 @@ void KoStyleManager::alteredStyle(const KoListStyle *style)
         warnText << "alteredStyle received from a non registered style!";
         return;
     }
-    emit styleHasChanged(id);
+    Q_EMIT styleHasChanged(id);
 }
 
 void KoStyleManager::alteredStyle(const KoTableStyle *style)
@@ -752,7 +748,7 @@ void KoStyleManager::alteredStyle(const KoTableStyle *style)
         warnText << "alteredStyle received from a non registered style!";
         return;
     }
-    emit styleHasChanged(id);
+    Q_EMIT styleHasChanged(id);
 }
 
 void KoStyleManager::alteredStyle(const KoTableColumnStyle *style)
@@ -767,7 +763,7 @@ void KoStyleManager::alteredStyle(const KoTableColumnStyle *style)
         warnText << "alteredStyle received from a non registered style!";
         return;
     }
-    emit styleHasChanged(id);
+    Q_EMIT styleHasChanged(id);
 }
 
 void KoStyleManager::alteredStyle(const KoTableRowStyle *style)
@@ -782,7 +778,7 @@ void KoStyleManager::alteredStyle(const KoTableRowStyle *style)
         warnText << "alteredStyle received from a non registered style!";
         return;
     }
-    emit styleHasChanged(id);
+    Q_EMIT styleHasChanged(id);
 }
 
 void KoStyleManager::alteredStyle(const KoTableCellStyle *style)
@@ -797,7 +793,7 @@ void KoStyleManager::alteredStyle(const KoTableCellStyle *style)
         warnText << "alteredStyle received from a non registered style!";
         return;
     }
-    emit styleHasChanged(id);
+    Q_EMIT styleHasChanged(id);
 }
 
 void KoStyleManager::alteredStyle(const KoSectionStyle *style)
@@ -808,18 +804,17 @@ void KoStyleManager::alteredStyle(const KoSectionStyle *style)
         warnText << "alteredStyle received from a non registered style!";
         return;
     }
-    emit styleHasChanged(id);
+    Q_EMIT styleHasChanged(id);
 }
 
-
 void KoStyleManager::beginEdit()
 {
-    emit editHasBegun();
+    Q_EMIT editHasBegun();
 }
 
 void KoStyleManager::endEdit()
 {
-    emit editHasEnded();
+    Q_EMIT editHasEnded();
 }
 
 KoCharacterStyle *KoStyleManager::characterStyle(int id) const
@@ -848,8 +843,7 @@ KoListStyle *KoStyleManager::listStyle(int id, bool *automatic) const
 
     if (style) {
         *automatic = true;
-    }
-    else {
+    } else {
         // *automatic is unchanged
     }
     return style;
@@ -882,74 +876,74 @@ KoSectionStyle *KoStyleManager::sectionStyle(int id) const
 
 KoCharacterStyle *KoStyleManager::characterStyle(const QString &name) const
 {
-    foreach(KoCharacterStyle *style, d->charStyles) {
+    foreach (KoCharacterStyle *style, d->charStyles) {
         if (style->name() == name)
             return style;
     }
-    return 0;
+    return nullptr;
 }
 
 KoParagraphStyle *KoStyleManager::paragraphStyle(const QString &name) const
 {
-    foreach(KoParagraphStyle *style, d->paragStyles) {
+    foreach (KoParagraphStyle *style, d->paragStyles) {
         if (style->name() == name)
             return style;
     }
-    return 0;
+    return nullptr;
 }
 
 KoListStyle *KoStyleManager::listStyle(const QString &name) const
 {
-    foreach(KoListStyle *style, d->listStyles) {
+    foreach (KoListStyle *style, d->listStyles) {
         if (style->name() == name)
             return style;
     }
-    return 0;
+    return nullptr;
 }
 
 KoTableStyle *KoStyleManager::tableStyle(const QString &name) const
 {
-    foreach(KoTableStyle *style, d->tableStyles) {
+    foreach (KoTableStyle *style, d->tableStyles) {
         if (style->name() == name)
             return style;
     }
-    return 0;
+    return nullptr;
 }
 
 KoTableColumnStyle *KoStyleManager::tableColumnStyle(const QString &name) const
 {
-    foreach(KoTableColumnStyle *style, d->tableColumnStyles) {
+    foreach (KoTableColumnStyle *style, d->tableColumnStyles) {
         if (style->name() == name)
             return style;
     }
-    return 0;
+    return nullptr;
 }
 
 KoTableRowStyle *KoStyleManager::tableRowStyle(const QString &name) const
 {
-    foreach(KoTableRowStyle *style, d->tableRowStyles) {
+    foreach (KoTableRowStyle *style, d->tableRowStyles) {
         if (style->name() == name)
             return style;
     }
-    return 0;
+    return nullptr;
 }
 
 KoTableCellStyle *KoStyleManager::tableCellStyle(const QString &name) const
 {
-    foreach(KoTableCellStyle *style, d->tableCellStyles) {
+    foreach (KoTableCellStyle *style, d->tableCellStyles) {
         if (style->name() == name)
             return style;
     }
-    return 0;
+    return nullptr;
 }
 
 KoSectionStyle *KoStyleManager::sectionStyle(const QString &name) const
 {
-    foreach(KoSectionStyle *style, d->sectionStyles) {
+    foreach (KoSectionStyle *style, d->sectionStyles) {
         if (style->name() == name)
             return style;
     }
-    return 0;
+    return nullptr;
 }
 
 KoOdfNotesConfiguration *KoStyleManager::notesConfiguration(KoOdfNotesConfiguration::NoteClass noteClass) const
@@ -959,7 +953,7 @@ KoOdfNotesConfiguration *KoStyleManager::notesConfiguration(KoOdfNotesConfigurat
     } else if (noteClass == KoOdfNotesConfiguration::Footnote) {
         return d->footNotesConfiguration;
     } else {
-        return 0;
+        return nullptr;
     }
 }
 
@@ -1005,7 +999,7 @@ KoListStyle *KoStyleManager::defaultOutlineStyle() const
     return d->defaultOutlineStyle;
 }
 
-void KoStyleManager::setOutlineStyle(KoListStyle* listStyle)
+void KoStyleManager::setOutlineStyle(KoListStyle *listStyle)
 {
     if (d->outlineStyle && d->outlineStyle->parent() == this)
         delete d->outlineStyle;
@@ -1018,42 +1012,42 @@ KoListStyle *KoStyleManager::outlineStyle() const
     return d->outlineStyle;
 }
 
-QList<KoCharacterStyle*> KoStyleManager::characterStyles() const
+QList<KoCharacterStyle *> KoStyleManager::characterStyles() const
 {
     return d->charStyles.values();
 }
 
-QList<KoParagraphStyle*> KoStyleManager::paragraphStyles() const
+QList<KoParagraphStyle *> KoStyleManager::paragraphStyles() const
 {
     return d->paragStyles.values();
 }
 
-QList<KoListStyle*> KoStyleManager::listStyles() const
+QList<KoListStyle *> KoStyleManager::listStyles() const
 {
     return d->listStyles.values();
 }
 
-QList<KoTableStyle*> KoStyleManager::tableStyles() const
+QList<KoTableStyle *> KoStyleManager::tableStyles() const
 {
     return d->tableStyles.values();
 }
 
-QList<KoTableColumnStyle*> KoStyleManager::tableColumnStyles() const
+QList<KoTableColumnStyle *> KoStyleManager::tableColumnStyles() const
 {
     return d->tableColumnStyles.values();
 }
 
-QList<KoTableRowStyle*> KoStyleManager::tableRowStyles() const
+QList<KoTableRowStyle *> KoStyleManager::tableRowStyles() const
 {
     return d->tableRowStyles.values();
 }
 
-QList<KoTableCellStyle*> KoStyleManager::tableCellStyles() const
+QList<KoTableCellStyle *> KoStyleManager::tableCellStyles() const
 {
     return d->tableCellStyles.values();
 }
 
-QList<KoSectionStyle*> KoStyleManager::sectionStyles() const
+QList<KoSectionStyle *> KoStyleManager::sectionStyles() const
 {
     return d->sectionStyles.values();
 }
@@ -1071,8 +1065,7 @@ KoParagraphStyle *KoStyleManager::defaultTableOfcontentsTitleStyle() const
 
 KoParagraphStyle *KoStyleManager::defaultBibliographyEntryStyle(const QString &bibType)
 {
-    KoParagraphStyle *style = paragraphStyle(d->defaultBibEntriesStyleId
-                                             .at(KoOdfBibliographyConfiguration::bibTypes.indexOf(bibType)));
+    KoParagraphStyle *style = paragraphStyle(d->defaultBibEntriesStyleId.at(KoOdfBibliographyConfiguration::bibTypes.indexOf(bibType)));
     return style;
 }
 
@@ -1098,7 +1091,7 @@ void KoStyleManager::addUnusedStyle(KoParagraphStyle *style)
         if (root->styleId() == 0)
             addUnusedStyle(root);
     }
-    if (root != d->defaultParagraphStyle && root->parentStyle() == 0)
+    if (root != d->defaultParagraphStyle && root->parentStyle() == nullptr)
         root->setParentStyle(d->defaultParagraphStyle);
     ++d->s_stylesNumber;
 }
@@ -1122,10 +1115,10 @@ void KoStyleManager::moveToUsedStyles(int id)
             moveToUsedStyles(root->styleId());
     }
 
-    if (root != d->defaultParagraphStyle && root->parentStyle() == 0)
+    if (root != d->defaultParagraphStyle && root->parentStyle() == nullptr)
         root->setParentStyle(d->defaultParagraphStyle);
 
-    emit styleAdded(style);
+    Q_EMIT paragraphStyleAdded(style);
 }
 
 KoParagraphStyle *KoStyleManager::unusedStyle(int id) const
@@ -1145,11 +1138,11 @@ QVector<int> KoStyleManager::usedParagraphStyles() const
 
 KoTextTableTemplate *KoStyleManager::tableTemplate(const QString &name) const
 {
-    foreach(KoTextTableTemplate *tableTemplate, d->tableTemplates) {
+    foreach (KoTextTableTemplate *tableTemplate, d->tableTemplates) {
         if (tableTemplate->name() == name)
             return tableTemplate;
     }
-    return 0;
+    return nullptr;
 }
 
 KoTextTableTemplate *KoStyleManager::tableTemplate(int id) const
