@@ -1,33 +1,20 @@
 /* This file is part of the Calligra project
- * Copyright (C) 2006-2009 Thomas Zander <zander@kde.org>
- * Copyright (C) 2008 Girish Ramakrishnan <girish@forwardbias.in>
- * Copyright (C) 2011 Stuart Dickson <stuart@furkinfantastic.net>
+ * SPDX-FileCopyrightText: 2006-2009 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2008 Girish Ramakrishnan <girish@forwardbias.in>
+ * SPDX-FileCopyrightText: 2011 Stuart Dickson <stuart@furkinfantastic.net>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 #include "TestStyles.h"
 
-#include <styles/KoParagraphStyle.h>
 #include "TextDebug.h"
-#include <QTextDocument>
 #include <QTextBlock>
 #include <QTextBlockFormat>
 #include <QTextCharFormat>
 #include <QTextCursor>
+#include <QTextDocument>
 #include <QTextLength>
+#include <styles/KoParagraphStyle.h>
 
 #include <QTest>
 
@@ -77,7 +64,7 @@ void TestStyles::testChangeParent()
 
     // test that separating will leave the child with exactly the same dataset
     // as it had before the inheritance
-    style3.setParentStyle(0);
+    style3.setParentStyle(nullptr);
     QCOMPARE(style1.topMargin(), 10.0);
     QCOMPARE(style3.topMargin(), 0.0); // we hadn't explicitly set the margin on style3
 
@@ -200,7 +187,7 @@ void TestStyles::testApplyParagraphStyleWithParent()
     QCOMPARE(rawFormat.properties().count(), 4);
     QCOMPARE(format.alignment(), Qt::AlignRight);
     QCOMPARE(rawFormat.property(KoParagraphStyle::StyleId).toInt(), 1002);
-    //since we have not specified any NextStyle it should be the same as the current style
+    // since we have not specified any NextStyle it should be the same as the current style
     QCOMPARE(rawFormat.property(KoParagraphStyle::StyleId).toInt(), rawFormat.property(KoParagraphStyle::NextStyle).toInt());
     QCOMPARE(format.leftMargin(), 10.0);
     QCOMPARE(format.rightMargin(), 0.0);
@@ -210,7 +197,7 @@ void TestStyles::testApplyParagraphStyleWithParent()
     QCOMPARE(rawFormat.properties().count(), 5);
     QCOMPARE(format2.alignment(), Qt::AlignCenter);
     QCOMPARE(rawFormat.property(KoParagraphStyle::StyleId).toInt(), 1003);
-    //since we have not specified any NextStyle it should be the same as the current style
+    // since we have not specified any NextStyle it should be the same as the current style
     QCOMPARE(rawFormat.property(KoParagraphStyle::StyleId).toInt(), rawFormat.property(KoParagraphStyle::NextStyle).toInt());
     QCOMPARE(format2.leftMargin(), 10.0);
     QCOMPARE(format2.rightMargin(), 20.0);
@@ -221,7 +208,7 @@ void TestStyles::testApplyParagraphStyleWithParent()
     QCOMPARE(rawFormat.property(KoParagraphStyle::LineSpacing).toReal(), 56.78);
     QCOMPARE(format3.alignment(), Qt::AlignLeft | Qt::AlignAbsolute);
     QCOMPARE(rawFormat.property(KoParagraphStyle::StyleId).toInt(), 1004);
-    //since we have not specified any NextStyle it should be the same as the current style
+    // since we have not specified any NextStyle it should be the same as the current style
     QCOMPARE(rawFormat.property(KoParagraphStyle::StyleId).toInt(), rawFormat.property(KoParagraphStyle::NextStyle).toInt());
     QCOMPARE(format3.leftMargin(), 10.0);
     QCOMPARE(format3.rightMargin(), 20.0);
@@ -274,15 +261,15 @@ void TestStyles::testUnapplyStyle()
 
     QTextCursor cursor(block);
     QTextBlockFormat bf = cursor.blockFormat();
-    KoParagraphStyle bfStyle (bf, cursor.charFormat());
+    KoParagraphStyle bfStyle(bf, cursor.charFormat());
     QCOMPARE(bf.alignment(), Qt::AlignCenter);
     QCOMPARE(bfStyle.leftMargin(), 40.);
     QTextCharFormat cf = cursor.charFormat();
     QCOMPARE(cf.colorProperty(KoCharacterStyle::OverlineColor), testOverlineColor);
-    QCOMPARE(cf.intProperty(KoCharacterStyle::OverlineMode), (int) KoCharacterStyle::ContinuousLineMode);
-    QCOMPARE(cf.intProperty(KoCharacterStyle::OverlineStyle), (int) KoCharacterStyle::DottedLine);
-    QCOMPARE(cf.intProperty(KoCharacterStyle::OverlineType), (int) KoCharacterStyle::DoubleLine);
-    QCOMPARE(cf.intProperty(KoCharacterStyle::OverlineWeight), (int) testOverlineWeight);
+    QCOMPARE(cf.intProperty(KoCharacterStyle::OverlineMode), (int)KoCharacterStyle::ContinuousLineMode);
+    QCOMPARE(cf.intProperty(KoCharacterStyle::OverlineStyle), (int)KoCharacterStyle::DottedLine);
+    QCOMPARE(cf.intProperty(KoCharacterStyle::OverlineType), (int)KoCharacterStyle::DoubleLine);
+    QCOMPARE(cf.intProperty(KoCharacterStyle::OverlineWeight), (int)testOverlineWeight);
     QCOMPARE(cf.doubleProperty(KoCharacterStyle::OverlineWidth), testOverlineWidth);
 
     head1.unapplyStyle(block);
@@ -301,25 +288,24 @@ void TestStyles::testUnapplyStyle()
     block = doc.begin();
     head1.applyStyle(block);
     bf = cursor.blockFormat();
-    KoParagraphStyle bfStyle2 (bf, cursor.charFormat());
+    KoParagraphStyle bfStyle2(bf, cursor.charFormat());
     QCOMPARE(bf.alignment(), Qt::AlignCenter);
     QCOMPARE(bfStyle2.leftMargin(), 40.);
     cf = cursor.charFormat();
-    //QCOMPARE(cf.fontOverline(), true);
+    // QCOMPARE(cf.fontOverline(), true);
     QCOMPARE(cf.colorProperty(KoCharacterStyle::OverlineColor), testOverlineColor);
-    QCOMPARE(cf.intProperty(KoCharacterStyle::OverlineMode), (int) KoCharacterStyle::ContinuousLineMode);
-    QCOMPARE(cf.intProperty(KoCharacterStyle::OverlineStyle), (int) KoCharacterStyle::DottedLine);
-    QCOMPARE(cf.intProperty(KoCharacterStyle::OverlineType), (int) KoCharacterStyle::DoubleLine);
-    QCOMPARE(cf.intProperty(KoCharacterStyle::OverlineWeight), (int) testOverlineWeight);
+    QCOMPARE(cf.intProperty(KoCharacterStyle::OverlineMode), (int)KoCharacterStyle::ContinuousLineMode);
+    QCOMPARE(cf.intProperty(KoCharacterStyle::OverlineStyle), (int)KoCharacterStyle::DottedLine);
+    QCOMPARE(cf.intProperty(KoCharacterStyle::OverlineType), (int)KoCharacterStyle::DoubleLine);
+    QCOMPARE(cf.intProperty(KoCharacterStyle::OverlineWeight), (int)testOverlineWeight);
     QCOMPARE(cf.doubleProperty(KoCharacterStyle::OverlineWidth), testOverlineWidth);
 
-
     head1.unapplyStyle(block);
     bf = cursor.blockFormat();
     QCOMPARE(bf.hasProperty(QTextFormat::BlockAlignment), false);
     QCOMPARE(bf.hasProperty(QTextFormat::BlockLeftMargin), false);
     cf = cursor.charFormat();
-    //QCOMPARE(cf.hasProperty(QTextFormat::FontOverline), false);
+    // QCOMPARE(cf.hasProperty(QTextFormat::FontOverline), false);
 
     doc.setHtml("bla bla<i>italic</i>enzo");
 
@@ -330,7 +316,7 @@ void TestStyles::testUnapplyStyle()
     QCOMPARE(bf.alignment(), Qt::AlignCenter);
     QCOMPARE(bfStyle3.leftMargin(), 40.);
     cf = cursor.charFormat();
-    //QCOMPARE(cf.fontOverline(), true);
+    // QCOMPARE(cf.fontOverline(), true);
     QCOMPARE(cf.hasProperty(KoCharacterStyle::OverlineColor), true);
     QCOMPARE(cf.hasProperty(KoCharacterStyle::OverlineMode), true);
     QCOMPARE(cf.hasProperty(KoCharacterStyle::OverlineStyle), true);
@@ -354,7 +340,7 @@ void TestStyles::testUnapplyStyle()
     QCOMPARE(bf.hasProperty(QTextFormat::BlockAlignment), false);
     QCOMPARE(bf.hasProperty(QTextFormat::BlockLeftMargin), false);
     cf = cursor.charFormat();
-    //QCOMPARE(cf.hasProperty(QTextFormat::FontOverline), false);
+    // QCOMPARE(cf.hasProperty(QTextFormat::FontOverline), false);
     QCOMPARE(cf.hasProperty(KoCharacterStyle::OverlineColor), false);
     QCOMPARE(cf.hasProperty(KoCharacterStyle::OverlineMode), false);
     QCOMPARE(cf.hasProperty(KoCharacterStyle::OverlineStyle), false);
@@ -362,10 +348,9 @@ void TestStyles::testUnapplyStyle()
     QCOMPARE(cf.hasProperty(KoCharacterStyle::OverlineWeight), false);
     QCOMPARE(cf.hasProperty(KoCharacterStyle::OverlineWidth), false);
 
-
     cursor.setPosition(8);
     cf = cursor.charFormat();
-    //QCOMPARE(cf.hasProperty(QTextFormat::FontOverline), false);
+    // QCOMPARE(cf.hasProperty(QTextFormat::FontOverline), false);
     QCOMPARE(cf.hasProperty(KoCharacterStyle::OverlineColor), false);
     QCOMPARE(cf.hasProperty(KoCharacterStyle::OverlineMode), false);
     QCOMPARE(cf.hasProperty(KoCharacterStyle::OverlineStyle), false);
@@ -375,7 +360,7 @@ void TestStyles::testUnapplyStyle()
     QCOMPARE(cf.fontItalic(), true);
     cursor.setPosition(12);
     cf = cursor.charFormat();
-    //QCOMPARE(cf.hasProperty(QTextFormat::FontOverline), false);
+    // QCOMPARE(cf.hasProperty(QTextFormat::FontOverline), false);
     QCOMPARE(cf.hasProperty(KoCharacterStyle::OverlineColor), false);
     QCOMPARE(cf.hasProperty(KoCharacterStyle::OverlineMode), false);
     QCOMPARE(cf.hasProperty(KoCharacterStyle::OverlineStyle), false);
@@ -386,7 +371,7 @@ void TestStyles::testUnapplyStyle()
 
     cursor.setPosition(13);
     cf = cursor.charFormat();
-    //QCOMPARE(cf.hasProperty(QTextFormat::FontOverline), false);
+    // QCOMPARE(cf.hasProperty(QTextFormat::FontOverline), false);
     QCOMPARE(cf.hasProperty(KoCharacterStyle::OverlineColor), false);
     QCOMPARE(cf.hasProperty(KoCharacterStyle::OverlineMode), false);
     QCOMPARE(cf.hasProperty(KoCharacterStyle::OverlineStyle), false);
