@@ -1,47 +1,34 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006, 2009-2010 Thomas Zander <zander@kde.org>
- * Copyright (C) 2008 Thorsten Zachmann <zachmann@kde.org>
- * Copyright (C) 2008 Girish Ramakrishnan <girish@forwardbias.in>
- * Copyright (C) 2011 C. Boemann <cbo@boemann.dk>
+ * SPDX-FileCopyrightText: 2006, 2009-2010 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2008 Thorsten Zachmann <zachmann@kde.org>
+ * SPDX-FileCopyrightText: 2008 Girish Ramakrishnan <girish@forwardbias.in>
+ * SPDX-FileCopyrightText: 2011 C. Boemann <cbo@boemann.dk>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "KoTextShapeData.h"
 
+#include "KoTextDocument.h"
+#include "styles/KoParagraphStyle.h"
+#include "styles/KoStyleManager.h"
+#include <KoTextEditor.h>
 #include <KoTextShapeDataBase.h>
 #include <KoTextShapeDataBase_p.h>
-#include "KoTextDocument.h"
-#include <KoTextEditor.h>
-#include "styles/KoStyleManager.h"
-#include "styles/KoParagraphStyle.h"
 
 #include <KoTextLayoutRootArea.h>
 
-#include <QTextDocument>
 #include <QTextBlock>
 #include <QTextCursor>
+#include <QTextDocument>
 
+#include <KoDocumentRdfBase.h>
 #include <KoGenStyle.h>
 #include <KoOdfLoadingContext.h>
+#include <KoShape.h>
 #include <KoShapeLoadingContext.h>
 #include <KoShapeSavingContext.h>
-#include <KoDocumentRdfBase.h>
 #include <KoStyleStack.h>
-#include <KoShape.h>
 #include <KoUnit.h>
 
 #include <KoXmlNS.h>
@@ -57,15 +44,15 @@ class KoTextShapeDataPrivate : public KoTextShapeDataBasePrivate
 {
 public:
     KoTextShapeDataPrivate()
-            : ownsDocument(true)
-            , topPadding(0)
-            , leftPadding(0)
-            , rightPadding(0)
-            , bottomPadding(0)
-            , direction(KoText::AutoDirection)
-            , textpage(0)
-            , rootArea(0)
-            , paragraphStyle(0)
+        : ownsDocument(true)
+        , topPadding(0)
+        , leftPadding(0)
+        , rightPadding(0)
+        , bottomPadding(0)
+        , direction(KoText::AutoDirection)
+        , textpage(nullptr)
+        , rootArea(nullptr)
+        , paragraphStyle(nullptr)
     {
     }
 
@@ -89,16 +76,13 @@ public:
     KoParagraphStyle *paragraphStyle; // the paragraph style of the shape (part of the graphic style)
 };
 
-
 KoTextShapeData::KoTextShapeData()
     : KoTextShapeDataBase(*(new KoTextShapeDataPrivate()))
 {
     setDocument(new QTextDocument, true);
 }
 
-KoTextShapeData::~KoTextShapeData()
-{
-}
+KoTextShapeData::~KoTextShapeData() = default;
 
 void KoTextShapeData::setDocument(QTextDocument *document, bool transferOwnership)
 {
@@ -111,7 +95,7 @@ void KoTextShapeData::setDocument(QTextDocument *document, bool transferOwnershi
 
     // The following avoids the normal case where the glyph metrices are rounded to integers and
     // hinted to the screen by freetype, which you of course don't want for WYSIWYG
-    if (! document->useDesignMetrics())
+    if (!document->useDesignMetrics())
         document->setUseDesignMetrics(true);
 
     KoTextDocument kodoc(document);
@@ -129,13 +113,13 @@ void KoTextShapeData::setDocument(QTextDocument *document, bool transferOwnershi
 
     // After setting the document (even if not changing it) we need to explicitly set the root area
     // to 0. Otherwise crashes may occur when inserting textshape in words (or resetting document)
-    d->rootArea = 0;
+    d->rootArea = nullptr;
 
     if (d->document == document)
         return;
     d->document = document;
 
-    if (kodoc.textEditor() == 0)
+    if (kodoc.textEditor() == nullptr)
         kodoc.setTextEditor(new KoTextEditor(d->document));
 }
 
@@ -162,7 +146,6 @@ void KoTextShapeData::setDirty()
     }
 }
 
-
 bool KoTextShapeData::isDirty() const
 {
     Q_D(const KoTextShapeData);
@@ -258,7 +241,7 @@ bool KoTextShapeData::loadOdf(const KoXmlElement &element, KoShapeLoadingContext
     KoTextLoader loader(context, shape);
 
     QTextCursor cursor(document());
-    loader.loadBody(element, cursor);   // now let's load the body from the ODF KoXmlElement.
+    loader.loadBody(element, cursor); // now let's load the body from the ODF KoXmlElement.
     KoTextEditor *editor = KoTextDocument(document()).textEditor();
     if (editor) { // at one point we have to get the position from the odf doc instead.
         editor->setPosition(0);
@@ -278,44 +261,43 @@ void KoTextShapeData::loadStyle(const KoXmlElement &element, KoShapeLoadingConte
 {
     Q_D(KoTextShapeData);
     // load the (text) style of the frame
-    const KoXmlElement *style = 0;
+    const KoXmlElement *style = nullptr;
     if (element.hasAttributeNS(KoXmlNS::draw, "style-name")) {
-        style = context.odfLoadingContext().stylesReader().findStyle(
-                    element.attributeNS(KoXmlNS::draw, "style-name"), "graphic",
-                    context.odfLoadingContext().useStylesAutoStyles());
+        style = context.odfLoadingContext().stylesReader().findStyle(element.attributeNS(KoXmlNS::draw, "style-name"),
+                                                                     "graphic",
+                                                                     context.odfLoadingContext().useStylesAutoStyles());
         if (!style) {
             warnTextLayout << "graphic style not found:" << element.attributeNS(KoXmlNS::draw, "style-name");
         }
     }
     if (element.hasAttributeNS(KoXmlNS::presentation, "style-name")) {
-        style = context.odfLoadingContext().stylesReader().findStyle(
-                    element.attributeNS(KoXmlNS::presentation, "style-name"), "presentation",
-                    context.odfLoadingContext().useStylesAutoStyles());
+        style = context.odfLoadingContext().stylesReader().findStyle(element.attributeNS(KoXmlNS::presentation, "style-name"),
+                                                                     "presentation",
+                                                                     context.odfLoadingContext().useStylesAutoStyles());
         if (!style) {
             warnTextLayout << "presentation style not found:" << element.attributeNS(KoXmlNS::presentation, "style-name");
         }
     }
 
-
     if (style) {
         KoStyleStack &styleStack = context.odfLoadingContext().styleStack();
         styleStack.save();
-        context.odfLoadingContext().addStyles(style, style->attributeNS(KoXmlNS::style, "family", "graphic").toLocal8Bit().constData());   // Load all parents
+        context.odfLoadingContext().addStyles(style, style->attributeNS(KoXmlNS::style, "family", "graphic").toLocal8Bit().constData()); // Load all parents
         styleStack.setTypeProperties("graphic");
         // Spacing (padding)
-        const QString paddingLeft(styleStack.property(KoXmlNS::fo, "padding-left" ));
+        const QString paddingLeft(styleStack.property(KoXmlNS::fo, "padding-left"));
         if (!paddingLeft.isEmpty()) {
             setLeftPadding(KoUnit::parseValue(paddingLeft));
         }
-        const QString paddingRight(styleStack.property(KoXmlNS::fo, "padding-right" ));
+        const QString paddingRight(styleStack.property(KoXmlNS::fo, "padding-right"));
         if (!paddingRight.isEmpty()) {
             setRightPadding(KoUnit::parseValue(paddingRight));
         }
-        const QString paddingTop(styleStack.property(KoXmlNS::fo, "padding-top" ));
+        const QString paddingTop(styleStack.property(KoXmlNS::fo, "padding-top"));
         if (!paddingTop.isEmpty()) {
             setTopPadding(KoUnit::parseValue(paddingTop));
         }
-        const QString paddingBottom(styleStack.property(KoXmlNS::fo, "padding-bottom" ));
+        const QString paddingBottom(styleStack.property(KoXmlNS::fo, "padding-bottom"));
         if (!paddingBottom.isEmpty()) {
             setBottomPadding(KoUnit::parseValue(paddingBottom));
         }
@@ -326,7 +308,7 @@ void KoTextShapeData::loadStyle(const KoXmlElement &element, KoShapeLoadingConte
         styleStack.restore();
 
         QString family = style->attributeNS(KoXmlNS::style, "family", "graphic");
-        KoParagraphStyle *defaultStyle = 0;
+        KoParagraphStyle *defaultStyle = nullptr;
         const KoXmlElement *dstyle = context.odfLoadingContext().stylesReader().defaultStyle(family);
         if (dstyle) {
             defaultStyle = new KoParagraphStyle();
@@ -342,9 +324,9 @@ void KoTextShapeData::loadStyle(const KoXmlElement &element, KoShapeLoadingConte
             }
             paragraphStyles.append(pStyle);
             QString family = style->attributeNS(KoXmlNS::style, "family", "graphic");
-            style = context.odfLoadingContext().stylesReader().findStyle(
-                    style->attributeNS(KoXmlNS::style, "parent-style-name"), family.toLocal8Bit().constData(),
-                    context.odfLoadingContext().useStylesAutoStyles());
+            style = context.odfLoadingContext().stylesReader().findStyle(style->attributeNS(KoXmlNS::style, "parent-style-name"),
+                                                                         family.toLocal8Bit().constData(),
+                                                                         context.odfLoadingContext().useStylesAutoStyles());
         }
         // rather than setting default style and apply to block we just set a final parent
         paragraphStyles.last()->setParentStyle(defaultStyle);
