@@ -1,30 +1,18 @@
 /* This file is part of the KDE libraries
-   Copyright (c) 1998 Stefan Taferner
+   SPDX-FileCopyrightText: 1998 Stefan Taferner
                  2001/2003 thierry lorthiois (lorthioist@wanadoo.fr)
                  2011 Inge Wallin (inge@lysator.liu.se)
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-only
 */
 #ifndef _WMFSTACK_H_
 #define _WMFSTACK_H_
 
-#include <QPen>
+#include <QBrush>
 #include <QColor>
 #include <QFont>
-#include <QBrush>
 #include <QImage>
+#include <QPen>
 
 /**
    Namespace for Windows Metafile (WMF) classes
@@ -42,25 +30,25 @@ class WmfDeviceContext;
 class KoWmfHandle
 {
 public:
-    virtual ~KoWmfHandle() {}
+    virtual ~KoWmfHandle() = default;
     virtual void apply(WmfDeviceContext *) = 0;
 };
 
-class KoWmfBrushHandle: public KoWmfHandle
+class KoWmfBrushHandle : public KoWmfHandle
 {
 public:
     void apply(WmfDeviceContext *) override;
     QBrush brush;
 };
 
-class KoWmfPenHandle: public KoWmfHandle
+class KoWmfPenHandle : public KoWmfHandle
 {
 public:
     void apply(WmfDeviceContext *) override;
     QPen pen;
 };
 
-class KoWmfPatternBrushHandle: public KoWmfHandle
+class KoWmfPatternBrushHandle : public KoWmfHandle
 {
 public:
     void apply(WmfDeviceContext *) override;
@@ -68,17 +56,15 @@ public:
     QImage image;
 };
 
-class KoWmfFontHandle: public KoWmfHandle
+class KoWmfFontHandle : public KoWmfHandle
 {
 public:
     void apply(WmfDeviceContext *) override;
     QFont font;
     int escapement;
     int orientation;
-    int height;                 // Can be negative. In 'font' above, we store the absolute value.
+    int height; // Can be negative. In 'font' above, we store the absolute value.
 };
-
-
 }
 
 #endif
