@@ -1,37 +1,25 @@
 /* This file is part of the KDE libraries
  *
- * Copyright (c) 2003 thierry lorthiois (lorthioist@wanadoo.fr)
- * Copyright (c) 2011 Inge Wallin (inge@lysator.liu.se)
+ * SPDX-FileCopyrightText: 2003 thierry lorthiois (lorthioist@wanadoo.fr)
+ * SPDX-FileCopyrightText: 2011 Inge Wallin (inge@lysator.liu.se)
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License version 2 as published by the Free Software Foundation.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
-*/
+ * SPDX-License-Identifier: LGPL-2.0-only
+ */
 
 #include "WmfWriter.h"
 
-#include "WmfStructs.h"
 #include "WmfParser.h"
+#include "WmfStructs.h"
 
 #include <VectorImageDebug.h>
 
-#include <QFile>
-#include <QDataStream>
-#include <QPolygon>
-#include <QPen>
 #include <QBrush>
 #include <QColor>
+#include <QDataStream>
+#include <QFile>
 #include <QFont>
+#include <QPen>
+#include <QPolygon>
 #include <QRegion>
 
 #include <math.h>
@@ -42,25 +30,22 @@
 namespace Libwmf
 {
 
-
 /**
  * Private data
  */
 class WmfWriterPrivate
 {
 public:
-    QRect    mBBox;      // bounding rectangle
-    int      mDpi;       // number of point per inch for the default size
-    int      mMaxRecordSize;
+    QRect mBBox; // bounding rectangle
+    int mDpi; // number of point per inch for the default size
+    int mMaxRecordSize;
 
     // memory allocation for WMF file
     QFile mFileOut;
     QDataStream mSt;
 };
 
-
-
-WmfWriter::WmfWriter(const QString& fileName)
+WmfWriter::WmfWriter(const QString &fileName)
     : d(new WmfWriterPrivate)
 {
     d->mDpi = 1024;
@@ -73,19 +58,16 @@ WmfWriter::~WmfWriter()
     delete d;
 }
 
-
 void WmfWriter::setDefaultDpi(int dpi)
 {
     d->mDpi = dpi;
 }
 
-
 //-----------------------------------------------------------------------------
 // Virtual Painter => create the WMF
 
 bool WmfWriter::begin()
 {
-
     if (!d->mFileOut.open(QIODevice::WriteOnly)) {
         debugVectorImage << "Cannot open file" << QFile::encodeName(d->mFileOut.fileName());
         return false;
@@ -94,7 +76,7 @@ bool WmfWriter::begin()
     d->mSt.setByteOrder(QDataStream::LittleEndian);
 
     // reserved placeable and standard header
-    for (int i = 0 ; i < 10 ; i++) {
+    for (int i = 0; i < 10; i++) {
         d->mSt << (quint32)0;
     }
 
@@ -105,7 +87,7 @@ bool WmfWriter::begin()
     // Brush
     d->mSt << (quint32)7 << (quint16)0x02FC;
     d->mSt << (quint16)1 << (quint32)0 << (quint16)0;
-    for (int i = 0 ; i < 4 ; i++) {
+    for (int i = 0; i < 4; i++) {
         d->mSt << (quint32)8 << (quint16)0x02FA << (quint16)0 << (quint32)0 << (quint32)0;
     }
     d->mMaxRecordSize = 8;
@@ -113,11 +95,10 @@ bool WmfWriter::begin()
     return true;
 }
 
-
 bool WmfWriter::end()
 {
-    WmfPlaceableHeader pheader = { 0x9AC6CDD7, 0, 0, 0, 0, 0, 0, 0, 0 };
-    quint16  checksum;
+    WmfPlaceableHeader pheader = {0x9AC6CDD7, 0, 0, 0, 0, 0, 0, 0, 0};
+    quint16 checksum;
 
     // End of the wmf file
     d->mSt << (quint32)3 << (quint16)0;
@@ -143,19 +124,16 @@ bool WmfWriter::end()
     return true;
 }
 
-
 void WmfWriter::save()
 {
     d->mSt << (quint32)3 << (quint16)0x001E;
 }
 
-
 void WmfWriter::restore()
 {
     d->mSt << (quint32)4 << (quint16)0x0127 << (quint16)1;
 }
 
-
 void WmfWriter::setPen(const QPen &pen)
 {
     int style;
@@ -167,8 +145,9 @@ void WmfWriter::setPen(const QPen &pen)
     // delete object
     d->mSt << (quint32)4 << (quint16)0x01f0 << (quint16)2;
 
-    for (style = 0 ; style < max ; style++) {
-        if (koWmfStylePen[ style ] == pen.style()) break;
+    for (style = 0; style < max; style++) {
+        if (koWmfStylePen[style] == pen.style())
+            break;
     }
     if (style == max) {
         // SolidLine
@@ -181,7 +160,6 @@ void WmfWriter::setPen(const QPen &pen)
     d->mSt << (quint32)4 << (quint16)0x012D << (quint16)2;
 }
 
-
 void WmfWriter::setBrush(const QBrush &brush)
 {
     int style;
@@ -193,8 +171,9 @@ void WmfWriter::setBrush(const QBrush &brush)
     // delete object
     d->mSt << (quint32)4 << (quint16)0x01f0 << (quint16)3;
 
-    for (style = 0 ; style < max ; style++) {
-        if (koWmfStyleBrush[ style ] == brush.style()) break;
+    for (style = 0; style < max; style++) {
+        if (koWmfStyleBrush[style] == brush.style())
+            break;
     }
     if (style == max) {
         // SolidPattern
@@ -207,18 +186,15 @@ void WmfWriter::setBrush(const QBrush &brush)
     d->mSt << (quint32)4 << (quint16)0x012D << (quint16)3;
 }
 
-
 void WmfWriter::setFont(const QFont &)
 {
 }
 
-
 void WmfWriter::setBackgroundColor(const QColor &c)
 {
     d->mSt << (quint32)5 << (quint16)0x0201 << (quint32)winColor(c);
 }
 
-
 void WmfWriter::setBackgroundMode(Qt::BGMode mode)
 {
     d->mSt << (quint32)4 << (quint16)0x0102;
@@ -228,13 +204,11 @@ void WmfWriter::setBackgroundMode(Qt::BGMode mode)
         d->mSt << (quint16)0;
 }
 
-
 void WmfWriter::setCompositionMode(QPainter::CompositionMode op)
 {
     d->mSt << (quint32)5 << (quint16)0x0104 << (quint32)qtRasterToWin32(op);
 }
 
-
 void WmfWriter::setWindow(int left, int top, int width, int height)
 {
     d->mBBox.setRect(left, top, width, height);
@@ -246,13 +220,10 @@ void WmfWriter::setWindow(int left, int top, int width, int height)
     d->mSt << (quint32)5 << (quint16)0x020C << (quint16)height << (quint16)width;
 }
 
-
 void WmfWriter::setClipRegion(const QRegion &)
 {
-
 }
 
-
 void WmfWriter::clipping(bool enable)
 {
     if (!enable) {
@@ -261,19 +232,16 @@ void WmfWriter::clipping(bool enable)
     }
 }
 
-
 void WmfWriter::moveTo(int left, int top)
 {
     d->mSt << (quint32)5 << (quint16)0x0214 << (quint16)top << (quint16)left;
 }
 
-
 void WmfWriter::lineTo(int left, int top)
 {
     d->mSt << (quint32)5 << (quint16)0x0213 << (quint16)top << (quint16)left;
 }
 
-
 void WmfWriter::drawRect(int left, int top, int width, int height)
 {
     QRect rec(left, top, width, height);
@@ -282,10 +250,9 @@ void WmfWriter::drawRect(int left, int top, int width, int height)
     d->mSt << (quint16)rec.bottom() << (quint16)rec.right() << (quint16)rec.top() << (quint16)rec.left();
 }
 
-
-void WmfWriter::drawRoundRect(int left, int top, int width, int height , int roudw, int roudh)
+void WmfWriter::drawRoundRect(int left, int top, int width, int height, int roudw, int roudh)
 {
-    int  widthCorner, heightCorner;
+    int widthCorner, heightCorner;
     QRect rec(left, top, width, height);
 
     // convert percentage (roundw, roudh) in (widthCorner, heightCorner)
@@ -298,7 +265,6 @@ void WmfWriter::drawRoundRect(int left, int top, int width, int height , int rou
     d->mMaxRecordSize = qMax(d->mMaxRecordSize, 9);
 }
 
-
 void WmfWriter::drawEllipse(int left, int top, int width, int height)
 {
     QRect rec(left, top, width, height);
@@ -307,11 +273,10 @@ void WmfWriter::drawEllipse(int left, int top, int width, int height)
     d->mSt << (quint16)rec.bottom() << (quint16)rec.right() << (quint16)rec.top() << (quint16)rec.left();
 }
 
-
-void WmfWriter::drawArc(int left, int top, int width, int height , int a, int alen)
+void WmfWriter::drawArc(int left, int top, int width, int height, int a, int alen)
 {
     int xCenter, yCenter;
-    int  offXStart, offYStart, offXEnd, offYEnd;
+    int offXStart, offYStart, offXEnd, offYEnd;
 
     angleToxy(offXStart, offYStart, offXEnd, offYEnd, a, alen);
     xCenter = left + (width / 2);
@@ -326,11 +291,10 @@ void WmfWriter::drawArc(int left, int top, int width, int height , int a, int al
     d->mMaxRecordSize = qMax(d->mMaxRecordSize, 11);
 }
 
-
-void WmfWriter::drawPie(int left, int top, int width, int height , int a, int alen)
+void WmfWriter::drawPie(int left, int top, int width, int height, int a, int alen)
 {
     int xCenter, yCenter;
-    int  offXStart, offYStart, offXEnd, offYEnd;
+    int offXStart, offYStart, offXEnd, offYEnd;
 
     angleToxy(offXStart, offYStart, offXEnd, offYEnd, a, alen);
     xCenter = left + (width / 2);
@@ -345,11 +309,10 @@ void WmfWriter::drawPie(int left, int top, int width, int height , int a, int al
     d->mMaxRecordSize = qMax(d->mMaxRecordSize, 11);
 }
 
-
-void WmfWriter::drawChord(int left, int top, int width, int height , int a, int alen)
+void WmfWriter::drawChord(int left, int top, int width, int height, int a, int alen)
 {
     int xCenter, yCenter;
-    int  offXStart, offYStart, offXEnd, offYEnd;
+    int offXStart, offYStart, offXEnd, offYEnd;
 
     angleToxy(offXStart, offYStart, offXEnd, offYEnd, a, alen);
     xCenter = left + (width / 2);
@@ -364,7 +327,6 @@ void WmfWriter::drawChord(int left, int top, int width, int height , int a, int
     d->mMaxRecordSize = qMax(d->mMaxRecordSize, 11);
 }
 
-
 void WmfWriter::drawPolyline(const QPolygon &pa)
 {
     int size = 4 + (pa.size() * 2);
@@ -375,7 +337,6 @@ void WmfWriter::drawPolyline(const QPolygon &pa)
     d->mMaxRecordSize = qMax(d->mMaxRecordSize, size);
 }
 
-
 void WmfWriter::drawPolygon(const QPolygon &pa, bool)
 {
     int size = 4 + (pa.size() * 2);
@@ -386,33 +347,30 @@ void WmfWriter::drawPolygon(const QPolygon &pa, bool)
     d->mMaxRecordSize = qMax(d->mMaxRecordSize, size);
 }
 
-
-void WmfWriter::drawPolyPolygon(QList<QPolygon>& listPa, bool)
+void WmfWriter::drawPolyPolygon(QList<QPolygon> &listPa, bool)
 {
-
     int sizeArrayPoly = 0;
 
-    foreach(const QPolygon & pa, listPa) {
+    foreach (const QPolygon &pa, listPa) {
         sizeArrayPoly += (pa.size() * 2);
     }
     int size = 4 + listPa.count() + sizeArrayPoly;
     d->mSt << (quint32)size << (quint16)0x0538 << (quint16)listPa.count();
 
     // number of point for each Polygon
-    foreach(const QPolygon & pa, listPa) {
+    foreach (const QPolygon &pa, listPa) {
         d->mSt << (quint16)pa.size();
     }
 
     // list of points
-    foreach(const QPolygon & pa, listPa) {
+    foreach (const QPolygon &pa, listPa) {
         pointArray(pa);
     }
 
     d->mMaxRecordSize = qMax(d->mMaxRecordSize, size);
 }
 
-
-void WmfWriter::drawImage(int , int , const QImage &, int , int , int , int)
+void WmfWriter::drawImage(int, int, const QImage &, int, int, int, int)
 {
     /*
         QImage img;
@@ -426,10 +384,9 @@ void WmfWriter::drawImage(int , int , const QImage &, int , int , int , int)
     */
 }
 
-
-void WmfWriter::drawText(int , int , int , int , int , const QString& , double)
+void WmfWriter::drawText(int, int, int, int, int, const QString &, double)
 {
-//    d->mSt << (quint32)3 << (quint16)0x0A32;
+    //    d->mSt << (quint32)3 << (quint16)0x0A32;
 }
 
 //-----------------------------------------------------------------------------
@@ -437,15 +394,14 @@ void WmfWriter::drawText(int , int , int , int , int , const QString& , double)
 
 void WmfWriter::pointArray(const QPolygon &pa)
 {
-    int  left, top, i, max;
+    int left, top, i, max;
 
-    for (i = 0, max = pa.size() ; i < max ; i++) {
+    for (i = 0, max = pa.size(); i < max; i++) {
         pa.point(i, &left, &top);
         d->mSt << (qint16)left << (qint16)top;
     }
 }
 
-
 quint32 WmfWriter::winColor(const QColor &color)
 {
     quint32 c;
@@ -457,7 +413,6 @@ quint32 WmfWriter::winColor(const QColor &color)
     return c;
 }
 
-
 void WmfWriter::angleToxy(int &xStart, int &yStart, int &xEnd, int &yEnd, int a, int alen)
 {
     double angleStart, angleLength;
@@ -471,13 +426,13 @@ void WmfWriter::angleToxy(int &xStart, int &yStart, int &xEnd, int &yEnd, int a,
     yEnd = -(int)(sin(angleLength) * 50);
 }
 
-
-quint16  WmfWriter::qtRasterToWin16(QPainter::CompositionMode op) const
+quint16 WmfWriter::qtRasterToWin16(QPainter::CompositionMode op) const
 {
     int i;
 
-    for (i = 0 ; i < 17 ; i++) {
-        if (koWmfOpTab16[ i ] == op)  break;
+    for (i = 0; i < 17; i++) {
+        if (koWmfOpTab16[i] == op)
+            break;
     }
 
     if (i < 17)
@@ -486,20 +441,18 @@ quint16  WmfWriter::qtRasterToWin16(QPainter::CompositionMode op) const
         return (quint16)0;
 }
 
-
-quint32  WmfWriter::qtRasterToWin32(QPainter::CompositionMode op) const
+quint32 WmfWriter::qtRasterToWin32(QPainter::CompositionMode op) const
 {
     int i;
 
-    for (i = 0 ; i < 15 ; i++) {
-        if (koWmfOpTab32[ i ].qtRasterOp == op)  break;
+    for (i = 0; i < 15; i++) {
+        if (koWmfOpTab32[i].qtRasterOp == op)
+            break;
     }
 
     if (i < 15)
-        return koWmfOpTab32[ i ].winRasterOp;
+        return koWmfOpTab32[i].winRasterOp;
     else
-        return koWmfOpTab32[ 0 ].winRasterOp;
+        return koWmfOpTab32[0].winRasterOp;
 }
-
-
 }
