@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2000, S.R.Haque <shaheedhaque@hotmail.com>.
+    SPDX-FileCopyrightText: 2000 S.R.Haque <shaheedhaque@hotmail.com>.
     This file is part of the KDE project
 
     This library is free software; you can redistribute it and/or
@@ -32,7 +32,6 @@ DESCRIPTION
 
 #include <kovectorimage_export.h>
 
-#include <QLinkedList>
 #include <QList>
 #include <QPoint>
 #include <QSize>
@@ -43,20 +42,15 @@ class QPolygon;
 class KOVECTORIMAGE_EXPORT KWmf
 {
 public:
-
     // Construction.
 
-    explicit KWmf(
-        unsigned dpi);
+    explicit KWmf(unsigned dpi);
     virtual ~KWmf();
 
     // Called to parse the given file.
 
-    bool parse(
-        const QString &file);
-    bool parse(
-        QDataStream &stream,
-        unsigned size);
+    bool parse(const QString &file);
+    bool parse(QDataStream &stream, unsigned size);
 
     class KOVECTORIMAGE_EXPORT DrawContext
     {
@@ -72,33 +66,16 @@ public:
 
     // Should be protected...
 
-    void brushSet(
-        unsigned color,
-        unsigned style);
-    void penSet(
-        unsigned color,
-        unsigned style,
-        unsigned width);
+    void brushSet(unsigned color, unsigned style);
+    void penSet(unsigned color, unsigned style, unsigned width);
 
 protected:
     // Override to get results of parsing.
 
-    virtual void gotEllipse(
-        const DrawContext &dc,
-        QString type,
-        QPoint topLeft,
-        QSize halfAxes,
-        unsigned startAngle,
-        unsigned stopAngle) = 0;
-    virtual void gotPolygon(
-        const DrawContext &dc,
-        const QPolygon &points) = 0;
-    virtual void gotPolyline(
-        const DrawContext &dc,
-        const QPolygon &points) = 0;
-    virtual void gotRectangle(
-        const DrawContext &dc,
-        const QPolygon &points) = 0;
+    virtual void gotEllipse(const DrawContext &dc, QString type, QPoint topLeft, QSize halfAxes, unsigned startAngle, unsigned stopAngle) = 0;
+    virtual void gotPolygon(const DrawContext &dc, const QPolygon &points) = 0;
+    virtual void gotPolyline(const DrawContext &dc, const QPolygon &points) = 0;
+    virtual void gotRectangle(const DrawContext &dc, const QPolygon &points) = 0;
 
 private:
     // Debug support.
@@ -117,7 +94,7 @@ private:
     int m_windowFlipX;
     int m_windowFlipY;
     DrawContext m_dc;
-    QLinkedList<DrawContext> m_savedDcs;
+    QList<DrawContext> m_savedDcs;
     QPoint m_lineFrom;
 
     // Windows handle management.
@@ -125,22 +102,24 @@ private:
     class WinObjHandle
     {
     public:
-        virtual ~WinObjHandle() {}
+        virtual ~WinObjHandle()
+        {
+        }
         virtual void apply(KWmf &p) = 0;
     };
 
-    class WinObjBrushHandle: public WinObjHandle
+    class WinObjBrushHandle : public WinObjHandle
     {
     public:
-        virtual void apply(KWmf &p);
+        void apply(KWmf &p) override;
         unsigned m_color;
         unsigned m_style;
     };
 
-    class WinObjPenHandle: public WinObjHandle
+    class WinObjPenHandle : public WinObjHandle
     {
     public:
-        virtual void apply(KWmf &p);
+        void apply(KWmf &p) override;
         unsigned m_color;
         unsigned m_style;
         unsigned m_width;
@@ -148,29 +127,18 @@ private:
 
     WinObjPenHandle *handleCreatePen(void);
     WinObjBrushHandle *handleCreateBrush(void);
-    QList<WinObjHandle *>m_objectHandles;
+    QList<WinObjHandle *> m_objectHandles;
 
     unsigned getColor(S32 color);
-    QPoint normalisePoint(
-        QDataStream &operands);
-    QSize normaliseSize(
-        QDataStream &operands);
-    void genericArc(
-        const QString &type,
-        QDataStream &operands);
+    QPoint normalisePoint(QDataStream &operands);
+    QSize normaliseSize(QDataStream &operands);
+    void genericArc(const QString &type, QDataStream &operands);
 
     // Opcode handling and painter methods.
 
-    void walk(
-        U32 words,
-        QDataStream &stream);
-    void skip(
-        U32 words,
-        QDataStream &operands);
-    void invokeHandler(
-        S16 opcode,
-        U32 words,
-        QDataStream &operands);
+    void walk(U32 words, QDataStream &stream);
+    void skip(U32 words, QDataStream &operands);
+    void invokeHandler(S16 opcode, U32 words, QDataStream &operands);
     /*
         // draw multiple polygons
         void opPolypolygon(U32 words, QDataStream &operands);
