@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
- * Copyright (C) 2007 Jan Hambrecht <jaham@gmx.net>
+ * SPDX-FileCopyrightText: 2007 Jan Hambrecht <jaham@gmx.net>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "KoLineStyleModel_p.h"
@@ -22,8 +9,8 @@
 #include <QPen>
 
 KoLineStyleModel::KoLineStyleModel(QObject *parent)
-    : QAbstractListModel(parent),
-    m_hasTempStyle(false)
+    : QAbstractListModel(parent)
+    , m_hasTempStyle(false)
 {
     // add standard dash patterns
     for (int i = Qt::NoPen; i < Qt::CustomDashLine; i++) {
@@ -32,7 +19,7 @@ KoLineStyleModel::KoLineStyleModel(QObject *parent)
     }
 }
 
-int KoLineStyleModel::rowCount(const QModelIndex &/*parent*/) const
+int KoLineStyleModel::rowCount(const QModelIndex & /*parent*/) const
 {
     return m_styles.count() + (m_hasTempStyle ? 1 : 0);
 }
@@ -40,9 +27,9 @@ int KoLineStyleModel::rowCount(const QModelIndex &/*parent*/) const
 QVariant KoLineStyleModel::data(const QModelIndex &index, int role) const
 {
     if (!index.isValid())
-         return QVariant();
+        return QVariant();
 
-    switch(role) {
+    switch (role) {
     case Qt::DecorationRole: {
         QPen pen(Qt::black);
         pen.setWidth(2);
