@@ -1,20 +1,8 @@
 /*  This file is part of the KDE project
 
-    Copyright (c) 2007 Sven Langkamp <sven.langkamp@gmail.com>
+    SPDX-FileCopyrightText: 2007 Sven Langkamp <sven.langkamp@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #ifndef KORESOURCESERVEROBSERVER_H
@@ -24,16 +12,15 @@
 
 #include "KoResourceServerPolicies.h"
 
-
 /**
  * The KoResourceServerObserver class provides a interface to observe a KoResourceServer.
  * To receive notifications it needs to be added to the resource server.
  */
-template <class T, class Policy = PointerStoragePolicy<T> >
+template<class T, class Policy = PointerStoragePolicy<T>>
 class KoResourceServerObserver
 {
 public:
-    virtual ~KoResourceServerObserver() {}
+    virtual ~KoResourceServerObserver() = default;
     typedef typename Policy::PointerType PointerType;
 
     virtual void unsetResourceServer() = 0;
@@ -56,22 +43,21 @@ public:
      */
     virtual void resourceChanged(PointerType resource) = 0;
 
-     /**
+    /**
      * Will be called by the resource server when resources are added or removed
      * from a tag category
      */
-    virtual void syncTaggedResourceView()=0;
+    virtual void syncTaggedResourceView() = 0;
 
-     /**
+    /**
      * Will be called by the resource server when a new tag category has been created
      */
-    virtual void syncTagAddition(const QString& tag)=0;
+    virtual void syncTagAddition(const QString &tag) = 0;
 
-     /**
+    /**
      * Will be called by the resource server when a new tag category has been deleted
      */
-    virtual void syncTagRemoval(const QString& tag)=0;
-
+    virtual void syncTagRemoval(const QString &tag) = 0;
 };
 
 #endif // KORESOURCESERVEROBSERVER_H
