@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
- * Copyright (C) 2007 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2007 Thomas Zander <zander@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 #ifndef KoRulerController_p_h
 #define KoRulerController_p_h
@@ -28,14 +15,14 @@
 
 #include <WidgetsDebug.h>
 
-#include <QVariant>
-#include <QTextOption>
-#include <QTextDocument>
+#include <QLocale>
 #include <QTextBlock>
 #include <QTextBlockFormat>
-#include <QTextLayout>
 #include <QTextCursor>
-#include <QLocale>
+#include <QTextDocument>
+#include <QTextLayout>
+#include <QTextOption>
+#include <QVariant>
 
 #include <KoRuler.h>
 
@@ -50,20 +37,21 @@ class Q_DECL_HIDDEN KoRulerController::Private
 {
 public:
     Private(KoRuler *r, KoCanvasResourceManager *crp)
-            : ruler(r),
-            resourceManager(crp),
-            lastPosition(-1),
-            originalTabIndex(-2),
-            currentTabIndex(-2) {
+        : ruler(r)
+        , resourceManager(crp)
+        , lastPosition(-1)
+        , originalTabIndex(-2)
+        , currentTabIndex(-2)
+    {
     }
 
-    void canvasResourceChanged(int key) {
-        if (key != KoText::CurrentTextPosition && key != KoText::CurrentTextDocument
-            && key != KoCanvasResourceManager::ActiveRange)
+    void canvasResourceChanged(int key)
+    {
+        if (key != KoText::CurrentTextPosition && key != KoText::CurrentTextDocument && key != KoCanvasResourceManager::ActiveRange)
             return;
 
         QTextBlock block = currentBlock();
-        if (! block.isValid()) {
+        if (!block.isValid()) {
             ruler->setShowIndents(false);
             ruler->setShowTabs(false);
             return;
@@ -84,8 +72,8 @@ public:
 
         QList<KoRuler::Tab> tabs;
         QVariant variant = format.property(KoParagraphStyle::TabPositions);
-        if (! variant.isNull()) {
-            foreach(const QVariant & var, qvariant_cast<QList<QVariant> >(variant)) {
+        if (!variant.isNull()) {
+            foreach (const QVariant &var, qvariant_cast<QList<QVariant>>(variant)) {
                 KoText::Tab textTab = var.value<KoText::Tab>();
                 KoRuler::Tab tab;
                 tab.position = textTab.position;
@@ -94,19 +82,20 @@ public:
             }
         }
         qreal tabStopDistance = format.doubleProperty(KoParagraphStyle::TabStopDistance);
-/*        if (tabStopDistance <= 0) {
-// kotextdocumentlayout hardly reachable from here :(
-    tabStopDistance = block.document()->documentLayout()->defaultTabSpacing();
-        } */
+        /*        if (tabStopDistance <= 0) {
+        // kotextdocumentlayout hardly reachable from here :(
+            tabStopDistance = block.document()->documentLayout()->defaultTabSpacing();
+                } */
         ruler->updateTabs(tabs, tabStopDistance);
 
         ruler->setShowIndents(true);
         ruler->setShowTabs(true);
     }
 
-    void indentsChanged() {
+    void indentsChanged()
+    {
         QTextBlock block = currentBlock();
-        if (! block.isValid())
+        if (!block.isValid())
             return;
         QTextCursor cursor(block);
         QTextBlockFormat bf = cursor.blockFormat();
@@ -116,11 +105,12 @@ public:
         cursor.setBlockFormat(bf);
     }
 
-    void tabChanged(int originalIndex, KoRuler::Tab *tab) {
+    void tabChanged(int originalIndex, KoRuler::Tab *tab)
+    {
         QVariant docVar = resourceManager->resource(KoText::CurrentTextDocument);
         if (docVar.isNull())
             return;
-        QTextDocument *doc = static_cast<QTextDocument*>(docVar.value<void*>());
+        QTextDocument *doc = static_cast<QTextDocument *>(docVar.value<void *>());
         if (doc == nullptr)
             return;
         const int position = resourceManager->intResource(KoText::CurrentTextPosition);
@@ -141,7 +131,7 @@ public:
                 currentTab = KoText::Tab();
                 currentTab.type = tab->type;
                 if (tab->type == QTextOption::DelimiterTab)
-                    currentTab.delimiter = QLocale::system().decimalPoint(); // TODO check language of text
+                    currentTab.delimiter = QLocale::system().decimalPoint()[0]; // TODO check language of text
                 currentTabIndex = tabList.count();
                 tabList << currentTab;
             } else {
@@ -168,7 +158,7 @@ public:
         QVector<KoText::Tab> sortedList = tabList;
         std::sort(sortedList.begin(), sortedList.end(), compareTabs);
         QList<QVariant> list;
-        foreach(const KoText::Tab & tab, sortedList) {
+        foreach (const KoText::Tab &tab, sortedList) {
             QVariant v;
             v.setValue(tab);
             list.append(v);
@@ -177,27 +167,30 @@ public:
         cursor.mergeBlockFormat(bf);
     }
 
-    QTextBlock currentBlock() {
+    QTextBlock currentBlock()
+    {
         QVariant docVar = resourceManager->resource(KoText::CurrentTextDocument);
         if (docVar.isNull())
             return QTextBlock();
-        QTextDocument *doc = static_cast<QTextDocument*>(docVar.value<void*>());
+        QTextDocument *doc = static_cast<QTextDocument *>(docVar.value<void *>());
         if (doc == nullptr)
             return QTextBlock();
         return doc->findBlock(resourceManager->intResource(KoText::CurrentTextPosition));
     }
 
-    bool relativeTabs() {
+    bool relativeTabs()
+    {
         QVariant docVar = resourceManager->resource(KoText::CurrentTextDocument);
         if (docVar.isNull())
             return false;
-        QTextDocument *doc = static_cast<QTextDocument*>(docVar.value<void*>());
+        QTextDocument *doc = static_cast<QTextDocument *>(docVar.value<void *>());
         if (doc == nullptr)
             return false;
         return KoTextDocument(doc).relativeTabs();
     }
 
-    void tabChangeInitiated() {
+    void tabChangeInitiated()
+    {
         tabList.clear();
         originalTabIndex = -2;
     }
