@@ -1,47 +1,32 @@
 /* This file is part of the KDE project
-   Copyright (c) 2007 C. Boemann <cbo@boemann.dk>
+   SPDX-FileCopyrightText: 2007 C. Boemann <cbo@boemann.dk>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "KoSliderCombo.h"
 #include "KoSliderCombo_p.h"
 
-#include <QTimer>
 #include <QApplication>
+#include <QDoubleSpinBox>
+#include <QFrame>
+#include <QHBoxLayout>
+#include <QLineEdit>
+#include <QMenu>
+#include <QMouseEvent>
 #include <QSize>
 #include <QSlider>
 #include <QStyle>
-#include <QStylePainter>
 #include <QStyleOptionSlider>
-#include <QLineEdit>
+#include <QStylePainter>
+#include <QTimer>
 #include <QValidator>
-#include <QHBoxLayout>
-#include <QFrame>
-#include <QMenu>
-#include <QMouseEvent>
-#include <QDoubleSpinBox>
-#include <QDesktopWidget>
 
-
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 #include <WidgetsDebug.h>
 
 KoSliderCombo::KoSliderCombo(QWidget *parent)
-   : QComboBox(parent)
-    ,d(new KoSliderComboPrivate())
+    : QComboBox(parent)
+    , d(new KoSliderComboPrivate())
 {
     d->thePublic = this;
     d->minimum = 0.0;
@@ -51,7 +36,7 @@ KoSliderCombo::KoSliderCombo(QWidget *parent)
     d->container->setAttribute(Qt::WA_WindowPropagation);
     QStyleOptionComboBox opt;
     opt.initFrom(this);
-//    d->container->setFrameStyle(style()->styleHint(QStyle::SH_ComboBox_PopupFrameStyle, &opt, this));
+    //    d->container->setFrameStyle(style()->styleHint(QStyle::SH_ComboBox_PopupFrameStyle, &opt, this));
 
     d->slider = new QSlider(Qt::Horizontal);
     d->slider->setMinimum(0);
@@ -59,10 +44,10 @@ KoSliderCombo::KoSliderCombo(QWidget *parent)
     d->slider->setPageStep(10);
     d->slider->setValue(0);
     // When set to true, causes flicker on Qt 4.6. Any reason to keep it?
-    d->firstShowOfSlider = false; //true;
+    d->firstShowOfSlider = false; // true;
 
-    QHBoxLayout * l = new QHBoxLayout();
-    l->setMargin(2);
+    QHBoxLayout *l = new QHBoxLayout();
+    l->setContentsMargins(2, 2, 2, 2);
     l->setSpacing(2);
     l->addWidget(d->slider);
     d->container->setLayout(l);
@@ -73,9 +58,15 @@ KoSliderCombo::KoSliderCombo(QWidget *parent)
     setEditable(true);
     setEditText(QLocale().toString(0.0, d->decimals));
 
-    connect(d->slider, SIGNAL(valueChanged(int)), SLOT(sliderValueChanged(int)));
-    connect(d->slider, SIGNAL(sliderReleased()), SLOT(sliderReleased()));
-    connect(lineEdit(), SIGNAL(editingFinished()), SLOT(lineEditFinished()));
+    connect(d->slider, &QSlider::valueChanged, this, [this](int value) {
+        d->sliderValueChanged(value);
+    });
+    connect(d->slider, &QSlider::sliderReleased, this, [this]() {
+        d->sliderReleased();
+    });
+    connect(lineEdit(), &QLineEdit::editingFinished, this, [this]() {
+        d->lineEditFinished();
+    });
 }
 
 KoSliderCombo::~KoSliderCombo()
@@ -94,7 +85,7 @@ QSize KoSliderCombo::minimumSizeHint() const
 
     const QFontMetrics &fm = fontMetrics();
 
-    sh.setWidth(5 * fm.width(QLatin1Char('8')));
+    sh.setWidth(5 * fm.boundingRect(QLatin1Char('8')).width());
     sh.setHeight(qMax(fm.lineSpacing(), 14) + 2);
 
     // add style and strut values
@@ -104,19 +95,19 @@ QSize KoSliderCombo::minimumSizeHint() const
     opt.editable = true;
     sh = style()->sizeFromContents(QStyle::CT_ComboBox, &opt, sh, this);
 
-    return sh.expandedTo(QApplication::globalStrut());
+    return sh;
 }
 
 void KoSliderCombo::KoSliderComboPrivate::showPopup()
 {
-    if(firstShowOfSlider) {
-        container->show(); //show container a bit early so the slider can be layout'ed
+    if (firstShowOfSlider) {
+        container->show(); // show container a bit early so the slider can be layout'ed
         firstShowOfSlider = false;
     }
 
     QStyleOptionSlider opt;
     opt.initFrom(slider);
-    opt.maximum=256;
+    opt.maximum = 256;
     opt.sliderPosition = opt.sliderValue = slider->value();
     int hdlPos = thePublic->style()->subControlRect(QStyle::CC_Slider, &opt, QStyle::SC_SliderHandle).center().x();
 
@@ -130,13 +121,14 @@ void KoSliderCombo::KoSliderComboPrivate::showPopup()
     QRect popupRect(thePublic->mapToGlobal(QPoint(arrowPos - hdlPos - slider->x(), thePublic->size().height())), popSize);
 
     // Make sure the popup is not drawn outside the screen area
-    QRect screenRect = QApplication::desktop()->availableGeometry(thePublic);
-    if (popupRect.right() > screenRect.right())
-        popupRect.translate(screenRect.right() - popupRect.right(), 0);
-    if (popupRect.left() < screenRect.left())
-        popupRect.translate(screenRect.left() - popupRect.left(), 0);
-    if (popupRect.bottom() > screenRect.bottom())
-        popupRect.translate(0, -(thePublic->height() + container->height()));
+    // todo port to wayland
+    // QRect screenRect = QApplication::desktop()->availableGeometry(thePublic);
+    // if (popupRect.right() > screenRect.right())
+    //    popupRect.translate(screenRect.right() - popupRect.right(), 0);
+    // if (popupRect.left() < screenRect.left())
+    //    popupRect.translate(screenRect.left() - popupRect.left(), 0);
+    // if (popupRect.bottom() > screenRect.bottom())
+    //    popupRect.translate(0, -(thePublic->height() + container->height()));
 
     container->setGeometry(popupRect);
     container->raise();
@@ -156,17 +148,16 @@ void KoSliderCombo::hideEvent(QHideEvent *)
 
 void KoSliderCombo::changeEvent(QEvent *e)
 {
-    switch (e->type())
-    {
-        case QEvent::EnabledChange:
-            if (!isEnabled())
-                d->hidePopup();
-            break;
-        case QEvent::PaletteChange:
-            d->container->setPalette(palette());
-            break;
-        default:
-            break;
+    switch (e->type()) {
+    case QEvent::EnabledChange:
+        if (!isEnabled())
+            d->hidePopup();
+        break;
+    case QEvent::PaletteChange:
+        d->container->setPalette(palette());
+        break;
+    default:
+        break;
     }
     QComboBox::changeEvent(e);
 }
@@ -191,27 +182,30 @@ void KoSliderCombo::mousePressEvent(QMouseEvent *e)
     opt.initFrom(this);
     opt.subControls = QStyle::SC_All;
     opt.editable = true;
-    QStyle::SubControl sc = style()->hitTestComplexControl(QStyle::CC_ComboBox, &opt, e->pos(),
-                                                           this);
-    if (sc == QStyle::SC_ComboBoxArrow && !d->container->isVisible())
-    {
+    QStyle::SubControl sc = style()->hitTestComplexControl(QStyle::CC_ComboBox, &opt, e->pos(), this);
+    if (sc == QStyle::SC_ComboBoxArrow && !d->container->isVisible()) {
         d->showPopup();
-    }
-    else
+    } else
         QComboBox::mousePressEvent(e);
 }
 
 void KoSliderCombo::keyPressEvent(QKeyEvent *e)
 {
-    if (e->key() == Qt::Key_Up) setValue(value() + d->slider->singleStep() * (maximum() - minimum()) / 256 + 0.5);
-    else if (e->key() == Qt::Key_Down) setValue(value() - d->slider->singleStep() * (maximum() - minimum()) / 256 - 0.5);
-    else QComboBox::keyPressEvent(e);
+    if (e->key() == Qt::Key_Up)
+        setValue(value() + d->slider->singleStep() * (maximum() - minimum()) / 256 + 0.5);
+    else if (e->key() == Qt::Key_Down)
+        setValue(value() - d->slider->singleStep() * (maximum() - minimum()) / 256 - 0.5);
+    else
+        QComboBox::keyPressEvent(e);
 }
 
 void KoSliderCombo::wheelEvent(QWheelEvent *e)
 {
-    if (e->delta() > 0) setValue(value() + d->slider->singleStep() * (maximum() - minimum()) / 256 + 0.5);
-    else setValue(value() - d->slider->singleStep() * (maximum() - minimum()) / 256 - 0.5);
+    if (e->angleDelta().y() > 0) {
+        setValue(value() + d->slider->singleStep() * (maximum() - minimum()) / 256 + 0.5);
+    } else {
+        setValue(value() - d->slider->singleStep() * (maximum() - minimum()) / 256 - 0.5);
+    }
 }
 
 void KoSliderCombo::KoSliderComboPrivate::lineEditFinished()
@@ -220,21 +214,21 @@ void KoSliderCombo::KoSliderComboPrivate::lineEditFinished()
     slider->blockSignals(true);
     slider->setValue(int((value - minimum) * 256 / (maximum - minimum) + 0.5));
     slider->blockSignals(false);
-    emit thePublic->valueChanged(value, true);
+    Q_EMIT thePublic->valueChanged(value, true);
 }
 
 void KoSliderCombo::KoSliderComboPrivate::sliderValueChanged(int slidervalue)
 {
-    thePublic->setEditText(QLocale().toString(minimum + (maximum - minimum)*slidervalue/256, decimals));
+    thePublic->setEditText(QLocale().toString(minimum + (maximum - minimum) * slidervalue / 256, decimals));
 
     qreal value = QLocale().toDouble(thePublic->currentText());
-    emit thePublic->valueChanged(value, false);
+    Q_EMIT thePublic->valueChanged(value, false);
 }
 
 void KoSliderCombo::KoSliderComboPrivate::sliderReleased()
 {
     qreal value = QLocale().toDouble(thePublic->currentText());
-    emit thePublic->valueChanged(value, true);
+    Q_EMIT thePublic->valueChanged(value, true);
 }
 
 qreal KoSliderCombo::maximum() const
@@ -260,8 +254,10 @@ qreal KoSliderCombo::value() const
 void KoSliderCombo::setDecimals(int dec)
 {
     d->decimals = dec;
-    if (dec == 0) lineEdit()->setValidator(new QIntValidator(this));
-    else lineEdit()->setValidator(new QDoubleValidator(this));
+    if (dec == 0)
+        lineEdit()->setValidator(new QIntValidator(this));
+    else
+        lineEdit()->setValidator(new QDoubleValidator(this));
 }
 
 void KoSliderCombo::setMinimum(qreal min)
@@ -276,30 +272,28 @@ void KoSliderCombo::setMaximum(qreal max)
 
 void KoSliderCombo::setValue(qreal value)
 {
-    if(value < d->minimum)
+    if (value < d->minimum)
         value = d->minimum;
-    if(value > d->maximum)
+    if (value > d->maximum)
         value = d->maximum;
     setEditText(QLocale().toString(value, d->decimals));
     d->slider->blockSignals(true);
     d->slider->setValue(int((value - d->minimum) * 256 / (d->maximum - d->minimum) + 0.5));
     d->slider->blockSignals(false);
-    emit valueChanged(value, true);
+    Q_EMIT valueChanged(value, true);
 }
 
 void KoSliderComboContainer::mousePressEvent(QMouseEvent *e)
 {
     QStyleOptionComboBox opt;
-    opt.init(m_parent);
+    opt.initFrom(m_parent);
     opt.subControls = QStyle::SC_All;
     opt.activeSubControls = QStyle::SC_ComboBoxArrow;
-    QStyle::SubControl sc = style()->hitTestComplexControl(QStyle::CC_ComboBox, &opt,
-                                                           m_parent->mapFromGlobal(e->globalPos()),
-                                                           m_parent);
+    QStyle::SubControl sc = style()->hitTestComplexControl(QStyle::CC_ComboBox, &opt, m_parent->mapFromGlobal(e->globalPos()), m_parent);
     if (sc == QStyle::SC_ComboBoxArrow)
         setAttribute(Qt::WA_NoMouseReplay);
     QMenu::mousePressEvent(e);
 }
 
-//have to include this because of Q_PRIVATE_SLOT
+// have to include this because of Q_PRIVATE_SLOT
 #include <moc_KoSliderCombo.cpp>
