@@ -1,36 +1,24 @@
 /*
- * Copyright (c) 2005 Boudewijn Rempt <boud@valdyas.org>
- * Copyright (c) 2005-2008 Thomas Zander <zander@kde.org>
- * Copyright (c) 2009 Peter Simonsson <peter.simonsson@gmail.com>
- * Copyright (c) 2010 Cyrille Berger <cberger@cberger.net>
+ * SPDX-FileCopyrightText: 2005 Boudewijn Rempt <boud@valdyas.org>
+ * SPDX-FileCopyrightText: 2005-2008 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2009 Peter Simonsson <peter.simonsson@gmail.com>
+ * SPDX-FileCopyrightText: 2010 Cyrille Berger <cberger@cberger.net>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 #ifndef _KO_TOOLBOX_H_
 #define _KO_TOOLBOX_H_
 
 #include <KoCanvasObserverBase.h>
 
-#include <QWidget>
 #include <QList>
+#include <QWidget>
 
 #include <KoToolManager.h>
 
 class KoCanvasController;
 class KoShapeLayer;
+class KoToolBoxLayout;
 
 /**
  * KoToolBox is a dock widget that can order tools according to type and
@@ -46,38 +34,39 @@ class KoShapeLayer;
  * rotating in a smart way to show the buttons optimally.
  * @see KoToolManager
  */
-class KoToolBox : public QWidget {
+class KoToolBox : public QWidget
+{
     Q_OBJECT
 public:
     /// constructor
     explicit KoToolBox();
-    ~KoToolBox();
+    ~KoToolBox() override;
+
+    void applyIconSize();
 
 public Q_SLOTS:
     /**
-     * Using the buttongroup id passed in addButton() you can set the new active button.
-     * If the id does not resolve to a visible button, this call is ignored.
+     * Set the new active button based on the currently active tool.
      * @param canvas the currently active canvas.
-     * @param id an id to identify the button to activate.
      */
-    void setActiveTool(KoCanvasController *canvas, int id);
+    void setActiveTool(KoCanvasController *canvas);
 
     /**
      * Show only the dynamic buttons that have a code from parameter codes.
      * The toolbox allows buttons to be optionally registered with a visibilityCode. This code
      * can be passed here and all buttons that have that code are shown. All buttons that
      * have another visibility code registered are hidden.
-     * @param canvas the currently active canvas.
      * @param codes a list of all the codes to show.
      */
     void setButtonsVisible(const QList<QString> &codes);
 
-
     /// Set the orientation of the layout to @p orientation
     void setOrientation(Qt::Orientation orientation);
 
     void setFloating(bool v);
 
+    KoToolBoxLayout *toolBoxLayout() const;
+
 private:
     /**
      * Add a button to the toolbox.
@@ -90,28 +79,26 @@ private:
     void addButton(KoToolAction *toolAction);
 
 private Q_SLOTS:
-    void setCurrentLayer(const KoCanvasController *canvas, const KoShapeLayer* newLayer);
+    void setCurrentLayer(const KoCanvasController *canvas, const KoShapeLayer *newLayer);
 
     /// add a tool post-initialization. The tool will also be activated.
     void toolAdded(KoToolAction *toolAction, KoCanvasController *canvas);
 
-    /// resize the toolbox to show the icons without any gap at the edge
-    void adjustToFit();
-
-    /// unlocks the with after adjustToFit
-    void resizeUnlock();
-
     /// set the icon size for all the buttons
     void slotContextIconSize();
 
 protected:
-    void paintEvent(QPaintEvent *event);
-    void resizeEvent(QResizeEvent* event);
-    void contextMenuEvent(QContextMenuEvent *event);
+    void paintEvent(QPaintEvent *event) override;
+    void changeEvent(QEvent *event) override;
+
+private:
+    void setupIconSizeMenu(QMenu *menu);
+
+    friend class KoToolBoxDocker;
 
 private:
     class Private;
-    Private * const d;
+    std::unique_ptr<Private> const d;
 };
 
 #endif // _KO_TOOLBOX_H_
