@@ -1,34 +1,21 @@
 /*
- *  Copyright (c) 2011 Srikanth Tiyyagura <srikanth.tulasiram@gmail.com>
+ *  SPDX-FileCopyrightText: 2011 Srikanth Tiyyagura <srikanth.tulasiram@gmail.com>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "KoResourceTaggingTest.h"
 
-#include <QTest>
 #include <QCoreApplication>
 #include <QFileInfo>
+#include <QTest>
 
-#include <kactioncollection.h>
+#include <KActionCollection>
 #include <WidgetsDebug.h>
 
 #include "KoResource.h"
 #include "KoResourceServerProvider.h"
 
-
 void KoResourceTaggingTest::initTestCase()
 {
     // use global png files as dummy pattern dir for now
@@ -41,13 +28,13 @@ void KoResourceTaggingTest::testInitialization()
 {
     KoResourceTagStore tagStore(KoResourceServerProvider::instance()->patternServer());
     QVERIFY(tagStore.tagNamesList().isEmpty());
-    QVERIFY(tagStore.assignedTagsList(0).isEmpty());
+    QVERIFY(tagStore.assignedTagsList(nullptr).isEmpty());
     QVERIFY(tagStore.searchTag("bla").isEmpty());
 }
 
 void KoResourceTaggingTest::testTagging()
 {
-    KoResourceServer<KoPattern>* patServer = KoResourceServerProvider::instance()->patternServer();
+    KoResourceServer<KoPattern> *patServer = KoResourceServerProvider::instance()->patternServer();
     KoResourceTagStore tagStore(patServer);
     KoResource *res = patServer->resources().constFirst();
     QVERIFY(res);
@@ -92,15 +79,14 @@ void KoResourceTaggingTest::testTagging()
 
     tagStore.delTag("test1");
     QVERIFY(tagStore.tagNamesList().size() == 1);
-
 }
 
 void KoResourceTaggingTest::testReadWriteXML()
 {
-    KoResourceServer<KoPattern>* patServer = KoResourceServerProvider::instance()->patternServer();
+    KoResourceServer<KoPattern> *patServer = KoResourceServerProvider::instance()->patternServer();
     KoResourceTagStore tagStore(patServer);
 
-    QList<KoPattern*> patterns = patServer->resources();
+    QList<KoPattern *> patterns = patServer->resources();
     Q_ASSERT(patterns.size() > 5);
     tagStore.addTag(patterns[0], "test0");
     tagStore.addTag(patterns[1], "test1");
@@ -112,7 +98,7 @@ void KoResourceTaggingTest::testReadWriteXML()
     tagStore.addTag(patterns[5], "test5");
     tagStore.addTag(patterns[5], "test5.1");
     tagStore.addTag(patterns[5], "test5.2");
-    tagStore.addTag(0, "dummytest");
+    tagStore.addTag(nullptr, "dummytest");
 
     QVERIFY(tagStore.tagNamesList().size() == 9);
 
