@@ -1,27 +1,13 @@
 /* This file is part of the KDE project
-   Copyright (C) 2018 Dag Andersen <danders@get2net.dk>
-   Copyright 2007 Stefan Nikolaus <stefan.nikolaus@kdemail.net>
+   SPDX-FileCopyrightText: 2018 Dag Andersen <danders@get2net.dk>
+   SPDX-FileCopyrightText: 2007 Stefan Nikolaus <stefan.nikolaus@kdemail.net>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KCHART_CHART_SHAPE_FACTORY
 #define KCHART_CHART_SHAPE_FACTORY
 
-
 // Qt
 #include <QStringList>
 
@@ -29,40 +15,38 @@
 #include <KoShapeFactoryBase.h>
 #include <QVariantList>
 
-
 class KoShape;
 class KoShapeConfigWidgetBase;
 
-namespace KoChart {
-    class ChartShape;
+namespace KoChart
+{
+class ChartShape;
 }
 
 class ChartShapePlugin : public QObject
 {
     Q_OBJECT
 public:
-
-    ChartShapePlugin(QObject *parent, const QVariantList&);
-    ~ChartShapePlugin() {}
+    ChartShapePlugin(QObject *parent, const QVariantList &);
+    ~ChartShapePlugin() = default;
 };
 
-
 class ChartShapeFactory : public KoShapeFactoryBase
 {
 public:
     ChartShapeFactory();
-    ~ChartShapeFactory() {}
+    ~ChartShapeFactory() = default;
 
     bool supports(const KoXmlElement &element, KoShapeLoadingContext &context) const override;
 
-    KoShape *createShape(const KoProperties* properties, KoDocumentResourceManager *documentResources) const override;
+    KoShape *createShape(const KoProperties *properties, KoDocumentResourceManager *documentResources) const override;
 
-    KoShape *createDefaultShape(KoDocumentResourceManager *documentResources = 0) const override;
+    KoShape *createDefaultShape(KoDocumentResourceManager *documentResources = nullptr) const override;
     // reimplemented to not create a default shape to just overwrite it afterwards
     KoShape *createShapeFromOdf(const KoXmlElement &element, KoShapeLoadingContext &context) override;
     void newDocumentResourceManager(KoDocumentResourceManager *manager) const override;
 
-    QList<KoShapeConfigWidgetBase*> createShapeOptionPanels() override;
+    QList<KoShapeConfigWidgetBase *> createShapeOptionPanels() override;
 
 private:
     KoChart::ChartShape *createBarChart(KoDocumentResourceManager *documentResources, int subtype) const;
@@ -77,8 +61,6 @@ private:
     KoChart::ChartShape *createFilledRadarChart(KoDocumentResourceManager *documentResources) const;
 
     void radarData(KoChart::ChartShape *shape) const;
-
 };
 
-
 #endif // KCHART_CHART_SHAPE_FACTORY
