@@ -1,25 +1,11 @@
 /* This file is part of the KDE project
 
-   Copyright 2008 Johannes Simon <johannes.simon@gmail.com>
-   Copyright 2009 Inge Wallin    <inge@lysator.liu.se>
+   SPDX-FileCopyrightText: 2008 Johannes Simon <johannes.simon@gmail.com>
+   SPDX-FileCopyrightText: 2009 Inge Wallin <inge@lysator.liu.se>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-
 // Own
 #include "ChartTableModel.h"
 
@@ -27,51 +13,49 @@
 #include <cmath>
 
 // Qt
-#include <QDomNode>
 #include <QDomDocument>
+#include <QDomNode>
 
 // Calligra
-#include <KoXmlReader.h>
-#include <KoXmlWriter.h>
 #include <KoGenStyles.h>
-#include <KoXmlNS.h>
 #include <KoOdfLoadingContext.h>
 #include <KoShapeLoadingContext.h>
+#include <KoXmlNS.h>
+#include <KoXmlReader.h>
+#include <KoXmlWriter.h>
 
 // KoChart
 #include "CellRegion.h"
-#include "OdfLoadingHelper.h"
 #include "ChartDebug.h"
+#include "OdfLoadingHelper.h"
 
-
-namespace KoChart {
+namespace KoChart
+{
 
 ChartTableModel::ChartTableModel(QObject *parent /* = 0 */)
     : QStandardItemModel(parent)
 {
 }
 
-ChartTableModel::~ChartTableModel()
-{
-}
+ChartTableModel::~ChartTableModel() = default;
 
 QVariant ChartTableModel::headerData(int section, Qt::Orientation orientation, int role) const
 {
     if (orientation == Qt::Horizontal) {
         if (role == Qt::DisplayRole) {
-            return CellRegion::columnName(section+1);
+            return CellRegion::columnName(section + 1);
         }
     }
     return QStandardItemModel::headerData(section, orientation, role);
 }
 
-QHash<QString, QVector<QRect> > ChartTableModel::cellRegion() const
+QHash<QString, QVector<QRect>> ChartTableModel::cellRegion() const
 {
     // FIXME: Unimplemented?
-    return QHash<QString, QVector<QRect> >();
+    return QHash<QString, QVector<QRect>>();
 }
 
-bool ChartTableModel::setCellRegion(const QString& /*regionName*/)
+bool ChartTableModel::setCellRegion(const QString & /*regionName*/)
 {
 #if 0 // FIXME: What does this code do?
     int result = 0;
@@ -87,45 +71,45 @@ bool ChartTableModel::setCellRegion(const QString& /*regionName*/)
     return true;
 }
 
-bool ChartTableModel::isCellRegionValid(const QString& regionName) const
+bool ChartTableModel::isCellRegionValid(const QString &regionName) const
 {
     Q_UNUSED(regionName);
 
     return true;
 }
 
-bool ChartTableModel::loadOdf(const KoXmlElement &tableElement,
-                              KoShapeLoadingContext &context)
+bool ChartTableModel::loadOdf(const KoXmlElement &tableElement, KoShapeLoadingContext &context)
 {
     Q_UNUSED(context);
 
-    debugChartOdf<<"Load table";
+    debugChartOdf << "Load table";
     setRowCount(0);
     setColumnCount(0);
 
-    //QDomDocument doc;
-    //KoXml::asQDomElement(doc, tableElement);
-    //QTextStream stream(stdout);
-    //stream << doc.documentElement();
+    // QDomDocument doc;
+    // KoXml::asQDomElement(doc, tableElement);
+    // QTextStream stream(stdout);
+    // stream << doc.documentElement();
 
     int row = 0;
-    KoXmlElement  n;
-    forEachElement (n, tableElement) {
+    KoXmlElement n;
+    forEachElement(n, tableElement)
+    {
         if (n.namespaceURI() != KoXmlNS::table)
             continue;
 
         if (n.localName() == "table-columns" || n.localName() == "table-header-columns") {
             int column = 0;
-            KoXmlElement  _n;
-            forEachElement (_n, n) {
+            KoXmlElement _n;
+            forEachElement(_n, n)
+            {
                 if (_n.namespaceURI() != KoXmlNS::table || _n.localName() != "table-column")
                     continue;
                 column += qMax(1, _n.attributeNS(KoXmlNS::table, "number-columns-repeated").toInt());
                 if (column > columnCount())
                     setColumnCount(column);
             }
-        }
-        else if (n.localName() == "table-rows" || n.localName() == "table-header-rows") {
+        } else if (n.localName() == "table-rows" || n.localName() == "table-header-rows") {
             if (n.localName() == "table-header-rows") {
                 if (row >= 1) {
                     // There can only be one header-row and only at the very beginning.
@@ -135,8 +119,9 @@ bool ChartTableModel::loadOdf(const KoXmlElement &tableElement,
                 }
             }
 
-            KoXmlElement  _n;
-            forEachElement (_n, n) {
+            KoXmlElement _n;
+            forEachElement(_n, n)
+            {
                 if (_n.namespaceURI() != KoXmlNS::table || _n.localName() != "table-row")
                     continue;
 
@@ -144,9 +129,10 @@ bool ChartTableModel::loadOdf(const KoXmlElement &tableElement,
                 setRowCount(row + 1);
 
                 // Loop through all cells in a table row.
-                int  column = 0;
-                KoXmlElement  __n;
-                forEachElement (__n, _n) {
+                int column = 0;
+                KoXmlElement __n;
+                forEachElement(__n, _n)
+                {
                     if (__n.namespaceURI() != KoXmlNS::table || __n.localName() != "table-cell")
                         continue;
 
@@ -183,11 +169,11 @@ bool ChartTableModel::loadOdf(const KoXmlElement &tableElement,
             } // foreach table:table-row
         }
     }
-    debugChartOdf<<"Loaded table:"<<rowCount()<<','<<columnCount();
+    debugChartOdf << "Loaded table:" << rowCount() << ',' << columnCount();
     return true;
 }
 
-bool ChartTableModel::saveOdf(KoXmlWriter &bodyWriter, KoGenStyles &mainStyles ) const
+bool ChartTableModel::saveOdf(KoXmlWriter &bodyWriter, KoGenStyles &mainStyles) const
 {
     Q_UNUSED(bodyWriter);
     Q_UNUSED(mainStyles);
