@@ -1,23 +1,10 @@
 /* This file is part of the KDE project
 
-   Copyright 2007-2008 Johannes Simon <johannes.simon@gmail.com>
-   Copyright 2009      Inge Wallin    <inge@lysator.liu.se>
-   Copyright 2018 Dag Andersen <danders@get2net.dk>
+   SPDX-FileCopyrightText: 2007-2008 Johannes Simon <johannes.simon@gmail.com>
+   SPDX-FileCopyrightText: 2009 Inge Wallin <inge@lysator.liu.se>
+   SPDX-FileCopyrightText: 2018 Dag Andersen <danders@get2net.dk>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // Own
@@ -26,52 +13,51 @@
 
 // Qt
 #include <QAction>
-#include <QMenu>
 #include <QLatin1String>
+#include <QMenu>
 
 // KF5
-#include <klocalizedstring.h>
-#include <kmessagebox.h>
+#include <KLocalizedString>
+#include <KMessageBox>
 #include <kfontchooser.h>
 
 // Calligra
-#include <interfaces/KoChartModel.h>
 #include <KoIcon.h>
+#include <interfaces/KoChartModel.h>
 
 // KChart
-#include <KChartChart>
-#include <KChartPosition>
-#include <KChartCartesianAxis>
-#include <KChartGridAttributes>
 #include <KChartAbstractCartesianDiagram>
-#include <KChartLegend>
+#include <KChartCartesianAxis>
+#include <KChartChart>
 #include <KChartDataValueAttributes>
-#include <KChartTextAttributes>
+#include <KChartGridAttributes>
+#include <KChartLegend>
 #include <KChartMarkerAttributes>
 #include <KChartMeasure>
+#include <KChartPosition>
+#include <KChartTextAttributes>
 
 // KoChart
-#include "ChartProxyModel.h"
-#include "PlotArea.h"
-#include "Legend.h"
-#include "DataSet.h"
 #include "Axis.h"
-#include "ui_ChartTableEditor.h"
-#include "NewAxisDialog.h"
 #include "AxisScalingDialog.h"
+#include "CellRegionDialog.h"
+#include "CellRegionStringValidator.h"
+#include "ChartDebug.h"
+#include "ChartProxyModel.h"
+#include "ChartTableModel.h"
+#include "DataSet.h"
 #include "FontEditorDialog.h"
 #include "FormatErrorBarDialog.h"
-#include "CellRegionDialog.h"
+#include "Legend.h"
+#include "NewAxisDialog.h"
+#include "PlotArea.h"
 #include "TableEditorDialog.h"
-#include "commands/ChartTypeCommand.h"
-#include "CellRegionStringValidator.h"
-#include "ChartTableModel.h"
 #include "TableSource.h"
-#include "ChartDebug.h"
+#include "commands/ChartTypeCommand.h"
+#include "ui_ChartTableEditor.h"
 
 using namespace KoChart;
 
-
 class DataSetConfigWidget::Private
 {
 public:
@@ -80,8 +66,8 @@ public:
 
     Ui::DataSetConfigWidget ui;
 
-    QList<Axis*> dataSetAxes;
-    QList<DataSet*> dataSets;
+    QList<Axis *> dataSetAxes;
+    QList<DataSet *> dataSets;
     int selectedDataSet;
 
     // Menus
@@ -92,59 +78,59 @@ public:
     QMenu *dataSetStockChartMenu;
 
     // chart type selection actions
-    QAction  *normalBarChartAction;
-    QAction  *stackedBarChartAction;
-    QAction  *percentBarChartAction;
+    QAction *normalBarChartAction;
+    QAction *stackedBarChartAction;
+    QAction *percentBarChartAction;
 
-    QAction  *normalLineChartAction;
-    QAction  *stackedLineChartAction;
-    QAction  *percentLineChartAction;
+    QAction *normalLineChartAction;
+    QAction *stackedLineChartAction;
+    QAction *percentLineChartAction;
 
-    QAction  *normalAreaChartAction;
-    QAction  *stackedAreaChartAction;
-    QAction  *percentAreaChartAction;
+    QAction *normalAreaChartAction;
+    QAction *stackedAreaChartAction;
+    QAction *percentAreaChartAction;
 
-    QAction  *circleChartAction;
-    QAction  *ringChartAction;
-    QAction  *radarChartAction;
-    QAction  *filledRadarChartAction;
+    QAction *circleChartAction;
+    QAction *ringChartAction;
+    QAction *radarChartAction;
+    QAction *filledRadarChartAction;
 
-    QAction  *scatterChartAction;
-    QAction  *bubbleChartAction;
+    QAction *scatterChartAction;
+    QAction *bubbleChartAction;
 
-    QAction  *hlcStockChartAction;
-    QAction  *ohlcStockChartAction;
-    QAction  *candlestickStockChartAction;
+    QAction *hlcStockChartAction;
+    QAction *ohlcStockChartAction;
+    QAction *candlestickStockChartAction;
 
-    QAction  *surfaceChartAction;
-    QAction  *ganttChartAction;
+    QAction *surfaceChartAction;
+    QAction *ganttChartAction;
 
     // chart type selection actions for datasets
-    QAction  *dataSetNormalBarChartAction;
-    QAction  *dataSetStackedBarChartAction;
-    QAction  *dataSetPercentBarChartAction;
+    QAction *dataSetNormalBarChartAction;
+    QAction *dataSetStackedBarChartAction;
+    QAction *dataSetPercentBarChartAction;
 
-    QAction  *dataSetNormalLineChartAction;
-    QAction  *dataSetStackedLineChartAction;
-    QAction  *dataSetPercentLineChartAction;
+    QAction *dataSetNormalLineChartAction;
+    QAction *dataSetStackedLineChartAction;
+    QAction *dataSetPercentLineChartAction;
 
-    QAction  *dataSetNormalAreaChartAction;
-    QAction  *dataSetStackedAreaChartAction;
-    QAction  *dataSetPercentAreaChartAction;
+    QAction *dataSetNormalAreaChartAction;
+    QAction *dataSetStackedAreaChartAction;
+    QAction *dataSetPercentAreaChartAction;
 
-    QAction  *dataSetCircleChartAction;
-    QAction  *dataSetRingChartAction;
-    QAction  *dataSetRadarChartAction;
-    QAction  *dataSetFilledRadarChartAction;
-    QAction  *dataSetScatterChartAction;
-    QAction  *dataSetBubbleChartAction;
+    QAction *dataSetCircleChartAction;
+    QAction *dataSetRingChartAction;
+    QAction *dataSetRadarChartAction;
+    QAction *dataSetFilledRadarChartAction;
+    QAction *dataSetScatterChartAction;
+    QAction *dataSetBubbleChartAction;
 
-    QAction  *dataSetHLCStockChartAction;
-    QAction  *dataSetOHLCStockChartAction;
-    QAction  *dataSetCandlestickStockChartAction;
+    QAction *dataSetHLCStockChartAction;
+    QAction *dataSetOHLCStockChartAction;
+    QAction *dataSetCandlestickStockChartAction;
 
-    QAction  *dataSetSurfaceChartAction;
-    QAction  *dataSetGanttChartAction;
+    QAction *dataSetSurfaceChartAction;
+    QAction *dataSetGanttChartAction;
 
     // marker selection actions for datasets
     QAction *dataSetNoMarkerAction;
@@ -170,7 +156,6 @@ public:
     FormatErrorBarDialog formatErrorBarDialog;
 };
 
-
 DataSetConfigWidget::Private::Private(DataSetConfigWidget *parent)
     : formatErrorBarDialog(parent)
 
@@ -179,31 +164,31 @@ DataSetConfigWidget::Private::Private(DataSetConfigWidget *parent)
 
     selectedDataSet = 0;
 
-    dataSetBarChartMenu = 0;
-    dataSetLineChartMenu = 0;
-    dataSetAreaChartMenu = 0;
-    dataSetRadarChartMenu = 0;
-    dataSetStockChartMenu = 0;
-    dataSetNormalBarChartAction = 0;
-    dataSetStackedBarChartAction = 0;
-    dataSetPercentBarChartAction = 0;
-    dataSetNormalLineChartAction = 0;
-    dataSetStackedLineChartAction = 0;
-    dataSetPercentLineChartAction = 0;
-    dataSetNormalAreaChartAction = 0;
-    dataSetStackedAreaChartAction = 0;
-    dataSetPercentAreaChartAction = 0;
-    dataSetCircleChartAction = 0;
-    dataSetRingChartAction = 0;
-    dataSetScatterChartAction = 0;
-    dataSetRadarChartAction = 0;
-    dataSetFilledRadarChartAction = 0;
-    dataSetHLCStockChartAction = 0;
-    dataSetOHLCStockChartAction = 0;
-    dataSetCandlestickStockChartAction = 0;
-    dataSetBubbleChartAction = 0;
-    dataSetSurfaceChartAction = 0;
-    dataSetGanttChartAction = 0;
+    dataSetBarChartMenu = nullptr;
+    dataSetLineChartMenu = nullptr;
+    dataSetAreaChartMenu = nullptr;
+    dataSetRadarChartMenu = nullptr;
+    dataSetStockChartMenu = nullptr;
+    dataSetNormalBarChartAction = nullptr;
+    dataSetStackedBarChartAction = nullptr;
+    dataSetPercentBarChartAction = nullptr;
+    dataSetNormalLineChartAction = nullptr;
+    dataSetStackedLineChartAction = nullptr;
+    dataSetPercentLineChartAction = nullptr;
+    dataSetNormalAreaChartAction = nullptr;
+    dataSetStackedAreaChartAction = nullptr;
+    dataSetPercentAreaChartAction = nullptr;
+    dataSetCircleChartAction = nullptr;
+    dataSetRingChartAction = nullptr;
+    dataSetScatterChartAction = nullptr;
+    dataSetRadarChartAction = nullptr;
+    dataSetFilledRadarChartAction = nullptr;
+    dataSetHLCStockChartAction = nullptr;
+    dataSetOHLCStockChartAction = nullptr;
+    dataSetCandlestickStockChartAction = nullptr;
+    dataSetBubbleChartAction = nullptr;
+    dataSetSurfaceChartAction = nullptr;
+    dataSetGanttChartAction = nullptr;
 
     // Data set chart type button
     QMenu *dataSetChartTypeMenu = new QMenu(i18n("Chart Type"), parent);
@@ -211,19 +196,18 @@ DataSetConfigWidget::Private::Private(DataSetConfigWidget *parent)
     // Default chart type is a bar chart
     dataSetChartTypeMenu->setIcon(ICON1(BarChartType));
 
-
     dataSetBarChartMenu = dataSetChartTypeMenu->addMenu(ICON1(BarChartType), i18n("Bar Chart"));
-    dataSetNormalBarChartAction  = dataSetBarChartMenu->addAction(ICON2(BarChartType, NormalChartSubtype), i18n("Normal"));
+    dataSetNormalBarChartAction = dataSetBarChartMenu->addAction(ICON2(BarChartType, NormalChartSubtype), i18n("Normal"));
     dataSetStackedBarChartAction = dataSetBarChartMenu->addAction(ICON2(BarChartType, StackedChartSubtype), i18n("Stacked"));
     dataSetPercentBarChartAction = dataSetBarChartMenu->addAction(ICON2(BarChartType, PercentChartSubtype), i18n("Percent"));
 
     dataSetLineChartMenu = dataSetChartTypeMenu->addMenu(ICON1(LineChartType), i18n("Line Chart"));
-    dataSetNormalLineChartAction  = dataSetLineChartMenu->addAction(ICON2(LineChartType, NormalChartSubtype), i18n("Normal"));
+    dataSetNormalLineChartAction = dataSetLineChartMenu->addAction(ICON2(LineChartType, NormalChartSubtype), i18n("Normal"));
     dataSetStackedLineChartAction = dataSetLineChartMenu->addAction(ICON2(LineChartType, NormalChartSubtype), i18n("Stacked"));
     dataSetPercentLineChartAction = dataSetLineChartMenu->addAction(ICON2(LineChartType, NormalChartSubtype), i18n("Percent"));
 
     dataSetAreaChartMenu = dataSetChartTypeMenu->addMenu(ICON1(AreaChartType), i18n("Area Chart"));
-    dataSetNormalAreaChartAction  = dataSetAreaChartMenu->addAction(ICON2(AreaChartType, NormalChartSubtype), i18n("Normal"));
+    dataSetNormalAreaChartAction = dataSetAreaChartMenu->addAction(ICON2(AreaChartType, NormalChartSubtype), i18n("Normal"));
     dataSetStackedAreaChartAction = dataSetAreaChartMenu->addAction(ICON2(AreaChartType, StackedChartSubtype), i18n("Stacked"));
     dataSetPercentAreaChartAction = dataSetAreaChartMenu->addAction(ICON2(AreaChartType, PercentChartSubtype), i18n("Percent"));
 
@@ -245,9 +229,9 @@ DataSetConfigWidget::Private::Private(DataSetConfigWidget *parent)
 
     ui.dataSetChartTypeMenu->setMenu(dataSetChartTypeMenu);
 
-    connect(dataSetChartTypeMenu, SIGNAL(triggered(QAction*)), parent, SLOT(dataSetChartTypeSelected(QAction*)));
+    connect(dataSetChartTypeMenu, &QMenu::triggered, parent, &DataSetConfigWidget::dataSetChartTypeSelected);
 
-    connect(ui.dataSetHasChartType, SIGNAL(toggled(bool)), parent, SLOT(ui_dataSetHasChartTypeChanged(bool)));
+    connect(ui.dataSetHasChartType, &QAbstractButton::toggled, parent, &DataSetConfigWidget::ui_dataSetHasChartTypeChanged);
 
     // Setup marker menu
     QMenu *datasetMarkerMenu = new QMenu(parent);
@@ -278,36 +262,30 @@ DataSetConfigWidget::Private::Private(DataSetConfigWidget *parent)
     dataSetMarkerFastCrossAction = datasetSelectMarkerMenu->addAction(QIcon(), QString());
 
     ui.datasetMarkerMenu->setMenu(datasetMarkerMenu);
-    connect(datasetMarkerMenu, SIGNAL(triggered(QAction*)), parent, SLOT(datasetMarkerSelected(QAction*)));
+    connect(datasetMarkerMenu, &QMenu::triggered, parent, &DataSetConfigWidget::datasetMarkerSelected);
 
     // Insert error bar button
     ui.formatErrorBar->setEnabled(false);
 
-    connect(ui.datasetBrush, SIGNAL(changed(QColor)),parent, SLOT(datasetBrushSelected(QColor)));
-    connect(ui.datasetPen, SIGNAL(changed(QColor)), parent, SLOT(datasetPenSelected(QColor)));
-    connect(ui.datasetShowCategory, SIGNAL(toggled(bool)), parent, SLOT(ui_datasetShowCategoryChanged(bool)));
-    connect(ui.datasetShowErrorBar, SIGNAL(toggled(bool)), parent, SLOT(ui_datasetShowErrorBarChanged(bool)));
-    connect(ui.dataSetShowNumber, SIGNAL(toggled(bool)), parent, SLOT(ui_dataSetShowNumberChanged(bool)));
-    connect(ui.datasetShowPercent, SIGNAL(toggled(bool)), parent, SLOT(ui_datasetShowPercentChanged(bool)));
+    connect(ui.datasetBrush, &KColorButton::changed, parent, &DataSetConfigWidget::datasetBrushSelected);
+    connect(ui.datasetPen, &KColorButton::changed, parent, &DataSetConfigWidget::datasetPenSelected);
+    connect(ui.datasetShowCategory, &QAbstractButton::toggled, parent, &DataSetConfigWidget::ui_datasetShowCategoryChanged);
+    connect(ui.datasetShowErrorBar, &QAbstractButton::toggled, parent, &DataSetConfigWidget::ui_datasetShowErrorBarChanged);
+    connect(ui.dataSetShowNumber, &QAbstractButton::toggled, parent, &DataSetConfigWidget::ui_dataSetShowNumberChanged);
+    connect(ui.datasetShowPercent, &QAbstractButton::toggled, parent, &DataSetConfigWidget::ui_datasetShowPercentChanged);
 
     // TODO
     // connect(ui.datasetShowSymbol, SIGNAL(toggled(bool)), parent, SLOT(ui_datasetShowSymbolChanged(bool)));
 
-
-    connect(ui.dataSets, SIGNAL(currentIndexChanged(int)), parent, SLOT(ui_dataSetSelectionChanged(int)));
-    connect(ui.dataSetAxes, SIGNAL(currentIndexChanged(int)), parent, SLOT(ui_dataSetAxisSelectionChanged(int)));
-
-}
-
-DataSetConfigWidget::Private::~Private()
-{
+    connect(ui.dataSets, &QComboBox::currentIndexChanged, parent, &DataSetConfigWidget::ui_dataSetSelectionChanged);
+    connect(ui.dataSetAxes, &QComboBox::currentIndexChanged, parent, &DataSetConfigWidget::ui_dataSetAxisSelectionChanged);
 }
 
+DataSetConfigWidget::Private::~Private() = default;
 
 // ================================================================
 //                     class DataSetConfigWidget
 
-
 DataSetConfigWidget::DataSetConfigWidget(QWidget *parent)
     : ConfigSubWidgetBase(parent)
     , d(new Private(this))
@@ -338,9 +316,9 @@ void DataSetConfigWidget::deleteSubDialogs(ChartType type)
     Q_UNUSED(type)
 }
 
-void DataSetConfigWidget::open(ChartShape* shape)
+void DataSetConfigWidget::open(ChartShape *shape)
 {
-    debugChartUiDataSet<<shape;
+    debugChartUiDataSet << shape;
 
     // reset these so we do not risc using old, deleted data
     // these are recalculated in updateData() anyway
@@ -352,7 +330,7 @@ void DataSetConfigWidget::open(ChartShape* shape)
 
 QAction *DataSetConfigWidget::createAction()
 {
-    return 0;
+    return nullptr;
 }
 
 void DataSetConfigWidget::ui_dataSetAxisSelectionChanged(int index)
@@ -360,18 +338,18 @@ void DataSetConfigWidget::ui_dataSetAxisSelectionChanged(int index)
     if (index < 0 || d->ui.dataSets->currentIndex() >= d->dataSets.count()) {
         return;
     }
-    debugChartUiDataSet<<index<<d->dataSetAxes;
+    debugChartUiDataSet << index << d->dataSetAxes;
     if (index >= d->dataSetAxes.count()) {
         // Add the axis
-        debugChartUiDataSet<<"create secondary y axis";
-        emit axisAdded(YAxisDimension, i18n("Axistitle"));
+        debugChartUiDataSet << "create secondary y axis";
+        Q_EMIT axisAdded(YAxisDimension, i18n("Axistitle"));
     }
     if (index < 0 || index >= d->dataSetAxes.count()) {
         return;
     }
     DataSet *dataSet = d->dataSets[d->ui.dataSets->currentIndex()];
     Axis *axis = d->dataSetAxes[index];
-    emit dataSetAxisChanged(dataSet, axis);
+    Q_EMIT dataSetAxisChanged(dataSet, axis);
 }
 
 void DataSetConfigWidget::updateMarkers()
@@ -396,20 +374,20 @@ void DataSetConfigWidget::updateMarkers()
     d->dataSetMarkerHorizontalBarAction->setIcon(dataSet->markerIcon(MarkerHorizontalBar));
     d->dataSetMarkerVerticalBarAction->setIcon(dataSet->markerIcon(MarkerVerticalBar));
 
-    switch(dataSet->odfSymbolType()) {
-        case NoSymbol:
-            d->ui.datasetMarkerMenu->setText(i18n("None"));
-            d->ui.datasetMarkerMenu->setIcon(QIcon());
-            break;
-        case NamedSymbol:
-            d->ui.datasetMarkerMenu->setIcon(dataSet->markerIcon(dataSet->markerStyle()));
-            d->ui.datasetMarkerMenu->setText(QString());
-            break;
-        case ImageSymbol:
-        case AutomaticSymbol:
-            d->ui.datasetMarkerMenu->setText(i18n("Auto"));
-            d->ui.datasetMarkerMenu->setIcon(QIcon());
-            break;
+    switch (dataSet->odfSymbolType()) {
+    case NoSymbol:
+        d->ui.datasetMarkerMenu->setText(i18n("None"));
+        d->ui.datasetMarkerMenu->setIcon(QIcon());
+        break;
+    case NamedSymbol:
+        d->ui.datasetMarkerMenu->setIcon(dataSet->markerIcon(dataSet->markerStyle()));
+        d->ui.datasetMarkerMenu->setText(QString());
+        break;
+    case ImageSymbol:
+    case AutomaticSymbol:
+        d->ui.datasetMarkerMenu->setText(i18n("Auto"));
+        d->ui.datasetMarkerMenu->setIcon(QIcon());
+        break;
     }
 }
 void DataSetConfigWidget::ui_dataSetErrorBarTypeChanged()
@@ -427,16 +405,16 @@ void DataSetConfigWidget::ui_dataSetHasChartTypeChanged(bool b)
     if (d->selectedDataSet < 0) {
         return;
     }
-    debugChartUiDataSet<<b;
+    debugChartUiDataSet << b;
     DataSet *dataSet = d->dataSets[d->selectedDataSet];
     Q_ASSERT(dataSet);
     if (!dataSet) {
         return;
     }
     if (b) {
-        emit dataSetChartTypeChanged(dataSet, chart->chartType(), chart->chartSubType());
+        Q_EMIT dataSetChartTypeChanged(dataSet, chart->chartType(), chart->chartSubType());
     } else {
-        emit dataSetChartTypeChanged(dataSet, LastChartType, NoChartSubtype);
+        Q_EMIT dataSetChartTypeChanged(dataSet, LastChartType, NoChartSubtype);
     }
 }
 
@@ -445,41 +423,41 @@ void DataSetConfigWidget::dataSetChartTypeSelected(QAction *action)
     if (d->selectedDataSet < 0)
         return;
 
-    debugChartUiDataSet<<action;
+    debugChartUiDataSet << action;
 
-    ChartType     type    = LastChartType;
-    ChartSubtype  subtype = NoChartSubtype;
+    ChartType type = LastChartType;
+    ChartSubtype subtype = NoChartSubtype;
 
     if (action == d->dataSetNormalBarChartAction) {
-        type    = BarChartType;
+        type = BarChartType;
         subtype = NormalChartSubtype;
     } else if (action == d->dataSetStackedBarChartAction) {
-        type    = BarChartType;
+        type = BarChartType;
         subtype = StackedChartSubtype;
     } else if (action == d->dataSetPercentBarChartAction) {
-        type    = BarChartType;
+        type = BarChartType;
         subtype = PercentChartSubtype;
     }
 
     else if (action == d->dataSetNormalLineChartAction) {
-        type    = LineChartType;
+        type = LineChartType;
         subtype = NormalChartSubtype;
     } else if (action == d->dataSetStackedLineChartAction) {
-        type    = LineChartType;
+        type = LineChartType;
         subtype = StackedChartSubtype;
     } else if (action == d->dataSetPercentLineChartAction) {
-        type    = LineChartType;
+        type = LineChartType;
         subtype = PercentChartSubtype;
     }
 
     else if (action == d->dataSetNormalAreaChartAction) {
-        type    = AreaChartType;
+        type = AreaChartType;
         subtype = NormalChartSubtype;
     } else if (action == d->dataSetStackedAreaChartAction) {
-        type    = AreaChartType;
+        type = AreaChartType;
         subtype = StackedChartSubtype;
     } else if (action == d->dataSetPercentAreaChartAction) {
-        type    = AreaChartType;
+        type = AreaChartType;
         subtype = PercentChartSubtype;
     }
 
@@ -496,13 +474,13 @@ void DataSetConfigWidget::dataSetChartTypeSelected(QAction *action)
         type = ScatterChartType;
 
     else if (action == d->dataSetHLCStockChartAction) {
-        type    = StockChartType;
+        type = StockChartType;
         subtype = HighLowCloseChartSubtype;
     } else if (action == d->dataSetStackedAreaChartAction) {
-        type    = StockChartType;
+        type = StockChartType;
         subtype = OpenHighLowCloseChartSubtype;
     } else if (action == d->dataSetCandlestickStockChartAction) {
-        type    = StockChartType;
+        type = StockChartType;
         subtype = CandlestickChartSubtype;
     }
 
@@ -510,8 +488,8 @@ void DataSetConfigWidget::dataSetChartTypeSelected(QAction *action)
         type = BubbleChartType;
 
     // FIXME: Not supported by KoChart yet:
-    //surface
-    //gantt
+    // surface
+    // gantt
 
     DataSet *dataSet = d->dataSets[d->selectedDataSet];
     Q_ASSERT(dataSet);
@@ -522,7 +500,7 @@ void DataSetConfigWidget::dataSetChartTypeSelected(QAction *action)
     if (iconName.size() > 0)
         d->ui.dataSetChartTypeMenu->setIcon(QIcon::fromTheme(iconName));
 
-    emit dataSetChartTypeChanged(dataSet, type, subtype);
+    Q_EMIT dataSetChartTypeChanged(dataSet, type, subtype);
 
     updateData(type, subtype);
 }
@@ -540,7 +518,7 @@ void DataSetConfigWidget::datasetMarkerSelected(QAction *action)
         symbolType = NoSymbol;
         type = "None";
     } else if (action == d->dataSetAutomaticMarkerAction) {
-        style = (OdfMarkerStyle) (d->selectedDataSet % numDefaultMarkerTypes);
+        style = (OdfMarkerStyle)(d->selectedDataSet % numDefaultMarkerTypes);
         type = "Auto";
         symbolType = AutomaticSymbol;
     } else if (action == d->dataSetMarkerCircleAction) {
@@ -591,26 +569,26 @@ void DataSetConfigWidget::datasetMarkerSelected(QAction *action)
         d->ui.datasetMarkerMenu->setText(type);
         d->ui.datasetMarkerMenu->setIcon(QIcon());
     }
-    emit dataSetMarkerChanged(dataSet, symbolType, style);
+    Q_EMIT dataSetMarkerChanged(dataSet, symbolType, style);
 
     updateData(dataSet->chartType(), dataSet->chartSubType());
 }
 
-void DataSetConfigWidget::datasetBrushSelected(const QColor& color)
+void DataSetConfigWidget::datasetBrushSelected(const QColor &color)
 {
     if (d->selectedDataSet < 0)
         return;
 
-    emit datasetBrushChanged(d->dataSets[d->selectedDataSet], color, -1);
+    Q_EMIT datasetBrushChanged(d->dataSets[d->selectedDataSet], color, -1);
     updateMarkers();
 }
 
-void DataSetConfigWidget::datasetPenSelected(const QColor& color)
+void DataSetConfigWidget::datasetPenSelected(const QColor &color)
 {
     if (d->selectedDataSet < 0)
         return;
 
-    emit datasetPenChanged(d->dataSets[d->selectedDataSet], color, -1);
+    Q_EMIT datasetPenChanged(d->dataSets[d->selectedDataSet], color, -1);
     updateMarkers();
 }
 
@@ -623,8 +601,8 @@ void DataSetConfigWidget::updateData(ChartType chartType, ChartSubtype subtype)
     if (!chartTypes.contains(chartType)) {
         return;
     }
-    QList<DataSet*> newDataSets = chart->plotArea()->dataSets();
-    debugChartUiDataSet<<d->selectedDataSet<<d->dataSets<<':'<<newDataSets;
+    QList<DataSet *> newDataSets = chart->plotArea()->dataSets();
+    debugChartUiDataSet << d->selectedDataSet << d->dataSets << ':' << newDataSets;
 
     blockSignals(true);
     d->dataSetAxes.clear();
@@ -633,29 +611,30 @@ void DataSetConfigWidget::updateData(ChartType chartType, ChartSubtype subtype)
     // Update the chart type specific settings in the "Data Sets" tab
     d->ui.errorBarProperties->hide();
     // TODO: error indication is not implemented
-//     if (chartType == BarChartType || chartType == LineChartType || chartType == AreaChartType || chartType == ScatterChartType) {
-//         d->ui.errorBarProperties->show();
-//     }
-    // TODO 
-//     d->ui.datasetShowSymbol->hide();
-//     if (chartType == LineChartType || chartType == AreaChartType || chartType == ScatterChartType || chartType == RadarChartType || chartType == FilledRadarChartType) {
-//         d->ui.datasetShowSymbol->show();
-//     }
-    
+    //     if (chartType == BarChartType || chartType == LineChartType || chartType == AreaChartType || chartType == ScatterChartType) {
+    //         d->ui.errorBarProperties->show();
+    //     }
+    // TODO
+    //     d->ui.datasetShowSymbol->hide();
+    //     if (chartType == LineChartType || chartType == AreaChartType || chartType == ScatterChartType || chartType == RadarChartType || chartType ==
+    //     FilledRadarChartType) {
+    //         d->ui.datasetShowSymbol->show();
+    //     }
+
     // Make sure we only allow legal chart type combinations
     if (isPolar(chartType)) {
         // TODO: check out this claim:
         // Pie charts and ring charts have no axes but radar charts do.
         // Disable choosing of attached axis if there is none.
         bool hasAxes = !(chartType == CircleChartType || chartType == RingChartType);
-//         d->ui.axisConfiguration->setEnabled(hasAxes);
+        //         d->ui.axisConfiguration->setEnabled(hasAxes);
         d->ui.dataSetAxes->setCurrentIndex(-1);
         d->ui.dataSetAxes->setEnabled(false);
         d->ui.dataSetHasChartType->setEnabled(hasAxes);
         d->ui.dataSetChartTypeMenu->setEnabled(hasAxes);
     } else {
         // All the cartesian chart types have axes.
-//         d->ui.axisConfiguration->setEnabled(true);
+        //         d->ui.axisConfiguration->setEnabled(true);
         d->dataSetAxes.append(chart->plotArea()->yAxis());
         if (chart->plotArea()->secondaryYAxis() && chart->plotArea()->secondaryYAxis()->isVisible()) {
             d->dataSetAxes.append(chart->plotArea()->secondaryYAxis());
@@ -675,7 +654,7 @@ void DataSetConfigWidget::updateData(ChartType chartType, ChartSubtype subtype)
     if (newDataSets != d->dataSets) {
         d->selectedDataSet = 0; // new datasets, select the first
         d->dataSets = newDataSets;
-        debugChartUiDataSet<<"new datasets"<<newDataSets;
+        debugChartUiDataSet << "new datasets" << newDataSets;
     }
     d->ui.dataSets->setCurrentIndex(d->selectedDataSet);
 
@@ -684,7 +663,6 @@ void DataSetConfigWidget::updateData(ChartType chartType, ChartSubtype subtype)
     ui_dataSetSelectionChanged(d->selectedDataSet);
 }
 
-
 void DataSetConfigWidget::slotShowFormatErrorBarDialog()
 {
     d->formatErrorBarDialog.show();
@@ -693,10 +671,8 @@ void DataSetConfigWidget::slotShowFormatErrorBarDialog()
 void DataSetConfigWidget::setupDialogs()
 {
     // Format Error Bars
-    connect(d->ui.formatErrorBar, SIGNAL(clicked()),
-             this, SLOT(slotShowFormatErrorBarDialog()));
-    connect(&d->formatErrorBarDialog, SIGNAL(accepted()),
-             this, SLOT(ui_dataSetErrorBarTypeChanged()));
+    connect(d->ui.formatErrorBar, &QAbstractButton::clicked, this, &DataSetConfigWidget::slotShowFormatErrorBarDialog);
+    connect(&d->formatErrorBarDialog, &QDialog::accepted, this, &DataSetConfigWidget::ui_dataSetErrorBarTypeChanged);
 }
 
 void DataSetConfigWidget::createActions()
@@ -706,21 +682,21 @@ void DataSetConfigWidget::createActions()
 void DataSetConfigWidget::ui_dataSetSelectionChanged(int index)
 {
     // Check for valid index
-    debugChartUiDataSet<<index<<d->dataSets;
+    debugChartUiDataSet << index << d->dataSets;
     if (index < 0 || index >= d->dataSets.size()) {
         return;
     }
     blockSignals(true);
 
     DataSet *dataSet = d->dataSets[index];
-    //d->ui.datasetColor->setText(axis->titleText());
+    // d->ui.datasetColor->setText(axis->titleText());
     d->ui.dataSetAxes->setCurrentIndex(d->dataSetAxes.indexOf(dataSet->attachedAxis()));
 
     d->ui.datasetBrush->setColor(dataSet->brush().color());
 
     d->ui.datasetPen->setColor(dataSet->pen().color());
 
-    debugChartUiDataSet<<dataSet->valueLabelType();
+    debugChartUiDataSet << dataSet->valueLabelType();
     d->ui.datasetShowCategory->setChecked(dataSet->valueLabelType().category);
 
     d->ui.dataSetShowNumber->setChecked(dataSet->valueLabelType().number);
@@ -747,8 +723,8 @@ void DataSetConfigWidget::ui_dataSetSelectionChanged(int index)
     if (chartType == LastChartType) {
         chartType = chart->chartType();
     }
-    bool disableMarkers = chartType == BarChartType || chartType == StockChartType || chartType == CircleChartType
-                            || chartType == RingChartType || chartType == BubbleChartType;
+    bool disableMarkers =
+        chartType == BarChartType || chartType == StockChartType || chartType == CircleChartType || chartType == RingChartType || chartType == BubbleChartType;
     d->ui.datasetMarkerMenu->setDisabled(disableMarkers);
 }
 
@@ -757,8 +733,8 @@ void DataSetConfigWidget::ui_datasetShowCategoryChanged(bool b)
     if (d->selectedDataSet < 0 || d->selectedDataSet >= d->dataSets.count()) {
         return;
     }
-    debugChartUiDataSet<<b;
-    emit datasetShowCategoryChanged(d->dataSets[d->selectedDataSet], b, -1);
+    debugChartUiDataSet << b;
+    Q_EMIT datasetShowCategoryChanged(d->dataSets[d->selectedDataSet], b, -1);
 }
 
 void DataSetConfigWidget::ui_datasetShowErrorBarChanged(bool b)
@@ -766,7 +742,7 @@ void DataSetConfigWidget::ui_datasetShowErrorBarChanged(bool b)
     if (d->selectedDataSet < 0 || d->selectedDataSet >= d->dataSets.count()) {
         return;
     }
-    debugChartUiDataSet<<b;
+    debugChartUiDataSet << b;
     d->ui.formatErrorBar->setEnabled(b);
 }
 
@@ -775,8 +751,8 @@ void DataSetConfigWidget::ui_dataSetShowNumberChanged(bool b)
     if (d->selectedDataSet < 0 || d->selectedDataSet >= d->dataSets.count()) {
         return;
     }
-    debugChartUiDataSet<<b;
-    emit dataSetShowNumberChanged(d->dataSets[d->selectedDataSet], b, -1);
+    debugChartUiDataSet << b;
+    Q_EMIT dataSetShowNumberChanged(d->dataSets[d->selectedDataSet], b, -1);
 }
 
 void DataSetConfigWidget::ui_datasetShowPercentChanged(bool b)
@@ -784,8 +760,8 @@ void DataSetConfigWidget::ui_datasetShowPercentChanged(bool b)
     if (d->selectedDataSet < 0 || d->selectedDataSet >= d->dataSets.count()) {
         return;
     }
-    debugChartUiDataSet<<b;
-    emit datasetShowPercentChanged(d->dataSets[d->selectedDataSet], b, -1);
+    debugChartUiDataSet << b;
+    Q_EMIT datasetShowPercentChanged(d->dataSets[d->selectedDataSet], b, -1);
 }
 
 void DataSetConfigWidget::ui_datasetShowSymbolChanged(bool b)
@@ -793,6 +769,6 @@ void DataSetConfigWidget::ui_datasetShowSymbolChanged(bool b)
     if (d->selectedDataSet < 0 || d->selectedDataSet >= d->dataSets.count()) {
         return;
     }
-    debugChartUiDataSet<<b;
-    emit datasetShowSymbolChanged(d->dataSets[d->selectedDataSet], b, -1);
+    debugChartUiDataSet << b;
+    Q_EMIT datasetShowSymbolChanged(d->dataSets[d->selectedDataSet], b, -1);
 }
