@@ -1,41 +1,27 @@
 /*
- *  Copyright (c) 2002 Patrick Julien  <freak@codepimps.org>
- *  Copyright (c) 2005-2006 C. Boemann <cbo@boemann.dk>
- *  Copyright (c) 2004,2006-2007 Cyrille Berger <cberger@cberger.net>
+ *  SPDX-FileCopyrightText: 2002 Patrick Julien <freak@codepimps.org>
+ *  SPDX-FileCopyrightText: 2005-2006 C. Boemann <cbo@boemann.dk>
+ *  SPDX-FileCopyrightText: 2004, 2006-2007 Cyrille Berger <cberger@cberger.net>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #ifndef KOLCMSCOLORSPACE_H_
 #define KOLCMSCOLORSPACE_H_
 
-#include <colorprofiles/LcmsColorProfileContainer.h>
 #include <KoColorSpaceAbstract.h>
+#include <colorprofiles/LcmsColorProfileContainer.h>
 
 class LcmsColorProfileContainer;
 
 class KoLcmsInfo
 {
     struct Private {
-        cmsUInt32Number cmType;  // The colorspace type as defined by littlecms
+        cmsUInt32Number cmType; // The colorspace type as defined by littlecms
         cmsColorSpaceSignature colorSpaceSignature; // The colorspace signature as defined in icm/icc files
     };
 
 public:
-
     KoLcmsInfo(cmsUInt32Number cmType, cmsColorSpaceSignature colorSpaceSignature)
         : d(new Private)
     {
@@ -66,7 +52,7 @@ struct KoLcmsDefaultTransformations {
     cmsHTRANSFORM toRGB;
     cmsHTRANSFORM fromRGB;
     static cmsHPROFILE s_RGBProfile;
-    static QMap< QString, QMap< LcmsColorProfileContainer *, KoLcmsDefaultTransformations * > > s_transformations;
+    static QMap<QString, QMap<LcmsColorProfileContainer *, KoLcmsDefaultTransformations *>> s_transformations;
 };
 
 /**
@@ -77,22 +63,20 @@ template<class _CSTraits>
 class LcmsColorSpace : public KoColorSpaceAbstract<_CSTraits>, public KoLcmsInfo
 {
     struct KoLcmsColorTransformation : public KoColorTransformation {
-
         KoLcmsColorTransformation(const KoColorSpace *colorSpace)
             : KoColorTransformation()
             , m_colorSpace(colorSpace)
         {
-            csProfile = 0;
-            cmstransform = 0;
-            cmsAlphaTransform = 0;
-            profiles[0] = 0;
-            profiles[1] = 0;
-            profiles[2] = 0;
+            csProfile = nullptr;
+            cmstransform = nullptr;
+            cmsAlphaTransform = nullptr;
+            profiles[0] = nullptr;
+            profiles[1] = nullptr;
+            profiles[2] = nullptr;
         }
 
         ~KoLcmsColorTransformation() override
         {
-
             if (cmstransform) {
                 cmsDeleteTransform(cmstransform);
             }
@@ -131,8 +115,8 @@ class LcmsColorSpace : public KoColorSpaceAbstract<_CSTraits>, public KoLcmsInfo
                     dst += pixelSize;
                 }
 
-                delete [] alpha;
-                delete [] dstalpha;
+                delete[] alpha;
+                delete[] dstalpha;
             } else {
                 while (numPixels > 0) {
                     qreal alpha = m_colorSpace->opacityF(src);
@@ -155,20 +139,15 @@ class LcmsColorSpace : public KoColorSpaceAbstract<_CSTraits>, public KoLcmsInfo
         mutable quint8 *qcolordata; // A small buffer for conversion from and to qcolor.
         KoLcmsDefaultTransformations *defaultTransformations;
 
-        mutable cmsHPROFILE   lastRGBProfile;  // Last used profile to transform to/from RGB
-        mutable cmsHTRANSFORM lastToRGB;       // Last used transform to transform to RGB
-        mutable cmsHTRANSFORM lastFromRGB;     // Last used transform to transform from RGB
+        mutable cmsHPROFILE lastRGBProfile; // Last used profile to transform to/from RGB
+        mutable cmsHTRANSFORM lastToRGB; // Last used transform to transform to RGB
+        mutable cmsHTRANSFORM lastFromRGB; // Last used transform to transform from RGB
         LcmsColorProfileContainer *profile;
         KoColorProfile *colorProfile;
     };
 
 protected:
-
-    LcmsColorSpace(const QString &id,
-                   const QString &name,
-                   cmsUInt32Number cmType,
-                   cmsColorSpaceSignature colorSpaceSignature,
-                   KoColorProfile *p)
+    LcmsColorSpace(const QString &id, const QString &name, cmsUInt32Number cmType, cmsColorSpaceSignature colorSpaceSignature, KoColorProfile *p)
         : KoColorSpaceAbstract<_CSTraits>(id, name)
         , KoLcmsInfo(cmType, colorSpaceSignature)
         , d(new Private())
@@ -178,11 +157,11 @@ protected:
         d->profile = asLcmsProfile(p);
         Q_ASSERT(d->profile);
         d->colorProfile = p;
-        d->qcolordata = 0;
-        d->lastRGBProfile = 0;
-        d->lastToRGB = 0;
-        d->lastFromRGB = 0;
-        d->defaultTransformations = 0;
+        d->qcolordata = nullptr;
+        d->lastRGBProfile = nullptr;
+        d->lastToRGB = nullptr;
+        d->lastFromRGB = nullptr;
+        d->defaultTransformations = nullptr;
     }
 
     ~LcmsColorSpace() override
@@ -201,32 +180,31 @@ protected:
 
         Q_ASSERT(d->profile);
 
-        if (KoLcmsDefaultTransformations::s_RGBProfile == 0) {
+        if (KoLcmsDefaultTransformations::s_RGBProfile == nullptr) {
             KoLcmsDefaultTransformations::s_RGBProfile = cmsCreate_sRGBProfile();
         }
-        d->defaultTransformations = KoLcmsDefaultTransformations::s_transformations[this->id()][ d->profile];
+        d->defaultTransformations = KoLcmsDefaultTransformations::s_transformations[this->id()][d->profile];
         if (!d->defaultTransformations) {
             d->defaultTransformations = new KoLcmsDefaultTransformations;
             d->defaultTransformations->fromRGB = cmsCreateTransform(KoLcmsDefaultTransformations::s_RGBProfile,
-                                                 TYPE_BGR_8,
-                                                 d->profile->lcmsProfile(),
-                                                 this->colorSpaceType(),
-                                                 KoColorConversionTransformation::internalRenderingIntent(),
-                                                 KoColorConversionTransformation::internalConversionFlags());
+                                                                    TYPE_BGR_8,
+                                                                    d->profile->lcmsProfile(),
+                                                                    this->colorSpaceType(),
+                                                                    KoColorConversionTransformation::internalRenderingIntent(),
+                                                                    KoColorConversionTransformation::internalConversionFlags());
             Q_ASSERT(d->defaultTransformations->fromRGB);
             d->defaultTransformations->toRGB = cmsCreateTransform(d->profile->lcmsProfile(),
-                                               this->colorSpaceType(),
-                                               KoLcmsDefaultTransformations::s_RGBProfile,
-                                               TYPE_BGR_8,
-                                               KoColorConversionTransformation::internalRenderingIntent(),
-                                               KoColorConversionTransformation::internalConversionFlags());
+                                                                  this->colorSpaceType(),
+                                                                  KoLcmsDefaultTransformations::s_RGBProfile,
+                                                                  TYPE_BGR_8,
+                                                                  KoColorConversionTransformation::internalRenderingIntent(),
+                                                                  KoColorConversionTransformation::internalConversionFlags());
             Q_ASSERT(d->defaultTransformations->toRGB);
-            KoLcmsDefaultTransformations::s_transformations[ this->id()][ d->profile ] = d->defaultTransformations;
+            KoLcmsDefaultTransformations::s_transformations[this->id()][d->profile] = d->defaultTransformations;
         }
     }
 
 public:
-
     bool hasHighDynamicRange() const override
     {
         return false;
@@ -243,20 +221,20 @@ public:
         return (p && p->asLcms()->colorSpaceSignature() == colorSpaceSignature());
     }
 
-    void fromQColor(const QColor &color, quint8 *dst, const KoColorProfile *koprofile = 0) const override
+    void fromQColor(const QColor &color, quint8 *dst, const KoColorProfile *koprofile = nullptr) const override
     {
         d->qcolordata[2] = color.red();
         d->qcolordata[1] = color.green();
         d->qcolordata[0] = color.blue();
 
         LcmsColorProfileContainer *profile = asLcmsProfile(koprofile);
-        if (profile == 0) {
+        if (profile == nullptr) {
             // Default sRGB
             Q_ASSERT(d->defaultTransformations && d->defaultTransformations->fromRGB);
 
             cmsDoTransform(d->defaultTransformations->fromRGB, d->qcolordata, dst, 1);
         } else {
-            if (d->lastFromRGB == 0 || (d->lastFromRGB != 0 && d->lastRGBProfile != profile->lcmsProfile())) {
+            if (d->lastFromRGB == nullptr || (d->lastFromRGB != nullptr && d->lastRGBProfile != profile->lcmsProfile())) {
                 d->lastFromRGB = cmsCreateTransform(profile->lcmsProfile(),
                                                     TYPE_BGR_8,
                                                     d->profile->lcmsProfile(),
@@ -264,7 +242,6 @@ public:
                                                     KoColorConversionTransformation::internalRenderingIntent(),
                                                     KoColorConversionTransformation::internalConversionFlags());
                 d->lastRGBProfile = profile->lcmsProfile();
-
             }
             cmsDoTransform(d->lastFromRGB, d->qcolordata, dst, 1);
         }
@@ -272,22 +249,24 @@ public:
         this->setOpacity(dst, (quint8)(color.alpha()), 1);
     }
 
-    void toQColor(const quint8 *src, QColor *c, const KoColorProfile *koprofile = 0) const override
+    void toQColor(const quint8 *src, QColor *c, const KoColorProfile *koprofile = nullptr) const override
     {
         LcmsColorProfileContainer *profile = asLcmsProfile(koprofile);
-        if (profile == 0) {
+        if (profile == nullptr) {
             // Default sRGB transform
             Q_ASSERT(d->defaultTransformations && d->defaultTransformations->toRGB);
-            cmsDoTransform(d->defaultTransformations->toRGB, const_cast <quint8 *>(src), d->qcolordata, 1);
+            cmsDoTransform(d->defaultTransformations->toRGB, const_cast<quint8 *>(src), d->qcolordata, 1);
         } else {
-            if (d->lastToRGB == 0 || (d->lastToRGB != 0 && d->lastRGBProfile != profile->lcmsProfile())) {
-                d->lastToRGB = cmsCreateTransform(d->profile->lcmsProfile(), this->colorSpaceType(),
-                                                  profile->lcmsProfile(), TYPE_BGR_8,
+            if (d->lastToRGB == nullptr || (d->lastToRGB != nullptr && d->lastRGBProfile != profile->lcmsProfile())) {
+                d->lastToRGB = cmsCreateTransform(d->profile->lcmsProfile(),
+                                                  this->colorSpaceType(),
+                                                  profile->lcmsProfile(),
+                                                  TYPE_BGR_8,
                                                   KoColorConversionTransformation::internalRenderingIntent(),
                                                   KoColorConversionTransformation::internalConversionFlags());
                 d->lastRGBProfile = profile->lcmsProfile();
             }
-            cmsDoTransform(d->lastToRGB, const_cast <quint8 *>(src), d->qcolordata, 1);
+            cmsDoTransform(d->lastToRGB, const_cast<quint8 *>(src), d->qcolordata, 1);
         }
         c->setRgb(d->qcolordata[2], d->qcolordata[1], d->qcolordata[0]);
         c->setAlpha(this->opacityU8(src));
@@ -296,13 +275,13 @@ public:
     KoColorTransformation *createBrightnessContrastAdjustment(const quint16 *transferValues) const override
     {
         if (!d->profile) {
-            return 0;
+            return nullptr;
         }
 
         cmsToneCurve *transferFunctions[3];
-        transferFunctions[0] = cmsBuildTabulatedToneCurve16(0, 256, transferValues);
-        transferFunctions[1] = cmsBuildGamma(0, 1.0);
-        transferFunctions[2] = cmsBuildGamma(0, 1.0);
+        transferFunctions[0] = cmsBuildTabulatedToneCurve16(nullptr, 256, transferValues);
+        transferFunctions[1] = cmsBuildGamma(nullptr, 1.0);
+        transferFunctions[2] = cmsBuildGamma(nullptr, 1.0);
 
         KoLcmsColorTransformation *adj = new KoLcmsColorTransformation(this);
         adj->profiles[1] = cmsCreateLinearizationDeviceLink(cmsSigLabData, transferFunctions);
@@ -310,9 +289,12 @@ public:
 
         adj->profiles[0] = d->profile->lcmsProfile();
         adj->profiles[2] = d->profile->lcmsProfile();
-        adj->cmstransform  = cmsCreateMultiprofileTransform(adj->profiles, 3, this->colorSpaceType(), this->colorSpaceType(),
-                             KoColorConversionTransformation::adjustmentRenderingIntent(),
-                             KoColorConversionTransformation::adjustmentConversionFlags());
+        adj->cmstransform = cmsCreateMultiprofileTransform(adj->profiles,
+                                                           3,
+                                                           this->colorSpaceType(),
+                                                           this->colorSpaceType(),
+                                                           KoColorConversionTransformation::adjustmentRenderingIntent(),
+                                                           KoColorConversionTransformation::adjustmentConversionFlags());
         adj->csProfile = d->profile->lcmsProfile();
         return adj;
     }
@@ -320,37 +302,41 @@ public:
     KoColorTransformation *createPerChannelAdjustment(const quint16 *const *transferValues) const override
     {
         if (!d->profile) {
-            return 0;
+            return nullptr;
         }
 
-        cmsToneCurve **transferFunctions = new cmsToneCurve*[ this->colorChannelCount()];
+        cmsToneCurve **transferFunctions = new cmsToneCurve *[this->colorChannelCount()];
 
         for (uint ch = 0; ch < this->colorChannelCount(); ch++) {
-            transferFunctions[ch] = transferValues[ch] ?
-                                    cmsBuildTabulatedToneCurve16(0, 256, transferValues[ch]) :
-                                    cmsBuildGamma(0, 1.0);
+            transferFunctions[ch] = transferValues[ch] ? cmsBuildTabulatedToneCurve16(nullptr, 256, transferValues[ch]) : cmsBuildGamma(nullptr, 1.0);
         }
 
-        cmsToneCurve **alphaTransferFunctions = new cmsToneCurve*[1];
-        alphaTransferFunctions[0] = transferValues[this->colorChannelCount()] ?
-                                    cmsBuildTabulatedToneCurve16(0, 256, transferValues[this->colorChannelCount()]) :
-                                    cmsBuildGamma(0, 1.0);
+        cmsToneCurve **alphaTransferFunctions = new cmsToneCurve *[1];
+        alphaTransferFunctions[0] = transferValues[this->colorChannelCount()]
+            ? cmsBuildTabulatedToneCurve16(nullptr, 256, transferValues[this->colorChannelCount()])
+            : cmsBuildGamma(nullptr, 1.0);
 
         KoLcmsColorTransformation *adj = new KoLcmsColorTransformation(this);
         adj->profiles[0] = cmsCreateLinearizationDeviceLink(this->colorSpaceSignature(), transferFunctions);
         adj->profiles[1] = cmsCreateLinearizationDeviceLink(cmsSigGrayData, alphaTransferFunctions);
-        adj->profiles[2] = 0;
+        adj->profiles[2] = nullptr;
         adj->csProfile = d->profile->lcmsProfile();
-        adj->cmstransform  = cmsCreateTransform(adj->profiles[0], this->colorSpaceType(), 0, this->colorSpaceType(),
-                                                KoColorConversionTransformation::adjustmentRenderingIntent(),
-                                                KoColorConversionTransformation::adjustmentConversionFlags());
+        adj->cmstransform = cmsCreateTransform(adj->profiles[0],
+                                               this->colorSpaceType(),
+                                               nullptr,
+                                               this->colorSpaceType(),
+                                               KoColorConversionTransformation::adjustmentRenderingIntent(),
+                                               KoColorConversionTransformation::adjustmentConversionFlags());
 
-        adj->cmsAlphaTransform  = cmsCreateTransform(adj->profiles[1], TYPE_GRAY_DBL, 0, TYPE_GRAY_DBL,
-                                  KoColorConversionTransformation::adjustmentRenderingIntent(),
-                                  KoColorConversionTransformation::adjustmentConversionFlags());
+        adj->cmsAlphaTransform = cmsCreateTransform(adj->profiles[1],
+                                                    TYPE_GRAY_DBL,
+                                                    nullptr,
+                                                    TYPE_GRAY_DBL,
+                                                    KoColorConversionTransformation::adjustmentRenderingIntent(),
+                                                    KoColorConversionTransformation::adjustmentConversionFlags());
 
-        delete [] transferFunctions;
-        delete [] alphaTransferFunctions;
+        delete[] transferFunctions;
+        delete[] alphaTransferFunctions;
         return adj;
     }
 
@@ -359,8 +345,7 @@ public:
         quint8 lab1[8], lab2[8];
         cmsCIELab labF1, labF2;
 
-        if (this->opacityU8(src1) == OPACITY_TRANSPARENT_U8
-                || this->opacityU8(src2) == OPACITY_TRANSPARENT_U8) {
+        if (this->opacityU8(src1) == OPACITY_TRANSPARENT_U8 || this->opacityU8(src2) == OPACITY_TRANSPARENT_U8) {
             return (this->opacityU8(src1) == this->opacityU8(src2) ? 0 : 255);
         }
         Q_ASSERT(this->toLabA16Converter());
@@ -384,8 +369,7 @@ public:
         cmsCIELab labF1;
         cmsCIELab labF2;
 
-        if (this->opacityU8(src1) == OPACITY_TRANSPARENT_U8
-                || this->opacityU8(src2) == OPACITY_TRANSPARENT_U8) {
+        if (this->opacityU8(src1) == OPACITY_TRANSPARENT_U8 || this->opacityU8(src2) == OPACITY_TRANSPARENT_U8) {
             return (this->opacityU8(src1) == this->opacityU8(src2) ? 0 : 255);
         }
         Q_ASSERT(this->toLabA16Converter());
@@ -419,7 +403,6 @@ public:
     }
 
 private:
-
     inline LcmsColorProfileContainer *lcmsProfile() const
     {
         return d->profile;
@@ -428,13 +411,13 @@ private:
     inline static LcmsColorProfileContainer *asLcmsProfile(const KoColorProfile *p)
     {
         if (!p) {
-            return 0;
+            return nullptr;
         }
 
         const IccColorProfile *iccp = dynamic_cast<const IccColorProfile *>(p);
 
         if (!iccp) {
-            return 0;
+            return nullptr;
         }
 
         Q_ASSERT(iccp->asLcms());
