@@ -1,38 +1,24 @@
 /* This file is part of the KDE project
- * 
- *   Copyright (C) 2017 Dag Andersen <danders@get2net.dk>
- * 
- *   This library is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Library General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- * 
- *   This library is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *   Library General Public License for more details.
- * 
- *   You should have received a copy of the GNU Library General Public License
- *   along with this library; see the file COPYING.LIB.  If not, write to
- *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *   Boston, MA 02110-1301, USA.
+ *
+ *   SPDX-FileCopyrightText: 2017 Dag Andersen <danders@get2net.dk>
+ *
+ *   SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "ChartResizeStrategy.h"
 
+#include <KLocalizedString>
+#include <KoCanvasBase.h>
 #include <KoShape.h>
 #include <KoShapeContainer.h>
-#include <KoCanvasBase.h>
-#include <KoShapeManager.h>
 #include <KoShapeContainerModel.h>
+#include <KoShapeManager.h>
 #include <commands/KoShapeMoveCommand.h>
 #include <commands/KoShapeSizeCommand.h>
-#include <klocalizedstring.h>
-
 
 ChartResizeStrategy::ChartResizeStrategy(KoShape *shape)
-    : m_chart(dynamic_cast<KoShapeContainer*>(shape))
-    , m_plotArea(0)
+    : m_chart(dynamic_cast<KoShapeContainer *>(shape))
+    , m_plotArea(nullptr)
 {
     if (m_chart) {
         QRectF rect = m_chart->boundingRect();
@@ -123,7 +109,7 @@ void ChartResizeStrategy::createCommand(KUndo2Command *cmd)
     // get the shapes that has actually been moved
     QVector<QPointF> oldPositions;
     QVector<QPointF> newPositions;
-    QList<KoShape*> movedShapes;
+    QList<KoShape *> movedShapes;
     for (int i = 0; i < m_shapes.count(); ++i) {
         KoShape *shape = m_shapes.at(i);
         QPointF pos = shape->position();
@@ -137,6 +123,6 @@ void ChartResizeStrategy::createCommand(KUndo2Command *cmd)
         new KoShapeMoveCommand(movedShapes, oldPositions, newPositions, cmd);
     }
     if (m_plotArea) {
-        new KoShapeSizeCommand(QList<KoShape*>()<<m_plotArea, QVector<QSizeF>()<<m_plotAreaStartSize, QVector<QSizeF>()<<m_plotArea->size(), cmd );
+        new KoShapeSizeCommand(QList<KoShape *>() << m_plotArea, QVector<QSizeF>() << m_plotAreaStartSize, QVector<QSizeF>() << m_plotArea->size(), cmd);
     }
 }
