@@ -1,29 +1,16 @@
 /* This file is part of the KDE project
-   Copyright (C) 2003 Ulrich Kuettler <ulrich.kuettler@gmx.de>
-   Copyright (C) 2006 Martin Pfeiffer <hubipete@gmx.net>
-   Copyright (C) 2006 Alfredo Beaumont Sainz <alfredo.beaumont@gmail.com>
+   SPDX-FileCopyrightText: 2003 Ulrich Kuettler <ulrich.kuettler@gmx.de>
+   SPDX-FileCopyrightText: 2006 Martin Pfeiffer <hubipete@gmx.net>
+   SPDX-FileCopyrightText: 2006 Alfredo Beaumont Sainz <alfredo.beaumont@gmail.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef ELEMENTFACTORY_H
 #define ELEMENTFACTORY_H
 
-#include <QString>
 #include "koformula_export.h"
+#include <QString>
 
 class BasicElement;
 
@@ -63,7 +50,6 @@ enum ElementType {
     Empty
 };
 
-
 /**
  * @short An implementation of the factory pattern to create element instances
  *
@@ -75,7 +61,8 @@ enum ElementType {
  *
  * @author Martin Pfeiffer
  */
-class KOFORMULA_EXPORT ElementFactory {
+class KOFORMULA_EXPORT ElementFactory
+{
 public:
     /// The default constructor
     ElementFactory();
@@ -86,14 +73,14 @@ public:
      * @param parent The parent element of the newly created element
      * @return A pointer to the new BasicElement derived element
      */
-    static BasicElement* createElement( const QString& tagName, BasicElement* parent );
+    static BasicElement *createElement(const QString &tagName, BasicElement *parent);
 
     /**
      * Obtain the MathML name of a ElementType.
      * @param type The given ElementType to get the MathML name from
      * @return The MathML name as QString
      */
-    static QString elementName( ElementType type );
+    static QString elementName(ElementType type);
 };
 
 #endif // ELEMENTFACTORY_H
