@@ -6,10 +6,11 @@
 class AttributeManager;
 class BasicElement;
 
-class TestAttributeManager : public QObject {
-Q_OBJECT
+class TestAttributeManager : public QObject
+{
+    Q_OBJECT
 public:
-    TestAttributeManager() {}
+    TestAttributeManager() = default;
 
 private Q_SLOTS:
     void initTestCase();
@@ -20,8 +21,8 @@ private Q_SLOTS:
     void testColorConversion();
 
 private:
-    AttributeManager* m_attributeManager;
-    BasicElement* m_basicElement;
+    AttributeManager *m_attributeManager;
+    BasicElement *m_basicElement;
 };
 
 #endif
