@@ -1,27 +1,14 @@
 /* This file is part of the KDE project
- * Copyright (C) 2007,2009 Jan Hambrecht <jaham@gmx.net>
+ * SPDX-FileCopyrightText: 2007, 2009 Jan Hambrecht <jaham@gmx.net>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "KarbonPatternEditStrategy.h"
 
 #include <KoShape.h>
-#include <KoViewConverter.h>
 #include <KoShapeBackgroundCommand.h>
+#include <KoViewConverter.h>
 
 #include <QPainter>
 #include <kundo2command.h>
@@ -31,21 +18,22 @@
 uint KarbonPatternEditStrategyBase::m_handleRadius = 3;
 uint KarbonPatternEditStrategyBase::m_grabSensitivity = 3;
 
-KarbonPatternEditStrategyBase::KarbonPatternEditStrategyBase(KoShape * s, KoImageCollection * imageCollection)
-        : m_selectedHandle(-1)
-        , m_oldFill(new KoPatternBackground(imageCollection)), m_newFill(new KoPatternBackground(imageCollection))
-        , m_shape(s), m_imageCollection(imageCollection)
-        , m_editing(false), m_modified(false)
+KarbonPatternEditStrategyBase::KarbonPatternEditStrategyBase(KoShape *s, KoImageCollection *imageCollection)
+    : m_selectedHandle(-1)
+    , m_oldFill(new KoPatternBackground(imageCollection))
+    , m_newFill(new KoPatternBackground(imageCollection))
+    , m_shape(s)
+    , m_imageCollection(imageCollection)
+    , m_editing(false)
+    , m_modified(false)
 {
     Q_ASSERT(m_shape);
     Q_ASSERT(imageCollection);
     // cache the shapes transformation matrix
-    m_matrix = shape()->absoluteTransformation(0);
+    m_matrix = shape()->absoluteTransformation(nullptr);
 }
 
-KarbonPatternEditStrategyBase::~KarbonPatternEditStrategyBase()
-{
-}
+KarbonPatternEditStrategyBase::~KarbonPatternEditStrategyBase() = default;
 
 void KarbonPatternEditStrategyBase::setEditing(bool on)
 {
@@ -70,16 +58,16 @@ bool KarbonPatternEditStrategyBase::isModified() const
     return m_modified;
 }
 
-KUndo2Command * KarbonPatternEditStrategyBase::createCommand()
+KUndo2Command *KarbonPatternEditStrategyBase::createCommand()
 {
-    QSharedPointer<KoPatternBackground>  fill = qSharedPointerDynamicCast<KoPatternBackground>(m_shape->background());
+    QSharedPointer<KoPatternBackground> fill = qSharedPointerDynamicCast<KoPatternBackground>(m_shape->background());
     if (fill && isModified()) {
         fill = m_oldFill;
         QSharedPointer<KoPatternBackground> newFill(new KoPatternBackground(m_imageCollection));
         newFill = m_newFill;
-        return new KoShapeBackgroundCommand(m_shape, newFill, 0);
+        return new KoShapeBackgroundCommand(m_shape, newFill, nullptr);
     }
-    return 0;
+    return nullptr;
 }
 
 void KarbonPatternEditStrategyBase::paintHandle(QPainter &painter, const KoViewConverter &converter, const QPointF &position) const
@@ -108,12 +96,12 @@ void KarbonPatternEditStrategyBase::repaint() const
     m_shape->update();
 }
 
-KoShape * KarbonPatternEditStrategyBase::shape() const
+KoShape *KarbonPatternEditStrategyBase::shape() const
 {
     return m_shape;
 }
 
-KoImageCollection * KarbonPatternEditStrategyBase::imageCollection()
+KoImageCollection *KarbonPatternEditStrategyBase::imageCollection()
 {
     return m_imageCollection;
 }
@@ -122,31 +110,29 @@ KoImageCollection * KarbonPatternEditStrategyBase::imageCollection()
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////////////////////////////////////////////////////////////////////
 
-KarbonPatternEditStrategy::KarbonPatternEditStrategy(KoShape * s, KoImageCollection * imageCollection)
-        : KarbonPatternEditStrategyBase(s, imageCollection)
+KarbonPatternEditStrategy::KarbonPatternEditStrategy(KoShape *s, KoImageCollection *imageCollection)
+    : KarbonPatternEditStrategyBase(s, imageCollection)
 {
     // cache the shapes transformation matrix
-    m_matrix = shape()->absoluteTransformation(0);
+    m_matrix = shape()->absoluteTransformation(nullptr);
     QSizeF size = shape()->size();
     // the fixed length of half the average shape dimension
     m_normalizedLength = 0.25 * (size.width() + size.height());
     // get the brush transformation matrix
     QTransform brushMatrix;
-    QSharedPointer<KoPatternBackground>  fill = qSharedPointerDynamicCast<KoPatternBackground>(shape()->background());
+    QSharedPointer<KoPatternBackground> fill = qSharedPointerDynamicCast<KoPatternBackground>(shape()->background());
     if (fill)
         brushMatrix = fill->transform();
 
     // the center handle at the center point of the shape
-    //m_origin = QPointF( 0.5 * size.width(), 0.5 * size.height() );
+    // m_origin = QPointF( 0.5 * size.width(), 0.5 * size.height() );
     m_handles.append(brushMatrix.map(QPointF()));
     // the direction handle with the length of half the average shape dimension
     QPointF dirVec = QPointF(m_normalizedLength, 0.0);
     m_handles.append(brushMatrix.map(dirVec));
 }
 
-KarbonPatternEditStrategy::~KarbonPatternEditStrategy()
-{
-}
+KarbonPatternEditStrategy::~KarbonPatternEditStrategy() = default;
 
 void KarbonPatternEditStrategy::paint(QPainter &painter, const KoViewConverter &converter) const
 {
@@ -194,7 +180,7 @@ void KarbonPatternEditStrategy::handleMouseMove(const QPointF &mouseLocation, Qt
 
     setModified();
 
-    QSharedPointer<KoPatternBackground>  fill = qSharedPointerDynamicCast<KoPatternBackground>(shape()->background());
+    QSharedPointer<KoPatternBackground> fill = qSharedPointerDynamicCast<KoPatternBackground>(shape()->background());
     if (fill) {
         m_newFill = updatedBackground();
         fill = m_newFill;
@@ -236,24 +222,22 @@ QSharedPointer<KoPatternBackground> KarbonPatternEditStrategy::updatedBackground
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////////////////////////////////////////////////////////////////////
 
-KarbonOdfPatternEditStrategy::KarbonOdfPatternEditStrategy(KoShape * s, KoImageCollection * imageCollection)
-        : KarbonPatternEditStrategyBase(s, imageCollection)
+KarbonOdfPatternEditStrategy::KarbonOdfPatternEditStrategy(KoShape *s, KoImageCollection *imageCollection)
+    : KarbonPatternEditStrategyBase(s, imageCollection)
 {
     m_handles.append(QPointF());
     m_handles.append(QPointF());
     updateHandles(qSharedPointerDynamicCast<KoPatternBackground>(shape()->background()));
 }
 
-KarbonOdfPatternEditStrategy::~KarbonOdfPatternEditStrategy()
-{
-}
+KarbonOdfPatternEditStrategy::~KarbonOdfPatternEditStrategy() = default;
 
 void KarbonOdfPatternEditStrategy::paint(QPainter &painter, const KoViewConverter &converter) const
 {
     KoShape::applyConversion(painter, converter);
 
-    QSharedPointer<KoPatternBackground>  fill = qSharedPointerDynamicCast<KoPatternBackground>(shape()->background());
-    if (! fill)
+    QSharedPointer<KoPatternBackground> fill = qSharedPointerDynamicCast<KoPatternBackground>(shape()->background());
+    if (!fill)
         return;
 
     painter.save();
@@ -266,13 +250,12 @@ void KarbonOdfPatternEditStrategy::paint(QPainter &painter, const KoViewConverte
         paintHandle(painter, converter, m_matrix.map(m_handles[origin]));
     if (fill->repeat() != KoPatternBackground::Stretched)
         paintHandle(painter, converter, m_matrix.map(m_handles[size]));
-
 }
 
 bool KarbonOdfPatternEditStrategy::selectHandle(const QPointF &mousePos, const KoViewConverter &converter)
 {
-    QSharedPointer<KoPatternBackground>  fill = qSharedPointerDynamicCast<KoPatternBackground>(shape()->background());
-    if (! fill)
+    QSharedPointer<KoPatternBackground> fill = qSharedPointerDynamicCast<KoPatternBackground>(shape()->background());
+    if (!fill)
         return false;
 
     if (fill->repeat() == KoPatternBackground::Stretched)
@@ -359,7 +342,7 @@ QSharedPointer<KoPatternBackground> KarbonOdfPatternEditStrategy::updatedBackgro
 
 void KarbonOdfPatternEditStrategy::updateHandles(QSharedPointer<KoPatternBackground> fill)
 {
-    if (! fill)
+    if (!fill)
         return;
 
     QRectF patternRect = fill->patternRectFromFillSize(shape()->size());
