@@ -1,25 +1,12 @@
 /* This file is part of the KDE project
- * Copyright (C) 2007 Jan Hambrecht <jaham@gmx.net>
+ * SPDX-FileCopyrightText: 2007 Jan Hambrecht <jaham@gmx.net>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "EllipseShapeConfigWidget.h"
 #include "EllipseShapeConfigCommand.h"
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 EllipseShapeConfigWidget::EllipseShapeConfigWidget()
 {
@@ -36,15 +23,15 @@ EllipseShapeConfigWidget::EllipseShapeConfigWidget()
     widget.endAngle->setMinimum(0.0);
     widget.endAngle->setMaximum(360.0);
 
-    connect(widget.ellipseType, SIGNAL(currentIndexChanged(int)), this, SIGNAL(propertyChanged()));
-    connect(widget.startAngle, SIGNAL(editingFinished()), this, SIGNAL(propertyChanged()));
-    connect(widget.endAngle, SIGNAL(editingFinished()), this, SIGNAL(propertyChanged()));
-    connect(widget.closeEllipse, SIGNAL(clicked(bool)), this, SLOT(closeEllipse()));
+    connect(widget.ellipseType, &QComboBox::currentIndexChanged, this, &KoShapeConfigWidgetBase::propertyChanged);
+    connect(widget.startAngle, &QAbstractSpinBox::editingFinished, this, &KoShapeConfigWidgetBase::propertyChanged);
+    connect(widget.endAngle, &QAbstractSpinBox::editingFinished, this, &KoShapeConfigWidgetBase::propertyChanged);
+    connect(widget.closeEllipse, &QAbstractButton::clicked, this, &EllipseShapeConfigWidget::closeEllipse);
 }
 
 void EllipseShapeConfigWidget::open(KoShape *shape)
 {
-    m_ellipse = dynamic_cast<EllipseShape*>(shape);
+    m_ellipse = dynamic_cast<EllipseShape *>(shape);
     if (!m_ellipse)
         return;
 
@@ -74,7 +61,7 @@ void EllipseShapeConfigWidget::save()
 KUndo2Command *EllipseShapeConfigWidget::createCommand()
 {
     if (!m_ellipse) {
-        return 0;
+        return nullptr;
     } else {
         EllipseShape::EllipseType type = static_cast<EllipseShape::EllipseType>(widget.ellipseType->currentIndex());
         return new EllipseShapeConfigCommand(m_ellipse, type, widget.startAngle->value(), widget.endAngle->value());
@@ -92,5 +79,5 @@ void EllipseShapeConfigWidget::closeEllipse()
     widget.startAngle->blockSignals(false);
     widget.endAngle->blockSignals(false);
 
-    emit propertyChanged();
+    Q_EMIT propertyChanged();
 }
