@@ -1,35 +1,22 @@
 /* This file is part of the KDE project
- * Copyright (C) 2007 Jan Hambrecht <jaham@gmx.net>
+ * SPDX-FileCopyrightText: 2007 Jan Hambrecht <jaham@gmx.net>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "enhancedpath/EnhancedPathShapeFactory.h"
 #include "enhancedpath/EnhancedPathShape.h"
 
-#include <KoShapeStroke.h>
+#include <KoColorBackground.h>
 #include <KoProperties.h>
+#include <KoShapeLoadingContext.h>
+#include <KoShapeStroke.h>
 #include <KoXmlNS.h>
 #include <KoXmlReader.h>
-#include <KoColorBackground.h>
-#include <KoShapeLoadingContext.h>
 
 #include <KoIcon.h>
 
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 #include <QString>
 
@@ -80,9 +67,7 @@ KoShape *EnhancedPathShapeFactory::createDefaultShape(KoDocumentResourceManager
 KoShape *EnhancedPathShapeFactory::createShape(const KoProperties *params, KoDocumentResourceManager *) const
 {
     QVariant viewboxData;
-    const QRect viewBox = (params->property(QLatin1String("viewBox"), viewboxData)) ?
-        viewboxData.toRect() :
-        QRect(0, 0, 100, 100);
+    const QRect viewBox = (params->property(QLatin1String("viewBox"), viewboxData)) ? viewboxData.toRect() : QRect(0, 0, 100, 100);
 
     EnhancedPathShape *shape = new EnhancedPathShape(viewBox);
 
@@ -116,9 +101,8 @@ KoShape *EnhancedPathShapeFactory::createShape(const KoProperties *params, KoDoc
     return shape;
 }
 
-KoProperties* EnhancedPathShapeFactory::dataToProperties(
-    const QString &modifiers, const QStringList &commands,
-    const ListType &handles, const ComplexType & formulae) const
+KoProperties *
+EnhancedPathShapeFactory::dataToProperties(const QString &modifiers, const QStringList &commands, const ListType &handles, const ComplexType &formulae) const
 {
     KoProperties *props = new KoProperties();
     props->setProperty("modifiers", modifiers);
@@ -338,7 +322,7 @@ void EnhancedPathShapeFactory::addSmiley()
     t.family = "funny";
     t.toolTip = i18n("Smiley");
     t.iconName = koIconName("smiley-shape");
-    KoProperties* properties = dataToProperties(modifiers, commands, handles, formulae);
+    KoProperties *properties = dataToProperties(modifiers, commands, handles, formulae);
     properties->setProperty(QLatin1String("viewBox"), QRect(0, 0, 21600, 21600));
     t.properties = properties;
 
@@ -418,7 +402,7 @@ void EnhancedPathShapeFactory::addCircularArrow()
     t.family = "arrow";
     t.toolTip = i18n("A circular-arrow");
     t.iconName = koIconName("circular-arrow-shape");
-    KoProperties* properties = dataToProperties(modifiers, commands, handles, formulae);
+    KoProperties *properties = dataToProperties(modifiers, commands, handles, formulae);
     properties->setProperty(QLatin1String("viewBox"), QRect(0, 0, 21600, 21600));
     t.properties = properties;
     addTemplate(t);
@@ -434,24 +418,24 @@ void EnhancedPathShapeFactory::addGearhead()
 
     uint toothCount = 10;
     qreal toothAngle = 360.0 / qreal(toothCount);
-    //kDebug() <<"toothAngle =" << toothAngle;
+    // kDebug() <<"toothAngle =" << toothAngle;
     qreal outerRadius = 0.5 * 25.0;
     qreal innerRadius = 0.5 * 17.0;
     QPointF center(20, 25);
     qreal radian = (270.0 - 0.35 * toothAngle) * M_PI / 180.0;
-    commands.append(QString("M %1 %2").arg(center.x() + innerRadius*cos(radian)).arg(center.y() + innerRadius*sin(radian)));
+    commands.append(QString("M %1 %2").arg(center.x() + innerRadius * cos(radian)).arg(center.y() + innerRadius * sin(radian)));
     QString cmd("L");
     for (uint i = 0; i < toothCount; ++i) {
         radian += 0.15 * toothAngle * M_PI / 180.0;
-        cmd += QString(" %1 %2").arg(center.x() + outerRadius*cos(radian)).arg(center.y() + outerRadius*sin(radian));
+        cmd += QString(" %1 %2").arg(center.x() + outerRadius * cos(radian)).arg(center.y() + outerRadius * sin(radian));
         radian += 0.35 * toothAngle * M_PI / 180.0;
-        cmd += QString(" %1 %2").arg(center.x() + outerRadius*cos(radian)).arg(center.y() + outerRadius*sin(radian));
+        cmd += QString(" %1 %2").arg(center.x() + outerRadius * cos(radian)).arg(center.y() + outerRadius * sin(radian));
         radian += 0.15 * toothAngle * M_PI / 180.0;
-        cmd += QString(" %1 %2").arg(center.x() + innerRadius*cos(radian)).arg(center.y() + innerRadius*sin(radian));
+        cmd += QString(" %1 %2").arg(center.x() + innerRadius * cos(radian)).arg(center.y() + innerRadius * sin(radian));
         radian += 0.35 * toothAngle * M_PI / 180.0;
-        cmd += QString(" %1 %2").arg(center.x() + innerRadius*cos(radian)).arg(center.y() + innerRadius*sin(radian));
+        cmd += QString(" %1 %2").arg(center.x() + innerRadius * cos(radian)).arg(center.y() + innerRadius * sin(radian));
     }
-    //kDebug() <<"gear command =" << cmd;
+    // kDebug() <<"gear command =" << cmd;
     commands.append(cmd);
     commands.append("Z");
     commands.append("N");
@@ -463,16 +447,15 @@ void EnhancedPathShapeFactory::addGearhead()
     t.family = "funny";
     t.toolTip = i18n("A gearhead");
     t.iconName = koIconName("gearhead-shape");
-    KoProperties* properties = dataToProperties(QString(), commands, ListType(), ComplexType());
+    KoProperties *properties = dataToProperties(QString(), commands, ListType(), ComplexType());
     properties->setProperty("background", QVariant::fromValue<QColor>(QColor(Qt::blue)));
     properties->setProperty(QLatin1String("viewBox"), QRect(0, 0, 40, 90));
     t.properties = properties;
     addTemplate(t);
 }
 
-bool EnhancedPathShapeFactory::supports(const KoXmlElement & e, KoShapeLoadingContext &context) const
+bool EnhancedPathShapeFactory::supports(const KoXmlElement &e, KoShapeLoadingContext &context) const
 {
     Q_UNUSED(context);
-    qInfo()<<Q_FUNC_INFO<<e.localName();
     return (e.localName() == "custom-shape" && e.namespaceURI() == KoXmlNS::draw);
 }
