@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C) 2007 Rob Buis <buis@kde.org>
+   SPDX-FileCopyrightText: 2007 Rob Buis <buis@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KOSPIRALSHAPE_H
@@ -32,10 +19,9 @@ class SpiralShape : public KoParameterShape
 {
 public:
     /// the possible spiral types
-    enum SpiralType
-    {
-        Curve = 0,   ///< spiral uses curves
-        Line = 1    ///< spiral uses lines
+    enum SpiralType {
+        Curve = 0, ///< spiral uses curves
+        Line = 1 ///< spiral uses lines
     };
 
     SpiralShape();
@@ -84,8 +70,10 @@ private:
 
     // fade parameter
     qreal m_fade;
+#if 0
     // angle for modifying the kind in radiant
     qreal m_kindAngle;
+#endif
     // the center of the spiral
     QPointF m_center;
     // the radii of the spiral
@@ -99,4 +87,3 @@ private:
 };
 
 #endif /* KOSPIRALSHAPE_H */
-
