@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
- * Copyright (c) 2010 Jan Hambrecht <jaham@gmx.net>
+ * SPDX-FileCopyrightText: 2010 Jan Hambrecht <jaham@gmx.net>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #ifndef CONVOLVEMATRIXEFFECTCONFIGWIDGET_H
@@ -34,10 +21,10 @@ class ConvolveMatrixEffectConfigWidget : public KoFilterEffectConfigWidgetBase
 {
     Q_OBJECT
 public:
-    explicit ConvolveMatrixEffectConfigWidget(QWidget *parent = 0);
+    explicit ConvolveMatrixEffectConfigWidget(QWidget *parent = nullptr);
 
     /// reimplemented from KoFilterEffectConfigWidgetBase
-    bool editFilterEffect(KoFilterEffect * filterEffect) override;
+    bool editFilterEffect(KoFilterEffect *filterEffect) override;
 
 private Q_SLOTS:
     void orderChanged(int value);
@@ -48,9 +35,10 @@ private Q_SLOTS:
     void preserveAlphaChanged(bool checked);
     void editKernel();
     void kernelChanged();
+
 private:
-    ConvolveMatrixEffect * m_effect;
-    KComboBox * m_edgeMode;
+    ConvolveMatrixEffect *m_effect;
+    KComboBox *m_edgeMode;
     QSpinBox *m_orderX;
     QSpinBox *m_orderY;
     QSpinBox *m_targetX;
@@ -58,7 +46,7 @@ private:
     QDoubleSpinBox *m_divisor;
     QDoubleSpinBox *m_bias;
     QCheckBox *m_preserveAlpha;
-    MatrixDataModel * m_matrixModel;
+    MatrixDataModel *m_matrixModel;
 };
 
 #endif // CONVOLVEMATRIXEFFECTCONFIGWIDGET_H
