@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
  *
- * Copyright (C) 2012 Inge Wallin <inge@lysator.liu.se>
+ * SPDX-FileCopyrightText: 2012 Inge Wallin <inge@lysator.liu.se>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 // Own
@@ -26,42 +13,36 @@
 #include <QString>
 
 // Calligra
-#include <KoXmlReader.h>
-#include <KoXmlNS.h>
-#include <KoXmlWriter.h>
 #include <KoGenStyle.h>
-#include <KoStyleStack.h>
-#include <KoShapeSavingContext.h>
 #include <KoOdfLoadingContext.h>
 #include <KoShapeLoadingContext.h>
 #include <KoShapePaintingContext.h>
+#include <KoShapeSavingContext.h>
+#include <KoStyleStack.h>
 #include <KoViewConverter.h>
+#include <KoXmlNS.h>
+#include <KoXmlReader.h>
+#include <KoXmlWriter.h>
 
 // Shape
-#include "utils.h"
 #include "ThreedDebug.h"
+#include "utils.h"
 
-
-//#define OdfObjectAttributes (OdfAllAttributes & ~(OdfGeometry | OdfTransformation))
+// #define OdfObjectAttributes (OdfAllAttributes & ~(OdfGeometry | OdfTransformation))
 #define OdfObjectAttributes (OdfAdditionalAttributes | OdfMandatories)
 
 // ================================================================
 //                             Sphere
 
-
 Sphere::Sphere(Object3D *parent)
     : Object3D(parent)
     , KoShape()
 {
 }
 
-Sphere::~Sphere()
-{
-}
+Sphere::~Sphere() = default;
 
-
-void Sphere::paint(QPainter &painter, const KoViewConverter &converter,
-                   KoShapePaintingContext &context)
+void Sphere::paint(QPainter &painter, const KoViewConverter &converter, KoShapePaintingContext &context)
 {
     Q_UNUSED(painter);
     Q_UNUSED(converter);
@@ -100,32 +81,24 @@ void Sphere::saveObjectOdf(KoShapeSavingContext &context) const
     saveOdfAttributes(context, OdfObjectAttributes);
     Object3D::saveObjectOdf(context);
 
-    writer.addAttribute("dr3d:center", QString("(%1 %2 %3)").arg(m_center.x())
-                        .arg(m_center.y()).arg(m_center.z()));
-    writer.addAttribute("dr3d:size", QString("(%1 %2 %3)").arg(m_size.x())
-                        .arg(m_size.y()).arg(m_size.z()));
+    writer.addAttribute("dr3d:center", QString("(%1 %2 %3)").arg(m_center.x()).arg(m_center.y()).arg(m_center.z()));
+    writer.addAttribute("dr3d:size", QString("(%1 %2 %3)").arg(m_size.x()).arg(m_size.y()).arg(m_size.z()));
 
     writer.endElement(); // dr3d:sphere
 }
 
-
 // ================================================================
 //                             Cube
 
-
 Cube::Cube(Object3D *parent)
     : Object3D(parent)
     , KoShape()
 {
 }
 
-Cube::~Cube()
-{
-}
+Cube::~Cube() = default;
 
-
-void Cube::paint(QPainter &painter, const KoViewConverter &converter,
-                 KoShapePaintingContext &context)
+void Cube::paint(QPainter &painter, const KoViewConverter &converter, KoShapePaintingContext &context)
 {
     Q_UNUSED(painter);
     Q_UNUSED(converter);
@@ -164,19 +137,15 @@ void Cube::saveObjectOdf(KoShapeSavingContext &context) const
     saveOdfAttributes(context, OdfObjectAttributes);
     Object3D::saveObjectOdf(context);
 
-    writer.addAttribute("dr3d:min-edge", QString("(%1 %2 %3)").arg(m_minEdge.x())
-                        .arg(m_minEdge.y()).arg(m_minEdge.z()));
-    writer.addAttribute("dr3d:max-edge", QString("(%1 %2 %3)").arg(m_maxEdge.x())
-                        .arg(m_maxEdge.y()).arg(m_maxEdge.z()));
+    writer.addAttribute("dr3d:min-edge", QString("(%1 %2 %3)").arg(m_minEdge.x()).arg(m_minEdge.y()).arg(m_minEdge.z()));
+    writer.addAttribute("dr3d:max-edge", QString("(%1 %2 %3)").arg(m_maxEdge.x()).arg(m_maxEdge.y()).arg(m_maxEdge.z()));
 
     writer.endElement(); // dr3d:cube
 }
 
-
 // ================================================================
 //                             Extrude
 
-
 Extrude::Extrude(Object3D *parent)
     : Object3D(parent)
     , KoShape()
@@ -188,13 +157,9 @@ Extrude::Extrude(Object3D *parent)
 {
 }
 
-Extrude::~Extrude()
-{
-}
+Extrude::~Extrude() = default;
 
-
-void Extrude::paint(QPainter &painter, const KoViewConverter &converter,
-                    KoShapePaintingContext &context)
+void Extrude::paint(QPainter &painter, const KoViewConverter &converter, KoShapePaintingContext &context)
 {
     Q_UNUSED(painter);
     Q_UNUSED(converter);
@@ -207,7 +172,6 @@ bool Extrude::loadOdf(const KoXmlElement &objectElement, KoShapeLoadingContext &
     loadOdfAttributes(objectElement, context, OdfObjectAttributes);
     Object3D::loadOdf(objectElement, context);
 
-    QString dummy;
     m_path = objectElement.attributeNS(KoXmlNS::svg, "d", "");
     m_viewBox = objectElement.attributeNS(KoXmlNS::svg, "viewBox", "");
 
@@ -236,7 +200,7 @@ void Extrude::saveObjectOdf(KoShapeSavingContext &context) const
     writer.endElement(); // dr3d:extrude
 }
 
-void Extrude::loadStyle(const KoXmlElement& element, KoShapeLoadingContext& context)
+void Extrude::loadStyle(const KoXmlElement &element, KoShapeLoadingContext &context)
 {
     // Load the common parts of the style.
     KoShape::loadStyle(element, context);
@@ -274,12 +238,12 @@ void Extrude::loadStyle(const KoXmlElement& element, KoShapeLoadingContext& cont
     }
 }
 
-QString Extrude::saveStyle(KoGenStyle& style, KoShapeSavingContext& context) const
+QString Extrude::saveStyle(KoGenStyle &style, KoShapeSavingContext &context) const
 {
     style.addProperty("dr3d:depth", QString("%1").arg(m_depth));
 
     style.addProperty("dr3d:close-front", m_closeFront);
-    style.addProperty("dr3d:close-back",  m_closeBack);
+    style.addProperty("dr3d:close-back", m_closeBack);
 
     if (m_backScale != 1.0) {
         style.addProperty("dr3d:back-scale", QString("%1").arg(m_backScale));
@@ -288,11 +252,9 @@ QString Extrude::saveStyle(KoGenStyle& style, KoShapeSavingContext& context) con
     return KoShape::saveStyle(style, context);
 }
 
-
 // ================================================================
 //                             Rotate
 
-
 Rotate::Rotate(Object3D *parent)
     : Object3D(parent)
     , KoShape()
@@ -306,13 +268,9 @@ Rotate::Rotate(Object3D *parent)
 {
 }
 
-Rotate::~Rotate()
-{
-}
+Rotate::~Rotate() = default;
 
-
-void Rotate::paint(QPainter &painter, const KoViewConverter &converter,
-                   KoShapePaintingContext &context)
+void Rotate::paint(QPainter &painter, const KoViewConverter &converter, KoShapePaintingContext &context)
 {
     Q_UNUSED(painter);
     Q_UNUSED(converter);
@@ -325,7 +283,6 @@ bool Rotate::loadOdf(const KoXmlElement &objectElement, KoShapeLoadingContext &c
     loadOdfAttributes(objectElement, context, OdfObjectAttributes);
     Object3D::loadOdf(objectElement, context);
 
-    QString dummy;
     m_path = objectElement.attributeNS(KoXmlNS::svg, "d", "");
     m_viewBox = objectElement.attributeNS(KoXmlNS::svg, "viewBox", "");
 
@@ -354,7 +311,7 @@ void Rotate::saveObjectOdf(KoShapeSavingContext &context) const
     writer.endElement(); // dr3d:rotate
 }
 
-void Rotate::loadStyle(const KoXmlElement& element, KoShapeLoadingContext& context)
+void Rotate::loadStyle(const KoXmlElement &element, KoShapeLoadingContext &context)
 {
     // Load the common parts of the style.
     KoShape::loadStyle(element, context);
@@ -410,7 +367,7 @@ void Rotate::loadStyle(const KoXmlElement& element, KoShapeLoadingContext& conte
     }
 }
 
-QString Rotate::saveStyle(KoGenStyle& style, KoShapeSavingContext& context) const
+QString Rotate::saveStyle(KoGenStyle &style, KoShapeSavingContext &context) const
 {
     if (m_horizontalSegments != -1) {
         style.addProperty("dr3d:horizontal-segments", QString("%1").arg(m_horizontalSegments));
@@ -424,7 +381,7 @@ QString Rotate::saveStyle(KoGenStyle& style, KoShapeSavingContext& context) cons
     }
 
     style.addProperty("dr3d:close-front", m_closeFront);
-    style.addProperty("dr3d:close-back",  m_closeBack);
+    style.addProperty("dr3d:close-back", m_closeBack);
 
     if (m_backScale != 1.0) {
         style.addProperty("dr3d:back-scale", QString("%1").arg(m_backScale));
