@@ -1,56 +1,42 @@
 /* This file is part of the KDE project
  *
- * Copyright (C) 2012 Inge Wallin <inge@lysator.liu.se>
+ * SPDX-FileCopyrightText: 2012 Inge Wallin <inge@lysator.liu.se>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 // Own
 #include "SceneObject.h"
 
 // Qt
-#include <QPainter>
-#include <QTimer>
-#include <QPixmapCache>
 #include <QBuffer>
+#include <QPainter>
+#include <QPixmapCache>
+#include <QTimer>
 
 // Calligra
-#include <KoViewConverter.h>
+#include <KoFilterEffectStack.h>
 #include <KoImageCollection.h>
 #include <KoImageData.h>
+#include <KoOdfLoadingContext.h>
 #include <KoShapeLoadingContext.h>
 #include <KoShapePaintingContext.h>
-#include <KoOdfLoadingContext.h>
 #include <KoShapeSavingContext.h>
-#include <KoXmlWriter.h>
+#include <KoViewConverter.h>
 #include <KoXmlNS.h>
-#include <KoFilterEffectStack.h>
+#include <KoXmlWriter.h>
 
 // 3D shape
 #include "Objects.h"
 #include "ThreedDebug.h"
 
-
 SceneObject::SceneObject(Object3D *parent, bool topLevel)
     : Object3D(parent)
 #if IMPLEMENT_AS_SHAPECONTAINER
     , KoShapeContainer()
 #endif
     , m_topLevel(topLevel)
-    , m_threeDParams(0)
+    , m_threeDParams(nullptr)
 {
 }
 
@@ -61,21 +47,18 @@ SceneObject::~SceneObject()
 }
 
 /// reimplemented from KoShapeContainer
-void SceneObject::paintComponent(QPainter &painter, const KoViewConverter &converter,
-                                 KoShapePaintingContext &paintcontext)
+void SceneObject::paintComponent(QPainter &painter, const KoViewConverter &converter, KoShapePaintingContext &paintcontext)
 {
     Q_UNUSED(painter);
     Q_UNUSED(converter);
     Q_UNUSED(paintcontext);
 }
 
-
-void SceneObject::paint(QPainter &painter, const KoViewConverter &converter,
-                        KoShapePaintingContext &context)
+void SceneObject::paint(QPainter &painter, const KoViewConverter &converter, KoShapePaintingContext &context)
 {
     Q_UNUSED(context);
 
-    //painter.setPen(QPen(QColor(172, 196, 206)));
+    // painter.setPen(QPen(QColor(172, 196, 206)));
     painter.setPen(QPen(QColor(0, 0, 0), 0));
 
 #if 1
@@ -102,7 +85,6 @@ void SceneObject::paint(QPainter &painter, const KoViewConverter &converter,
 #endif
 }
 
-
 void SceneObject::saveOdf(KoShapeSavingContext &context) const
 {
     if (m_topLevel) {
@@ -140,11 +122,9 @@ bool SceneObject::loadOdf(const KoXmlElement &sceneElement, KoShapeLoadingContex
 {
     // Load style information.
     if (m_topLevel) {
-        loadOdfAttributes(sceneElement, context,
-                          (OdfAdditionalAttributes | OdfMandatories | OdfGeometry));
+        loadOdfAttributes(sceneElement, context, (OdfAdditionalAttributes | OdfMandatories | OdfGeometry));
     } else {
-        loadOdfAttributes(sceneElement, context,
-                          (OdfAdditionalAttributes | OdfMandatories));
+        loadOdfAttributes(sceneElement, context, (OdfAdditionalAttributes | OdfMandatories));
     }
     Object3D::loadOdf(sceneElement, context);
 
@@ -170,44 +150,40 @@ bool SceneObject::loadOdf(const KoXmlElement &sceneElement, KoShapeLoadingContex
     //
     // The lights are skipped here, they are taken care of by the call
     // to load3dScene() above.
-    KoXmlElement  elem;
-    forEachElement(elem, sceneElement) {
-
+    KoXmlElement elem;
+    forEachElement(elem, sceneElement)
+    {
         if (elem.localName() == "scene" && elem.namespaceURI() == KoXmlNS::dr3d) {
-            SceneObject  *scene = new SceneObject(this, false);
+            SceneObject *scene = new SceneObject(this, false);
             scene->loadOdf(elem, context);
             m_objects.append(scene);
 #if IMPLEMENT_AS_SHAPECONTAINER
             addShape(scene);
 #endif
 
-        }
-        else if (elem.localName() == "sphere" && elem.namespaceURI() == KoXmlNS::dr3d) {
-            Sphere  *sphere = new Sphere(this);
+        } else if (elem.localName() == "sphere" && elem.namespaceURI() == KoXmlNS::dr3d) {
+            Sphere *sphere = new Sphere(this);
             sphere->loadOdf(elem, context);
             m_objects.append(sphere);
 #if IMPLEMENT_AS_SHAPECONTAINER
             addShape(sphere);
 #endif
-        }
-        else if (elem.localName() == "cube" && elem.namespaceURI() == KoXmlNS::dr3d) {
-            Cube  *cube = new Cube(this);
+        } else if (elem.localName() == "cube" && elem.namespaceURI() == KoXmlNS::dr3d) {
+            Cube *cube = new Cube(this);
             cube->loadOdf(elem, context);
             m_objects.append(cube);
 #if IMPLEMENT_AS_SHAPECONTAINER
             addShape(cube);
 #endif
-        }
-        else if (elem.localName() == "extrude" && elem.namespaceURI() == KoXmlNS::dr3d) {
-            Extrude  *extrude = new Extrude(this);
+        } else if (elem.localName() == "extrude" && elem.namespaceURI() == KoXmlNS::dr3d) {
+            Extrude *extrude = new Extrude(this);
             extrude->loadOdf(elem, context);
             m_objects.append(extrude);
 #if IMPLEMENT_AS_SHAPECONTAINER
             addShape(extrude);
 #endif
-        }
-        else if (elem.localName() == "rotate" && elem.namespaceURI() == KoXmlNS::dr3d) {
-            Rotate  *rotate = new Rotate(this);
+        } else if (elem.localName() == "rotate" && elem.namespaceURI() == KoXmlNS::dr3d) {
+            Rotate *rotate = new Rotate(this);
             rotate->loadOdf(elem, context);
             m_objects.append(rotate);
 #if IMPLEMENT_AS_SHAPECONTAINER
@@ -224,7 +200,6 @@ bool SceneObject::loadOdf(const KoXmlElement &sceneElement, KoShapeLoadingContex
     return true;
 }
 
-
 void SceneObject::waitUntilReady(const KoViewConverter &converter, bool asynchronous) const
 {
     Q_UNUSED(converter);
