@@ -1,29 +1,16 @@
 /* This file is part of the KDE project
  *
- * Copyright (C) 2012 Inge Wallin <inge@lysator.liu.se>
+ * SPDX-FileCopyrightText: 2012 Inge Wallin <inge@lysator.liu.se>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef THREEDSHAPE_H
 #define THREEDSHAPE_H
 
 // Qt
-#include <QObject>
 #include <QList>
+#include <QObject>
 
 // Calligra
 #include <Ko3dScene.h>
@@ -32,15 +19,15 @@
 // Shape
 #include "Object3D.h"
 
-
 #define THREEDSHAPEID "ThreedShape"
 
-
 class SceneObject : public Object3D //, public QObject
 #if IMPLEMENT_AS_SHAPECONTAINER
-    , public KoShapeContainer
+    ,
+                    public KoShapeContainer
 #else
-    , public KoShape
+    ,
+                    public KoShape
 #endif
 {
 public:
@@ -53,12 +40,10 @@ public:
     ~SceneObject() override;
 
     /// reimplemented from KoShapeContainer
-    void paintComponent(QPainter &painter, const KoViewConverter &converter,
-                                KoShapePaintingContext &paintcontext) override;
+    void paintComponent(QPainter &painter, const KoViewConverter &converter, KoShapePaintingContext &paintcontext) override;
 
     // reimplemented from KoShape
-    void paint(QPainter &painter, const KoViewConverter &converter,
-                       KoShapePaintingContext &context) override;
+    void paint(QPainter &painter, const KoViewConverter &converter, KoShapePaintingContext &context) override;
     // reimplemented from KoShape
     void saveOdf(KoShapeSavingContext &context) const override;
     // reimplemented from KoShape
@@ -75,11 +60,10 @@ public:
 
 private:
     // View attributes
-    bool       m_topLevel;
-    Ko3dScene *m_threeDParams;    // Camera and rendering parameters plus lightsources.
+    bool m_topLevel;
+    Ko3dScene *m_threeDParams; // Camera and rendering parameters plus lightsources.
 
-    QList<Object3D*> m_objects;
+    QList<Object3D *> m_objects;
 };
 
-
 #endif
