@@ -1,39 +1,26 @@
 /* This file is part of the KDE project
- * Copyright (C) 2007, 2008 Fredy Yanardi <fyanardi@gmail.com>
- * Copyright (C) 2009-2010 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2007, 2008 Fredy Yanardi <fyanardi@gmail.com>
+ * SPDX-FileCopyrightText: 2009-2010 Thomas Zander <zander@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "BgSpellCheck.h"
 #include "SpellCheck.h"
+#include "SpellCheckDebug.h"
 
 #include <KoCharacterStyle.h>
 
-#include <QTextDocument>
 #include <QCoreApplication>
 #include <QTextBlock>
-#include <kdebug.h>
+#include <QTextDocument>
 
 #define MaxCharsPerRun 1000
 
-BgSpellCheck::BgSpellCheck(const Speller &speller, QObject *parent):
-    BackgroundChecker(speller, parent)
+BgSpellCheck::BgSpellCheck(const Speller &speller, QObject *parent)
+    : BackgroundChecker(speller, parent)
 {
-    connect(this, SIGNAL(misspelling(const QString &, int)), this, SLOT(foundMisspelling(const QString &, int)));
+    connect(this, &Sonnet::BackgroundChecker::misspelling, this, &BgSpellCheck::foundMisspelling);
     QString lang = speller.language();
     if (lang.isEmpty()) // have *some* default...
         lang = "en_US";
@@ -51,7 +38,7 @@ void BgSpellCheck::setDefaultLanguage(const QString &language)
     m_defaultLanguage = language;
     int index = m_defaultLanguage.indexOf('_');
     if (index > 0) {
-        m_defaultCountry = m_defaultLanguage.mid(index+1);
+        m_defaultCountry = m_defaultLanguage.mid(index + 1);
         m_defaultLanguage = m_defaultLanguage.left(index);
     }
 }
@@ -68,14 +55,14 @@ void BgSpellCheck::startRun(QTextDocument *document, int startPosition, int endP
         if (m_currentCountry.isEmpty()) {
             changeLanguage(m_currentLanguage);
         } else {
-            changeLanguage(m_currentLanguage+'_'+m_currentCountry);
+            changeLanguage(m_currentLanguage + '_' + m_currentCountry);
         }
     }
     if (m_currentPosition < m_endPosition) {
-        kDebug(31000) << "Starting:" << m_currentPosition << m_endPosition;
+        debugSpellCheck << "Starting:" << m_currentPosition << m_endPosition;
         start();
     } else {
-        emit done();
+        Q_EMIT done();
     }
 }
 
@@ -99,8 +86,7 @@ QString BgSpellCheck::fetchMoreText()
         }
 
         iter = block.begin();
-        while (!iter.atEnd() && iter.fragment().position() + iter.fragment().length() <=
-                m_currentPosition) {
+        while (!iter.atEnd() && iter.fragment().position() + iter.fragment().length() <= m_currentPosition) {
             ++iter;
         }
 
@@ -120,11 +106,11 @@ QString BgSpellCheck::fetchMoreText()
     else
         country = m_defaultCountry;
 
-    // qDebug() << "init" << language << country << "/" << iter.fragment().position();
-    while(true) {
+    // debugSpellCheck << "init" << language << country << "/" << iter.fragment().position();
+    while (true) {
         end = iter.fragment().position() + iter.fragment().length();
-        // qDebug() << " + " << iter.fragment().position() << "-" << iter.fragment().position() + iter.fragment().length()
-            // << block.text().mid(iter.fragment().position() - block.position(), iter.fragment().length());
+        // debugSpellCheck << " + " << iter.fragment().position() << "-" << iter.fragment().position() + iter.fragment().length()
+        // << block.text().mid(iter.fragment().position() - block.position(), iter.fragment().length());
         if (end >= qMin(m_endPosition, m_currentPosition + MaxCharsPerRun)) {
             break;
         }
@@ -136,28 +122,24 @@ QString BgSpellCheck::fetchMoreText()
             break;
         }
         Q_ASSERT(iter.fragment().isValid());
-        // qDebug() << "Checking for viability forwarding to " << iter.fragment().position();
+        // debugSpellCheck << "Checking for viability forwarding to " << iter.fragment().position();
         cf = iter.fragment().charFormat();
-        // qDebug() << " new fragment language;"
-            // << (cf.hasProperty(KoCharacterStyle::Language) ?  cf.property(KoCharacterStyle::Language).toString() : "unset");
+        // debugSpellCheck << " new fragment language;"
+        // << (cf.hasProperty(KoCharacterStyle::Language) ?  cf.property(KoCharacterStyle::Language).toString() : "unset");
 
-        if ((cf.hasProperty(KoCharacterStyle::Language)
-                    && language != cf.property(KoCharacterStyle::Language).toString())
-                || (!cf.hasProperty(KoCharacterStyle::Language)
-                    && language != m_defaultLanguage)) {
+        if ((cf.hasProperty(KoCharacterStyle::Language) && language != cf.property(KoCharacterStyle::Language).toString())
+            || (!cf.hasProperty(KoCharacterStyle::Language) && language != m_defaultLanguage)) {
             break;
         }
 
-        if ((cf.hasProperty(KoCharacterStyle::Country)
-                    && country != cf.property(KoCharacterStyle::Country).toString())
-                || (!cf.hasProperty(KoCharacterStyle::Country)
-                    && country != m_defaultCountry)) {
+        if ((cf.hasProperty(KoCharacterStyle::Country) && country != cf.property(KoCharacterStyle::Country).toString())
+            || (!cf.hasProperty(KoCharacterStyle::Country) && country != m_defaultCountry)) {
             break;
         }
     }
 
     if (m_currentLanguage != language || m_currentCountry != country) {
-        kDebug(31000) << "switching to language" << language << country;
+        debugSpellCheck << "switching to language" << language << country;
         m_currentLanguage = language;
         m_currentCountry = country;
 #if 0
@@ -181,8 +163,8 @@ QString BgSpellCheck::fetchMoreText()
 
 void BgSpellCheck::foundMisspelling(const QString &word, int start)
 {
-    // kDebug(31000) << "Mispelling: " << word << " : " << start;
-    emit misspelledWord(word, m_currentPosition + start, true);
+    // debugSpellCheck << "Misspelling: " << word << " : " << start;
+    Q_EMIT misspelledWord(word, m_currentPosition + start, true);
     BackgroundChecker::continueChecking();
 }
 
@@ -195,5 +177,3 @@ QString BgSpellCheck::currentCountry() const
 {
     return m_currentCountry;
 }
-
-#include <BgSpellCheck.moc>
