@@ -1,49 +1,36 @@
 /* This file is part of the KDE project
- * Copyright (C) 2010 Christoph Goerlich <chgoerlich@gmx.de>
- * Copyright (C) 2012 Shreya Pandit <shreya@shreyapandit.com>
+ * SPDX-FileCopyrightText: 2010 Christoph Goerlich <chgoerlich@gmx.de>
+ * SPDX-FileCopyrightText: 2012 Shreya Pandit <shreya@shreyapandit.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "SpellCheckMenu.h"
 #include "SpellCheck.h"
 #include "SpellCheckDebug.h"
 
-#include <kactionmenu.h>
-#include <klocalizedstring.h>
+#include <KActionMenu>
+#include <KLocalizedString>
 
-#include <QMenu>
 #include <QAction>
+#include <QMenu>
 
 SpellCheckMenu::SpellCheckMenu(const Sonnet::Speller &speller, SpellCheck *spellCheck)
-    : QObject(spellCheck),
-    m_spellCheck(spellCheck),
-    m_speller(speller),
-    m_suggestionsMenuAction(0),
-    m_ignoreWordAction(0),
-    m_addToDictionaryAction(0),
-    m_suggestionsMenu(0),
-    m_currentMisspelledPosition(-1)
+    : QObject(spellCheck)
+    , m_spellCheck(spellCheck)
+    , m_speller(speller)
+    , m_suggestionsMenuAction(nullptr)
+    , m_ignoreWordAction(nullptr)
+    , m_addToDictionaryAction(nullptr)
+    , m_suggestionsMenu(nullptr)
+    , m_currentMisspelledPosition(-1)
 {
     m_suggestionsMenuAction = new KActionMenu(i18n("Spelling"), this);
     m_suggestionsMenu = m_suggestionsMenuAction->menu();
-    connect(m_suggestionsMenu, SIGNAL(aboutToShow()), this, SLOT(createSuggestionsMenu()));
+    connect(m_suggestionsMenu, &QMenu::aboutToShow, this, &SpellCheckMenu::createSuggestionsMenu);
 
     m_addToDictionaryAction = new QAction(i18n("Add to Dictionary"), this);
-    connect(m_addToDictionaryAction, SIGNAL(triggered()), this, SLOT(addWordToDictionary()));
+    connect(m_addToDictionaryAction, &QAction::triggered, this, &SpellCheckMenu::addWordToDictionary);
 
     // disabling this as if it calls the speller it's only changed in a local copy
     // see addWordToDictionary for how it should be done, except background checker
@@ -57,14 +44,11 @@ SpellCheckMenu::SpellCheckMenu(const Sonnet::Speller &speller, SpellCheck *spell
     setVisible(false);
 }
 
-SpellCheckMenu::~SpellCheckMenu()
-{
+SpellCheckMenu::~SpellCheckMenu() = default;
 
-}
-
-QPair<QString, QAction*> SpellCheckMenu::menuAction()
+QPair<QString, QAction *> SpellCheckMenu::menuAction()
 {
-    return QPair<QString, QAction*>("spelling_suggestions", m_suggestionsMenuAction);
+    return QPair<QString, QAction *>("spelling_suggestions", m_suggestionsMenuAction);
 }
 
 void SpellCheckMenu::createSuggestionsMenu()
@@ -80,7 +64,9 @@ void SpellCheckMenu::createSuggestionsMenu()
         for (int i = 0; i < m_suggestions.count(); ++i) {
             const QString &suggestion = m_suggestions.at(i);
             QAction *action = new QAction(suggestion, m_suggestionsMenu);
-            connect(action, &QAction::triggered, [this, suggestion] { replaceWord(suggestion); });
+            connect(action, &QAction::triggered, [this, suggestion] {
+                replaceWord(suggestion);
+            });
             m_suggestionsMenu->addAction(action);
         }
     }
@@ -94,7 +80,7 @@ void SpellCheckMenu::ignoreWord()
     // see comment in ctor why this will never work
     m_speller.addToSession(m_currentMisspelled);
 
-    emit clearHighlightingForWord(m_currentMisspelledPosition);
+    Q_EMIT clearHighlightingForWord(m_currentMisspelledPosition);
 
     m_currentMisspelled.clear();
     m_currentMisspelledPosition = -1;
@@ -111,10 +97,10 @@ void SpellCheckMenu::addWordToDictionary()
     m_currentMisspelledPosition = -1;
 }
 
-void SpellCheckMenu::setMisspelled(const QString &word, int position,int length)
+void SpellCheckMenu::setMisspelled(const QString &word, int position, int length)
 {
     m_currentMisspelled = word;
-    m_lengthMisspelled=length;
+    m_lengthMisspelled = length;
     m_currentMisspelledPosition = position;
 }
 
@@ -147,7 +133,7 @@ void SpellCheckMenu::replaceWord(const QString &suggestion)
     if (suggestion.isEmpty() || m_currentMisspelledPosition < 0)
         return;
 
-    m_spellCheck->replaceWordBySuggestion(suggestion, m_currentMisspelledPosition,m_lengthMisspelled);
+    m_spellCheck->replaceWordBySuggestion(suggestion, m_currentMisspelledPosition, m_lengthMisspelled);
 
     m_currentMisspelled.clear();
     m_currentMisspelledPosition = -1;
