@@ -1,40 +1,26 @@
 /* This file is part of the KDE project
- * Copyright (C) 2011 Smit Patel <smitpatel24@gmail.com>
+ * SPDX-FileCopyrightText: 2011 Smit Patel <smitpatel24@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "BibliographyPreview.h"
 
 #include "KoBibliographyInfo.h"
-#include "KoZoomHandler.h"
 #include "KoTextDocumentLayout.h"
+#include "KoZoomHandler.h"
 #include "TextTool.h"
 
 #include <KoInlineTextObjectManager.h>
 #include <KoParagraphStyle.h>
 #include <KoShapePaintingContext.h>
 
-
-BibliographyPreview::BibliographyPreview(QWidget *parent) :
-    QFrame(parent),
-    m_textShape(0),
-    m_pm(0),
-    m_styleManager(0),
-    m_previewPixSize(QSize(0,0))
+BibliographyPreview::BibliographyPreview(QWidget *parent)
+    : QFrame(parent)
+    , m_textShape(nullptr)
+    , m_pm(nullptr)
+    , m_styleManager(nullptr)
+    , m_previewPixSize(QSize(0, 0))
 {
 }
 
@@ -44,7 +30,7 @@ BibliographyPreview::~BibliographyPreview()
 
     if (m_pm) {
         delete m_pm;
-        m_pm = 0;
+        m_pm = nullptr;
     }
 }
 
@@ -62,7 +48,7 @@ void BibliographyPreview::paintEvent(QPaintEvent *event)
     p->translate(5.5, 1.5);
     p->setRenderHint(QPainter::Antialiasing);
     QRect rectang = rect();
-    rectang.adjust(-4,-4,-4,-4);
+    rectang.adjust(-4, -4, -4, -4);
 
     if (m_pm) {
         p->drawPixmap(rectang, *m_pm, m_pm->rect());
@@ -82,8 +68,8 @@ void BibliographyPreview::updatePreview(KoBibliographyInfo *newbibInfo)
     KoTextDocument(bibDocument).setStyleManager(m_styleManager);
     KoBibliographyInfo *info = newbibInfo->clone();
 
-    bibFormat.setProperty(KoParagraphStyle::BibliographyData, QVariant::fromValue<KoBibliographyInfo*>(info) );
-    bibFormat.setProperty(KoParagraphStyle::GeneratedDocument, QVariant::fromValue<QTextDocument*>(bibDocument) );
+    bibFormat.setProperty(KoParagraphStyle::BibliographyData, QVariant::fromValue<KoBibliographyInfo *>(info));
+    bibFormat.setProperty(KoParagraphStyle::GeneratedDocument, QVariant::fromValue<QTextDocument *>(bibDocument));
 
     deleteTextShape();
 
@@ -102,23 +88,23 @@ void BibliographyPreview::updatePreview(KoBibliographyInfo *newbibInfo)
     textCharFormat.setProperty(QTextCharFormat::ForegroundBrush, QBrush(Qt::black));
     cursor.setCharFormat(textCharFormat);
 
-    cursor.movePosition(QTextCursor::End,QTextCursor::MoveAnchor);
+    cursor.movePosition(QTextCursor::End, QTextCursor::MoveAnchor);
 
     QTextBlockFormat titleBlockFormat;
-    cursor.insertBlock(titleBlockFormat,textCharFormat);
+    cursor.insertBlock(titleBlockFormat, textCharFormat);
     cursor.insertText(info->m_indexTitleTemplate.text);
 
     textCharFormat.setFontPointSize(12);
     textCharFormat.setFontWeight(QFont::Normal);
     QTextBlockFormat blockFormat;
-    cursor.insertBlock(blockFormat,textCharFormat);
-    cursor.insertBlock(blockFormat,textCharFormat);
+    cursor.insertBlock(blockFormat, textCharFormat);
+    cursor.insertBlock(blockFormat, textCharFormat);
     cursor.insertText("CIT01: Title, Author, Organisation, URL");
 
     KoTextDocument(m_textShape->textShapeData()->document()).setStyleManager(m_styleManager);
 
-    KoTextDocumentLayout *lay = dynamic_cast<KoTextDocumentLayout*>(m_textShape->textShapeData()->document()->documentLayout());
-    connect(lay, SIGNAL(finishedLayout()), this, SLOT(finishedPreviewLayout()));
+    KoTextDocumentLayout *lay = dynamic_cast<KoTextDocumentLayout *>(m_textShape->textShapeData()->document()->documentLayout());
+    connect(lay, &KoTextDocumentLayout::finishedLayout, this, &BibliographyPreview::finishedPreviewLayout);
     if (lay) {
         lay->layout();
     }
@@ -128,7 +114,7 @@ void BibliographyPreview::finishedPreviewLayout()
 {
     if (m_pm) {
         delete m_pm;
-        m_pm = 0;
+        m_pm = nullptr;
     }
 
     if (m_previewPixSize.isEmpty()) {
@@ -147,10 +133,10 @@ void BibliographyPreview::finishedPreviewLayout()
         } else {
             m_textShape->setSize(m_previewPixSize);
         }
-        KoShapePaintingContext paintContext; //FIXME
+        KoShapePaintingContext paintContext; // FIXME
         m_textShape->paintComponent(p, m_zoomHandler, paintContext);
     }
-    emit pixmapGenerated();
+    Q_EMIT pixmapGenerated();
     update();
 }
 
@@ -168,7 +154,7 @@ void BibliographyPreview::deleteTextShape()
             lay->setBlockLayout(true);
         }
         delete m_textShape;
-        m_textShape = 0;
+        m_textShape = nullptr;
     }
 }
 
