@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C)  2015 Camilla Boemann <cbo@boemann.dk>
+   SPDX-FileCopyrightText: 2015 Camilla Boemann <cbo@boemann.dk>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "ListLevelWidget.h"
@@ -23,10 +10,10 @@
 
 #include <KoListLevelProperties.h>
 
-#include <QPainter>
 #include <QDebug>
-#include <QPaintEvent>
 #include <QGridLayout>
+#include <QPaintEvent>
+#include <QPainter>
 
 static void drawMeasureArrow(QPainter &painter, int x, int y, bool pointRight)
 {
@@ -38,7 +25,7 @@ static void drawMeasureArrow(QPainter &painter, int x, int y, bool pointRight)
         --x; // makes arrow more pointy
         painter.drawLine(x, y, x - d, y + d);
         painter.drawLine(x, y, x - d, y - d);
-    }  else {
+    } else {
         ++x; // makes arrow more pointy
         painter.drawLine(x, y, x + d, y + d);
         painter.drawLine(x, y, x + d, y - d);
@@ -48,7 +35,9 @@ static void drawMeasureArrow(QPainter &painter, int x, int y, bool pointRight)
 class LabelDrawingWidget : public QWidget
 {
 public:
-    LabelDrawingWidget() : QWidget(), m_align(2)
+    LabelDrawingWidget()
+        : QWidget()
+        , m_align(2)
     {
     }
 
@@ -68,7 +57,7 @@ protected:
         pen.setWidthF(2.0);
         painter.setPen(pen);
 
-        int x = width() / 2 + 30 * (m_align -1);
+        int x = width() / 2 + 30 * (m_align - 1);
 
         // the |< arrow
         drawMeasureArrow(painter, x, 5, false);
@@ -79,7 +68,7 @@ protected:
     int m_align;
 };
 
-ListLevelWidget::ListLevelWidget(QWidget* parent)
+ListLevelWidget::ListLevelWidget(QWidget *parent)
     : QWidget(parent)
 {
     widget.setupUi(this);
@@ -87,16 +76,17 @@ ListLevelWidget::ListLevelWidget(QWidget* parent)
     widget.format->addItems(KoOdfNumberDefinition::userFormatDescriptions());
 
     QGridLayout *bulletLayout = new QGridLayout();
-    m_charSelect = new KCharSelect(0, 0, KCharSelect::FontCombo | KCharSelect::BlockCombos | KCharSelect::CharacterTable | KCharSelect::DetailBrowser);
-    bulletLayout->addWidget(m_charSelect, 0,0);
+    m_charSelect =
+        new KCharSelect(nullptr, nullptr, KCharSelect::FontCombo | KCharSelect::BlockCombos | KCharSelect::CharacterTable | KCharSelect::DetailBrowser);
+    bulletLayout->addWidget(m_charSelect, 0, 0);
     widget.bulletTab->setLayout(bulletLayout);
 
     widget.geometryGrid->addWidget(m_label = new LabelDrawingWidget, 4, 0);
 
-    connect(widget.format, SIGNAL(currentIndexChanged(int)), this, SLOT(numberFormatChanged(int)));
-    connect(widget.addTabStop, SIGNAL(toggled(bool)), widget.relativeTabStop, SLOT(setEnabled(bool)));
-    connect(widget.labelFollowedBy, SIGNAL(currentIndexChanged(int)), this, SLOT(labelFollowedByChanged(int)));
-    connect(widget.alignment, SIGNAL(currentIndexChanged(int)), this, SLOT(alignmentChanged(int)));
+    connect(widget.format, &QComboBox::currentIndexChanged, this, &ListLevelWidget::numberFormatChanged);
+    connect(widget.addTabStop, &QAbstractButton::toggled, widget.relativeTabStop, &QWidget::setEnabled);
+    connect(widget.labelFollowedBy, &QComboBox::currentIndexChanged, this, &ListLevelWidget::labelFollowedByChanged);
+    connect(widget.alignment, &QComboBox::currentIndexChanged, this, &ListLevelWidget::alignmentChanged);
 }
 
 void ListLevelWidget::paintEvent(QPaintEvent *ev)
@@ -151,8 +141,7 @@ void ListLevelWidget::alignmentChanged(int a)
 
 void ListLevelWidget::numberFormatChanged(int index)
 {
-    widget.synchro->setEnabled(index == KoOdfNumberDefinition::AlphabeticLowerCase 
-                            || index ==KoOdfNumberDefinition::AlphabeticUpperCase);
+    widget.synchro->setEnabled(index == KoOdfNumberDefinition::AlphabeticLowerCase || index == KoOdfNumberDefinition::AlphabeticUpperCase);
 }
 
 void ListLevelWidget::setDisplay(const KoListLevelProperties &props)
@@ -179,7 +168,7 @@ void ListLevelWidget::setDisplay(const KoListLevelProperties &props)
     widget.suffix->setText(props.listItemSuffix());
     widget.displayLevels->setValue(props.displayLevel());
 
-    switch(props.labelType()) {
+    switch (props.labelType()) {
     case KoListStyle::BulletCharLabelType:
         widget.tabWidget->setCurrentIndex(1);
         break;
@@ -203,7 +192,7 @@ void ListLevelWidget::save(KoListLevelProperties &props) const
         props.clearTabStopPosition();
     }
 
-    switch(widget.tabWidget->currentIndex()) {
+    switch (widget.tabWidget->currentIndex()) {
     case 0:
         props.setLabelType(KoListStyle::NumberLabelType);
         props.setNumberFormat(KoOdfNumberDefinition::FormatSpecification(widget.format->currentIndex()));
