@@ -1,37 +1,24 @@
 /* This file is part of the KDE project
- * Copyright (C) 2001 David Faure <faure@kde.org>
- * Copyright (C) 2005-2007, 2009, 2010 Thomas Zander <zander@kde.org>
- * Copyright (C) 2010-2011 Boudewijn Rempt <boud@kogmbh.com>
- * Copyright (C) 2013 Aman Madaan <madaan.amanmadaan@gmail.com>
+ * SPDX-FileCopyrightText: 2001 David Faure <faure@kde.org>
+ * SPDX-FileCopyrightText: 2005-2007, 2009, 2010 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2010-2011 Boudewijn Rempt <boud@kogmbh.com>
+ * SPDX-FileCopyrightText: 2013 Aman Madaan <madaan.amanmadaan@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "SimpleLinksWidget.h"
 
-#include "ReferencesTool.h"
-#include <QAction>
-#include <KoBookmarkManager.h>
 #include "ManageBookmarkDialog.h"
-#include <KoTextDocument.h>
+#include "ReferencesTool.h"
 #include <KoBookmark.h>
-#include <KoTextRangeManager.h>
-#include <KoTextRange.h>
-#include <KoCanvasResourceManager.h>
+#include <KoBookmarkManager.h>
 #include <KoCanvasBase.h>
+#include <KoCanvasResourceManager.h>
+#include <KoTextDocument.h>
+#include <KoTextRange.h>
+#include <KoTextRangeManager.h>
+#include <QAction>
 
 SimpleLinksWidget::SimpleLinksWidget(ReferencesTool *tool, QWidget *parent)
     : QWidget(parent)
@@ -41,9 +28,9 @@ SimpleLinksWidget::SimpleLinksWidget(ReferencesTool *tool, QWidget *parent)
     Q_ASSERT(tool);
     widget.insertLink->setDefaultAction(tool->action("insert_link"));
     widget.invokeBookmarkHandler->setDefaultAction(tool->action("invoke_bookmark_handler"));
-    connect(widget.insertLink, SIGNAL(clicked(bool)), this, SIGNAL(doneWithFocus()));
-    connect(widget.invokeBookmarkHandler, SIGNAL(clicked(bool)), this, SIGNAL(doneWithFocus()));
-    connect(widget.invokeBookmarkHandler, SIGNAL(aboutToShowMenu()), this, SLOT(preparePopUpMenu()));
+    connect(widget.insertLink, &QAbstractButton::clicked, this, &SimpleLinksWidget::doneWithFocus);
+    connect(widget.invokeBookmarkHandler, &QAbstractButton::clicked, this, &SimpleLinksWidget::doneWithFocus);
+    connect(widget.invokeBookmarkHandler, &FormattingButton::aboutToShowMenu, this, &SimpleLinksWidget::preparePopUpMenu);
 }
 
 void SimpleLinksWidget::preparePopUpMenu()
@@ -52,18 +39,18 @@ void SimpleLinksWidget::preparePopUpMenu()
         widget.invokeBookmarkHandler->addAction(m_referenceTool->action("insert_bookmark"));
         widget.invokeBookmarkHandler->addSeparator();
         widget.invokeBookmarkHandler->addAction(m_referenceTool->action("manage_bookmarks"));
-        connect(m_referenceTool->action("manage_bookmarks"),
-                SIGNAL(triggered()), this, SLOT(manageBookmarks()), Qt::UniqueConnection);
+        connect(m_referenceTool->action("manage_bookmarks"), &QAction::triggered, this, &SimpleLinksWidget::manageBookmarks, Qt::UniqueConnection);
     }
 }
 
 void SimpleLinksWidget::manageBookmarks()
 {
     QString name;
-    const KoBookmarkManager *manager =  KoTextDocument(m_referenceTool->editor()->document()).textRangeManager()->bookmarkManager();
-    QPointer<ManageBookmarkDialog> dia = new ManageBookmarkDialog(manager->bookmarkNameList(), m_referenceTool->editor(), m_referenceTool->canvas()->canvasWidget());
-    connect(dia, SIGNAL(nameChanged(QString,QString)), manager, SLOT(rename(QString,QString)));
-    connect(dia, SIGNAL(bookmarkDeleted(QString)), manager, SLOT(remove(QString)));
+    const KoBookmarkManager *manager = KoTextDocument(m_referenceTool->editor()->document()).textRangeManager()->bookmarkManager();
+    QPointer<ManageBookmarkDialog> dia =
+        new ManageBookmarkDialog(manager->bookmarkNameList(), m_referenceTool->editor(), m_referenceTool->canvas()->canvasWidget());
+    connect(dia.data(), &ManageBookmarkDialog::nameChanged, manager, &KoBookmarkManager::rename);
+    connect(dia.data(), &ManageBookmarkDialog::bookmarkDeleted, manager, &KoBookmarkManager::remove);
     if (dia->exec() == QDialog::Accepted) {
         name = dia->selectedBookmarkName();
     } else {
@@ -87,7 +74,4 @@ void SimpleLinksWidget::manageBookmarks()
     }
 }
 
-SimpleLinksWidget::~SimpleLinksWidget()
-{
-
-}
+SimpleLinksWidget::~SimpleLinksWidget() = default;
