@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
- * Copyright (C) 2007 Thomas Zander <zander@kde.org>
- * Copyright (C) 2013 Thorsten Zachmann <zachmann@kde.org>
+ * SPDX-FileCopyrightText: 2007 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2013 Thorsten Zachmann <zachmann@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "StyleManager.h"
@@ -23,33 +10,35 @@
 #include "StylesManagerModel.h"
 #include "StylesSortFilterProxyModel.h"
 
+#include <KoCharacterStyle.h>
+#include <KoParagraphStyle.h>
 #include <KoStyleManager.h>
 #include <KoStyleThumbnailer.h>
-#include <KoParagraphStyle.h>
-#include <KoCharacterStyle.h>
 
+#include <QInputDialog>
 #include <QListView>
+#include <QMessageBox>
 #include <QModelIndex>
 #include <QTabWidget>
-#include <QInputDialog>
-#include <QMessageBox>
 
 #include <QDebug>
 
 StyleManager::StyleManager(QWidget *parent)
-        : QWidget(parent)
-        , m_styleManager(0)
-        , m_paragraphStylesModel(new StylesManagerModel(this))
-        , m_characterStylesModel(new StylesManagerModel(this))
-        , m_paragraphProxyModel(new StylesSortFilterProxyModel(this))
-        , m_characterProxyModel(new StylesSortFilterProxyModel(this))
-        , m_thumbnailer(new KoStyleThumbnailer())
-        , m_unappliedStyleChanges(false)
+    : QSplitter(parent)
+    , m_styleManager(nullptr)
+    , m_paragraphStylesModel(new StylesManagerModel(this))
+    , m_characterStylesModel(new StylesManagerModel(this))
+    , m_paragraphProxyModel(new StylesSortFilterProxyModel(this))
+    , m_characterProxyModel(new StylesSortFilterProxyModel(this))
+    , m_thumbnailer(new KoStyleThumbnailer())
+    , m_unappliedStyleChanges(false)
 {
     widget.setupUi(this);
-    layout()->setMargin(0);
+    widget.tabs->tabBar()->setExpanding(true);
     widget.bNew->setToolTip(i18n("Create a new style inheriting the current style"));
 
+    widget.buttonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Apply);
+
     // Force "Base" background of the style listviews to white, so the background
     // is consistent with the one of the preview area. Also the usual document text colors
     // are dark, because made for a white paper background, so with a dark UI
@@ -70,24 +59,24 @@ StyleManager::StyleManager(QWidget *parent)
     m_characterProxyModel->setSourceModel(m_characterStylesModel);
     m_paragraphProxyModel->sort(0);
     m_characterProxyModel->sort(0);
-    //m_paragraphProxyModel->setSortRole(Qt::DisplayRole);
-    //m_characterProxyModel->setSortRole(Qt::DisplayRole);
+    // m_paragraphProxyModel->setSortRole(Qt::DisplayRole);
+    // m_characterProxyModel->setSortRole(Qt::DisplayRole);
     widget.paragraphStylesListView->setModel(m_paragraphProxyModel);
     widget.characterStylesListView->setModel(m_characterProxyModel);
 
-    connect(widget.paragraphStylesListView, SIGNAL(clicked(QModelIndex)), this, SLOT(slotParagraphStyleSelected(QModelIndex)));
-    connect(widget.characterStylesListView, SIGNAL(clicked(QModelIndex)), this, SLOT(slotCharacterStyleSelected(QModelIndex)));
+    connect(widget.paragraphStylesListView, &QAbstractItemView::clicked, this, &StyleManager::slotParagraphStyleSelected);
+    connect(widget.characterStylesListView, &QAbstractItemView::clicked, this, &StyleManager::slotCharacterStyleSelected);
 
-    connect(widget.bNew, SIGNAL(pressed()), this, SLOT(buttonNewPressed()));
-    //connect(widget.bDelete, SIGNAL(pressed()), this, SLOT(buttonDeletePressed()));
+    connect(widget.bNew, &QAbstractButton::pressed, this, &StyleManager::buttonNewPressed);
+    // connect(widget.bDelete, SIGNAL(pressed()), this, SLOT(buttonDeletePressed()));
     widget.bDelete->setVisible(false); // TODO make it visible when we can safely delete styles
 
-    connect(widget.tabs, SIGNAL(currentChanged(int)), this, SLOT(tabChanged(int)));
+    connect(widget.tabs, &QTabWidget::currentChanged, this, &StyleManager::tabChanged);
 
-    connect(widget.paragraphStylePage, SIGNAL(styleChanged()), this, SLOT(currentParagraphStyleChanged()));
-    connect(widget.characterStylePage, SIGNAL(styleChanged()), this, SLOT(currentCharacterStyleChanged()));
-    connect(widget.paragraphStylePage, SIGNAL(nameChanged(QString)), this, SLOT(currentParagraphNameChanged(QString)));
-    connect(widget.characterStylePage, SIGNAL(nameChanged(QString)), this, SLOT(currentCharacterNameChanged(QString)));
+    connect(widget.paragraphStylePage, &ParagraphGeneral::styleChanged, this, &StyleManager::currentParagraphStyleChanged);
+    connect(widget.characterStylePage, &CharacterGeneral::styleChanged, this, &StyleManager::currentCharacterStyleChanged);
+    connect(widget.paragraphStylePage, &ParagraphGeneral::nameChanged, this, &StyleManager::currentParagraphNameChanged);
+    connect(widget.characterStylePage, &CharacterGeneral::nameChanged, this, &StyleManager::currentCharacterNameChanged);
 }
 
 StyleManager::~StyleManager()
@@ -101,15 +90,15 @@ void StyleManager::setStyleManager(KoStyleManager *sm)
     Q_ASSERT(sm);
     m_styleManager = sm;
 
-    widget.paragraphStylePage->setStyleManager(m_styleManager); //also updates style combos
-    widget.characterStylePage->setStyleManager(m_styleManager); //also updates style combos
+    widget.paragraphStylePage->setStyleManager(m_styleManager); // also updates style combos
+    widget.characterStylePage->setStyleManager(m_styleManager); // also updates style combos
     widget.tabs->setCurrentIndex(widget.tabs->indexOf(widget.paragraphStylesListView));
-    connect(sm, SIGNAL(styleAdded(KoParagraphStyle*)), this, SLOT(addParagraphStyle(KoParagraphStyle*)));
-    connect(sm, SIGNAL(styleAdded(KoCharacterStyle*)), this, SLOT(addCharacterStyle(KoCharacterStyle*)));
-    connect(sm, SIGNAL(styleRemoved(KoParagraphStyle*)), this, SLOT(removeParagraphStyle(KoParagraphStyle*)));
-    connect(sm, SIGNAL(styleRemoved(KoCharacterStyle*)), this, SLOT(removeCharacterStyle(KoCharacterStyle*)));
+    connect(sm, &KoStyleManager::paragraphStyleAdded, this, &StyleManager::addParagraphStyle);
+    connect(sm, &KoStyleManager::characterStyleAdded, this, &StyleManager::addCharacterStyle);
+    connect(sm, &KoStyleManager::paragraphStyleRemoved, this, &StyleManager::removeParagraphStyle);
+    connect(sm, &KoStyleManager::characterStyleRemoved, this, &StyleManager::removeCharacterStyle);
 
-    QList<KoCharacterStyle*> styles;
+    QList<KoCharacterStyle *> styles;
     QList<KoParagraphStyle *> paragraphStyles = m_styleManager->paragraphStyles();
     KoParagraphStyle *defaultParagraphStyle = m_styleManager->defaultParagraphStyle();
     foreach (KoParagraphStyle *style, paragraphStyles) {
@@ -135,16 +124,15 @@ void StyleManager::setParagraphStyle(KoParagraphStyle *style)
 {
     widget.characterStylePage->save();
     widget.paragraphStylePage->save();
-    KoParagraphStyle *localStyle = 0;
+    KoParagraphStyle *localStyle = nullptr;
 
     if (style) {
-        QMap<KoParagraphStyle*, KoParagraphStyle*>::ConstIterator it = m_modifiedParagraphStyles.constFind(style);
+        QMap<KoParagraphStyle *, KoParagraphStyle *>::ConstIterator it = m_modifiedParagraphStyles.constFind(style);
         if (it == m_modifiedParagraphStyles.constEnd()) {
             localStyle = style->clone();
             m_modifiedParagraphStyles.insert(localStyle, style);
             m_paragraphStylesModel->replaceStyle(style, localStyle);
-        }
-        else {
+        } else {
             localStyle = dynamic_cast<KoParagraphStyle *>(it.key());
         }
 
@@ -153,7 +141,7 @@ void StyleManager::setParagraphStyle(KoParagraphStyle *style)
     widget.paragraphStylePage->setStyle(localStyle, 0, false);
     widget.stackedWidget->setCurrentWidget(widget.paragraphStylePage);
     widget.tabs->setCurrentIndex(widget.tabs->indexOf(widget.paragraphStylesListView));
-    widget.paragraphStylesListView->setEnabled(style != 0);
+    widget.paragraphStylesListView->setEnabled(style != nullptr);
 }
 
 void StyleManager::setCharacterStyle(KoCharacterStyle *style, bool canDelete)
@@ -161,17 +149,15 @@ void StyleManager::setCharacterStyle(KoCharacterStyle *style, bool canDelete)
     Q_UNUSED(canDelete);
     widget.paragraphStylePage->save();
     widget.characterStylePage->save();
-    KoCharacterStyle *localStyle = 0;
+    KoCharacterStyle *localStyle = nullptr;
 
     if (style) {
-        QMap<KoCharacterStyle*, KoCharacterStyle*>::ConstIterator it =
-        m_modifiedCharacterStyles.constFind(style);
+        QMap<KoCharacterStyle *, KoCharacterStyle *>::ConstIterator it = m_modifiedCharacterStyles.constFind(style);
         if (it == m_modifiedCharacterStyles.constEnd()) {
             localStyle = style->clone();
             m_modifiedCharacterStyles.insert(localStyle, style);
             m_characterStylesModel->replaceStyle(style, localStyle);
-        }
-        else {
+        } else {
             localStyle = it.key();
         }
         widget.characterStylesListView->setCurrentIndex(m_characterProxyModel->mapFromSource(m_characterStylesModel->styleIndex(localStyle)));
@@ -179,8 +165,8 @@ void StyleManager::setCharacterStyle(KoCharacterStyle *style, bool canDelete)
     widget.characterStylePage->setStyle(localStyle, false);
     widget.stackedWidget->setCurrentWidget(widget.characterStylePage);
     widget.tabs->setCurrentIndex(widget.tabs->indexOf(widget.characterStylesListView));
-    widget.characterStylePage->setEnabled(style != 0);
- //   widget.bDelete->setEnabled(canDelete);
+    widget.characterStylePage->setEnabled(style != nullptr);
+    //   widget.bDelete->setEnabled(canDelete);
 }
 
 void StyleManager::setUnit(const KoUnit &unit)
@@ -195,16 +181,16 @@ void StyleManager::save()
     }
     widget.paragraphStylePage->save();
     widget.characterStylePage->save();
-    widget.paragraphStylePage->setStyle(0, 0, false);
-    widget.characterStylePage->setStyle(0, false);
+    widget.paragraphStylePage->setStyle(nullptr, 0, false);
+    widget.characterStylePage->setStyle(nullptr, false);
 
     m_styleManager->beginEdit();
 
-    for (QMap<KoParagraphStyle*, KoParagraphStyle*>::ConstIterator it(m_modifiedParagraphStyles.constBegin()); it != m_modifiedParagraphStyles.constEnd(); ++it) {
+    for (QMap<KoParagraphStyle *, KoParagraphStyle *>::ConstIterator it(m_modifiedParagraphStyles.constBegin()); it != m_modifiedParagraphStyles.constEnd();
+         ++it) {
         if (it.value() == 0) {
             m_styleManager->add(it.key());
-        }
-        else {
+        } else {
             KoParagraphStyle *altered = it.key();
             m_styleManager->alteredStyle(altered);
             m_paragraphStylesModel->replaceStyle(altered, it.value());
@@ -213,11 +199,11 @@ void StyleManager::save()
     }
     m_modifiedParagraphStyles.clear();
 
-    for (QMap<KoCharacterStyle*, KoCharacterStyle*>::ConstIterator it(m_modifiedCharacterStyles.constBegin()); it != m_modifiedCharacterStyles.constEnd(); ++it) {
+    for (QMap<KoCharacterStyle *, KoCharacterStyle *>::ConstIterator it(m_modifiedCharacterStyles.constBegin()); it != m_modifiedCharacterStyles.constEnd();
+         ++it) {
         if (it.value() == 0) {
             m_styleManager->add(it.key());
-        }
-        else {
+        } else {
             KoCharacterStyle *altered = it.key();
             m_styleManager->alteredStyle(altered);
             m_characterStylesModel->replaceStyle(altered, it.value());
@@ -229,34 +215,36 @@ void StyleManager::save()
     m_styleManager->endEdit();
 
     // set the paragraph and character style new so it has a cloned style to work on and we don't change the actual style.
-    KoParagraphStyle *paragraphStyle = dynamic_cast<KoParagraphStyle*>(m_paragraphProxyModel->data(widget.paragraphStylesListView->currentIndex(),
-                                                                       StylesManagerModel::StylePointer).value<KoCharacterStyle*>());
+    KoParagraphStyle *paragraphStyle = dynamic_cast<KoParagraphStyle *>(
+        m_paragraphProxyModel->data(widget.paragraphStylesListView->currentIndex(), StylesManagerModel::StylePointer).value<KoCharacterStyle *>());
     if (paragraphStyle) {
         setParagraphStyle(paragraphStyle);
     }
 
-    KoCharacterStyle *characterStyle = m_characterProxyModel->data(widget.characterStylesListView->currentIndex(),
-                                                                   StylesManagerModel::StylePointer).value<KoCharacterStyle*>();
+    KoCharacterStyle *characterStyle =
+        m_characterProxyModel->data(widget.characterStylesListView->currentIndex(), StylesManagerModel::StylePointer).value<KoCharacterStyle *>();
     if (characterStyle) {
         setCharacterStyle(characterStyle);
     }
 
-    m_unappliedStyleChanges = false;
+    setUnappliedStyleChanges(false);
 }
 
 void StyleManager::currentParagraphStyleChanged()
 {
-    KoParagraphStyle *style = dynamic_cast<KoParagraphStyle*>(m_paragraphProxyModel->data(widget.paragraphStylesListView->currentIndex(), StylesManagerModel::StylePointer).value<KoCharacterStyle*>());
+    KoParagraphStyle *style = dynamic_cast<KoParagraphStyle *>(
+        m_paragraphProxyModel->data(widget.paragraphStylesListView->currentIndex(), StylesManagerModel::StylePointer).value<KoCharacterStyle *>());
     if (style) {
         widget.paragraphStylePage->save();
         m_paragraphStylesModel->updateStyle(style);
-        m_unappliedStyleChanges = true;
+        setUnappliedStyleChanges(true);
     }
 }
 
 void StyleManager::currentParagraphNameChanged(const QString &name)
 {
-    KoCharacterStyle *style = m_paragraphProxyModel->data(widget.paragraphStylesListView->currentIndex(), StylesManagerModel::StylePointer).value<KoCharacterStyle*>();
+    KoCharacterStyle *style =
+        m_paragraphProxyModel->data(widget.paragraphStylesListView->currentIndex(), StylesManagerModel::StylePointer).value<KoCharacterStyle *>();
     if (style) {
         style->setName(name);
         currentParagraphStyleChanged();
@@ -265,62 +253,64 @@ void StyleManager::currentParagraphNameChanged(const QString &name)
 
 void StyleManager::currentCharacterStyleChanged()
 {
-    KoCharacterStyle *style = m_characterProxyModel->data(widget.characterStylesListView->currentIndex(), StylesManagerModel::StylePointer).value<KoCharacterStyle*>();
+    KoCharacterStyle *style =
+        m_characterProxyModel->data(widget.characterStylesListView->currentIndex(), StylesManagerModel::StylePointer).value<KoCharacterStyle *>();
     if (style) {
         widget.characterStylePage->save();
         m_characterStylesModel->updateStyle(style);
-        m_unappliedStyleChanges = true;
+        setUnappliedStyleChanges(true);
     }
 }
 
 void StyleManager::currentCharacterNameChanged(const QString &name)
 {
-    KoCharacterStyle *style = m_characterProxyModel->data(widget.characterStylesListView->currentIndex(), StylesManagerModel::StylePointer).value<KoCharacterStyle*>();
+    KoCharacterStyle *style =
+        m_characterProxyModel->data(widget.characterStylesListView->currentIndex(), StylesManagerModel::StylePointer).value<KoCharacterStyle *>();
     if (style) {
         style->setName(name);
         currentCharacterStyleChanged();
     }
 }
 
-
 void StyleManager::addParagraphStyle(KoParagraphStyle *style)
 {
-    widget.paragraphStylePage->setStyleManager(m_styleManager); //updates style combos
+    widget.paragraphStylePage->setStyleManager(m_styleManager); // updates style combos
     m_paragraphStylesModel->addStyle(style);
     setParagraphStyle(style);
-    m_unappliedStyleChanges = true;
+    setUnappliedStyleChanges(true);
 }
 
 void StyleManager::addCharacterStyle(KoCharacterStyle *style)
 {
-    widget.characterStylePage->setStyleManager(m_styleManager); //updates style combos
+    widget.characterStylePage->setStyleManager(m_styleManager); // updates style combos
     m_characterStylesModel->addStyle(style);
     setCharacterStyle(style);
-    m_unappliedStyleChanges = true;
+    setUnappliedStyleChanges(true);
 }
 
-void StyleManager::removeParagraphStyle(KoParagraphStyle* style)
+void StyleManager::removeParagraphStyle(KoParagraphStyle *style)
 {
     if (m_modifiedParagraphStyles.contains(style)) {
         m_modifiedParagraphStyles.remove(style);
         m_paragraphStylesModel->removeStyle(style);
     }
-    widget.paragraphStylePage->setStyleManager(m_styleManager); //updates style combos
+    widget.paragraphStylePage->setStyleManager(m_styleManager); // updates style combos
 }
 
-void StyleManager::removeCharacterStyle(KoCharacterStyle* style)
+void StyleManager::removeCharacterStyle(KoCharacterStyle *style)
 {
     if (m_modifiedCharacterStyles.contains(style)) {
         m_modifiedCharacterStyles.remove(style);
         m_characterStylesModel->removeStyle(style);
     }
-    widget.characterStylePage->setStyleManager(m_styleManager); //updates style combos
+    widget.characterStylePage->setStyleManager(m_styleManager); // updates style combos
 }
 
 void StyleManager::slotParagraphStyleSelected(const QModelIndex &index)
 {
     if (checkUniqueStyleName()) {
-        KoParagraphStyle *paragraphStyle = dynamic_cast<KoParagraphStyle*>(m_paragraphProxyModel->data(index, StylesManagerModel::StylePointer).value<KoCharacterStyle*>());
+        KoParagraphStyle *paragraphStyle =
+            dynamic_cast<KoParagraphStyle *>(m_paragraphProxyModel->data(index, StylesManagerModel::StylePointer).value<KoCharacterStyle *>());
         if (paragraphStyle) {
             setParagraphStyle(paragraphStyle);
             return;
@@ -331,7 +321,7 @@ void StyleManager::slotParagraphStyleSelected(const QModelIndex &index)
 void StyleManager::slotCharacterStyleSelected(const QModelIndex &index)
 {
     if (checkUniqueStyleName()) {
-        KoCharacterStyle *characterStyle = m_characterProxyModel->data(index, StylesManagerModel::StylePointer).value<KoCharacterStyle*>();
+        KoCharacterStyle *characterStyle = m_characterProxyModel->data(index, StylesManagerModel::StylePointer).value<KoCharacterStyle *>();
         if (characterStyle) {
             setCharacterStyle(characterStyle, false);
             return;
@@ -342,28 +332,26 @@ void StyleManager::slotCharacterStyleSelected(const QModelIndex &index)
 void StyleManager::buttonNewPressed()
 {
     if (checkUniqueStyleName()) {
-        if (widget.tabs->indexOf(widget.paragraphStylesListView) == widget.tabs->currentIndex()){
-            KoParagraphStyle *newStyle = 0;
-            KoParagraphStyle *style = dynamic_cast<KoParagraphStyle*>(m_paragraphProxyModel->data(widget.paragraphStylesListView->currentIndex(),
-                                                                      StylesManagerModel::StylePointer).value<KoCharacterStyle*>());
+        if (widget.tabs->indexOf(widget.paragraphStylesListView) == widget.tabs->currentIndex()) {
+            KoParagraphStyle *newStyle = nullptr;
+            KoParagraphStyle *style = dynamic_cast<KoParagraphStyle *>(
+                m_paragraphProxyModel->data(widget.paragraphStylesListView->currentIndex(), StylesManagerModel::StylePointer).value<KoCharacterStyle *>());
             if (style) {
                 newStyle = style->clone();
-            }
-            else {
+            } else {
                 newStyle = new KoParagraphStyle();
             }
             newStyle->setName(i18n("New Style"));
             m_modifiedParagraphStyles.insert(newStyle, 0);
             addParagraphStyle(newStyle);
             widget.paragraphStylePage->selectName();
-        }
-        else {
-            KoCharacterStyle *newStyle = 0;
-            KoCharacterStyle *style = m_characterProxyModel->data(widget.characterStylesListView->currentIndex(), StylesManagerModel::StylePointer).value<KoCharacterStyle*>();
+        } else {
+            KoCharacterStyle *newStyle = nullptr;
+            KoCharacterStyle *style =
+                m_characterProxyModel->data(widget.characterStylesListView->currentIndex(), StylesManagerModel::StylePointer).value<KoCharacterStyle *>();
             if (style) {
                 newStyle = style->clone();
-            }
-            else {
+            } else {
                 newStyle = new KoCharacterStyle();
             }
             newStyle->setName(i18n("New Style"));
@@ -379,34 +367,42 @@ void StyleManager::tabChanged(int index)
     int paragraphIndex = widget.tabs->indexOf(widget.paragraphStylesListView);
     if (!checkUniqueStyleName(paragraphIndex == index ? widget.tabs->indexOf(widget.characterStylesListView) : paragraphIndex)) {
         // this is needed to not call tab changed during the resetting of the tab as this leads to en endless recursion.
-        disconnect(widget.tabs, SIGNAL(currentChanged(int)), this, SLOT(tabChanged(int)));
-        if (widget.tabs->indexOf(widget.paragraphStylesListView) == widget.tabs->currentIndex()){
+        disconnect(widget.tabs, &QTabWidget::currentChanged, this, &StyleManager::tabChanged);
+        if (widget.tabs->indexOf(widget.paragraphStylesListView) == widget.tabs->currentIndex()) {
             widget.tabs->setCurrentIndex(widget.tabs->indexOf(widget.characterStylesListView));
         } else {
             widget.tabs->setCurrentIndex(widget.tabs->indexOf(widget.paragraphStylesListView));
         }
-        connect(widget.tabs, SIGNAL(currentChanged(int)), this, SLOT(tabChanged(int)));
-    }
-    else {
+        connect(widget.tabs, &QTabWidget::currentChanged, this, &StyleManager::tabChanged);
+    } else {
         if (paragraphIndex == index) {
-            KoParagraphStyle *style = dynamic_cast<KoParagraphStyle*>(m_paragraphProxyModel->data(widget.paragraphStylesListView->currentIndex(),
-                        StylesManagerModel::StylePointer).value<KoCharacterStyle*>());
+            KoParagraphStyle *style = dynamic_cast<KoParagraphStyle *>(
+                m_paragraphProxyModel->data(widget.paragraphStylesListView->currentIndex(), StylesManagerModel::StylePointer).value<KoCharacterStyle *>());
             setParagraphStyle(style);
             widget.stackedWidget->setCurrentWidget(widget.paragraphStylePage);
-        }
-        else {
-            KoCharacterStyle *style = m_characterProxyModel->data(widget.characterStylesListView->currentIndex(), StylesManagerModel::StylePointer).value<KoCharacterStyle*>();
+        } else {
+            KoCharacterStyle *style =
+                m_characterProxyModel->data(widget.characterStylesListView->currentIndex(), StylesManagerModel::StylePointer).value<KoCharacterStyle *>();
             setCharacterStyle(style);
             widget.stackedWidget->setCurrentWidget(widget.characterStylePage);
         }
     }
 }
 
-bool StyleManager::unappliedStyleChanges()
+bool StyleManager::unappliedStyleChanges() const
 {
     return m_unappliedStyleChanges;
 }
 
+void StyleManager::setUnappliedStyleChanges(bool unappliedStyleChanges)
+{
+    if (m_unappliedStyleChanges == unappliedStyleChanges) {
+        return;
+    }
+    m_unappliedStyleChanges = unappliedStyleChanges;
+    Q_EMIT unappliedStyleChangesChanged(m_unappliedStyleChanges);
+}
+
 bool StyleManager::checkUniqueStyleName()
 {
     return checkUniqueStyleName(widget.tabs->currentIndex());
@@ -421,8 +417,7 @@ bool StyleManager::checkUniqueStyleName(int widgetIndex)
         styleName = widget.paragraphStylePage->styleName();
         listView = widget.paragraphStylesListView;
         index = m_paragraphProxyModel->mapFromSource(m_paragraphStylesModel->styleIndex(widget.paragraphStylePage->style()));
-    }
-    else {
+    } else {
         styleName = widget.characterStylePage->styleName();
         index = m_characterProxyModel->mapFromSource(m_characterStylesModel->styleIndex(widget.characterStylePage->style()));
         listView = widget.characterStylesListView;
@@ -430,8 +425,16 @@ bool StyleManager::checkUniqueStyleName(int widgetIndex)
 
     QModelIndexList stylesByName;
     if (index.isValid()) {
-        stylesByName.append(m_paragraphProxyModel->match(m_paragraphProxyModel->index(0, 0), Qt::DisplayRole, QVariant(styleName), -1, Qt::MatchFlags(Qt::MatchExactly | Qt::MatchWrap)));
-        stylesByName.append(m_characterProxyModel->match(m_characterProxyModel->index(0, 0), Qt::DisplayRole, QVariant(styleName), -1, Qt::MatchFlags(Qt::MatchExactly | Qt::MatchWrap)));
+        stylesByName.append(m_paragraphProxyModel->match(m_paragraphProxyModel->index(0, 0),
+                                                         Qt::DisplayRole,
+                                                         QVariant(styleName),
+                                                         -1,
+                                                         Qt::MatchFlags(Qt::MatchExactly | Qt::MatchWrap)));
+        stylesByName.append(m_characterProxyModel->match(m_characterProxyModel->index(0, 0),
+                                                         Qt::DisplayRole,
+                                                         QVariant(styleName),
+                                                         -1,
+                                                         Qt::MatchFlags(Qt::MatchExactly | Qt::MatchWrap)));
     }
 
     bool unique = stylesByName.size() <= 1;
@@ -446,3 +449,8 @@ bool StyleManager::checkUniqueStyleName(int widgetIndex)
     }
     return unique;
 }
+
+QDialogButtonBox *StyleManager::buttonBox() const
+{
+    return widget.buttonBox;
+}
