@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
- * Copyright (C) 2011 Pierre Stirnweiss <pstirnweiss@googlemail.com>
+ * SPDX-FileCopyrightText: 2011 Pierre Stirnweiss <pstirnweiss@googlemail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
-*/
+ * SPDX-License-Identifier: LGPL-2.0-or-later
+ */
 
 /*
  * This class is heavily inspired by QLineEdit, so here goes credit because credit is due (from klineedit.h):
@@ -35,26 +22,26 @@
 
 #include <KoIcon.h>
 
+#include <QFocusEvent>
 #include <QImage>
+#include <QKeyEvent>
 #include <QLineEdit>
 #include <QModelIndex>
-#include <QPainter>
-#include <QPaintEvent>
-#include <QFocusEvent>
 #include <QMouseEvent>
-#include <QKeyEvent>
+#include <QPaintEvent>
+#include <QPainter>
 #include <QPushButton>
 #include <QString>
 
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 #include <QDebug>
 
-StylesComboPreview::StylesComboPreview(QWidget *parent) :
-    QLineEdit(parent),
-    m_renamingNewStyle(false),
-    m_shouldAddNewStyle(false),
-    m_addButton(0)
+StylesComboPreview::StylesComboPreview(QWidget *parent)
+    : QLineEdit(parent)
+    , m_renamingNewStyle(false)
+    , m_shouldAddNewStyle(false)
+    , m_addButton(nullptr)
 {
     init();
 }
@@ -62,7 +49,7 @@ StylesComboPreview::StylesComboPreview(QWidget *parent) :
 StylesComboPreview::~StylesComboPreview()
 {
     delete m_addButton;
-    m_addButton = 0;
+    m_addButton = nullptr;
 }
 
 void StylesComboPreview::init()
@@ -73,13 +60,13 @@ void StylesComboPreview::init()
     }
 
     m_addButton = new QPushButton(this);
-    m_addButton->setCursor( Qt::ArrowCursor );
+    m_addButton->setCursor(Qt::ArrowCursor);
     m_addButton->setIcon(koIcon("list-add"));
     m_addButton->setFlat(true);
-    m_addButton->setMinimumSize(16,16);
+    m_addButton->setMinimumSize(16, 16);
     m_addButton->setMaximumSize(16, 16);
     m_addButton->setToolTip(i18n("Create a new style with the current properties"));
-    connect(m_addButton, SIGNAL(clicked()), this, SLOT(addNewStyle()));
+    connect(m_addButton, &QAbstractButton::clicked, this, &StylesComboPreview::addNewStyle);
 
     updateAddButton();
 }
@@ -92,7 +79,7 @@ void StylesComboPreview::updateAddButton()
 
     const QSize geom = size();
     const int buttonWidth = m_addButton->size().width();
-    m_addButton->move(geom.width() - buttonWidth , (geom.height()-m_addButton->size().height())/2);
+    m_addButton->move(geom.width() - buttonWidth, (geom.height() - m_addButton->size().height()) / 2);
 }
 
 void StylesComboPreview::setAddButtonShown(bool show)
@@ -102,7 +89,7 @@ void StylesComboPreview::setAddButtonShown(bool show)
 
 QSize StylesComboPreview::availableSize() const
 {
-    return QSize(contentsRect().width()- m_addButton->width(), contentsRect().height()); ///TODO dynamic resizing when button shown/hidden.
+    return QSize(contentsRect().width() - m_addButton->width(), contentsRect().height()); /// TODO dynamic resizing when button shown/hidden.
 }
 
 void StylesComboPreview::setPreview(const QImage &image)
@@ -112,17 +99,17 @@ void StylesComboPreview::setPreview(const QImage &image)
 
 bool StylesComboPreview::isAddButtonShown() const
 {
-    return m_addButton != 0;
+    return m_addButton != nullptr;
 }
 
-void StylesComboPreview::resizeEvent( QResizeEvent * ev )
+void StylesComboPreview::resizeEvent(QResizeEvent *ev)
 {
     QLineEdit::resizeEvent(ev);
-    emit resized();
+    Q_EMIT resized();
     updateAddButton();
 }
 
-void StylesComboPreview::keyPressEvent( QKeyEvent *e )
+void StylesComboPreview::keyPressEvent(QKeyEvent *e)
 {
     if (m_shouldAddNewStyle && e->key() == Qt::Key_Escape) {
         m_renamingNewStyle = false;
@@ -130,16 +117,14 @@ void StylesComboPreview::keyPressEvent( QKeyEvent *e )
         setReadOnly(true);
         setText(QString());
         e->accept();
-    }
-    else if (m_shouldAddNewStyle && (e->key() == Qt::Key_Enter || e->key() == Qt::Key_Return)) {
+    } else if (m_shouldAddNewStyle && (e->key() == Qt::Key_Enter || e->key() == Qt::Key_Return)) {
         m_renamingNewStyle = false;
         m_shouldAddNewStyle = false;
-        emit newStyleRequested(text());
+        Q_EMIT newStyleRequested(text());
         setReadOnly(true);
         setText(QString());
         e->accept();
-    }
-    else {
+    } else {
         QLineEdit::keyPressEvent(e);
     }
 }
@@ -150,7 +135,7 @@ void StylesComboPreview::focusOutEvent(QFocusEvent *e)
         if (m_shouldAddNewStyle) {
             m_renamingNewStyle = false;
             m_shouldAddNewStyle = false;
-            emit newStyleRequested(text());
+            Q_EMIT newStyleRequested(text());
             setReadOnly(true);
             setText(QString());
             e->accept();
@@ -158,8 +143,7 @@ void StylesComboPreview::focusOutEvent(QFocusEvent *e)
         setReadOnly(true);
         m_renamingNewStyle = false;
         setText(QString());
-    }
-    else {
+    } else {
         QLineEdit::focusOutEvent(e);
     }
 }
@@ -168,19 +152,18 @@ void StylesComboPreview::mouseReleaseEvent(QMouseEvent *event)
 {
     Q_UNUSED(event);
     if (!m_renamingNewStyle) {
-        emit clicked();
+        Q_EMIT clicked();
     }
 }
 
-void StylesComboPreview::paintEvent( QPaintEvent *ev )
+void StylesComboPreview::paintEvent(QPaintEvent *ev)
 {
     if (!m_renamingNewStyle) {
         QLineEdit::paintEvent(ev);
         QPainter p(this);
         p.setClipRect(ev->rect());
         p.drawImage(contentsRect().topLeft(), m_stylePreview);
-    }
-    else {
+    } else {
         QLineEdit::paintEvent(ev);
     }
 }
