@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
- * Copyright (C) 2012 Pierre Stirnweiss <pstirnweiss@googlemail.org>
+ * SPDX-FileCopyrightText: 2012 Pierre Stirnweiss <pstirnweiss@googlemail.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef STYLESFILTEREDMODELBASE_H
@@ -30,21 +17,22 @@
  * QSortFilterProxyModel implementation was a great source of inspiration.
  *
  * It is to be noted that this is in no way a full proxyModel. It is built with several assumptions:
- * - it is used to filter a StylesModel which in turn is a flat list of items. There is only one level of items. (this also means that "parent" QModelIndexes are always invalid)
+ * - it is used to filter a StylesModel which in turn is a flat list of items. There is only one level of items. (this also means that "parent" QModelIndexes
+ * are always invalid)
  * - there is no header in the model.
  * - the model has only one column
  * - only the following methods are used when updating the underlying model's data: resetModel, insertRows, moveRows, removeRows (cf QAbstractItemModel)
-*/
+ */
 
 class StylesFilteredModelBase : public AbstractStylesModel
 {
     Q_OBJECT
 public:
-    explicit StylesFilteredModelBase(QObject *parent = 0);
+    explicit StylesFilteredModelBase(QObject *parent = nullptr);
 
     /** Re-implement from QAbstractItemModel. */
 
-    QModelIndex index(int row, int column=0, const QModelIndex &parent = QModelIndex()) const override;
+    QModelIndex index(int row, int column = 0, const QModelIndex &parent = QModelIndex()) const override;
 
     QModelIndex parent(const QModelIndex &child) const override;
 
@@ -62,15 +50,15 @@ public:
     void setStyleThumbnailer(KoStyleThumbnailer *thumbnailer) override;
 
     /** Return a @class QModelIndex for the specified @param style.
-      * @param style may be either a character or paragraph style.
-    */
+     * @param style may be either a character or paragraph style.
+     */
     QModelIndex indexOf(const KoCharacterStyle *style) const override;
 
     /** Returns a QImage which is a preview of the style specified by @param row of the given @param size.
-      * If size isn't specified, the default size of the given @class KoStyleThumbnailer is used.
-    */
+     * If size isn't specified, the default size of the given @class KoStyleThumbnailer is used.
+     */
     QImage stylePreview(int row, const QSize &size = QSize()) override;
-//    virtual QImage stylePreview(QModelIndex &index, const QSize &size = QSize());
+    //    virtual QImage stylePreview(QModelIndex &index, const QSize &size = QSize());
 
     AbstractStylesModel::Type stylesType() const override;
 
@@ -81,14 +69,14 @@ public:
     void setStylesModel(AbstractStylesModel *sourceModel);
 
 protected Q_SLOTS:
-    void modelAboutToBeReset();
-    void modelReset();
-    void rowsAboutToBeInserted(const QModelIndex &parent, int start, int end);
-    void rowsAboutToBeMoved(const QModelIndex &sourceParent, int sourceStart, int sourceEnd, const QModelIndex &destinationParent, int destinationRow);
-    void rowsAboutToBeRemoved(const QModelIndex &parent, int start, int end);
-    void rowsInserted(const QModelIndex &parent, int start, int end);
-    void rowsMoved(const QModelIndex &sourceParent, int sourceStart, int sourceEnd, const QModelIndex &destinationParent, int destinationRow);
-    void rowsRemoved(const QModelIndex &parent, int start, int end);
+    void slotModelAboutToBeReset();
+    void slotModelReset();
+    void slotRowsAboutToBeInserted(const QModelIndex &parent, int start, int end);
+    void slotRowsAboutToBeMoved(const QModelIndex &sourceParent, int sourceStart, int sourceEnd, const QModelIndex &destinationParent, int destinationRow);
+    void slotRowsAboutToBeRemoved(const QModelIndex &parent, int start, int end);
+    void slotRowsInserted(const QModelIndex &parent, int start, int end);
+    void slotRowsMoved(const QModelIndex &sourceParent, int sourceStart, int sourceEnd, const QModelIndex &destinationParent, int destinationRow);
+    void slotRowsRemoved(const QModelIndex &parent, int start, int end);
 
 protected:
     virtual void createMapping();
