@@ -1,70 +1,57 @@
 /* This file is part of the KDE project
- * Copyright (C) 2011 Sebastian Sauer <mail@dipe.org>
+ * SPDX-FileCopyrightText: 2011 Sebastian Sauer <mail@dipe.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "ChapterVariable.h"
 
 #include "VariablesDebug.h"
 
-#include <KoXmlReader.h>
-#include <KoXmlWriter.h>
+#include <KoParagraphStyle.h>
 #include <KoProperties.h>
 #include <KoShape.h>
-#include <KoShapeSavingContext.h>
 #include <KoShapeLoadingContext.h>
-#include <KoXmlNS.h>
-#include <KoTextLayoutRootArea.h>
-#include <KoTextDocumentLayout.h>
-#include <KoParagraphStyle.h>
+#include <KoShapeSavingContext.h>
 #include <KoTextBlockData.h>
+#include <KoTextDocumentLayout.h>
+#include <KoTextLayoutRootArea.h>
+#include <KoXmlNS.h>
+#include <KoXmlReader.h>
+#include <KoXmlWriter.h>
 
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
-#include <QFontMetricsF>
-#include <QTextDocument>
 #include <QAbstractTextDocumentLayout>
-#include <QTextInlineObject>
-#include <QLabel>
 #include <QComboBox>
+#include <QFontMetricsF>
 #include <QGridLayout>
+#include <QLabel>
 #include <QSpinBox>
+#include <QTextDocument>
+#include <QTextInlineObject>
 
 ChapterVariable::ChapterVariable()
-        : KoVariable(true)
-        , m_format(ChapterName)
-        , m_level(1)
+    : KoVariable(true)
+    , m_format(ChapterName)
+    , m_level(1)
 {
 }
 
 void ChapterVariable::readProperties(const KoProperties *props)
 {
-    m_format = (FormatTypes) props->intProperty("format");
+    m_format = (FormatTypes)props->intProperty("format");
     m_level = qMax(1, props->intProperty("level"));
 }
 
 void ChapterVariable::resize(const QTextDocument *_document, QTextInlineObject &object, int _posInDocument, const QTextCharFormat &format, QPaintDevice *pd)
 {
-    QTextDocument *document = const_cast<QTextDocument*>(_document);
+    QTextDocument *document = const_cast<QTextDocument *>(_document);
     int posInDocument = _posInDocument;
     bool checkBackwards = true;
     QTextFrame::iterator startIt, endIt;
 
-    KoTextDocumentLayout *lay = qobject_cast<KoTextDocumentLayout*>(document->documentLayout());
+    KoTextDocumentLayout *lay = qobject_cast<KoTextDocumentLayout *>(document->documentLayout());
     KoTextDocumentLayout *ref = lay->referencedLayout();
     if (ref) {
         KoTextLayoutRootArea *rootArea = lay->rootAreaForPosition(posInDocument);
@@ -78,8 +65,8 @@ void ChapterVariable::resize(const QTextDocument *_document, QTextInlineObject &
             return; // should not happen
         }
         int pagenumber = page->pageNumber();
-        foreach(KoTextLayoutRootArea *a, ref->rootAreas()) {
-            KoTextPage * p = a->page();
+        foreach (KoTextLayoutRootArea *a, ref->rootAreas()) {
+            KoTextPage *p = a->page();
             if (!p || p->pageNumber() != pagenumber)
                 continue;
             startIt = a->startTextFrameIterator();
@@ -106,7 +93,7 @@ void ChapterVariable::resize(const QTextDocument *_document, QTextInlineObject &
             int level = block.blockFormat().intProperty(KoParagraphStyle::OutlineLevel);
             if (level == m_level) {
                 KoTextBlockData data(block);
-                switch(m_format) {
+                switch (m_format) {
                 case ChapterName:
                     setValue(block.text());
                     break;
@@ -114,13 +101,13 @@ void ChapterVariable::resize(const QTextDocument *_document, QTextInlineObject &
                     setValue(data.counterText());
                     break;
                 case ChapterNumberName:
-                    setValue(QString("%1 %2").arg(data.counterText()).arg(block.text()));
+                    setValue(QString("%1 %2").arg(data.counterText(), block.text()));
                     break;
                 case ChapterPlainNumber:
                     setValue(data.counterPlainText());
                     break;
                 case ChapterPlainNumberName:
-                    setValue(QString("%1 %2").arg(data.counterPlainText()).arg(block.text()));
+                    setValue(QString("%1 %2").arg(data.counterPlainText(), block.text()));
                     break;
                 default:
                     break;
@@ -136,9 +123,8 @@ void ChapterVariable::resize(const QTextDocument *_document, QTextInlineObject &
 
             // If we search forwards and reached the end of the page then we continue searching backwards
             // at the beginning of the page.
-            if (!block.isValid() ||
-                (endIt.currentBlock().isValid() && block.position() > endIt.currentBlock().position()) ||
-                (endIt.currentFrame() && block.position() > endIt.currentFrame()->firstCursorPosition().block().position()) ) {
+            if (!block.isValid() || (endIt.currentBlock().isValid() && block.position() > endIt.currentBlock().position())
+                || (endIt.currentFrame() && block.position() > endIt.currentFrame()->firstCursorPosition().block().position())) {
                 if (startIt.currentBlock().isValid())
                     block = startIt.currentBlock();
                 else if (startIt.currentFrame())
@@ -157,7 +143,7 @@ void ChapterVariable::saveOdf(KoShapeSavingContext &context)
 {
     KoXmlWriter *writer = &context.xmlWriter();
     writer->startElement("text:chapter ", false);
-    switch(m_format) {
+    switch (m_format) {
     case ChapterName:
         writer->addAttribute("text:display", "name");
         break;
@@ -181,7 +167,7 @@ void ChapterVariable::saveOdf(KoShapeSavingContext &context)
     writer->endElement(); // text:chapter
 }
 
-bool ChapterVariable::loadOdf(const KoXmlElement & element, KoShapeLoadingContext & context)
+bool ChapterVariable::loadOdf(const KoXmlElement &element, KoShapeLoadingContext &context)
 {
     Q_UNUSED(context);
 
@@ -205,7 +191,7 @@ bool ChapterVariable::loadOdf(const KoXmlElement & element, KoShapeLoadingContex
     return true;
 }
 
-QWidget* ChapterVariable::createOptionsWidget()
+QWidget *ChapterVariable::createOptionsWidget()
 {
     QWidget *widget = new QWidget();
     QGridLayout *layout = new QGridLayout(widget);
@@ -217,7 +203,8 @@ QWidget* ChapterVariable::createOptionsWidget()
     layout->addWidget(formatLabel, 0, 0);
     QComboBox *formatEdit = new QComboBox(widget);
     formatLabel->setBuddy(formatEdit);
-    formatEdit->addItems( QStringList() << i18n("Number") << i18n("Name") << i18n("Number and name") << i18n("Number without separator") << i18n("Number and name without separator") );
+    formatEdit->addItems(QStringList() << i18n("Number") << i18n("Name") << i18n("Number and name") << i18n("Number without separator")
+                                       << i18n("Number and name without separator"));
     formatEdit->setCurrentIndex(2);
     layout->addWidget(formatEdit, 0, 1);
 
@@ -230,15 +217,15 @@ QWidget* ChapterVariable::createOptionsWidget()
     levelEdit->setValue(m_level);
     layout->addWidget(levelEdit, 1, 1);
 
-    connect(formatEdit, SIGNAL(currentIndexChanged(int)), this, SLOT(formatChanged(int)));
-    connect(levelEdit, SIGNAL(valueChanged(int)), this, SLOT(levelChanged(int)));
+    connect(formatEdit, &QComboBox::currentIndexChanged, this, &ChapterVariable::formatChanged);
+    connect(levelEdit, &QSpinBox::valueChanged, this, &ChapterVariable::levelChanged);
 
     return widget;
 }
 
 void ChapterVariable::formatChanged(int format)
 {
-    m_format = (FormatTypes) format;
+    m_format = (FormatTypes)format;
 }
 
 void ChapterVariable::levelChanged(int level)
