@@ -1,44 +1,31 @@
 /* This file is part of the KDE project
- * Copyright (C) 2010 C. Boemann <cbo@boemann.dk>
- * Copyright (C) 2012 Gopalakrishna Bhat A <gopalakbhat@gmail.com>
+ * SPDX-FileCopyrightText: 2010 C. Boemann <cbo@boemann.dk>
+ * SPDX-FileCopyrightText: 2012 Gopalakrishna Bhat A <gopalakbhat@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
- 
+
 #include "FullScreenPlayer.h"
 
 #include <KoIcon.h>
 
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
-#include <phonon/videowidget.h>
+#include <phonon/SeekSlider>
+#include <phonon/VolumeSlider>
 #include <phonon/audiooutput.h>
 #include <phonon/mediaobject.h>
-#include <phonon/VolumeSlider>
-#include <phonon/SeekSlider>
+#include <phonon/videowidget.h>
 
-#include <QUrl>
-#include <QVBoxLayout>
 #include <QHBoxLayout>
 #include <QKeyEvent>
 #include <QLabel>
 #include <QToolButton>
+#include <QUrl>
+#include <QVBoxLayout>
 
 FullScreenPlayer::FullScreenPlayer(const QUrl &url)
-    : QWidget(0)
+    : QWidget(nullptr)
     , m_seekSlider(new Phonon::SeekSlider(this))
     , m_volumeSlider(new Phonon::VolumeSlider(this))
 {
@@ -49,7 +36,7 @@ FullScreenPlayer::FullScreenPlayer(const QUrl &url)
     Phonon::createPath(m_mediaObject, m_videoWidget);
 
     m_audioOutput = new Phonon::AudioOutput(Phonon::VideoCategory);
-    connect(m_audioOutput, SIGNAL(mutedChanged(bool)), this, SLOT(muteStateChanged(bool)));
+    connect(m_audioOutput, &Phonon::AudioOutput::mutedChanged, this, &FullScreenPlayer::muteStateChanged);
 
     Phonon::createPath(m_mediaObject, m_audioOutput);
 
@@ -65,27 +52,27 @@ FullScreenPlayer::FullScreenPlayer(const QUrl &url)
     m_play = new QToolButton(this);
     m_play->setIcon(koIcon("media-playback-start"));
     m_play->setToolTip(i18n("Play"));
-    connect(m_play, SIGNAL(clicked()), this, SLOT(play()));
+    connect(m_play, &QAbstractButton::clicked, this, &FullScreenPlayer::play);
 
     m_pause = new QToolButton(this);
     m_pause->setIcon(koIcon("media-playback-pause"));
     m_pause->setToolTip(i18n("Pause"));
-    connect(m_pause, SIGNAL(clicked()), this, SLOT(pause()));
+    connect(m_pause, &QAbstractButton::clicked, this, &FullScreenPlayer::pause);
 
     m_stop = new QToolButton(this);
     m_stop->setIcon(koIcon("media-playback-stop"));
     m_stop->setToolTip(i18n("Stop"));
-    connect(m_stop, SIGNAL(clicked()), this, SLOT(stop()));
+    connect(m_stop, &QAbstractButton::clicked, this, &FullScreenPlayer::stop);
 
     m_volumeIconMuted = new QToolButton(this);
     m_volumeIconMuted->setIcon(koIcon("audio-volume-muted"));
     m_volumeIconMuted->setToolTip(i18n("Unmute"));
-    connect(m_volumeIconMuted, SIGNAL(clicked()), this, SLOT(unmute()));
+    connect(m_volumeIconMuted, &QAbstractButton::clicked, this, &FullScreenPlayer::unmute);
 
     m_volumeIconUnmuted = new QToolButton(this);
     m_volumeIconUnmuted->setIcon(koIcon("audio-volume-medium"));
     m_volumeIconUnmuted->setToolTip(i18n("Mute"));
-    connect(m_volumeIconUnmuted, SIGNAL(clicked()), this, SLOT(mute()));
+    connect(m_volumeIconUnmuted, &QAbstractButton::clicked, this, &FullScreenPlayer::mute);
 
     QHBoxLayout *playbackControls = new QHBoxLayout();
     playbackControls->addWidget(m_play);
@@ -101,16 +88,15 @@ FullScreenPlayer::FullScreenPlayer(const QUrl &url)
     QVBoxLayout *layout = new QVBoxLayout;
     layout->addWidget(m_videoWidget);
     layout->addLayout(playbackControls);
-    layout->setMargin(0);
+    layout->setContentsMargins({});
     setLayout(layout);
     show();
     setWindowState(Qt::WindowFullScreen);
 
     m_mediaObject->setCurrentSource(url);
-    connect(m_mediaObject, SIGNAL(finished()), this, SLOT(stop()));
-    connect(m_mediaObject, SIGNAL(stateChanged(Phonon::State,Phonon::State)),
-            this, SLOT(playStateChanged(Phonon::State,Phonon::State)));
-    connect(m_mediaObject, SIGNAL(tick(qint64)), this, SLOT(updatePlaybackTime(qint64)));
+    connect(m_mediaObject, &Phonon::MediaObject::finished, this, &FullScreenPlayer::stop);
+    connect(m_mediaObject, &Phonon::MediaObject::stateChanged, this, &FullScreenPlayer::playStateChanged);
+    connect(m_mediaObject, &Phonon::MediaObject::tick, this, &FullScreenPlayer::updatePlaybackTime);
 
     play();
 
@@ -118,13 +104,10 @@ FullScreenPlayer::FullScreenPlayer(const QUrl &url)
     unmute();
 }
 
-FullScreenPlayer::~FullScreenPlayer()
-{
-}
+FullScreenPlayer::~FullScreenPlayer() = default;
 
 void FullScreenPlayer::play()
 {
-
     m_mediaObject->play();
 }
 
@@ -160,9 +143,9 @@ void FullScreenPlayer::mousePressEvent(QMouseEvent *event)
 
 void FullScreenPlayer::keyPressEvent(QKeyEvent *event)
 {
-    if(event->key()==Qt::Key_Escape) {
-       m_mediaObject->stop();
-       deleteLater();
+    if (event->key() == Qt::Key_Escape) {
+        m_mediaObject->stop();
+        deleteLater();
     }
 }
 
@@ -171,36 +154,34 @@ void FullScreenPlayer::playStateChanged(Phonon::State newState, Phonon::State ol
     Q_UNUSED(oldState);
 
     switch (newState) {
-        case Phonon::PlayingState:
-                m_play->setVisible(false);
-                m_pause->setVisible(true);
-                break;
-        case Phonon::PausedState:
-                m_play->setVisible(true);
-                m_pause->setVisible(false);
-                break;
-        default:
-            ;
+    case Phonon::PlayingState:
+        m_play->setVisible(false);
+        m_pause->setVisible(true);
+        break;
+    case Phonon::PausedState:
+        m_play->setVisible(true);
+        m_pause->setVisible(false);
+        break;
+    default:;
     }
 }
 
 void FullScreenPlayer::updatePlaybackTime(qint64 currentTime)
 {
     QString currentPlayTime = QString("%1:%2:%3")
-            .arg((currentTime / 3600000) % 60, 2, 10, QChar('0'))
-            .arg((currentTime / 60000) % 60, 2, 10, QChar('0'))
-            .arg((currentTime / 1000) % 60, 2, 10, QChar('0'));
+                                  .arg((currentTime / 3600000) % 60, 2, 10, QChar('0'))
+                                  .arg((currentTime / 60000) % 60, 2, 10, QChar('0'))
+                                  .arg((currentTime / 1000) % 60, 2, 10, QChar('0'));
 
     qint64 time = m_mediaObject->totalTime();
     QString totalTime = QString("%1:%2:%3")
-            .arg((time / 3600000) % 60, 2, 10, QChar('0'))
-            .arg((time / 60000) % 60, 2, 10, QChar('0'))
-            .arg((time / 1000) % 60, 2, 10, QChar('0'));
+                            .arg((time / 3600000) % 60, 2, 10, QChar('0'))
+                            .arg((time / 60000) % 60, 2, 10, QChar('0'))
+                            .arg((time / 1000) % 60, 2, 10, QChar('0'));
 
-    m_playbackTime->setText(QString("%1/%2").arg(currentPlayTime).arg(totalTime));
+    m_playbackTime->setText(QString("%1/%2").arg(currentPlayTime, totalTime));
 }
 
-
 void FullScreenPlayer::muteStateChanged(bool muted)
 {
     if (muted) {
