@@ -1,45 +1,33 @@
 /* This file is part of the KDE project
- * Copyright (C) 2007, 2009 Thomas Zander <zander@kde.org>
- * Copyright (C) 2008 Thorsten Zachmann <zachmann@kde.org>
- * Copyright (C) 2009 C. Boemann <cbo@boemann.dk>
+ * SPDX-FileCopyrightText: 2007, 2009 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2008 Thorsten Zachmann <zachmann@kde.org>
+ * SPDX-FileCopyrightText: 2009 C. Boemann <cbo@boemann.dk>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 #include "VideoCollection.h"
-#include "VideoData.h"
-#include "KoShapeSavingContext.h"
 
+#include "VideoData.h"
+#include "VideoDebug.h"
+
+#include "KoShapeSavingContext.h"
 #include <KoStoreDevice.h>
-#include <QCryptographicHash>
 #include <KoXmlWriter.h>
+#include <QCryptographicHash>
 
 #include <QMap>
-#include <kdebug.h>
-#include <kmimetype.h>
+#include <QMimeDatabase>
+#include <QMimeType>
+#include <QUrl>
 
 class VideoCollection::Private
 {
 public:
-    ~Private()
-    {
-   }
+    ~Private() = default;
 
-    QMap<qint64, VideoData*> videos;
+    QMap<qint64, VideoData *> videos;
     // an extra map to find all dataObjects based on the key of a store.
-    QMap<QByteArray, VideoData*> storeVideos;
+    QMap<QByteArray, VideoData *> storeVideos;
 };
 
 VideoCollection::VideoCollection(QObject *parent)
@@ -51,15 +39,15 @@ VideoCollection::VideoCollection(QObject *parent)
 
 VideoCollection::~VideoCollection()
 {
-    foreach(VideoData *id, d->videos) {
-        id->setCollection(0);
+    foreach (VideoData *id, d->videos) {
+        id->setCollection(nullptr);
     }
     delete d;
 }
 
 bool VideoCollection::completeLoading(KoStore *store)
 {
-    Q_UNUSED( store );
+    Q_UNUSED(store);
     d->storeVideos.clear();
     return true;
 }
@@ -67,9 +55,9 @@ bool VideoCollection::completeLoading(KoStore *store)
 bool VideoCollection::completeSaving(KoStore *store, KoXmlWriter *manifestWriter, KoShapeSavingContext *context)
 {
     Q_UNUSED(context);
-    QMap<qint64, VideoData *>::iterator dataIt(d->videos.begin());
+    QMap<qint64, VideoData *>::ConstIterator dataIt(d->videos.constBegin());
 
-    while (dataIt != d->videos.end()) {
+    while (dataIt != d->videos.constEnd()) {
         if (!dataIt.value()->saveName().isEmpty()) {
             VideoData *videoData = dataIt.value();
             if (store->open(videoData->saveName())) {
@@ -78,19 +66,20 @@ bool VideoCollection::completeSaving(KoStore *store, KoXmlWriter *manifestWriter
                 store->close();
                 // TODO error handling
                 if (ok) {
-                    const QString mimetype(KMimeType::findByPath(videoData->saveName(), 0 , true)->name());
+                    QMimeDatabase db;
+                    const QString mimetype(db.mimeTypeForFile(videoData->saveName(), QMimeDatabase::MatchExtension).name());
                     manifestWriter->addManifestEntry(videoData->saveName(), mimetype);
                 } else {
-                    kWarning(30006) << "saving video failed";
+                    warnVideo << "saving video failed";
                 }
             } else {
-                kWarning(30006) << "saving video failed: open store failed";
+                warnVideo << "saving video failed: open store failed";
             }
             dataIt.value()->setSaveName(QString());
         }
         ++dataIt;
     }
-    saveCounter=0;
+    saveCounter = 0;
     return true;
 }
 
@@ -118,12 +107,12 @@ VideoData *VideoCollection::createVideoData(const QString &href, KoStore *store)
 {
     // the tricky thing with a 'store' is that we need to read the data now
     // as the store will no longer be readable after the loading completed.
-    // The solution we use is to read the data, store it in a KTemporaryFile
+    // The solution we use is to read the data, store it in a QTemporaryFile
     // and read and parse it on demand when the video data is actually needed.
     // This leads to having two keys, one for the store and one for the
     // actual video data. We need the latter so if someone else gets the same
     // video data they can find this data and share (warm fuzzy feeling here)
-    QByteArray storeKey = (QString::number((qint64) store) + href).toLatin1();
+    QByteArray storeKey = (QString::number((qint64)store) + href).toLatin1();
     if (d->storeVideos.contains(storeKey))
         return new VideoData(*(d->storeVideos.value(storeKey)));
 
