@@ -1,114 +1,60 @@
 /* This file is part of the KDE project
-   Copyright 2009 Thomas Zander <zander@kde.org>
-   Copyright 2006-2007 Stefan Nikolaus <stefan.nikolaus@kdemail.net>
-   Copyright 2006 Robert Knight <robertknight@gmail.com>
-   Copyright 2006 Inge Wallin <inge@lysator.liu.se>
-   Copyright 1999-2002,2004 Laurent Montel <montel@kde.org>
-   Copyright 2002-2005 Ariya Hidayat <ariya@kde.org>
-   Copyright 1999-2004 David Faure <faure@kde.org>
-   Copyright 2004-2005 Meni Livne <livne@kde.org>
-   Copyright 2001-2003 Philipp Mueller <philipp.mueller@gmx.de>
-   Copyright 2002-2003 Norbert Andres <nandres@web.de>
-   Copyright 2003 Hamish Rodda <rodda@kde.org>
-   Copyright 2003 Joseph Wenninger <jowenn@kde.org>
-   Copyright 2003 Lukas Tinkl <lukas@kde.org>
-   Copyright 2000-2002 Werner Trobin <trobin@kde.org>
-   Copyright 2002 Harri Porten <porten@kde.org>
-   Copyright 2002 John Dailey <dailey@vt.edu>
-   Copyright 2002 Daniel Naber <daniel.naber@t-online.de>
-   Copyright 1999-2000 Torben Weis <weis@kde.org>
-   Copyright 1999-2000 Stephan Kulow <coolo@kde.org>
-   Copyright 2000 Bernd Wuebben <wuebben@kde.org>
-   Copyright 2000 Wilco Greven <greven@kde.org>
-   Copyright 2000 Simon Hausmann <hausmann@kde.org
-   Copyright 1999 Michael Reiher <michael.reiher@gmx.de>
-   Copyright 1999 Boris Wedl <boris.wedl@kfunigraz.ac.at>
-   Copyright 1999 Reginald Stadlbauer <reggie@kde.org>
+   SPDX-FileCopyrightText: 2009 Thomas Zander <zander@kde.org>
+   SPDX-FileCopyrightText: 2006-2007 Stefan Nikolaus <stefan.nikolaus@kdemail.net>
+   SPDX-FileCopyrightText: 2006 Robert Knight <robertknight@gmail.com>
+   SPDX-FileCopyrightText: 2006 Inge Wallin <inge@lysator.liu.se>
+   SPDX-FileCopyrightText: 1999-2002, 2004 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2002-2005 Ariya Hidayat <ariya@kde.org>
+   SPDX-FileCopyrightText: 1999-2004 David Faure <faure@kde.org>
+   SPDX-FileCopyrightText: 2004-2005 Meni Livne <livne@kde.org>
+   SPDX-FileCopyrightText: 2001-2003 Philipp Mueller <philipp.mueller@gmx.de>
+   SPDX-FileCopyrightText: 2002-2003 Norbert Andres <nandres@web.de>
+   SPDX-FileCopyrightText: 2003 Hamish Rodda <rodda@kde.org>
+   SPDX-FileCopyrightText: 2003 Joseph Wenninger <jowenn@kde.org>
+   SPDX-FileCopyrightText: 2003 Lukas Tinkl <lukas@kde.org>
+   SPDX-FileCopyrightText: 2000-2002 Werner Trobin <trobin@kde.org>
+   SPDX-FileCopyrightText: 2002 Harri Porten <porten@kde.org>
+   SPDX-FileCopyrightText: 2002 John Dailey <dailey@vt.edu>
+   SPDX-FileCopyrightText: 2002 Daniel Naber <daniel.naber@t-online.de>
+   SPDX-FileCopyrightText: 1999-2000 Torben Weis <weis@kde.org>
+   SPDX-FileCopyrightText: 1999-2000 Stephan Kulow <coolo@kde.org>
+   SPDX-FileCopyrightText: 2000 Bernd Wuebben <wuebben@kde.org>
+   SPDX-FileCopyrightText: 2000 Wilco Greven <greven@kde.org>
+   SPDX-FileCopyrightText: 2000 Simon Hausmann <hausmann@kde.org
+   SPDX-FileCopyrightText: 1999 Michael Reiher <michael.reiher@gmx.de>
+   SPDX-FileCopyrightText: 1999 Boris Wedl <boris.wedl@kfunigraz.ac.at>
+   SPDX-FileCopyrightText: 1999 Reginald Stadlbauer <reggie@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // Local
 #include "Canvas.h"
 #include "CanvasBase_p.h"
-
-// std
-#include <assert.h>
-#include <float.h>
-#include <stdlib.h>
+#include "HeaderWidgets.h"
+#include "View.h"
 
 // Qt
-#include <QApplication>
-#include <QBuffer>
-#include <QByteArray>
-#include <QClipboard>
-#include <QDragLeaveEvent>
-#include <QDragMoveEvent>
-#include <QDropEvent>
-#include <QEvent>
-#include <QFocusEvent>
-#include <QKeyEvent>
-#include <QLabel>
-#include <QList>
 #include <QMenu>
 #include <QMouseEvent>
 #include <QPainter>
-#include <QPaintEvent>
-#include <QPixmap>
-#include <QPoint>
 #include <QScrollBar>
-#include <QTextStream>
 #include <QToolTip>
-#include <QWidget>
 
 // KF5
 #include <kxmlguifactory.h>
 
 // Calligra
-#include <KoCanvasController.h>
 #include <KoShapeManager.h>
 #include <KoToolManager.h>
 #include <KoToolProxy.h>
 #include <KoZoomHandler.h>
-#include <KoPointerEvent.h>
 
 // Sheets
-#include "SheetsDebug.h"
-#include "CellStorage.h"
-#include "Doc.h"
-#include "Global.h"
-#include "HeaderWidgets.h"
-#include "Localization.h"
-#include "Map.h"
-#include "RowColumnFormat.h"
-#include "Sheet.h"
-#include "Util.h"
-#include "Validity.h"
-#include "View.h"
-
-// commands
-#include "commands/CopyCommand.h"
-#include "commands/DeleteCommand.h"
-#include "commands/PasteCommand.h"
-#include "commands/StyleCommand.h"
-
-// ui
-#include "ui/CellView.h"
+#include "core/Cell.h"
+#include "core/Sheet.h"
+#include "engine/SheetsDebug.h"
 #include "ui/Selection.h"
-#include "ui/SheetView.h"
 
 #define MIN_SIZE 10
 
@@ -127,9 +73,9 @@ public:
  ****************************************************************/
 
 Canvas::Canvas(View *view)
-        : QWidget(view)
-        , CanvasBase(view ? view->doc() : 0)
-        , cd(new Private)
+    : QWidget(view)
+    , CanvasBase(view ? view->doc() : nullptr)
+    , cd(new Private)
 {
     cd->view = view;
 
@@ -139,29 +85,66 @@ Canvas::Canvas(View *view)
     QWidget::setFocusPolicy(Qt::StrongFocus);
     setMouseTracking(true);
 
-    installEventFilter(this);   // for TAB key processing, otherwise focus change
+    installEventFilter(this); // for TAB key processing, otherwise focus change
     setAcceptDrops(true);
     setAttribute(Qt::WA_InputMethodEnabled, true); // ensure using the InputMethod
 }
 
 Canvas::~Canvas()
 {
-    foreach (QAction* action, actions()) {
+    foreach (QAction *action, actions()) {
         removeAction(action);
     }
 
     delete cd;
 }
 
-View* Canvas::view() const
+View *Canvas::view() const
 {
     return cd->view;
 }
 
-void Canvas::mousePressEvent(QMouseEvent* event)
+void Canvas::validateSelection()
 {
-    //KoPointerEvent pev(event, QPointF());
-    //mousePressed(&pev);
+    Sheet *const sheet = activeSheet();
+    if (!sheet)
+        return;
+
+    if (selection()->isSingular()) {
+        const Cell cell = Cell(sheet, selection()->cursor()).masterCell();
+        Validity validity = cell.validity();
+        if (validity.displayValidationInformation()) {
+            const QString title = validity.titleInfo();
+            QString message = validity.messageInfo();
+            if (title.isEmpty() && message.isEmpty())
+                return;
+
+            QString resultText("<html><body>");
+            if (!title.isEmpty()) {
+                resultText += "<h2>" + title + "</h2>";
+            }
+            if (!message.isEmpty()) {
+                message.replace(QChar('\n'), QString("<br>"));
+                resultText += "<p>" + message + "</p>";
+            }
+            resultText += "</body></html>";
+
+            const double xpos = sheet->columnPosition(cell.column()) + cell.width();
+            const double ypos = sheet->rowPosition(cell.row()) + cell.height();
+            const QPointF position = QPointF(xpos, ypos) - offset();
+            QToolTip::showText(view()->mapToGlobal(QPoint(position.x(), position.y())), resultText);
+        } else {
+            QToolTip::hideText();
+        }
+    } else {
+        QToolTip::hideText();
+    }
+}
+
+void Canvas::mousePressEvent(QMouseEvent *event)
+{
+    // KoPointerEvent pev(event, QPointF());
+    // mousePressed(&pev);
 
     QMouseEvent *const origEvent = event;
     QPointF documentPosition;
@@ -182,7 +165,7 @@ void Canvas::mousePressEvent(QMouseEvent* event)
         debugSheets << "newEvent->globalPos():" << event->globalPos();
     }
 
-#if 0  // This is disabled for now as per irc, as it blocks resize.
+#if 0 // This is disabled for now as per irc, as it blocks resize.
     // If the celltool is not active and we initiate a click on something that is not a flake element, we need
     // to reactivate the cell tool. THis is a temporary solution, pending the flake updates.
     if (KoToolManager::instance()->activeToolId() != "KSpreadCellToolId")
@@ -191,7 +174,7 @@ void Canvas::mousePressEvent(QMouseEvent* event)
 #endif
 
     // flake
-    if(d->toolProxy) {
+    if (d->toolProxy) {
         d->toolProxy->mousePressEvent(event, documentPosition);
 
         if (!event->isAccepted() && event->button() == Qt::RightButton) {
@@ -204,12 +187,12 @@ void Canvas::mousePressEvent(QMouseEvent* event)
     }
 }
 
-void Canvas::showContextMenu(const QPoint& globalPos)
+void Canvas::showContextMenu(const QPoint &globalPos)
 {
     view()->unplugActionList("toolproxy_action_list");
     view()->plugActionList("toolproxy_action_list", toolProxy()->popupActionList());
     if (KXMLGUIFactory *factory = view()->factory()) {
-        QMenu* menu = dynamic_cast<QMenu*>(factory->container("default_canvas_popup", view()));
+        QMenu *menu = dynamic_cast<QMenu *>(factory->container("default_canvas_popup", view()));
         // Only show the menu, if there are items. The plugged action list counts as one action.
         if (menu && menu->actions().count() > 1) {
             menu->exec(globalPos);
@@ -217,10 +200,10 @@ void Canvas::showContextMenu(const QPoint& globalPos)
     }
 }
 
-void Canvas::mouseReleaseEvent(QMouseEvent* event)
+void Canvas::mouseReleaseEvent(QMouseEvent *event)
 {
-//    KoPointerEvent pev(event, QPointF());
-//    mouseReleased(&pev);
+    //    KoPointerEvent pev(event, QPointF());
+    //    mouseReleased(&pev);
 
     QPointF documentPosition;
     if (layoutDirection() == Qt::LeftToRight) {
@@ -233,18 +216,18 @@ void Canvas::mouseReleaseEvent(QMouseEvent* event)
     }
 
     // flake
-    if(d->toolProxy)
+    if (d->toolProxy)
         d->toolProxy->mouseReleaseEvent(event, documentPosition);
 
     if (layoutDirection() == Qt::RightToLeft) {
-       delete event;
+        delete event;
     }
 }
 
-void Canvas::mouseMoveEvent(QMouseEvent* event)
+void Canvas::mouseMoveEvent(QMouseEvent *event)
 {
-//    KoPointerEvent pev(event, QPointF());
-//    mouseMoved(&pev);
+    //    KoPointerEvent pev(event, QPointF());
+    //    mouseMoved(&pev);
 
     QPointF documentPosition;
     if (layoutDirection() == Qt::LeftToRight) {
@@ -257,18 +240,18 @@ void Canvas::mouseMoveEvent(QMouseEvent* event)
     }
 
     // flake
-    if(d->toolProxy)
+    if (d->toolProxy)
         d->toolProxy->mouseMoveEvent(event, documentPosition);
 
     if (layoutDirection() == Qt::RightToLeft) {
-       delete event;
+        delete event;
     }
 }
 
-void Canvas::mouseDoubleClickEvent(QMouseEvent* event)
+void Canvas::mouseDoubleClickEvent(QMouseEvent *event)
 {
-//    KoPointerEvent pev(event, QPointF());
-//    mouseDoubleClicked(&pev);
+    //    KoPointerEvent pev(event, QPointF());
+    //    mouseDoubleClicked(&pev);
 
     QPointF documentPosition;
     if (layoutDirection() == Qt::LeftToRight) {
@@ -287,7 +270,7 @@ void Canvas::mouseDoubleClickEvent(QMouseEvent* event)
         // TODO: figure out a way to make the flake's functionality work. It'd likely require turning the main app
         // widget into a KoShape or something along those lines.
         if (KoToolManager::instance()->activeToolId() != "KSpreadCellToolId") {
-            if (!shapeManager()->shapeAt (documentPosition, KoFlake::ShapeOnTop)) {
+            if (!shapeManager()->shapeAt(documentPosition, KoFlake::ShapeOnTop)) {
                 KoToolManager::instance()->switchToolRequested("KSpreadCellToolId");
                 return;
             }
@@ -297,34 +280,33 @@ void Canvas::mouseDoubleClickEvent(QMouseEvent* event)
     }
 
     if (layoutDirection() == Qt::RightToLeft) {
-       // delete event;
+        // delete event;
     }
-
 }
 
 bool Canvas::event(QEvent *e)
 {
-    if(toolProxy()) {
+    if (toolProxy()) {
         toolProxy()->processEvent(e);
     }
     return QWidget::event(e);
 }
 
-void Canvas::paintEvent(QPaintEvent* event)
+void Canvas::paintEvent(QPaintEvent *event)
 {
     QPainter painter(this);
     paint(&painter, event->rect());
     event->accept();
 }
 
-void Canvas::dragEnterEvent(QDragEnterEvent* event)
+void Canvas::dragEnterEvent(QDragEnterEvent *event)
 {
     if (CanvasBase::dragEnter(event->mimeData())) {
         event->acceptProposedAction();
     }
 }
 
-void Canvas::dragMoveEvent(QDragMoveEvent* event)
+void Canvas::dragMoveEvent(QDragMoveEvent *event)
 {
     if (CanvasBase::dragMove(event->mimeData(), event->pos(), event->source())) {
         event->acceptProposedAction();
@@ -333,7 +315,7 @@ void Canvas::dragMoveEvent(QDragMoveEvent* event)
     }
 }
 
-void Canvas::dragLeaveEvent(QDragLeaveEvent*)
+void Canvas::dragLeaveEvent(QDragLeaveEvent *)
 {
     CanvasBase::dragLeave();
 }
@@ -349,22 +331,24 @@ void Canvas::dropEvent(QDropEvent *event)
 
 void Canvas::setVertScrollBarPos(qreal pos)
 {
-    if (pos < 0) pos = view()->vertScrollBar()->maximum() - pos;
+    if (pos < 0)
+        pos = view()->vertScrollBar()->maximum() - pos;
     view()->vertScrollBar()->setValue((int)pos);
 }
 
 void Canvas::setHorizScrollBarPos(qreal pos)
 {
-    if (pos < 0) pos = view()->horzScrollBar()->maximum() - pos;
+    if (pos < 0)
+        pos = view()->horzScrollBar()->maximum() - pos;
     view()->horzScrollBar()->setValue((int)pos);
 }
 
-KoZoomHandler* Canvas::zoomHandler() const
+KoZoomHandler *Canvas::zoomHandler() const
 {
     return view()->zoomHandler();
 }
 
-Sheet* Canvas::activeSheet() const
+Sheet *Canvas::activeSheet() const
 {
     return view()->activeSheet();
 }
@@ -374,22 +358,22 @@ bool Canvas::isViewLoading() const
     return view()->isLoading();
 }
 
-SheetView* Canvas::sheetView(const Sheet* sheet) const
+SheetView *Canvas::sheetView(Sheet *sheet) const
 {
     return view()->sheetView(sheet);
 }
 
-Calligra::Sheets::Selection* Canvas::selection() const
+Calligra::Sheets::Selection *Canvas::selection() const
 {
     return view()->selection();
 }
 
-ColumnHeader* Canvas::columnHeader() const
+ColumnHeader *Canvas::columnHeader() const
 {
     return view()->columnHeader();
 }
 
-RowHeader* Canvas::rowHeader() const
+RowHeader *Canvas::rowHeader() const
 {
     return view()->rowHeader();
 }
