@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C) 2006 Stefan Nikolaus <stefan.nikolaus@kdemail.net>
+   SPDX-FileCopyrightText: 2006 Stefan Nikolaus <stefan.nikolaus@kdemail.net>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KSPREAD_SOLVER
@@ -22,7 +9,7 @@
 
 #include <gsl/gsl_multimin.h>
 
-#include <kxmlguiclient.h>
+#include <KXMLGUIClient>
 
 #include <Cell.h>
 
@@ -53,14 +40,14 @@ public:
     /**
      * Constructor.
      */
-    Solver(QObject* parent, const QVariantList& args);
+    Solver(QObject *parent, const QVariantList &args);
 
     /**
      * Destructor.
      */
     ~Solver();
 
-    double evaluate(const gsl_vector* vector, void* parameters);
+    double evaluate(const gsl_vector *vector, void *parameters);
 
 protected Q_SLOTS:
     /**
@@ -79,7 +66,7 @@ private:
     Q_DISABLE_COPY(Solver)
 
     class Private;
-    Private * const d;
+    Private *const d;
 };
 
 } // namespace Plugins
