@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
- * Copyright 2015 Friedrich W. H. Kossebau <kossebau@kde.org>
+ * SPDX-FileCopyrightText: 2015 Friedrich W. H. Kossebau <kossebau@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -20,9 +20,8 @@
 #ifndef PAMOCK_H
 #define PAMOCK_H
 
-
-#include <KoPart.h>
 #include <KoComponentData.h>
+#include <KoPart.h>
 
 #include <KAboutData>
 
@@ -32,12 +31,26 @@ class MockPart : public KoPart
 {
 public:
     MockPart()
-    : KoPart(KoComponentData(KAboutData(QStringLiteral("test"), QStringLiteral("Test"), QStringLiteral("0.0.9"))), 0)
-    {}
-    KoView *createViewInstance(KoDocument* document, QWidget* parent) override { Q_UNUSED(document); Q_UNUSED(parent); return 0; }
-    KoMainWindow *createMainWindow() override { return 0; }
+        : KoPart(KoComponentData(KAboutData(QStringLiteral("test"), QStringLiteral("Test"), QStringLiteral("0.0.9"))), nullptr)
+    {
+    }
+    KoView *createViewInstance(KoDocument *document, QWidget *parent) override
+    {
+        Q_UNUSED(document);
+        Q_UNUSED(parent);
+        return nullptr;
+    }
+    KoMainWindow *createMainWindow() override
+    {
+        return nullptr;
+    }
+
 protected:
-    QGraphicsItem *createCanvasItem(KoDocument* document) override { Q_UNUSED(document); return 0; }
+    QGraphicsItem *createCanvasItem(KoDocument *document) override
+    {
+        Q_UNUSED(document);
+        return nullptr;
+    }
 };
 
 #endif // PAMOCK_H
