@@ -1,40 +1,26 @@
 /* This file is part of the KDE project
-   Copyright 2011 Marijn Kruisselbrink <mkruisselbrink@kde.org>
-   Copyright 2011 Sebastian Sauer <sebastian.sauer@kdab.com>
+   SPDX-FileCopyrightText: 2011 Marijn Kruisselbrink <mkruisselbrink@kde.org>
+   SPDX-FileCopyrightText: 2011 Sebastian Sauer <sebastian.sauer@kdab.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "TestCell.h"
 
-#include <KoStore.h>
-#include <KoOdfStylesReader.h>
-#include <KoOdfLoadingContext.h>
-#include <KoShapeLoadingContext.h>
 #include <KoDocumentResourceManager.h>
+#include <KoOdfLoadingContext.h>
+#include <KoOdfStylesReader.h>
+#include <KoShapeLoadingContext.h>
+#include <KoStore.h>
 
-#include <sheets/Cell.h>
-#include <sheets/CellStorage.h>
-#include <sheets/Map.h>
-#include <sheets/Sheet.h>
-#include <sheets/Style.h>
-#include <sheets/odf/OdfLoadingContext.h>
-#include <sheets/Value.h>
-#include <sheets/odf/SheetsOdf.h>
+#include <core/CellStorage.h>
+#include <core/Map.h>
+#include <core/Sheet.h>
+#include <core/odf/OdfLoadingContext.h>
+#include <core/odf/SheetsOdf.h>
+#include <engine/Value.h>
 
+#include <QBuffer>
 #include <QTest>
 
 using namespace Calligra::Sheets;
@@ -42,7 +28,11 @@ using namespace Calligra::Sheets;
 KoXmlDocument CellTest::xmlDocument(const QString &content)
 {
     KoXmlDocument document;
-    QString xml = "<table:table-cell xmlns:text=\"urn:oasis:names:tc:opendocument:xmlns:text:1.0\" xmlns:table=\"urn:oasis:names:tc:opendocument:xmlns:table:1.0\" xmlns:draw=\"urn:oasis:names:tc:opendocument:xmlns:drawing:1.0\" xmlns:style=\"urn:oasis:names:tc:opendocument:xmlns:style:1.0\" xmlns:number=\"urn:oasis:names:tc:opendocument:xmlns:datastyle:1.0\" >" + content + "</table:table-cell>";
+    QString xml =
+        "<table:table-cell xmlns:text=\"urn:oasis:names:tc:opendocument:xmlns:text:1.0\" xmlns:table=\"urn:oasis:names:tc:opendocument:xmlns:table:1.0\" "
+        "xmlns:draw=\"urn:oasis:names:tc:opendocument:xmlns:drawing:1.0\" xmlns:style=\"urn:oasis:names:tc:opendocument:xmlns:style:1.0\" "
+        "xmlns:number=\"urn:oasis:names:tc:opendocument:xmlns:datastyle:1.0\" >"
+        + content + "</table:table-cell>";
     bool ok = document.setContent(xml, true);
     return ok ? document : KoXmlDocument();
 }
@@ -66,8 +56,8 @@ void CellTest::testRichText()
     QString cellStyleName;
 
     Map map;
-    Sheet* sheet = map.addNewSheet();
-    CellStorage* storage = sheet->cellStorage();
+    Sheet *sheet = dynamic_cast<Sheet *>(map.addNewSheet());
+    CellStorage *storage = sheet->fullCellStorage();
     storage->setValue(1, 1, Value(1));
 
     Cell cell = storage->firstInRow(1);
