@@ -1,39 +1,28 @@
-/* This file is part of the KDE project
-   Copyright 2007 Sascha Pfau <MrPeacock@web.de>
-
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; only
-   version 2 of the License.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
-*/
+// This file is part of the KDE project
+// SPDX-FileCopyrightText: 2007 Sascha Pfau <MrPeacock@web.de>
+// SPDX-License-Identifier: LGPL-2.0-only
 
 #ifndef CALLIGRA_SHEETS_TEST_DATETIME_FUNCTIONS
 #define CALLIGRA_SHEETS_TEST_DATETIME_FUNCTIONS
 
 #include <QObject>
 
-#include <Value.h>
+#include <engine/Value.h>
 
 namespace Calligra
 {
 namespace Sheets
 {
 
-class TestDatetimeFunctions: public QObject
+class MapBase;
+class SheetBase;
+
+class TestDatetimeFunctions : public QObject
 {
     Q_OBJECT
 
 private Q_SLOTS:
+    void cleanupTestCase();
     void initTestCase();
     void testYEARFRAC();
     void testDATEDIF();
@@ -53,6 +42,7 @@ private Q_SLOTS:
     void testDAYS360();
     void testEDATE();
     void testEOMONTH();
+    void testHOUR_data();
     void testHOUR();
     void testISOWEEKNUM();
     void testMINUTE();
@@ -69,7 +59,9 @@ private Q_SLOTS:
     void testWEEKS();
 
 private:
-    Value evaluate(const QString&, Value& ex);
+    MapBase *m_map;
+    SheetBase *m_sheet;
+    Value evaluate(const QString &, Value &ex);
 };
 
 } // namespace Sheets
