@@ -1,27 +1,14 @@
 /* This file is part of the KDE project
- * Copyright (C) 2007 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2007 Thomas Zander <zander@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 #ifndef KPRSOUNDCOLLECTION_H
 #define KPRSOUNDCOLLECTION_H
 
 #include <KoDataCenterBase.h>
-#include <QStringList>
 #include <QObject>
+#include <QStringList>
 #include <QVariant>
 
 #include "stage_export.h"
@@ -32,11 +19,12 @@ class KoStore;
 /**
  * An collection of KPrSoundData objects to allow loading and saving them all together to the KoStore.
  */
-class STAGE_EXPORT KPrSoundCollection : public QObject, public KoDataCenterBase {
+class STAGE_EXPORT KPrSoundCollection : public QObject, public KoDataCenterBase
+{
     Q_OBJECT
 public:
     /// constructor
-    explicit KPrSoundCollection(QObject *parent = 0);
+    explicit KPrSoundCollection(QObject *parent = nullptr);
     ~KPrSoundCollection() override;
 
     /**
@@ -50,7 +38,7 @@ public:
      * and have a recognized KPrSoundData::storeHref().
      * @return returns true if save was successful (no sounds failed).
      */
-    bool completeSaving(KoStore *store, KoXmlWriter * manifestWriter, KoShapeSavingContext * context ) override;
+    bool completeSaving(KoStore *store, KoXmlWriter *manifestWriter, KoShapeSavingContext *context) override;
 
     KPrSoundData *findSound(const QString &title);
 
@@ -61,11 +49,10 @@ protected:
     void addSound(KPrSoundData *image);
     void removeSound(KPrSoundData *image);
 
-
 private:
     class Private;
-    Private * const d;
+    Private *const d;
 };
 
-Q_DECLARE_METATYPE(KPrSoundCollection*)
+Q_DECLARE_METATYPE(KPrSoundCollection *)
 #endif
