@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
- * Copyright (C) 2010 Benjamin Port <port.benjamin@gmail.com>
+ * SPDX-FileCopyrightText: 2010 Benjamin Port <port.benjamin@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -19,13 +19,12 @@
 
 #include "KPrAnimationAttribute.h"
 
-KPrAnimationAttribute::KPrAnimationAttribute(const QString &attributeName):m_attributeName(attributeName)
+KPrAnimationAttribute::KPrAnimationAttribute(const QString &attributeName)
+    : m_attributeName(attributeName)
 {
 }
 
-KPrAnimationAttribute::~KPrAnimationAttribute()
-{
-}
+KPrAnimationAttribute::~KPrAnimationAttribute() = default;
 
 QString KPrAnimationAttribute::attributeName() const
 {
