@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
- * Copyright (C) 2010 Benjamin Port <port.benjamin@gmail.com>
+ * SPDX-FileCopyrightText: 2010 Benjamin Port <port.benjamin@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -26,9 +26,7 @@ KPrAnimationValue::KPrAnimationValue(KPrShapeAnimation *shapeAnimation)
 {
 }
 
-KPrAnimationValue::~KPrAnimationValue()
-{
-}
+KPrAnimationValue::~KPrAnimationValue() = default;
 
 void KPrAnimationValue::setCache(KPrAnimationCache *cache)
 {
