@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
- * Copyright (C) 2010 Benjamin Port <port.benjamin@gmail.com>
+ * SPDX-FileCopyrightText: 2010 Benjamin Port <port.benjamin@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -27,8 +27,8 @@
 
 #include <QTransform>
 
-
-KPrAttributeY::KPrAttributeY() : KPrAnimationAttribute("y")
+KPrAttributeY::KPrAttributeY()
+    : KPrAnimationAttribute("y")
 {
 }
 
@@ -43,9 +43,9 @@ void KPrAttributeY::updateCache(KPrAnimationCache *cache, KPrShapeAnimation *sha
     cache->update(shape, shapeAnimation->textBlockUserData(), "transform", transform);
 }
 
-void KPrAttributeY::initCache(KPrAnimationCache *animationCache, int step, KPrShapeAnimation * shapeAnimation, qreal startValue, qreal endValue)
+void KPrAttributeY::initCache(KPrAnimationCache *animationCache, int step, KPrShapeAnimation *shapeAnimation, qreal startValue, qreal endValue)
 {
-    KoShape * shape = shapeAnimation->shape();
+    KoShape *shape = shapeAnimation->shape();
     qreal v1 = (startValue * animationCache->pageSize().height() - shape->position().y()) * animationCache->zoom();
     qreal v2 = (endValue * animationCache->pageSize().height() - shape->position().y()) * animationCache->zoom();
     animationCache->init(step, shape, shapeAnimation->textBlockUserData(), "transform", QTransform().translate(0, v1));
