@@ -1,15 +1,14 @@
 #include "TestDeleteSlidesCommand.h"
 
+#include "KPrCustomSlideShows.h"
 #include "KPrDocument.h"
 #include "KoPAMasterPage.h"
 #include "KoPAPage.h"
 #include "PAMock.h"
 #include "commands/KPrDeleteSlidesCommand.h"
-#include "KPrCustomSlideShows.h"
 
 #include <QTest>
 
-
 void TestDeleteSlidesCommand::delSlide()
 {
     MockDocument doc;
@@ -21,10 +20,10 @@ void TestDeleteSlidesCommand::delSlide()
     doc.insertPage(page1, 0);
 
     KoPAPage *p1 = dynamic_cast<KoPAPage *>(doc.pageByIndex(0, false));
-    KoPAMasterPage * m1 = dynamic_cast<KoPAMasterPage *>(doc.pageByIndex(0, true));
+    KoPAMasterPage *m1 = dynamic_cast<KoPAMasterPage *>(doc.pageByIndex(0, true));
 
-    QVERIFY(p1 != 0);
-    QVERIFY(m1 != 0);
+    QVERIFY(p1 != nullptr);
+    QVERIFY(m1 != nullptr);
 
     KoPAPage *page2 = new KoPAPage(master1);
     doc.insertPage(page2, 0);
@@ -38,8 +37,8 @@ void TestDeleteSlidesCommand::delSlide()
     KoPAPage *page5 = new KoPAPage(master1);
     doc.insertPage(page5, 0);
 
-    //Create List 1 2 4 1 5 2 2 3
-    QList<KoPAPageBase*> slideList1;
+    // Create List 1 2 4 1 5 2 2 3
+    QList<KoPAPageBase *> slideList1;
 
     slideList1.append(page1);
     slideList1.append(page2);
@@ -50,8 +49,8 @@ void TestDeleteSlidesCommand::delSlide()
     slideList1.append(page2);
     slideList1.append(page3);
 
-    //Create List 1 2 3 4 5 4 3 2
-    QList<KoPAPageBase*> slideList2;
+    // Create List 1 2 3 4 5 4 3 2
+    QList<KoPAPageBase *> slideList2;
 
     slideList2.append(page1);
     slideList2.append(page2);
@@ -62,11 +61,11 @@ void TestDeleteSlidesCommand::delSlide()
     slideList2.append(page3);
     slideList2.append(page2);
 
-    //expected Lists
-    QList<KoPAPageBase*> resultSlideList1(slideList1);
+    // expected Lists
+    QList<KoPAPageBase *> resultSlideList1(slideList1);
     resultSlideList1.removeAll(page2);
 
-    QList<KoPAPageBase*> resultSlideList2(slideList2);
+    QList<KoPAPageBase *> resultSlideList2(slideList2);
     resultSlideList2.removeAll(page2);
 
     QString customShowName1 = "test 1";
@@ -78,9 +77,9 @@ void TestDeleteSlidesCommand::delSlide()
     KPrDeleteSlidesCommand cmd(&doc, page2);
 
     cmd.redo();
-    //Page removed from document
+    // Page removed from document
     QVERIFY(!doc.pages(false).contains(page2));
-    //Page removed from custom slide shows
+    // Page removed from custom slide shows
     QCOMPARE(doc.customSlideShows()->getByName(customShowName1), resultSlideList1);
     QCOMPARE(doc.customSlideShows()->getByName(customShowName2), resultSlideList2);
 
