@@ -1,23 +1,9 @@
 /* This file is part of the KDE project
- * Copyright (C) 2012 Paul Mendez <paulestebanms@gmail.com>
+ * SPDX-FileCopyrightText: 2012 Paul Mendez <paulestebanms@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
-
 #ifndef KPRANIMATIONGROUPPROXYMODEL_H
 #define KPRANIMATIONGROUPPROXYMODEL_H
 
@@ -29,7 +15,7 @@ class KPrAnimationGroupProxyModel : public QSortFilterProxyModel
 {
     Q_OBJECT
 public:
-    explicit KPrAnimationGroupProxyModel(QObject *parent = 0);
+    explicit KPrAnimationGroupProxyModel(QObject *parent = nullptr);
     ~KPrAnimationGroupProxyModel() override;
 
     /**
