@@ -16,7 +16,12 @@ public:
     ~KPrPentagonWipeEffectFactory() override;
     QString subTypeName(int subType) const override;
 
-    enum SubType { Up, UpReverse, Down, DownReverse };
+    enum SubType {
+        Up,
+        UpReverse,
+        Down,
+        DownReverse
+    };
 };
 
 #endif /* KPRPENTAGONWIPEEFFECTFACTORY_H */
