@@ -1,78 +1,82 @@
 /* This file is part of the KDE project
- * Copyright (C) 2007, 2010 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2007, 2010 Thomas Zander <zander@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "KWPageSettingsDialog.h"
+#include "KWDocumentColumns.h"
 #include "KWPageStyle.h"
 #include "KWPageStyle_p.h"
-#include "KWDocumentColumns.h"
 
 #include <KWDocument.h>
-#include <commands/KWPageStylePropertiesCommand.h>
-#include <commands/KWNewPageStyleCommand.h>
 #include <commands/KWChangePageStyleCommand.h>
+#include <commands/KWNewPageStyleCommand.h>
+#include <commands/KWPageStylePropertiesCommand.h>
 
 #include <KoUnit.h>
 
-#include <QPushButton>
+#include <QInputDialog>
 #include <QListWidget>
-#include <kinputdialog.h>
-#include <kdebug.h>
+#include <QPushButton>
+
+using namespace Qt::StringLiterals;
 
 KWPageSettingsDialog::KWPageSettingsDialog(QWidget *parent, KWDocument *document, const KWPage &page)
-        : KoPageLayoutDialog(parent, page.pageStyle().pageLayout()),
-        m_document(document),
-        m_page(page),
-        m_pageStyle(page.pageStyle())
+    : KoPageLayoutDialog(parent, page.pageStyle().pageLayout())
+    , m_document(document)
+    , m_page(page)
+    , m_pageStyle(page.pageStyle())
 {
     Q_ASSERT(document);
-    setButtons(KDialog::Ok | KDialog::Apply | KDialog::Cancel);
-    connect(this, SIGNAL(applyClicked()), this, SLOT(slotApplyClicked()));
+    setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Apply | QDialogButtonBox::Cancel);
+    connect(buttonBox(), &QDialogButtonBox::clicked, this, &KWPageSettingsDialog::slotButtonClicked);
     showUnitchooser(true);
     Q_ASSERT(page.isValid());
 
     m_columns = new KWDocumentColumns(this, m_page.pageStyle().columns());
     KPageWidgetItem *columnsPage = addPage(m_columns, i18n("Columns"));
 
-    QWidget *pageStyleWidget = new QWidget(this);
-    QHBoxLayout *pageStyleLayout = new QHBoxLayout(pageStyleWidget);
-    pageStyleLayout->setMargin(0);
+    auto pageStyleWidget = new QWidget(this);
+    auto pageStyleLayout = new QHBoxLayout(pageStyleWidget);
+    pageStyleLayout->setContentsMargins({});
+    pageStyleLayout->setSpacing({});
     KPageWidgetItem *stylePage = addPage(pageStyleWidget, i18n("Style"));
     m_pageStylesView = new QListWidget(this);
     pageStyleLayout->addWidget(m_pageStylesView, 1);
-    connect(m_pageStylesView, SIGNAL(currentRowChanged(int)), this, SLOT(pageStyleCurrentRowChanged(int)));
-    QVBoxLayout *pageStyleLayout2 = new QVBoxLayout();
+    auto separator = new QFrame(this);
+    separator->setFrameStyle(QFrame::VLine);
+    separator->setFixedWidth(1);
+    pageStyleLayout->addWidget(separator);
+    connect(m_pageStylesView, &QListWidget::currentRowChanged, this, &KWPageSettingsDialog::pageStyleCurrentRowChanged);
+    auto pageStyleLayout2 = new QVBoxLayout();
+    pageStyleLayout2->setContentsMargins(style()->pixelMetric(QStyle::PM_LayoutLeftMargin),
+                                         style()->pixelMetric(QStyle::PM_LayoutTopMargin),
+                                         style()->pixelMetric(QStyle::PM_LayoutRightMargin),
+                                         style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
+    pageStyleLayout2->setSpacing(style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
     pageStyleLayout->addLayout(pageStyleLayout2);
+
     m_clonePageStyleButton = new QPushButton(i18n("Clone"), pageStyleWidget);
-    connect(m_clonePageStyleButton, SIGNAL(clicked()), this, SLOT(pageStyleCloneClicked()));
+    m_clonePageStyleButton->setIcon(QIcon::fromTheme(u"edit-clone-symbolic"_s));
+    connect(m_clonePageStyleButton, &QAbstractButton::clicked, this, &KWPageSettingsDialog::pageStyleCloneClicked);
     pageStyleLayout2->addWidget(m_clonePageStyleButton);
+
     m_deletePageStyleButton = new QPushButton(i18n("Delete"), pageStyleWidget);
-    connect(m_deletePageStyleButton, SIGNAL(clicked()), this, SLOT(pageStyleDeleteClicked()));
+    m_deletePageStyleButton->setIcon(QIcon::fromTheme(u"delete-symbolic"_s));
+    connect(m_deletePageStyleButton, &QAbstractButton::clicked, this, &KWPageSettingsDialog::pageStyleDeleteClicked);
     pageStyleLayout2->addWidget(m_deletePageStyleButton);
     pageStyleLayout2->addStretch();
-    foreach(KPageWidgetItem *item, QList<KPageWidgetItem*>() << columnsPage << stylePage)
+
+    for (const auto item : {columnsPage, stylePage}) {
         m_pages[item->name()] = item;
+    }
 
     reloadPageStyles();
 
-    showPageSpread(false); //TODO better would be allow n pages to face rather then only 2
+    showPageSpread(false); // TODO better would be allow n pages to face rather then only 2
     showTextDirection(true); // TODO can we hide this in selected usecases? Use the resource manager bidi-check maybe?
-    //showApplyToDocument(true); // TODO uncommand when we can handle it.
+    // showApplyToDocument(true); // TODO uncommand when we can handle it.
 
 #if 0
     bool simpleSetup = m_document->pageCount() == 1
@@ -125,11 +129,11 @@ KWPageSettingsDialog::KWPageSettingsDialog(QWidget *parent, KWDocument *document
 #endif
 
     onDocumentUnitChange(m_document->unit());
-    connect(m_document, SIGNAL(unitChanged(KoUnit)), SLOT(onDocumentUnitChange(KoUnit)));
-    connect(this, SIGNAL(unitChanged(KoUnit)), SLOT(setDocumentUnit(KoUnit)));
+    connect(m_document, &KoDocument::unitChanged, this, &KWPageSettingsDialog::onDocumentUnitChange);
+    connect(this, &KoPageLayoutDialog::unitChanged, this, &KWPageSettingsDialog::setDocumentUnit);
 }
 
-KPageWidgetItem* KWPageSettingsDialog::pageItem(const QString &name) const
+KPageWidgetItem *KWPageSettingsDialog::pageItem(const QString &name) const
 {
     return m_pages.value(name);
 }
@@ -167,7 +171,7 @@ void KWPageSettingsDialog::slotApplyClicked()
 
         // its a page spread, which words can handle, so we can safely set the
         // normal page size and assume that the page object will do the right thing
-        lay.width /= (qreal) 2;
+        lay.width /= (qreal)2;
     }
     styleToUpdate.setPageLayout(lay);
     styleToUpdate.setColumns(m_columns->columns());
@@ -177,6 +181,13 @@ void KWPageSettingsDialog::slotApplyClicked()
     m_document->firePageSetupChanged();
 }
 
+void KWPageSettingsDialog::slotButtonClicked(QAbstractButton *button)
+{
+    if (button == buttonBox()->button(QDialogButtonBox::Apply)) {
+        slotApplyClicked();
+    }
+}
+
 void KWPageSettingsDialog::setDocumentUnit(const KoUnit &unit)
 {
     m_document->setUnit(unit);
@@ -191,7 +202,7 @@ void KWPageSettingsDialog::onDocumentUnitChange(const KoUnit &unit)
 void KWPageSettingsDialog::reloadPageStyles()
 {
     QStringList pagestyles = m_document->pageManager()->pageStyles().keys();
-    qSort(pagestyles);
+    std::sort(pagestyles.begin(), pagestyles.end());
     m_pageStylesView->clear();
     m_pageStylesView->addItems(pagestyles);
     m_pageStylesView->setCurrentRow(pagestyles.indexOf(m_pageStyle.name()));
@@ -203,17 +214,28 @@ void KWPageSettingsDialog::pageStyleCloneClicked()
     Q_ASSERT(item);
     KWPageStyle pagestyle = m_document->pageManager()->pageStyle(item->text());
     Q_ASSERT(pagestyle.isValid());
-    class Validator : public QValidator {
+    class Validator : public QValidator
+    {
     public:
-        Validator(KWDocument *document) : QValidator(), m_document(document) {}
-        virtual State validate(QString &input, int&) const {
+        Validator(KWDocument *document)
+            : QValidator()
+            , m_document(document)
+        {
+        }
+        State validate(QString &input, int &) const override
+        {
             return input.trimmed().isEmpty() || m_document->pageManager()->pageStyle(input).isValid() ? Intermediate : Acceptable;
         }
+
     private:
         KWDocument *m_document;
     };
     Validator validator(m_document);
-    QString name = KInputDialog::getText(i18n("Clone Page Style"), i18n("Add a new page style with the name:"), pagestyle.name(), 0, this, &validator);
+    QString name = QInputDialog::getText(this,
+                                         i18n("Clone Page Style"),
+                                         i18n("Add a new page style with the name:"),
+                                         QLineEdit::Normal,
+                                         pagestyle.name()); // QT5TODO: &validator);
     if (name.isEmpty())
         return;
     pagestyle.detach(name);
@@ -248,6 +270,6 @@ void KWPageSettingsDialog::pageStyleCurrentRowChanged(int row)
     m_columns->setColumns(m_pageStyle.columns());
     m_clonePageStyleButton->setEnabled(pagestyle.isValid());
     m_deletePageStyleButton->setEnabled(pagestyle.isValid() && item->text() != m_document->pageManager()->defaultPageStyle().name());
-    enableButtonOk(pagestyle.isValid());
-    enableButtonApply(pagestyle.isValid());
+    buttonBox()->button(QDialogButtonBox::Ok)->setEnabled(pagestyle.isValid());
+    buttonBox()->button(QDialogButtonBox::Apply)->setEnabled(pagestyle.isValid());
 }
