@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006-2007 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2006-2007 Thomas Zander <zander@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KWSHAPECONFIGFACTORY_H
@@ -39,11 +26,13 @@ public:
     void addUser();
     void removeUser();
 
-    KWDocument *document() const {
+    KWDocument *document() const
+    {
         return m_document;
     }
 
-    bool keepAspectRatio() const {
+    bool keepAspectRatio() const
+    {
         return m_protectAspectRatio;
     }
     void setKeepAspectRatio(bool on);
@@ -62,8 +51,11 @@ class KWFrameConnectSelectorFactory : public KoShapeConfigFactoryBase
 {
 public:
     /// constructor
-    explicit KWFrameConnectSelectorFactory(FrameConfigSharedState *state) : m_state(state) {}
-    ~KWFrameConnectSelectorFactory() override {}
+    explicit KWFrameConnectSelectorFactory(FrameConfigSharedState *state)
+        : m_state(state)
+    {
+    }
+    ~KWFrameConnectSelectorFactory() override = default;
 
     /// reimplemented method from superclass
     KoShapeConfigWidgetBase *createConfigWidget(KoShape *shape) override;
@@ -73,7 +65,8 @@ public:
     /// reimplemented method from superclass
     bool showForShapeId(const QString &id) const override;
     /// reimplemented method from superclass
-    int sortingOrder() const override {
+    int sortingOrder() const override
+    {
         return 15;
     }
 
@@ -86,15 +79,19 @@ class KWAnchoringFactory : public KoShapeConfigFactoryBase
 {
 public:
     /// constructor
-    explicit KWAnchoringFactory(FrameConfigSharedState *state) : m_state(state) {}
-    ~KWAnchoringFactory() override {}
+    explicit KWAnchoringFactory(FrameConfigSharedState *state)
+        : m_state(state)
+    {
+    }
+    ~KWAnchoringFactory() override = default;
 
     /// reimplemented method from superclass
     KoShapeConfigWidgetBase *createConfigWidget(KoShape *shape) override;
     /// reimplemented method from superclass
     QString name() const override;
     /// reimplemented method from superclass
-    int sortingOrder() const override {
+    int sortingOrder() const override
+    {
         return 0;
     }
     /// reimplemented method from superclass
@@ -109,8 +106,11 @@ class KWRunAroundPropertiesFactory : public KoShapeConfigFactoryBase
 {
 public:
     /// constructor
-    explicit KWRunAroundPropertiesFactory(FrameConfigSharedState *state) : m_state(state) {}
-    ~KWRunAroundPropertiesFactory() override {}
+    explicit KWRunAroundPropertiesFactory(FrameConfigSharedState *state)
+        : m_state(state)
+    {
+    }
+    ~KWRunAroundPropertiesFactory() override = default;
 
     /// reimplemented method from superclass
     KoShapeConfigWidgetBase *createConfigWidget(KoShape *shape) override;
@@ -120,7 +120,8 @@ public:
     bool showForShapeId(const QString &id) const override;
 
     /// reimplemented method from superclass
-    int sortingOrder() const override {
+    int sortingOrder() const override
+    {
         return 5;
     }
 
@@ -128,5 +129,4 @@ private:
     FrameConfigSharedState *m_state;
 };
 
-
 #endif
