@@ -1,37 +1,24 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006, 2009,2010 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2006, 2009, 2010 Thomas Zander <zander@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "KWCopyShape.h"
-#include "KWPage.h"
-#include "KWPageManager.h"
 #include "KWFrame.h"
 #include "KWFrameSet.h"
-#include "KWTextFrameSet.h"
+#include "KWPage.h"
+#include "KWPageManager.h"
 #include "KWRootAreaProvider.h"
+#include "KWTextFrameSet.h"
 
-#include <KoShapeStrokeModel.h>
-#include <KoShapeLoadingContext.h>
-#include <KoViewConverter.h>
-#include <KoTextShapeData.h>
 #include <KoShapeContainer.h>
+#include <KoShapeLoadingContext.h>
+#include <KoShapeStrokeModel.h>
 #include <KoTextDocumentLayout.h>
 #include <KoTextLayoutRootArea.h>
+#include <KoTextShapeData.h>
+#include <KoViewConverter.h>
 #include <KoXmlReader.h>
 
 #include <QPainter>
@@ -41,14 +28,14 @@
 #include <algorithm>
 
 KWCopyShape::KWCopyShape(KoShape *original, const KWPageManager *pageManager)
-        : KoShape()
-        ,m_original(original)
-        ,m_pageManager(pageManager)
+    : KoShape()
+    , m_original(original)
+    , m_pageManager(pageManager)
 {
     setSize(m_original->size());
     setSelectable(original->isSelectable());
     // allow selecting me to get the tool for the original to still work.
-    QSet<KoShape*> delegates;
+    QSet<KoShape *> delegates;
     delegates << m_original;
     setToolDelegates(delegates);
 
@@ -64,10 +51,10 @@ void KWCopyShape::paint(QPainter &painter, const KoViewConverter &converter, KoS
 {
     Q_ASSERT(m_original);
 
-    //paint all child shapes
-    KoShapeContainer* container = dynamic_cast<KoShapeContainer*>(m_original);
+    // paint all child shapes
+    KoShapeContainer *container = dynamic_cast<KoShapeContainer *>(m_original);
     if (container) {
-        QList<KoShape*> sortedObjects = container->shapes();
+        QList<KoShape *> sortedObjects = container->shapes();
         sortedObjects.append(m_original);
         std::sort(sortedObjects.begin(), sortedObjects.end(), KoShape::compareShapeZIndex);
 
@@ -79,16 +66,15 @@ void KWCopyShape::paint(QPainter &painter, const KoViewConverter &converter, KoS
 
         KWPage copypage = m_pageManager->page(this);
         Q_ASSERT(copypage.isValid());
-        foreach(KoShape *shape, sortedObjects) {
+        foreach (KoShape *shape, sortedObjects) {
             painter.save();
             if (shape != m_original) {
                 painter.setTransform(shape->absoluteTransformation(&converter) * baseMatrix);
             }
-            KoTextShapeData *data = qobject_cast<KoTextShapeData*>(shape->userData());
-            if (data == 0) {
+            KoTextShapeData *data = qobject_cast<KoTextShapeData *>(shape->userData());
+            if (data == nullptr) {
                 shape->paint(painter, converter, paintcontext);
-            }
-            else {
+            } else {
                 // Since the rootArea is shared between the copyShape and the originalShape we need to
                 // temporary switch the used KoTextPage to be sure the proper page-numbers are displayed.
                 KWPage originalpage = m_pageManager->page(shape);
@@ -118,7 +104,7 @@ void KWCopyShape::paint(QPainter &painter, const KoViewConverter &converter, KoS
             }
         }
     } else {
-        //paint the original shape
+        // paint the original shape
         painter.save();
         m_original->paint(painter, converter, paintcontext);
         painter.restore();
@@ -148,7 +134,7 @@ QRectF KWCopyShape::boundingRect() const
     QRectF bb = KoShape::boundingRect();
     QPointF offset = bb.topLeft() - m_original->boundingRect().topLeft();
 
-    KoShapeContainer* container = dynamic_cast<KoShapeContainer*>(m_original);
+    KoShapeContainer *container = dynamic_cast<KoShapeContainer *>(m_original);
     if (container) {
         foreach (KoShape *shape, container->shapes()) {
             bb |= shape->boundingRect().translated(offset);
@@ -161,7 +147,7 @@ QRectF KWCopyShape::boundingRect() const
 void KWCopyShape::saveOdf(KoShapeSavingContext &context) const
 {
     Q_ASSERT(m_original);
-    KWCopyShape *me = const_cast<KWCopyShape*>(this);
+    KWCopyShape *me = const_cast<KWCopyShape *>(this);
     me->setAdditionalAttribute("draw:copy-of", m_original->name());
     saveOdfAttributes(context, OdfAllAttributes);
     me->removeAdditionalAttribute("draw:copy-of");
