@@ -1,25 +1,10 @@
 /* This file is part of the KDE project
  *
- * Copyright (c) 2010 Arjen Hiemstra <ahiemstra@heimr.nl>
+ * SPDX-FileCopyrightText: 2010 Arjen Hiemstra <ahiemstra@heimr.nl>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
-
-
 #ifndef KOFINDTOOLBAR_H
 #define KOFINDTOOLBAR_H
 
@@ -46,7 +31,7 @@ public:
      * \param parent The parent QWidget
      * \param f Qt window flags
      */
-    explicit KoFindToolbar(KoFindBase *find, KActionCollection *ac, QWidget *parent = 0, Qt::WindowFlags f = 0);
+    explicit KoFindToolbar(KoFindBase *find, KActionCollection *ac, QWidget *parent = nullptr, Qt::WindowFlags f = Qt::WindowFlags());
     ~KoFindToolbar() override;
 
 public Q_SLOTS:
@@ -59,10 +44,10 @@ public Q_SLOTS:
      * Set focus to this widget, show it including replace related features.
      */
     void activateReplace();
-    
+
 private:
     class Private;
-    Private * const d;
+    Private *const d;
 
     Q_PRIVATE_SLOT(d, void matchFound())
     Q_PRIVATE_SLOT(d, void noMatchFound())
